package fr.unedic.cali.asu.antecedent;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.parcours.asp.ParcoursLiquidationDemandeSousJacenteCSPDroitCommun;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieConventionGestionPE;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieConventionGestionPESpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import java.util.List;

public abstract class GrapheAntecedent
{
  private static final int TAILLE_LIBELLE_CG = 50;
  
  public void alimenterGrapheDecisionAntecedent(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    initialiserDossierExamen(demande);
    
    alimenterConditionsAdmission(demande);
    
    liquiderAspSousJacent(contexte, demande);
    
    alimenterConstituantsAdmission(demande);
    
    alimenterConditionsAdmissionSupplementaire(demande);
  }
  
  private void liquiderAspSousJacent(Contexte contexte, Demande demande)
    throws CoucheLogiqueException
  {
    List contextes = demande.getListContexteDemande();
    if ((OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contextes, "AREENTRCSP")) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 9)))
    {
      demande.getDemandeur().setChronoPeriodePasseProfessionnelLiquidationRevision(demande.getDemandeur().getChronoPeriodePasseProfessionnel());
      ParcoursLiquidationDemandeSousJacenteCSPDroitCommun parcours = new ParcoursLiquidationDemandeSousJacenteCSPDroitCommun();
      try
      {
        parcours.demarrer(contexte);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode(), ex);
      }
    }
  }
  
  protected abstract void initialiserDossierExamen(Demande paramDemande)
    throws CoucheLogiqueException;
  
  protected abstract void alimenterConditionsAdmission(Demande paramDemande)
    throws CoucheLogiqueException;
  
  protected abstract void alimenterConstituantsAdmission(Demande paramDemande)
    throws CoucheLogiqueException;
  
  protected abstract void alimenterConditionsAdmissionSupplementaire(Demande paramDemande)
    throws CoucheLogiqueException;
  
  protected void alimenterCompetence(Demande p_demande, CompetenceSpec p_competence, SaisieAntecedent p_saisieAntecedent)
    throws CoucheLogiqueException
  {
    int competenceFinanciere = 1;
    int competenceAdministrative = 1;
    String numeroConventionGestion = null;
    if (p_saisieAntecedent.getContexteDemande().intValue() == 3)
    {
      competenceFinanciere = 2;
      competenceAdministrative = 2;
    }
    else if ((p_saisieAntecedent.getContexteDemande().intValue() == 5) || (p_saisieAntecedent.getContexteDemande().intValue() == 6))
    {
      competenceFinanciere = 2;
      competenceAdministrative = 1;
      
      String identifiantCompetence = p_saisieAntecedent.getIdentifiantCompetence();
      ActiviteSalarie periodeCompetence = (ActiviteSalarie)p_demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantCompetence);
      if (periodeCompetence != null) {
        numeroConventionGestion = periodeCompetence.getEntreprise().getNumeroConventionGestion();
      }
    }
    else if (p_saisieAntecedent.getContexteDemande().intValue() == 9)
    {
      competenceFinanciere = 1;
      competenceAdministrative = 1;
    }
    else
    {
      String identifiantCompetence = p_saisieAntecedent.getIdentifiantCompetence();
      ActiviteSalarie periodeCompetence = (ActiviteSalarie)p_demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantCompetence);
      if (periodeCompetence != null)
      {
        numeroConventionGestion = periodeCompetence.getEntreprise().getNumeroConventionGestion();
        int champApplication = periodeCompetence.getMetier().getChampApplication();
        if (champApplication == 3)
        {
          competenceFinanciere = 2;
          competenceAdministrative = 2;
        }
        else if (champApplication == 4)
        {
          competenceFinanciere = 2;
        }
      }
      else if ((p_saisieAntecedent.getEtablissementFinanceur() != null) && (p_saisieAntecedent.getCodeAffectation() != null))
      {
        competenceFinanciere = 2;
        competenceAdministrative = 1;
      }
    }
    p_competence.setCompetenceAdministrative(competenceAdministrative);
    p_competence.setCompetenceFinanciere(competenceFinanciere);
    p_competence.setNumeroConventionGestion(numeroConventionGestion);
    
    FabriqueStrategieConventionGestionPE fabrique = new FabriqueStrategieConventionGestionPE();
    CritereStrategie criterePE = new CritereStrategie();
    criterePE.setDatePivot(p_demande.getSaisieAntecedent().getDateDernierJourCalcule());
    StrategieConventionGestionPESpec strategie = (StrategieConventionGestionPESpec)fabrique.getStrategie(criterePE);
    strategie.verifierConventionGestionPoleEmploiForceePourAntecedent(numeroConventionGestion, p_demande);
    if (p_saisieAntecedent.getEtablissementFinanceur() != null)
    {
      ConventionGestionSpec convention = OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(p_saisieAntecedent.getEtablissementFinanceur(), p_saisieAntecedent.getCodeAffectation(), p_demande.getDateDepot(), p_demande.getCommentaire()));
      
      p_competence.setNumeroConventionGestion(convention.getNumeroConventionGestion());
      p_competence.setCodeAffectationConvention(convention.getCodeAffectation());
      p_competence.setApplicationDesAides(convention.getApplicationAides());
      p_competence.setEstAideAdr(convention.isEstAideAdr());
      p_competence.setEstAideAllocationDeces(convention.isEstAideAllocationDeces());
      p_competence.setEstAideArce(convention.isEstAideArce());
      p_competence.setEstAideCongeNonPaye(convention.isEstAideCongeNonPaye());
      p_competence.setEstAideFinDroit(convention.isEstAideFinDroit());
      p_competence.setPrecompteCrc(convention.estPrecompteCRC());
      p_competence.setSignataireConvention(convention.getSignataire());
      p_competence.setIdExterneEmployeurSp(p_saisieAntecedent.getIdExterneEmployeurSp());
      String libelleConvention = convention.getLibelleAffectation();
      String libelleConventionTronque = new String();
      if (libelleConvention != null)
      {
        int taille = libelleConvention.length();
        if (taille > 50) {
          taille = 50;
        }
        libelleConventionTronque = libelleConvention.substring(0, taille);
      }
      p_competence.setLibelleAffectationConventionGestion(libelleConventionTronque);
      p_competence.setDebutValiditeConventionGestion(convention.getDebutValidite());
      p_competence.setFinValiditeConventionGestion(convention.getFinValidite());
    }
  }
}

/* Location:
 * Qualified Name:     GrapheAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */