package fr.unedic.cali.asu.caa14.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.caa14.calcul.dom.FormuleMontantASPAREF;
import fr.unedic.cali.asu.caa14.calcul.dom.FormuleMontantRegimeGeneralASPARE;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.DeterminationReliquat;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire50Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire55Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire60Ans;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantAsp;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class FacadeCalculLignePourLiquidationCAA14Impl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  protected static final int DIX = 10;
  
  public Quantite calculerCapital(AttributionSpec attribution, MontantAsuSpec pmontant, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    
    BigDecimal capital = new BigDecimal("0.00");
    
    Damj pji = pointDeDepart;
    
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, false);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = pmontant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Quantite calculerCapital(AttributionSpec pattribution, Damj dateAttribution, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pattribution;
    IndividuSpec individu = attribution.getDemandeur();
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    FormuleMontantSpec formuleMontant = getFormuleMontant();
    
    BigDecimal capital = new BigDecimal("0.00");
    
    Competences competences = new Competences();
    competences.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
    competences.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
    competences.setConventionGestion(attribution.getConventionGestion());
    
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = new DonneesEntreesRecuperationMontant(attribution, pointDeDepart);
    if (((attribution.getDemandeAssurance() != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemandeAssurance(), "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemandeAssurance(), "AREENTRCSP")))
    {
      donneesEntreesRecuperationMontant.getDonneesCalculMontant().setProduit(pattribution.getProduitExecution());
      donneesEntreesRecuperationMontant.getDonneesCalculMontantAsp().setProduitAreSousJacent(pattribution.getProduit());
    }
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    
    Damj pji = pointDeDepart;
    
    boolean bornerRetraite = true;
    DonneesTemporaires donneesForcees = ((Demande)pattribution.getDemande()).getDonneesTemporaires();
    if (donneesForcees != null) {
      bornerRetraite = !donneesForcees.isLeverBornageDureeEffectiveRetraite();
    }
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, bornerRetraite);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      Damj date = pji;
      
      Collection anniversaires = new ArrayList();
      anniversaires.add(OutillagePeriodes.genererAnniversaire50Ans(individu).getDateEffet());
      anniversaires.add(OutillagePeriodes.genererAnniversaire55Ans(individu).getDateEffet());
      anniversaires.add(OutillagePeriodes.genererAnniversaire60Ans(individu).getDateEffet());
      anniversaires.add(dji);
      
      Iterator i = anniversaires.iterator();
      while ((i.hasNext()) && (date.estAvant(dji)))
      {
        Damj anniversaire = (Damj)i.next();
        if (date.estAvant(anniversaire))
        {
          BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(date));
          if (tauxavantageVieillesse != null) {
            ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).setTauxAvantageVieillesse(tauxavantageVieillesse);
          }
          BigDecimal montant = formuleMontant.calculer(constituantsIndemnisation, dateAttribution).getMontantBrut().getValeur();
          BigDecimal duree = new BigDecimal(date.joursEntre(Damj.min(anniversaire, dji)));
          
          capital = capital.add(montant.multiply(duree));
          
          date = anniversaire;
        }
      }
    }
    return new QuantiteEuro(capital);
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite quantiteInitiale, Quantite nbHeuresFormation)
    throws IllegalArgumentException
  {
    return DeterminationReliquat.determinerDureeEffectiveReliquat(quantiteInitiale, nbHeuresFormation);
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec formuleMontant = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      formuleMontant = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      formuleMontant = getFormuleMontantEnFormation();
    } else {
      formuleMontant = getFormuleMontant();
    }
    return formuleMontant.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec pattribution)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pattribution;
    
    return (attribution.getCompetenceFinanciere() == 2) && ((attribution.getCompetenceAdministrative() != 1) || ((((AttributionAssuranceSpec)pattribution).getConventionGestion() != null) && (!((AttributionAssuranceSpec)pattribution).getConventionGestion().estPrecompteCRC())));
  }
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantRegimeGeneralASPARE();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantASPAREF();
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec attribution, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  private ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    Damj dateAttribution = null;
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation ebiCourant = new ElementBaseIndemnisationAREF();
    
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    DonneesCalculMontantAsp donneesCalculMontantAsp = donneesEntreesRecuperationMontant.getDonneesCalculMontantAsp();
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      ebiCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else if (donneesEntreesRecuperationMontant.getCompetences() == null) {
      ebiCourant.setAvecPrecompteCRC(Boolean.TRUE);
    } else if ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
      ebiCourant.setAvecPrecompteCRC(Boolean.FALSE);
    }
    ebiCourant.setCoefficientAvantageVieillesse(new BigDecimal("0.00"));
    ebiCourant.setTauxAvantageVieillesse(new BigDecimal("0.00"));
    ebiCourant.setMontantAvantageVieillesse(new BigDecimal("0.00"));
    
    ebiCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    ebiCourant.setCoefficientSaisonnier(donneesCalculMontant.getCoefficientSaisonnier());
    
    Sjr sjr = OutilMappingSjmSjr.convertirSjr(donneesCalculMontant.getSalaireJournalier());
    ebiCourant.setSjr(sjr);
    
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(ebiCourant, ProduitAsuCaa14P02.getInstance(), dateCalcul);
    ebiCourant.setSjr(sjrRevalorise);
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite())
    {
      ebiCourant.setListePensionInvalidite(donneesCalculMontant.getListePensionInvalidite());
      
      ebiCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(ebiCourant, individu, dateCalcul, dateAttribution));
    }
    else
    {
      ebiCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
    }
    ebiCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    ebiCourant.setProduitAreActif(donneesCalculMontantAsp.getProduitAreSousJacent());
    if (donneesCalculMontantAsp.isContextePAPPresent())
    {
      ebiCourant.setContextePAPPresent(donneesCalculMontantAsp.isContextePAPPresent());
      
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(individu, dateCalcul);
      
      BigDecimal montantAV = BigDecimal.ZERO;
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        ebiCourant.setDateEffetAV(dateCalcul);
      }
      BigDecimal coeffAV = montantAV.divide(sjrRevalorise.getSalaire(), 10, 4);
      ebiCourant.setCoefficientAvantageVieillesse(coeffAV);
      ebiCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrRevalorise.getSalaire()));
      BigDecimal tauxavantageVieillesse = parametresIndemnisation.getTauxAvantageViellesse(individu.getAgeALaDate(dateCalcul));
      if (tauxavantageVieillesse != null) {
        ebiCourant.setTauxAvantageVieillesse(tauxavantageVieillesse);
      }
    }
    constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiCourant);
    
    return constituantsIndemnisation;
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculLignePourLiquidationCAA14Impl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */