package fr.unedic.cali.asu.caa14.p01.calcul.dom;

import fr.unedic.cali.asu.caa14.p01.calcul.outilsfonctionnels.CotisationRetraiteComplementaire;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleMontantRegimeGeneralASRARE
  implements FormuleMontantSpec
{
  private static final BigDecimal FACTEUR_PLAFOND = new BigDecimal("0.75");
  private static final BigDecimal FACTEUR_BASE = new BigDecimal("0.404");
  private static final BigDecimal FACTEUR_PLANCHER = new BigDecimal("0.574");
  protected static final BigDecimal COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE = new BigDecimal("1");
  protected static final BigDecimal MONTANT_PAR_DEFAUT = new BigDecimal(0);
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_dateCalcul)
    throws CoucheLogiqueException
  {
    Montant leMontant = new Montant();
    Quantite montantBrut = null;
    BigDecimal resultat = null;
    BigDecimal montantPlafond = null;
    BigDecimal montantBase = null;
    BigDecimal montantPlancher = null;
    BigDecimal montantMini = null;
    BigDecimal montantPartieA = null;
    BigDecimal montantPartieB = null;
    BigDecimal montantPartieC = null;
    
    ElementBaseIndemnisation coefficient = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_dateCalcul);
    
    BigDecimal coefficientSurParametre = COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE;
    if (coefficient.getCoefficientTempsPartiel() != null) {
      coefficientSurParametre = coefficient.getCoefficientTempsPartiel();
    }
    BigDecimal coefficientSurSalaire = COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE;
    if (coefficient.getCoefficientSaisonnier() != null) {
      coefficientSurSalaire = coefficient.getCoefficientSaisonnier();
    }
    montantPlafond = FACTEUR_PLAFOND.multiply(coefficient.getSjr().getSalaire()).multiply(coefficientSurSalaire);
    
    montantBase = FACTEUR_BASE.multiply(coefficient.getSjr().getSalaire()).multiply(coefficientSurSalaire).add(parametres.getPartieFixe().multiply(coefficientSurParametre)).max(MONTANT_PAR_DEFAUT);
    
    montantPlancher = FACTEUR_PLANCHER.multiply(coefficient.getSjr().getSalaire()).multiply(coefficientSurSalaire).max(new BigDecimal(0));
    
    montantMini = parametres.getAllocationMinimale().multiply(coefficientSurParametre);
    
    montantPartieC = montantBase.max(montantPlancher).max(montantMini);
    montantPartieB = montantPartieC.min(montantPlafond);
    montantPartieA = montantPartieB.subtract(coefficient.getMontantPensionInvaliditeADeduire());
    
    resultat = montantPartieA.max(parametres.getSeuilMinimalAREF());
    if (resultat.equals(montantPlafond)) {
      leMontant.setJustificationCalculMontant("03");
    } else if (resultat.equals(montantPlancher)) {
      leMontant.setJustificationCalculMontant("01");
    } else if (resultat.equals(parametres.getSeuilMinimalAREF())) {
      leMontant.setJustificationCalculMontant("04");
    }
    leMontant.setMontantBrutSansPensionInvaliditeADeduire(new Quantite(Mathematiques.arrondiASup(montantPartieB, 2), UniteMonaitaire.EUROS));
    
    resultat = resultat.max(MONTANT_PAR_DEFAUT);
    
    resultat = Mathematiques.arrondiASup(resultat, 2);
    
    montantBrut = new Quantite(resultat, UniteMonaitaire.EUROS);
    
    leMontant.setPensionInvaliditeADeduirePriseEnCompte(new Quantite(coefficient.getMontantPensionInvaliditeADeduire(), UniteMonaitaire.get("Euros")));
    
    leMontant.setPlafond(new Quantite(Mathematiques.arrondiASup(montantPlafond, 2), UniteMonaitaire.get("Euros")));
    leMontant.setPlancher(new Quantite(Mathematiques.arrondiASup(montantPlancher, 2), UniteMonaitaire.get("Euros")));
    
    leMontant.setMini(new Quantite(Mathematiques.arrondiASup(montantMini, 2), UniteMonaitaire.get("Euros")));
    
    leMontant.setMiniFormation(new Quantite(Mathematiques.arrondiASup(parametres.getSeuilMinimalAREF(), 2), UniteMonaitaire.get("Euros")));
    
    leMontant.setBase(new Quantite(Mathematiques.arrondiASup(montantBase, 2), UniteMonaitaire.get("Euros")));
    leMontant.setMontantBrut(montantBrut);
    
    boolean estAvecCRC = coefficient.getAvecPrecompteCRC() != null ? coefficient.getAvecPrecompteCRC().booleanValue() : true;
    
    leMontant.setAvecPrecompteCRC(estAvecCRC);
    if (estAvecCRC)
    {
      leMontant.setCrc(CotisationRetraiteComplementaire.getCotisationEffective(leMontant, coefficient.getSjr().getSalaire(), coefficientSurSalaire, resultat, parametres.getAllocationMinimale(), parametres.getCotisationRetraiteComplementaire()));
    }
    else
    {
      leMontant.setCrc(new Quantite(0, UniteMonaitaire.get("Euros")));
      
      leMontant.setSjrNonReduit(coefficient.getSjr().getSalaire());
    }
    return leMontant;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec p_formuleMontantDroitAssocie) {}
  
  public void setFormuleMontantApplicable(int p_formuleMontantApplicable) {}
}

/* Location:
 * Qualified Name:     FormuleMontantRegimeGeneralASRARE
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */