package fr.unedic.cali.asu.calcul;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.fabriques.FabriqueMajCompteurFormation;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieReglesArSurCiPuisRepriseAsu;
import fr.unedic.cali.asu.may17.p02.calcul.dom.MontantMAYF;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieMajCompteurFormationSpec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieReglesArSurCiPuisRepriseAsuSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.datelimite.asp.OutilAllongementDateLimiteIndemnisation;
import fr.unedic.cali.calcul.FacadeCalculProduitPeriodiqueAbstraite;
import fr.unedic.cali.calcul.FacadeCalculProduitPeriodiqueSpec;
import fr.unedic.cali.calcul.OutillageCalculADate;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.QuantiteNonIndemnises;
import fr.unedic.cali.calcul.dom.Somme;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.ActionFormation;
import fr.unedic.cali.calcul.dom.periode.DebutActionFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeCalcul;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationASP;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoRemplissage;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT.ElementContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyse;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodesPriseEnCompte;
import fr.unedic.cali.calcul.outilsfonctionnels.proratisation.PeriodeProratisationFactory;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantAREFSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.liquidation.pnds.StrategieDeterminationPNDSSpec;
import fr.unedic.cali.liquidation.pnds.outilsfonctionnels.FabriqueStrategieDeterminationPNDS;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeAllongementCSP;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChrono;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class FacadeCalculGammeImpl
  extends FacadeCalculProduitPeriodiqueAbstraite
{
  protected static final int SEUIL_MOIS_NI = 3;
  
  public Damj getDateFinProduit(AttributionSpec attribution, QuantiteDroitSpec quantite, Damj dateFinQuantite)
  {
    return dateFinQuantite;
  }
  
  public void controlerAPosterioriContexteUT(AttributionSpec attribution, ContexteUT contexteUT, UniteTraitement ut, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {}
  
  public void imputerQuantiteIndemnisationDuAuxPNDS(UniteTraitement ut, ConstituantsIndemnisation constituantsIndemnisation, ArretProduitAvecRaison arretProduitAvecRaison, AttributionSpec attribution)
    throws CoucheLogiqueException
  {}
  
  public void forcerImputationQuantiteIndemnisation(PeriodeAnalyseSpec pa, ConstituantsIndemnisation constituantsIndemnisation, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {}
  
  public void miseAJourMontantSurSommes(AttributionSpec attribution, UniteTraitement ut, ConstituantsIndemnisation constituantsIndemnisation, Damj dateCalcul)
    throws CoucheLogiqueException
  {}
  
  public ChronologiePeriodes filtrerFormationsEffectives(ChronologiePeriodes chronologiePeriodesGAEC, ChronologiePeriodes chronologiePeriodesPECSansFiltre)
    throws CoucheLogiqueException
  {
    return chronologiePeriodesGAEC;
  }
  
  public Collection filtrerRadiationSegmentante(Collection collectionPeriodesPourAttribution, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return collectionPeriodesPourAttribution;
  }
  
  public void filtrePriseEnComptePeriodesActiviteSurUT(PeriodesPriseEnCompte periodesPriseEnCompte, Periode periodeUT, ContexteUT contexteUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    filtrerPeriodePriseEnCompteSurDateAttribution(periodesPriseEnCompte, periodeUT, attribution);
    
    traitementFDD(periodesPriseEnCompte, periodeUT, contexteUT, attribution);
    
    appliqueStrategieFiltreARSurCIPuisReprise(periodesPriseEnCompte, periodeUT, contexteUT, attribution);
  }
  
  protected void filtrerPeriodePriseEnCompteSurDateAttribution(PeriodesPriseEnCompte periodesPriseEnCompte, Periode periodeUT, AttributionSpec attribution)
  {
    if (periodeUT.contient(attribution.getDateAttribution()))
    {
      periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(attribution.getDateAttribution(), 5);
      periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(attribution.getDateAttribution(), 4);
    }
  }
  
  protected void appliqueStrategieFiltreARSurCIPuisReprise(PeriodesPriseEnCompte periodesPriseEnCompte, Periode periodeUT, ContexteUT contexteUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(periodeUT.getDebut());
    StrategieReglesArSurCiPuisRepriseAsuSpec strategie = (StrategieReglesArSurCiPuisRepriseAsuSpec)FabriqueStrategieReglesArSurCiPuisRepriseAsu.getInstance().getStrategie(critere);
    
    strategie.filtrePriseEnComptePeriodesActiviteSurUT(periodesPriseEnCompte, periodeUT, contexteUT, attribution);
  }
  
  protected void traitementFDD(PeriodesPriseEnCompte periodesPriseEnCompte, Periode periodeUT, ContexteUT contexteUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {}
  
  public void ajouterConstituantsIndemnisationFuturs(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attribution, UniteTraitement ut)
    throws CoucheLogiqueException
  {}
  
  public void controlerPjiAttribution(AttributionSpec attribution, Damj dateExecution)
    throws CoucheLogiqueException
  {}
  
  public void controlerAttribution(AttributionSpec attribution)
    throws ContexteException
  {}
  
  public void controlerDureeDetectionMaintien(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec attribution)
    throws CoucheLogiqueException
  {}
  
  public void cumulerMontantGlobalServiAttribution(ConstituantsIndemnisation constituantsIndemnisation, Quantite nbJoursImputes, MontantBaseSpec montant, AttributionSpec attribution) {}
  
  public BigDecimal recupererPlafondGlobal(AttributionSpec attribution, Damj dateDebut)
  {
    return null;
  }
  
  public BigDecimal recupererPlafondGlobalDerogatoire(AttributionSpec attribution)
  {
    return null;
  }
  
  public BigDecimal determinerCumulServiADate(AttributionSpec attribution, UniteTraitement ut, ContexteUT contexteUT, ConstituantsIndemnisation constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public BigDecimal determinerMontantRestantAvantPlafond(AttributionSpec attribution, UniteTraitement ut, ContexteUT contexteUT, ConstituantsIndemnisation constituantsIndemnisation, MontantBaseSpec montant, PeriodeAnalyseSpec pa)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public String recupererCategorieAttribution(AttributionSpec attribution, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public void incrementationNbMoisInactivite(ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite) {}
  
  public int calculerCompteurNombreJoursIndemnisesSurUT(UniteTraitement ut, int cumulNombreJoursServi)
  {
    return 0;
  }
  
  public int calculerCompteurFormationSurUT(UniteTraitement ut)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodeSegmentantes = ut.getQualificationPeriodes().getPeriodesSegmentantes();
    Iterator<ObjetChronoPeriodeCalcul> ite = periodeSegmentantes.iterer();
    Damj datePrescriptionActionFormation = null;
    
    ArrayList<Damj> chronoDateDebutAF = new ArrayList();
    while (ite.hasNext())
    {
      ObjetChronoPeriodeCalcul periode = (ObjetChronoPeriodeCalcul)ite.next();
      if ((periode instanceof DebutActionFormation))
      {
        CritereStrategie critere = new CritereStrategie();
        datePrescriptionActionFormation = ((DebutActionFormation)periode).getActionFormation().getDatePrescription();
        critere.setDatePivot(datePrescriptionActionFormation);
        StrategieMajCompteurFormationSpec strategie = (StrategieMajCompteurFormationSpec)FabriqueMajCompteurFormation.getInstance().getStrategie(critere);
        if (strategie.remiseAzeroCompteur()) {
          chronoDateDebutAF.add(periode.getDateDebut());
        }
      }
    }
    int nbJourFormation = ut.getNbJoursFormationEnDebutDUT();
    Iterator iteratorSomme = ut.getCollectionSommes().iterator();
    while (iteratorSomme.hasNext())
    {
      Somme somme = (Somme)iteratorSomme.next();
      if (((somme.getMontant() instanceof MontantAREFSpec)) || ((somme.getMontant() instanceof MontantMAYF)))
      {
        if ((!chronoDateDebutAF.isEmpty()) && (chronoDateDebutAF.contains(somme.getDateDebut()))) {
          nbJourFormation = 0;
        }
        nbJourFormation += somme.getNbBase().getValeurEntiere();
      }
    }
    return nbJourFormation;
  }
  
  public void ajouterEvenementDebutImputation(PeriodeAnalyseSpec pa, List listeQuantiteDroitActives) {}
  
  public ChronologiePeriodes recupererPeriodeAPartirDesPECs(ChronologiePeriodes chronologiePeriodesPECSansFiltre, Periode periodeUT, Damj dateDJA)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Quantite convertir(Quantite quantite, Unite unite, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDebutPa)
    throws CoucheLogiqueException
  {
    return quantite;
  }
  
  public int initialiserCumulNombreJoursServi(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return 0;
  }
  
  public void alimenterGrapheAntecedentCalcul(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
  }
  
  public boolean verifierEligibilitePaiementParAvance(UniteTraitement ut)
  {
    return true;
  }
  
  public void miseAJourUtAvecDnjGaec(AttributionSpec attribution, UniteTraitement ut)
    throws CoucheLogiqueException
  {}
  
  public boolean alimenterLA2K()
    throws CoucheLogiqueException
  {
    return true;
  }
  
  public String recupererRsodPourSuivi(AttributionSpec attribution)
  {
    return attribution.getRsod();
  }
  
  public BigDecimal recupererAnneeAffectation(AttributionSpec attribution)
  {
    return null;
  }
  
  public Damj recupererPremierJourExecutableNcp(AttributionSpec attribution)
  {
    return attribution.getPji();
  }
  
  public ConstituantsCalculActiviteReduiteSpec miseAJourCumulActivite(UniteTraitement ut, AttributionSpec attribution, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    return constituantsCalculActiviteReduite;
  }
  
  public fr.unedic.cali.calcul.dom.UniteTraitementForcee creerUniteTraitementForcee(Damj dateDebut, Damj dateFin)
  {
    return new fr.unedic.cali.asu.calcul.dom.UniteTraitementForcee(dateDebut, dateFin);
  }
  
  public void miseAJourCompteurs(AttributionSpec attribution, UniteTraitement ut) {}
  
  public Quantite determinerQuantiteAvantPlafond(BigDecimal montantDisponible, BigDecimal montantBrut, Unite uniteQuantite, UniteTraitement ut)
  {
    return null;
  }
  
  public void majCumulServiQuantitePlafonne(ConstituantsIndemnisation constituantsIndemnisation, UniteTraitement ut) {}
  
  public void calculSommePlafond(Quantite quantiteAImputer, Quantite quantiteImputable, UniteTraitement ut, Damj dateFin, Damj dateDebut, Damj dateFinQuantiteDroit, QuantiteIndemnisationSpec quantiteIndemnisation, PeriodeAnalyseSpec pa, FacadeCalculProduitPeriodiqueSpec facadeCalculProduit, MontantBaseSpec montant)
    throws CoucheLogiqueException
  {}
  
  public void traitementActiviteReduiteSurPa(PeriodeAnalyseSpec pa, UniteTraitement ut, AttributionSpec attribution, MontantBaseSpec montant, BigDecimal sjr)
    throws CoucheLogiqueException
  {}
  
  public void miseAjourNombreMoisNonIndemnise(AttributionSpec attribution, UniteTraitement ut, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, ContexteUT contexteUT, ArretProduitAvecRaison arretProduitAvecRaison)
    throws CoucheLogiqueException
  {
    boolean utIndemnisee = false;
    boolean chevaucheDebutMois = false;
    boolean chevaucheFinMois = false;
    boolean estAttenteDrv = false;
    
    CalendrierExecutionCalculPeriodique calendrierPeriodique = null;
    if (attribution.getCalendrierExecutionCalcul() != null) {
      calendrierPeriodique = (CalendrierExecutionCalculPeriodique)attribution.getCalendrierExecutionCalcul();
    }
    if ((calendrierPeriodique != null) && (calendrierPeriodique.getDateDrv() != null) && (calendrierPeriodique.getDateDrv().estAvantOuCoincideAvec(ut.getDateDebut()))) {
      estAttenteDrv = true;
    }
    if (((ut.isNeutralisee()) && ((arretProduitAvecRaison.recupereLendemainDateArret() == null) || (arretProduitAvecRaison.recupereLendemainDateArret().coincideAvec(ut.getDateFin().lendemain())))) || ((ut.getListePeriodesAnalyse() != null) && (!ut.getListePeriodesAnalyse().estVide()) && (((PeriodeAnalyse)ut.getListePeriodesAnalyse().dernierElement()).getDateFin().coincideAvec(ut.getDateFin())))) {
      chevaucheFinMois = true;
    }
    if (attribution.getDateAttribution().estAvantOuCoincideAvec(ut.getDateDebut())) {
      chevaucheDebutMois = true;
    }
    if ((ut.getQuantiteIndemnisee() != null) && (ut.getQuantiteIndemnisee().getValeurEntiere() > 0)) {
      utIndemnisee = true;
    }
    AttributionSpec attributionPrec = ((AttributionAssuranceSpec)attribution).getAttributionPrecedente();
    while (attributionPrec != null)
    {
      if (contexteUT.getListeOrdonneeCandidats().contains(attributionPrec))
      {
        ContexteUT.ElementContexteUT elementContexteUT = contexteUT.getElementContexteUT(attributionPrec);
        if ((elementContexteUT.getQuantiteIndemnisee() != null) && (elementContexteUT.getQuantiteIndemnisee().getValeurEntiere() > 0)) {
          utIndemnisee = true;
        }
        if ((attributionPrec.getDateAttribution().estAvantOuCoincideAvec(ut.getDateDebut())) && (attributionPrec.getCalendrierExecutionCalcul().getDernierJourIndemnisable().lendemain().coincideAvec(attribution.getDateAttribution()))) {
          chevaucheDebutMois = true;
        }
      }
      attributionPrec = ((AttributionAssuranceSpec)attributionPrec).getAttributionPrecedente();
    }
    if ((!utIndemnisee) && (chevaucheDebutMois) && (chevaucheFinMois) && (!estAttenteDrv))
    {
      constituantsCalculActiviteReduite.setCumulMoisNonIndemnise(constituantsCalculActiviteReduite.getCumulMoisNonIndemnise() + 1);
      if (contexteUT.getListeOrdonneeCandidats().size() > 1) {
        miseAJourCumulMoisNiSurAttributionPrec(attribution, constituantsCalculActiviteReduite.getCumulMoisNonIndemnise(), contexteUT);
      }
    }
    else if ((constituantsCalculActiviteReduite.getCumulMoisNonIndemnise() < 3) && ((chevaucheFinMois) || (contexteUT.getListeOrdonneeCandidats().size() == 1)))
    {
      constituantsCalculActiviteReduite.setCumulMoisNonIndemnise(0);
      miseAJourCumulMoisNiSurAttributionPrec(attribution, 0, contexteUT);
    }
  }
  
  private void miseAJourCumulMoisNiSurAttributionPrec(AttributionSpec attribution, int cumulMoisNi, ContexteUT contexteUT)
    throws CoucheLogiqueException
  {
    AttributionSpec attributionPrecedente = ((AttributionAssuranceSpec)attribution).getAttributionPrecedente();
    while (attributionPrecedente != null)
    {
      if (contexteUT.getListeOrdonneeCandidats().contains(attributionPrecedente))
      {
        ContexteUT.ElementContexteUT elementContexteUT = contexteUT.getElementContexteUT(attributionPrecedente);
        elementContexteUT.miseAjourCumulMoisNi(cumulMoisNi);
      }
      attributionPrecedente = ((AttributionAssuranceSpec)attributionPrecedente).getAttributionPrecedente();
    }
  }
  
  public boolean verifierApplicationForcageSurUT(UniteTraitement ut, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return true;
  }
  
  public void mettreAjourDateFinDispositif(AttributionSpec attribution, UniteTraitement ut, CalendrierExecutionCalculPeriodique calendrier, QualificationPeriodes qualificationPeriodes)
    throws CoucheLogiqueException
  {}
  
  public boolean enregistrerDispositifPBJCNCP(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return false;
  }
  
  protected void miseAJourDateFinCSP(AttributionSpec attribution, UniteTraitement ut, CalendrierExecutionCalculPeriodique calendrier, QualificationPeriodes qualificationPeriodes)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attrib = (AttributionAssuranceSpec)attribution;
    Damj dateDebutDispositif = recupererDateDebutDispositif(attribution);
    Damj dateFinCSPMax = OutilAllongementDateLimiteIndemnisation.recupererDateFinAllongementMax(dateDebutDispositif);
    Damj septiemeMois = OutilAllongementDateLimiteIndemnisation.recupererDateDepartCalculAllongement(dateDebutDispositif);
    Damj dateFinCSP = ut.getConstituantsIndemnisationEnDebutUT().getDateFinDispositifCSP();
    Periode periodeUT = ut.getPeriode();
    ChronologiePeriodes periodesSuspensives = qualificationPeriodes.getPeriodesSuspensives();
    
    boolean estContextePap = false;
    if (OutilsTrancheCalcul.estTrancheActive(attribution))
    {
      TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(attribution);
      estContextePap = tranche.isContextePAPPresent();
    }
    else
    {
      ElementBaseIndemnisation ebi = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation();
      estContextePap = ebi.isContextePAPPresent();
    }
    if ((periodeUT.getFin().estApresOuCoincideAvec(septiemeMois)) && (!estContextePap))
    {
      Damj dateFinPeriode = periodeUT.getFin();
      
      ChronologiePeriodes periodesSuspProratisee = (ChronologiePeriodes)periodesSuspensives.copier(new FiltrePeriodeAllongementCSP());
      
      periodesSuspProratisee = retirerActiviteesConservees(periodesSuspProratisee, dateDebutDispositif);
      
      Iterator<ObjetChronoPeriodeCalcul> itInterrupt = qualificationPeriodes.getPeriodesInterruptivesDefinitives().iterer();
      while (itInterrupt.hasNext())
      {
        ObjetChronoPeriodeCalcul interruptifDefinitif = (ObjetChronoPeriodeCalcul)itInterrupt.next();
        if (interruptifDefinitif.getDateDebut().estAvantOuCoincideAvec(dateFinPeriode)) {
          dateFinPeriode = interruptifDefinitif.getDateDebut().veille();
        }
      }
      ChronologiePeriodes chronoAAllonger = periodesSuspProratisee;
      chronoAAllonger = traiterPnds(attrib, periodesSuspProratisee, periodeUT);
      
      Damj dateDebutProratisation = Damj.max(septiemeMois, periodeUT.getDebut());
      dateDebutProratisation = Damj.max(dateDebutProratisation, attrib.getDateAttribution());
      if (dateDebutProratisation.estAvant(dateFinPeriode))
      {
        Periode periode = new Periode(dateDebutProratisation, dateFinPeriode);
        chronoAAllonger = PeriodeProratisationFactory.decoupeEtProratiseParDefaut(chronoAAllonger, periode);
        if ((!periodesSuspProratisee.estVide()) && (!chronoAAllonger.estVide()))
        {
          chronoAAllonger = OutillageCalculADate.retourneLesTrous(chronoAAllonger, ObjetChronoRemplissage.class, periode.getDebut(), periode.getFin());
          
          chronoAAllonger = OutillageCalculADate.retourneLesTrous(chronoAAllonger, ObjetChronoRemplissage.class, periode.getDebut(), periode.getFin());
        }
        Iterator<ObjetChronoPeriode> it = chronoAAllonger.iterer();
        while (it.hasNext())
        {
          ObjetChronoPeriode chronoPeriode = (ObjetChronoPeriode)it.next();
          if (dateFinCSP.estApresOuCoincideAvec(chronoPeriode.getDateDebut()))
          {
            int nbJourAllongement = chronoPeriode.getDuree();
            dateFinCSP = determinerFinCSP(dateFinCSP, nbJourAllongement, dateFinCSPMax);
          }
        }
      }
    }
    calendrier.setDateFinDispositifCSP(dateFinCSP);
    ut.getConstituantsIndemnisationEnDebutUT().setDateFinDispositifCSP(dateFinCSP);
    if (dateFinCSP.estContenueDans(periodeUT))
    {
      ObjetChronoPeriodeCalcul interruptif = new ObjetChronoPeriodeLimiteIndemnisationASP(dateFinCSP.lendemain(), attribution.getRsod());
      qualificationPeriodes.ajouterPeriodesInterruptivesDefinitives(interruptif);
    }
  }
  
  private ChronologiePeriodes retirerActiviteesConservees(ChronologiePeriodes periodesSuspProratisee, Damj dateDebutDispositif)
  {
    ChronologiePeriodes periodesAvecActiviteesConservees = periodesSuspProratisee;
    
    periodesAvecActiviteesConservees.iterer();
    while (periodesAvecActiviteesConservees.encoreSuivant())
    {
      ObjetChrono periodeTravail = (PeriodeActiviteEmploiCalcul)periodesSuspProratisee.elementSuivant();
      if (periodeTravail.getDateDebut().estAvant(dateDebutDispositif)) {
        periodesSuspProratisee.supprimer(periodeTravail);
      }
    }
    return periodesSuspProratisee;
  }
  
  private static Damj determinerFinCSP(Damj dateFinCSP, int nbJourAllongement, Damj dateFinCSPMax)
  {
    Damj nouvelleDateFinCSP = new Damj(dateFinCSP);
    nouvelleDateFinCSP = nouvelleDateFinCSP.deplacerVersAvant(new DureeCalendaire(0, 0, nbJourAllongement));
    return Damj.min(nouvelleDateFinCSP, dateFinCSPMax);
  }
  
  private static Damj recupererDateDebutDispositif(AttributionSpec attribution)
  {
    Damj dateDebutDispositif;
    Damj dateDebutDispositif;
    if (attribution.getDemande().estEnContexteDemande("AREENTRCSP"))
    {
      dateDebutDispositif = ((GammeAsuSpec)attribution.getGamme()).calculerPointDepartCSP(attribution.getDemande());
    }
    else
    {
      Demande demandePrecedente = (Demande)OutilRecherche.rechercherDemandePrecedente(attribution.getDemande().getChronologieDemandesAssuranceSansCourante(), attribution.getDemande(), new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      
      dateDebutDispositif = ((GammeAsuSpec)attribution.getGamme()).calculerPointDepartCSP(demandePrecedente);
    }
    return dateDebutDispositif;
  }
  
  public boolean verifierTraitementPasss(AttributionSpec attribution)
  {
    return true;
  }
  
  public void miseAjourPeriodeAV(ChronologiePeriodes chronoPeriode, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    OutilRetraite outilRetraite = OutilRetraite.getInstance();
    if ((chronoPeriode != null) && (!chronoPeriode.estVide()))
    {
      chronoPeriode.iterer();
      while (chronoPeriode.encoreSuivant())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)chronoPeriode.elementSuivant();
        if (((periode instanceof PeriodeAvantageVieillesse)) && ((((PeriodeAvantageVieillesse)periode).getCodeNature().equals("1")) || (((PeriodeAvantageVieillesse)periode).getCodeNature().equals("M")))) {
          periode.setDateDebut(Damj.max(periode.getDateDebut(), individu.getDateNaissance().deplacerVersAvant(outilRetraite.getAgeMinDepartRetraite(individu))));
        }
      }
    }
  }
  
  public void traitementPeriodesNonIndemnises(UniteTraitement ut, QualificationPeriodes qualificationPeriodes, QuantiteNonIndemnises quantiteNonIndemnises, ConstituantsIndemnisation constituantsIndemnisation)
    throws CoucheLogiqueException
  {}
  
  public int recupererPopulation()
  {
    return 0;
  }
  
  public void appliquerFiltreSurFDDSuiteEpuismentOuDateAnniverssaire(PeriodesPriseEnCompte periodesPriseEnCompte, Periode periodeUT, ContexteUT contexteUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    if ((OutilDemande.estUneDemandeFinDeDroitSurEpuissement((AttributionAssuranceSpec)attribution, periodeUT)) && (!((AttributionAssuranceSpec)attribution).getOuvertureDroit().getDateAttribution().coincideAvec(periodeUT.getDebut())))
    {
      Damj dateFinTraitementARattributionPrecedente = null;
      ContexteUT.ElementContexteUT elementContexteUT = null;
      List<?> listeAttributions = contexteUT.getListeOrdonneeCandidats();
      Iterator<?> it = listeAttributions.iterator();
      while (it.hasNext())
      {
        AttributionSpec attributionCandidate = (AttributionSpec)it.next();
        if (attributionCandidate != attribution)
        {
          elementContexteUT = contexteUT.getElementContexteUT(attributionCandidate);
          dateFinTraitementARattributionPrecedente = (dateFinTraitementARattributionPrecedente == null) || ((elementContexteUT.recupererDateTraitementARSurMoisDJI() != null) && (dateFinTraitementARattributionPrecedente.estAvant(elementContexteUT.recupererDateTraitementARSurMoisDJI()))) ? elementContexteUT.recupererDateTraitementARSurMoisDJI() : dateFinTraitementARattributionPrecedente;
        }
      }
      if (dateFinTraitementARattributionPrecedente != null)
      {
        periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(dateFinTraitementARattributionPrecedente.lendemain(), 5);
        periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(dateFinTraitementARattributionPrecedente.lendemain(), 4);
      }
      else
      {
        periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(periodeUT.getFin().lendemain(), 5);
        periodesPriseEnCompte.tronquePeriodeParTypologieEnDebut(periodeUT.getFin().lendemain(), 4);
      }
    }
  }
  
  private ChronologiePeriodes traiterPnds(AttributionAssuranceSpec attrib, ChronologiePeriodes periodesTravail, Periode periodeUt)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesSuspProratiseeSansPNDS = periodesTravail;
    
    Collection listePNDs = new ArrayList();
    
    CritereStrategie critere = new CritereStrategie();
    Damj dateDebutGenerationPNDs = periodeUt.getDebut();
    critere.setDatePivot(dateDebutGenerationPNDs);
    StrategieDeterminationPNDSSpec strategie = FabriqueStrategieDeterminationPNDS.determinerStrategieDeterminationPNDS(critere);
    listePNDs = strategie.determinationPNDSPourCalcul(periodesTravail, attrib.getDemandeur());
    if ((listePNDs != null) && (!listePNDs.isEmpty()))
    {
      periodesSuspProratiseeSansPNDS = new ChronologiePeriodes();
      ChronologiePeriodes chronoPNDSsurUT = new ChronologiePeriodes();
      
      Iterator<ObjetChronoPeriodeConcrete> ite = listePNDs.iterator();
      while (ite.hasNext())
      {
        ObjetChronoPeriode pnd = (ObjetChronoPeriode)ite.next();
        Periode per = new Periode(pnd.getDateDebut(), pnd.getDateFin());
        if (per.chevauche(periodeUt)) {
          chronoPNDSsurUT.ajouter(new ObjetChronoRemplissage(2, per.getDebut(), per.getFin()));
        }
      }
      ChronologiePeriodes chronoPeriodesEligibles = new ChronologiePeriodes();
      if (!chronoPNDSsurUT.estVide())
      {
        chronoPeriodesEligibles = OutillageCalculADate.retourneLesTrous(chronoPNDSsurUT, ObjetChronoRemplissage.class, periodeUt.getDebut(), periodeUt.getFin());
        
        periodesTravail.iterer();
        while (periodesTravail.encoreSuivant())
        {
          PeriodeActiviteEmploiCalcul periodeTravail = (PeriodeActiviteEmploiCalcul)periodesTravail.elementSuivant();
          chronoPeriodesEligibles.iterer();
          while (chronoPeriodesEligibles.encoreSuivant())
          {
            Temporel temp = chronoPeriodesEligibles.elementSuivant();
            Periode periodeEligibleAllongement = new Periode(temp.getDateDebut(), temp.getDateFin());
            if (periodeTravail.chevauche(periodeEligibleAllongement)) {
              periodesSuspProratiseeSansPNDS.ajouter(PeriodeProratisationFactory.decoupeEtProratiseParDefaut(periodesTravail, periodeEligibleAllongement));
            }
          }
        }
      }
      periodesSuspProratiseeSansPNDS = periodesTravail;
    }
    return periodesSuspProratiseeSansPNDS;
  }
  
  public void miseAjourCumulAllongementAREF(UniteTraitement ut, ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec p_attribution) {}
}

/* Location:
 * Qualified Name:     FacadeCalculGammeImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */