package fr.unedic.cali.asu.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.parcours.ResultatDeterminationEtatDroit;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.parcours.ResultatTraitementReliquatSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.produits.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.Differe;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisLegal;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.FacadeCalculProduitFactory;
import fr.unedic.cali.calcul.FacadeCalculProduitPourLiquidationAbstraite;
import fr.unedic.cali.calcul.FacadeCalculProduitSpec;
import fr.unedic.cali.calcul.MoteurCalcul;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvantSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.EtatAuDji;
import fr.unedic.cali.calcul.dom.EtatAuDjiSpec;
import fr.unedic.cali.calcul.outilsfonctionnels.OutilGestionPoursuite;
import fr.unedic.cali.dom.AntecedentSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.PoursuiteSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.LigneAsuCaa14;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.LigneAsuCsa06;
import fr.unedic.cali.dom.affectation.LigneAsuCva10;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.migration.outilsfonctionnels.OutilsMigration;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.AppelCalcul;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateAttribution;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.ResultatApres;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.parcours.ResultatDeterminationEtatDroitProduit;
import fr.unedic.cali.parcours.ResultatExecutionCalcul;
import fr.unedic.cali.util.ObjetChronoPeriodeConcreteCarence;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public abstract class FacadeCalculProduitPourLiquidationAsuAbstraite
  extends FacadeCalculProduitPourLiquidationAbstraite
  implements FacadeCalculProduitPourLiquidationAsuSpec
{
  public ResultatExecutionCalcul executerCalculDeterminationEtatDroit(AttributionSpec attributionAEtudier, Damj dateEtude, boolean priseEnCompteGaec, boolean determinationApres)
    throws ApplicativeException
  {
    ResultatDeterminationEtatDroitProduit resultatPendant = null;
    ResultatExecutionCalcul resultatCalcul = new ResultatExecutionCalcul();
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)attributionAEtudier;
    
    ResultatAvant resultatAvant = appelExecutionAvant(dateEtude, priseEnCompteGaec, attribution);
    if (OutilDemande.estUneDemandeFinDroit(attribution.getDemande()))
    {
      resultatPendant = (ResultatDeterminationEtatDroit)AppelCalcul.executerCalculDeterminationEtatDroit(attribution, dateEtude);
      if (resultatPendant == null) {
        resultatPendant = new ResultatDeterminationEtatDroit();
      }
      if (OutilFinDroit.estCasParticulierFinDroitEnAttributionAvecDuree0Jour(attribution.getDemande()))
      {
        resultatPendant.setAttribution(attributionAEtudier);
        resultatPendant.setEtatAttribution(2);
        Quantite duree = new Quantite(0, Unite.get("jour"));
        ((ResultatDeterminationEtatDroit)resultatPendant).setReliquatDureeIndemnisation(duree);
        resultatPendant.setReliquatAREAvecMaintien(duree);
      }
      else
      {
        resultatPendant.setAttribution(attributionAEtudier);
        resultatPendant.setEtatAttribution(3);
        Quantite duree = attribution.getAccesseurDroits().getDureeIndemnisationTheorique();
        ((ResultatDeterminationEtatDroit)resultatPendant).setReliquatDureeIndemnisation(duree);
        resultatPendant.setReliquatAREAvecMaintien(duree);
      }
    }
    else if ((resultatAvant != null) && (resultatAvant.getEtat() == 9))
    {
      resultatPendant = new ResultatDeterminationEtatDroit();
      resultatPendant.setEtatAttribution(1);
      resultatPendant.setAttribution(attributionAEtudier);
    }
    else if ((resultatAvant != null) && (resultatAvant.getEtat() == 1))
    {
      ObjetChronoPeriodePriseEnCharge periodePec = OutillagePEC.getPeriodePECContenant(attribution.getDemandeur(), OutilGestionPoursuite.getInstance().recupererDateAttributionOuPjpSiPoursuite(attribution));
      if (periodePec == null)
      {
        resultatPendant = reportAntecedentTheorique(attribution);
      }
      else
      {
        attribution.setUnJourDiffereConsomme(resultatAvant.isDiffereEntame());
        
        resultatPendant = reportAntecedentTheorique(attribution);
      }
    }
    else
    {
      resultatPendant = (ResultatDeterminationEtatDroit)AppelCalcul.executerCalculDeterminationEtatDroit(attribution, dateEtude);
      if (resultatPendant == null) {
        resultatPendant = reportAntecedentTheorique(attribution);
      }
    }
    resultatAvant = gestionDroitsFiges(attribution, resultatAvant);
    
    resultatCalcul.setResultatAvant(resultatAvant);
    resultatCalcul.setResultatPendant(resultatPendant);
    
    postTraitementMajCarence(dateEtude, resultatAvant);
    if ((resultatCalcul.getEtatAttribution() == 3) && (dateEtude != null) && (determinationApres) && (((AttributionAssuranceSpec)resultatCalcul.getAttributionEtudiee()).getDemandeSuivantePourTraitementReliquat() != null) && ((resultatCalcul.isCalendrierNul()) || ((resultatCalcul.getDernierJourIndemnisable() != null) && ((dateEtude.estApres(resultatCalcul.getDernierJourIndemnisable())) || (forcerTraitementDuReliquat(((AttributionAssuranceSpec)resultatCalcul.getAttributionEtudiee()).getDemandeSuivantePourTraitementReliquat(), (AttributionAssuranceSpec)resultatCalcul.getAttributionEtudiee()))))))
    {
      ResultatTraitementReliquatSpec resultatTraitementReliquat = (ResultatTraitementReliquatSpec)((ProduitAsuSpec)attribution.getProduit()).traiterReliquat(resultatCalcul, dateEtude);
      if (resultatTraitementReliquat != null)
      {
        ResultatApres resultatApres = new ResultatApres();
        resultatApres.setReliquatDureeIndemnisation(resultatTraitementReliquat.getQuantiteReliquat());
        boolean estReliquatValide = resultatTraitementReliquat.isReliquatValide();
        if (estReliquatValide)
        {
          resultatApres.setEtatAttribution(3);
          resultatApres.setDateEtatAttribution(dateEtude);
        }
        else
        {
          resultatApres.setEtatAttribution(resultatTraitementReliquat.getCauseNonvalidite());
          resultatApres.setDateEtatAttribution(resultatTraitementReliquat.getDateNonValidite());
        }
        resultatApres.setReliquatValide(estReliquatValide);
        resultatApres.setContexteExamen(resultatTraitementReliquat.getContexteExamen());
        resultatApres.setQuantiteFormation(resultatTraitementReliquat.getQuantiteFormation());
        resultatApres.setQuantiteAide(resultatTraitementReliquat.getQuantiteAide());
        resultatApres.setQuantiteJourImputationDonneesForcees(resultatTraitementReliquat.getQuantiteJourImputationDonneesForcees());
        resultatApres.setQuantiteReliquatRenouvellement(resultatTraitementReliquat.getQuantiteReliquatRenouvellement());
        resultatApres.setTypeAide(resultatTraitementReliquat.getTypeAide());
        resultatCalcul.setResultatApres(resultatApres);
      }
    }
    return resultatCalcul;
  }
  
  private boolean forcerTraitementDuReliquat(DemandeSpec demandeCourante, AttributionAssuranceSpec attributionPrecedente)
    throws CoucheLogiqueException
  {
    return ("ASU_27".equalsIgnoreCase(demandeCourante.getEvenementReferenceExamen().getTypeExamen())) || (estDemandeAsuDroitOptionReadmission(demandeCourante)) || (estDemandeEnSortieDeCsp(demandeCourante, attributionPrecedente));
  }
  
  private boolean estDemandeAsuDroitOptionReadmission(DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    return (GammeAsu.getInstance().equals(demandeCourante.getGamme())) && (((Demande)demandeCourante).estDroitOptionReadmission()) && (GestionnaireDateApplication.getInstance().recupererDateApplication("Application du droit d'option élargi.").estAvantOuCoincideAvec(demandeCourante.getDateRecherche()));
  }
  
  private boolean estDemandeEnSortieDeCsp(DemandeSpec demandeCourante, AttributionAssuranceSpec attributionPrecedente)
  {
    return (estDemandeAsuSuiteIde(demandeCourante)) && (estAttributionPrecedenteCsp(attributionPrecedente));
  }
  
  private boolean estDemandeAsuSuiteIde(DemandeSpec demandeCourante)
  {
    return "ASU_01".equals(demandeCourante.getEvenementReferenceExamen().getTypeExamen());
  }
  
  private boolean estAttributionPrecedenteCsp(AttributionAssuranceSpec attributionPrecedente)
  {
    return ((LigneAsuCaa14.getInstance().getNomUnique().equals(attributionPrecedente.getProduitExecution().getLigne().getNomUnique())) || (LigneAsuCva10.getInstance().getNomUnique().equals(attributionPrecedente.getProduitExecution().getLigne().getNomUnique()))) && ((LigneAsuCge01.getInstance().getNomUnique().equals(attributionPrecedente.getProduit().getLigne().getNomUnique())) || (LigneAsuCsa06.getInstance().getNomUnique().equals(attributionPrecedente.getProduit().getLigne().getNomUnique())));
  }
  
  private ResultatAvant gestionDroitsFiges(AttributionAssuranceSpec attribution, ResultatAvant resultatAvant)
  {
    if (resultatAvant == null)
    {
      Damj pji = null;
      if (attribution.getCalendrierExecutionCalcul() != null) {
        pji = attribution.getCalendrierExecutionCalcul().getPremierJourIndemnisable();
      }
      ResultatAvant resultat = new ResultatAvant(pji, new ArrayList(), true);
      resultat.setEtat(0);
      return resultat;
    }
    return resultatAvant;
  }
  
  private ResultatAvant appelExecutionAvant(Damj dateEtude, boolean priseEnCompteGaec, AttributionAssuranceSpec attribution)
    throws ApplicativeException
  {
    ResultatAvant resultatAvant = null;
    if ((attribution.getDemande() == null) || (!OutilsMigration.estFigee(attribution.getDemande())) || (attribution.getCalendrierExecutionCalcul() == null) || (attribution.getCalendrierExecutionCalcul().getEtatAuDJI() == null)) {
      try
      {
        resultatAvant = AppelAvant.executerCalculDeterminationEtatAvant(attribution, priseEnCompteGaec, dateEtude);
        attribution.setUnJourDiffereConsomme(resultatAvant.isDiffereEntame());
      }
      catch (CoucheLogiqueException cLE)
      {
        if ((attribution.getDemande() == null) || (!OutilsMigration.estFigee(attribution.getDemande()))) {
          throw cLE;
        }
      }
    }
    return resultatAvant;
  }
  
  private void postTraitementMajCarence(Damj dateEtude, ResultatAvant resultatAvant)
  {
    Iterator<?> iterator = null;
    CarenceSpec carenceCourante = null;
    if ((resultatAvant != null) && (dateEtude != null) && (resultatAvant.getListeCarencesEffectives() != null))
    {
      iterator = resultatAvant.getListeCarencesEffectives().iterator();
      while (iterator.hasNext())
      {
        carenceCourante = (CarenceSpec)iterator.next();
        
        majDiffereEntame(dateEtude, resultatAvant, carenceCourante);
        majReliquatCarences(dateEtude, resultatAvant, carenceCourante);
      }
    }
  }
  
  private void majReliquatCarences(Damj dateEtude, ResultatAvant resultatAvant, CarenceSpec carenceCourante)
  {
    if ((carenceCourante instanceof CarencePrefixeAFixer))
    {
      CarencePrefixeAFixer carence = (CarencePrefixeAFixer)carenceCourante;
      if (carence.getPeriodeApplicationCarence() != null) {
        if ((dateEtude.estApresOuCoincideAvec(carence.getPeriodeApplicationCarence().getDebut())) && (dateEtude.estAvant(carence.getPeriodeApplicationCarence().getFin())))
        {
          int dureeReliquat = new Periode(dateEtude.lendemain(), carence.getPeriodeApplicationCarence().getFin()).getDuree();
          
          carence.getPeriodeApplicationCarence().setFin(dateEtude);
          carence.setReliquat(new Quantite(dureeReliquat, Unite.get("jour")));
          carence.setOrigineReliquat(new ObjetChronoPeriodeConcreteCarence(carence.getPeriodeApplicationCarence()));
        }
        else if (dateEtude.estAvant(carence.getPeriodeApplicationCarence().getDebut()))
        {
          carence.setReliquat(new Quantite(carence.getPeriodeApplicationCarence().getDuree(), Unite.get("jour")));
          carence.setPeriodeApplicationCarence(null);
          gestionOrigineReliquat(resultatAvant, carence);
        }
      }
    }
  }
  
  private void majDiffereEntame(Damj dateEtude, ResultatAvant resultatAvant, CarenceSpec carenceCourante)
  {
    if ((carenceCourante instanceof Differe))
    {
      Differe delaiAttente = (Differe)carenceCourante;
      if ((delaiAttente.getPeriodeApplicationCarence() != null) && (dateEtude.estAvant(delaiAttente.getPeriodeApplicationCarence().getDebut()))) {
        resultatAvant.setDiffereEntame(false);
      }
    }
  }
  
  private void gestionOrigineReliquat(ResultatAvant resultatAvant, CarencePrefixeAFixer carence)
  {
    if ((carence.getOrigine() != null) && (resultatAvant.getCalendrierExecutionAvantCalcul() != null)) {
      if (((carence instanceof PreavisMesureConservatoireNonIndemnisable)) || ((carence instanceof PreavisLegal)) || ((carence instanceof CarenceIccp))) {
        carence.setOrigineReliquat(new ObjetChronoPeriodeConcreteCarence(carence.getOrigine().getDateDebut(), resultatAvant.getCalendrierExecutionAvantCalcul().getDernierJourAvant()));
      } else if ((carence instanceof CarenceIslr)) {
        carence.setOrigineReliquat(new ObjetChronoPeriodeConcreteCarence(carence.getOrigine().getDateDebut(), Damj.max(resultatAvant.getCalendrierExecutionAvantCalcul().getDernierJourAvant(), carence.getOrigine().getDateFin())));
      }
    }
  }
  
  protected ResultatDeterminationEtatDroit reportAntecedentTheorique(AttributionAssuranceSpec attributionAEtudier)
    throws ApplicativeException
  {
    ResultatDeterminationEtatDroit resultatCalcul = new ResultatDeterminationEtatDroit();
    
    resultatCalcul.setAttribution(attributionAEtudier);
    resultatCalcul.setEtatAttribution(3);
    
    resultatCalcul.setReliquatDureeIndemnisation(attributionAEtudier.getAccesseurDroits().getDureeIndemnisationTheorique());
    resultatCalcul.setReliquatAREAvecMaintien(attributionAEtudier.getAccesseurDroits().getDureeIndemnisationTheorique());
    resultatCalcul.setReliquatProlongation(attributionAEtudier.getAccesseurDroits().getDureeProlongation());
    if ((attributionAEtudier.getCalendrierExecutionCalcul() != null) && (attributionAEtudier.getCalendrierExecutionCalcul().getEtatAuDJI() != null)) {
      resultatCalcul.setReliquatProlongation(attributionAEtudier.getCalendrierExecutionCalcul().getEtatAuDJI().getReliquatDureeProlongation());
    }
    if (!OutilsTrancheCalcul.estTrancheActive(attributionAEtudier))
    {
      ElementBaseIndemnisation ebiASU = attributionAEtudier.getElementBaseIndemnisation();
      resultatCalcul.setReliquatFranchiseCP(new QuantiteJour(Integer.toString(ebiASU.getDureeFranchiseCp())));
      resultatCalcul.setReliquatFranchiseSalaire(new QuantiteJour(Integer.toString(ebiASU.getDureeFranchiseSalaire())));
    }
    if (((attributionAEtudier instanceof AntecedentSpec)) && (!attributionAEtudier.estEnReexamen()) && (!(attributionAEtudier instanceof PoursuiteSpec)))
    {
      resultatCalcul = (ResultatDeterminationEtatDroit)AppelCalcul.executerCalculDeterminationEtatDroit(attributionAEtudier, null);
      if (resultatCalcul.getReliquatDureeIndemnisation() == null)
      {
        resultatCalcul.setReliquatDureeIndemnisation(attributionAEtudier.getAccesseurDroits().getDureeIndemnisationTheorique());
        resultatCalcul.setReliquatAREAvecMaintien(attributionAEtudier.getAccesseurDroits().getDureeIndemnisationTheorique());
        resultatCalcul.setAttribution(attributionAEtudier);
        resultatCalcul.setEtatAttribution(3);
      }
    }
    return resultatCalcul;
  }
  
  public int determinerNbJoursImputesContextePmvs(AttributionSpec attribution, Periode periode)
    throws ApplicativeException
  {
    Damj a = periode.getDebut().getDebutMois();
    Damj b = periode.getDebut().getDebutMoisSuivant();
    Damj c = periode.getFin().getDebutMois();
    Damj d = periode.getFin().getDebutMoisSuivant();
    
    attribution.setCalendrierExecutionAvant(null);
    attribution.setCalendrierExecutionCalcul(null);
    ResultatExecutionCalcul resultatA = executerCalculDeterminationEtatDroit(attribution, a, true, false);
    attribution.setCalendrierExecutionAvant(null);
    attribution.setCalendrierExecutionCalcul(null);
    ResultatExecutionCalcul resultatB = executerCalculDeterminationEtatDroit(attribution, b, true, false);
    attribution.setCalendrierExecutionAvant(null);
    attribution.setCalendrierExecutionCalcul(null);
    ResultatExecutionCalcul resultatC = executerCalculDeterminationEtatDroit(attribution, c, true, false);
    attribution.setCalendrierExecutionAvant(null);
    attribution.setCalendrierExecutionCalcul(null);
    ResultatExecutionCalcul resultatD = executerCalculDeterminationEtatDroit(attribution, d, true, false);
    
    int nbJoursImputesAB = resultatB.getCumulJourIndemnise() - resultatA.getCumulJourIndemnise();
    if ((periode.getDebut().estApres(attribution.getCalendrierExecutionCalcul().getPremierJourIndemnisable())) && (!periode.getDebut().estLeDebutDuMois()))
    {
      BigDecimal prorata = Mathematiques.diviseASup(new BigDecimal(nbJoursImputesAB), new BigDecimal(b.joursEntre(a)), 2);
      
      nbJoursImputesAB = prorata.multiply(new BigDecimal(nbJoursImputesAB)).intValue();
    }
    int nbJoursImputesCD = resultatD.getCumulJourIndemnise() - resultatC.getCumulJourIndemnise();
    if ((periode.getFin().estAvant(attribution.getCalendrierExecutionCalcul().getDernierJourIndemnisable())) && (!periode.getFin().estLaFinDuMois()))
    {
      BigDecimal prorata = Mathematiques.diviseASup(new BigDecimal(nbJoursImputesCD), new BigDecimal(d.joursEntre(c)), 2);
      
      nbJoursImputesCD = prorata.multiply(new BigDecimal(nbJoursImputesCD)).intValue();
    }
    int nbJoursImputesBC = resultatC.getCumulJourIndemnise() - resultatB.getCumulJourIndemnise();
    
    return nbJoursImputesAB + nbJoursImputesBC + nbJoursImputesCD;
  }
  
  public int determinerNombreMoisIndemnise(AttributionSpec attributionSpec, Damj dateEtude)
    throws ApplicativeException
  {
    int retour = 0;
    ResultatDeterminationEtatDroitProduit resultatPendant = null;
    List listeAttributionsEntiere = null;
    List listeAttributionAExecutees = new ArrayList();
    Map mapCalendrier = null;
    
    resultatPendant = (ResultatDeterminationEtatDroit)AppelCalcul.executerCalculDeterminationEtatDroit(attributionSpec, dateEtude);
    if ((resultatPendant != null) && (resultatPendant.isEstNombreMoisIndemnisationAssuranceAlimente()))
    {
      retour = resultatPendant.getNombreMoisIndemnisationAssurance();
    }
    else if (listeAttributionPrecedenteContientAttributionNeutralisee(attributionSpec))
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_NB_MOIS_ASU_IMP_A_DETERMINER", 1);
    }
    else
    {
      listeAttributionsEntiere = attributionSpec.getDemandeur().getListeAttributionsExecutables();
      
      Damj dateAttributionOdOrigine = ((AttributionAssuranceSpec)attributionSpec).getOuvertureDroit().getDateAttribution();
      Iterator ite = listeAttributionsEntiere.iterator();
      while (ite.hasNext())
      {
        Damj dateAttribution = ((AttributionSpec)ite.next()).getDateAttribution();
        if (dateAttribution.estAvant(dateAttributionOdOrigine)) {
          ite.remove();
        }
      }
      Collections.sort(listeAttributionsEntiere, new ComparateurSurDateAttribution());
      
      Damj dateDebutExecution = ((DossierExamenSpec)listeAttributionsEntiere.get(0)).getDateDebut();
      AppelAvant.executerAvant(listeAttributionsEntiere, dateDebutExecution);
      
      Iterator iterateurAttributionsEntiere = listeAttributionsEntiere.iterator();
      List listeAttributionTraitee = new ArrayList();
      AttributionSpec attribution = null;
      AttributionSpec attributionPrecedente = null;
      List listAttribution = null;
      while (iterateurAttributionsEntiere.hasNext())
      {
        attribution = (AttributionSpec)iterateurAttributionsEntiere.next();
        
        listAttribution = ((DemandeSpec)attribution.getDemande().copie()).getListeDossiersExamen();
        Iterator iterator = listAttribution.iterator();
        while (iterator.hasNext())
        {
          DossierExamenSpec dossierExamen = (DossierExamenSpec)iterator.next();
          if ((dossierExamen instanceof AttributionSpec))
          {
            AttributionSpec attrib = (AttributionSpec)dossierExamen;
            if ((attribution instanceof PoursuiteSpec))
            {
              if (((PoursuiteSpec)attribution).getUniteTraitement() != null) {
                ((PoursuiteSpec)attrib).setUniteTraitement(((PoursuiteSpec)attribution).getUniteTraitement());
              }
              if (((PoursuiteSpec)attribution).getUniteTraitementAvant() != null) {
                ((PoursuiteSpec)attrib).setUniteTraitementAvant(((PoursuiteSpec)attribution).getUniteTraitementAvant());
              }
            }
            listeAttributionTraitee.add(attrib);
            listeAttributionAExecutees.add(attrib);
          }
        }
        Iterator iteratorDossierExamen = listAttribution.iterator();
        while (iteratorDossierExamen.hasNext())
        {
          DossierExamenSpec dossierExamen = (DossierExamenSpec)iteratorDossierExamen.next();
          if ((dossierExamen instanceof AttributionSpec))
          {
            attribution = (AttributionSpec)dossierExamen;
            if (((attribution instanceof AttributionAssuranceSpec)) && (((AttributionAssuranceSpec)attribution).getAttributionPrecedente() != null) && (attributionPrecedente != null)) {
              ((Demande)attribution.getDemande()).setDemandeOrigine((Demande)attributionPrecedente.getDemande());
            }
            mapCalendrier = MoteurCalcul.executerCalcul(dateDebutExecution, dateEtude, listeAttributionAExecutees, true, false);
            CalendrierExecutionCalculPeriodique calendrier = (CalendrierExecutionCalculPeriodique)mapCalendrier.get(attribution);
            
            attribution.setCalendrierExecutionCalcul(calendrier);
            if ((attribution instanceof AttributionAssuranceSpec)) {
              attributionPrecedente = attribution;
            }
          }
        }
      }
      for (int i = 1; i <= listeAttributionTraitee.size(); i++) {
        if (retour == 0)
        {
          attribution = (AttributionSpec)listeAttributionTraitee.get(listeAttributionTraitee.size() - i);
          CalendrierExecutionCalculPeriodique calendrier = (CalendrierExecutionCalculPeriodique)mapCalendrier.get(attribution);
          if (calendrier != null)
          {
            EtatAuDjiSpec etatAuDji = calendrier.getEtatAuDJI();
            if ((etatAuDji != null) && (etatAuDji.isEstNbMoisIndemniseAsu())) {
              retour = etatAuDji.getNbMoisIndemniseAsu();
            }
          }
        }
      }
    }
    return retour;
  }
  
  private boolean listeAttributionPrecedenteContientAttributionNeutralisee(AttributionSpec attributionSpec)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)attributionSpec;
    boolean estTrouve = false;
    boolean retour = false;
    while ((!estTrouve) && (!retour)) {
      if (attribution != null)
      {
        if (attribution.estNeutralise()) {
          retour = true;
        } else if ((attribution instanceof OdSpec)) {
          estTrouve = true;
        } else {
          attribution = attribution.getAttributionPrecedente();
        }
      }
      else {
        estTrouve = true;
      }
    }
    return retour;
  }
  
  public Damj recupererDateFinDroitTheorique(AttributionSpec attributionSpec)
    throws CoucheLogiqueException
  {
    FacadeCalculProduitSpec facadeCalculProduit = null;
    facadeCalculProduit = FacadeCalculProduitFactory.getInstance().getInstanceGestionnaireCalculProduit(attributionSpec.getProduitExecution());
    
    return facadeCalculProduit.recupererDateFinDroitTheorique(attributionSpec.getCalendrierExecutionCalcul(), attributionSpec);
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec attributionSpec, Damj dateCalcul)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Boolean determinerReliquatValide(AttributionSpec attribution, Damj dateRecherche)
    throws CoucheLogiqueException
  {
    Quantite reliquat = null;
    Boolean resultat = null;
    if ((!((Demande)attribution.getDemande()).estUneDemandeFinDroit()) && (attribution.getCalendrierExecutionCalcul() != null) && (attribution.getCalendrierExecutionCalcul().getEtatAuDJI() != null))
    {
      EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attribution.getCalendrierExecutionCalcul().getEtatAuDJI();
      reliquat = etatAuDji.getReliquatDureeIndemnisation();
      if (dateRecherche.estApres(attribution.getCalendrierExecutionCalcul().getDernierJourIndemnisable())) {
        resultat = reliquatValide(reliquat);
      } else {
        resultat = Boolean.TRUE;
      }
    }
    else if (((ProduitAsuSpec)attribution.getProduit()).estUnProduitSansDuree())
    {
      if ((dateRecherche.estApres(((AttributionAssuranceSpec)attribution).getDateLimiteIndemnisation())) && (attribution.getCalendrierExecutionCalcul() != null) && (attribution.getCalendrierExecutionCalcul().getEtatAuDJI() != null))
      {
        EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attribution.getCalendrierExecutionCalcul().getEtatAuDJI();
        reliquat = etatAuDji.getReliquatDureeIndemnisation();
        resultat = reliquatValide(reliquat);
      }
      else
      {
        resultat = Boolean.TRUE;
      }
    }
    else
    {
      reliquat = ((AttributionAssuranceSpec)attribution).getDureeIndemnisationInitiale();
      resultat = reliquatValide(reliquat);
    }
    return resultat;
  }
  
  private Boolean reliquatValide(Quantite reliquat)
  {
    if ((reliquat != null) && (BigDecimal.ZERO.compareTo(reliquat.getValeur()) < 0)) {
      return Boolean.TRUE;
    }
    return Boolean.FALSE;
  }
  
  public Damj recupererDateDrv(AttributionSpec attributionSpec)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
  
  public Damj recupererDateEpuisementDuree(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitPourLiquidationAsuAbstraite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */