package fr.unedic.cali.asu.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.calcul.dom.periode.Pans;
import fr.unedic.cali.calcul.dom.periode.PansMensuel;
import fr.unedic.cali.calcul.dom.periode.PansNonInstallee;
import fr.unedic.cali.calcul.dom.periode.PansSpec;
import fr.unedic.cali.calcul.dom.periode.PansSupraMensuel;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FilltrePeriodeTravailCalculPANSNonRemuneree;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculCES;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculDeclaree;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculHorsCES;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculHorsPANS;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculHorsPANSNonInstallee;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculJustifiee;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculPANS;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculPANSMensuel;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculPANSNonInstallee;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalculPANSSupraMensuel;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.fabriques.FabriqueStrategieDeterminationPriseEnCompteGainsSurPANS;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieDeterminationPriseEnCompteGainSurPansSpec;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class DeterminerStatutCasGeneral
  extends DefinitionStatutUtTraitementActiviteReduite
{
  private static final BigDecimal PIVOT_DECLARE = new BigDecimal("0.90");
  
  public static int definirStatutUtPourCasGeneralAvantGestionPansMensuelEtSupra(ChronologiePeriodes periodesDecalantes, Periode periodeUt, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    int statut = 2;
    if (periodesDecalantes.estVide())
    {
      statut = 3;
    }
    else if (estActualiseMaintienEuropeen(periodesDecalantes, periodeUt, attribution))
    {
      BigDecimal totalGainsJustifiees = BigDecimal.ZERO;
      BigDecimal totalGainsDeclares = BigDecimal.ZERO;
      BigDecimal totalHeuresJustifiees = BigDecimal.ZERO;
      BigDecimal totalHeuresDeclarees = BigDecimal.ZERO;
      BigDecimal totalGainsDeclaresCES = BigDecimal.ZERO;
      BigDecimal totalHeuresDeclareesCES = BigDecimal.ZERO;
      boolean pansAuForfait = false;
      boolean unHorsCESOuDSMTravail = true;
      boolean unCESavecDSMTravail = false;
      boolean existePans = false;
      boolean pansSeulSurMois = false;
      ChronologiePeriodes periodesDeclarees = null;
      ChronologiePeriodes periodesJustifiees = null;
      ChronologiePeriodes periodesCES = null;
      ChronologiePeriodes periodesPANS = null;
      ChronologiePeriodes periodesPANSNonInstallees = null;
      
      periodesDeclarees = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculDeclaree());
      
      periodesJustifiees = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculJustifiee()).copier(new FiltrePeriodeTravailCalculHorsCES());
      
      unHorsCESOuDSMTravail = (!periodesJustifiees.estVide()) || (!periodesDeclarees.estVide());
      
      periodesJustifiees = (ChronologiePeriodes)periodesJustifiees.copier(new FiltrePeriodeTravailCalculHorsPANS()).copier(new FiltrePeriodeTravailCalculHorsPANSNonInstallee());
      
      periodesCES = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculCES());
      
      periodesPANS = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculPANS());
      
      periodesPANSNonInstallees = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculPANSNonInstallee());
      pansSeulSurMois = periodesJustifiees.estVide();
      
      unCESavecDSMTravail = (!periodesCES.estVide()) && (!periodesDeclarees.estVide());
      
      periodesCES.iterer();
      while (periodesCES.encoreSuivant())
      {
        PeriodeTravail periodeCES = (PeriodeTravail)periodesCES.elementSuivant();
        totalGainsDeclaresCES = totalGainsDeclaresCES.add(periodeCES.getGain());
        totalHeuresDeclareesCES = totalHeuresDeclareesCES.add(periodeCES.getNombreHeures());
      }
      periodesDeclarees.iterer();
      while (periodesDeclarees.encoreSuivant())
      {
        PeriodeTravail periodeDeclaree = (PeriodeTravail)periodesDeclarees.elementSuivant();
        totalGainsDeclares = totalGainsDeclares.add(periodeDeclaree.getGain());
        totalHeuresDeclarees = totalHeuresDeclarees.add(periodeDeclaree.getNombreHeures());
      }
      if ((unCESavecDSMTravail) && (totalGainsDeclares.compareTo(totalGainsDeclaresCES) < 0))
      {
        totalGainsDeclares = totalGainsDeclaresCES;
        totalHeuresDeclarees = totalHeuresDeclareesCES;
      }
      effectuerConversionHeureNonRenseigne(periodesJustifiees, periodeUt.getDebut(), attribution);
      
      periodesJustifiees.iterer();
      while (periodesJustifiees.encoreSuivant())
      {
        PeriodeTravail paec = (PeriodeTravail)periodesJustifiees.elementSuivant();
        totalGainsJustifiees = totalGainsJustifiees.add(paec.getGain());
        totalHeuresJustifiees = totalHeuresJustifiees.add(paec.getNombreHeures());
      }
      periodesPANS.iterer();
      while (periodesPANS.encoreSuivant())
      {
        Pans pansCalcul = (Pans)periodesPANS.elementSuivant();
        if ((pansCalcul.estForfait()) && (!determinerPriseEnCompteGainsSurPANS(periodeUt.getDebut())))
        {
          pansAuForfait = true;
        }
        else
        {
          totalGainsJustifiees = totalGainsJustifiees.add(pansCalcul.getGain());
          if (pansCalcul.getNombreHeures() != null) {
            totalHeuresJustifiees = totalHeuresJustifiees.add(pansCalcul.getNombreHeures());
          }
        }
        existePans = true;
      }
      periodesPANSNonInstallees.iterer();
      while (periodesPANSNonInstallees.encoreSuivant())
      {
        PansNonInstallee pans = (PansNonInstallee)periodesPANSNonInstallees.elementSuivant();
        totalGainsJustifiees = totalGainsJustifiees.add(pans.getGain());
        if (pans.getNombreHeures() != null) {
          totalHeuresJustifiees = totalHeuresJustifiees.add(pans.getNombreHeures());
        }
        existePans = true;
      }
      BigDecimal cumulGainPrimes = calculGainPrimes(periodeUt, periodesDecalantes);
      
      totalGainsJustifiees = totalGainsJustifiees.add(totalGainsDeclaresCES).add(cumulGainPrimes);
      totalHeuresJustifiees = totalHeuresJustifiees.add(totalHeuresDeclareesCES);
      
      periodesJustifiees.iterer();
      PeriodeTravail periodeCourante = null;
      boolean catPat = false;
      boolean trouve = false;
      while ((periodesJustifiees.encoreSuivant()) && (!trouve))
      {
        periodeCourante = (PeriodeTravail)periodesJustifiees.elementSuivant();
        if ((periodeCourante instanceof PeriodeActiviteEmploiCalcul))
        {
          catPat = ActiviteReduite.estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante);
          if (!catPat) {
            trouve = true;
          }
        }
      }
      CritereStrategie critereStrategie = new CritereStrategie();
      critereStrategie.setDatePivot(periodeUt.getDebut());
      StrategieDeterminationPriseEnCompteGainSurPansSpec strategieDeterminationGainsPansSurUT = (StrategieDeterminationPriseEnCompteGainSurPansSpec)FabriqueStrategieDeterminationPriseEnCompteGainsSurPANS.getInstance().getStrategie(critereStrategie);
      if (pansAuForfait) {
        statut = 3;
      } else if (((strategieDeterminationGainsPansSurUT.comparerGainsHeuresDeclareJustifie(attribution.getProduit(), periodeUt.getDebut(), pansSeulSurMois, totalGainsJustifiees, totalGainsDeclares, totalHeuresJustifiees, totalHeuresDeclarees)) && (determinerPresenceGainHeureJustifiees(totalGainsJustifiees, totalHeuresJustifiees, existePans, periodeUt.getDebut(), catPat))) || (!unHorsCESOuDSMTravail)) {
        statut = 3;
      } else if ((totalGainsDeclares.compareTo(BigDecimal.ZERO) == 0) || (totalHeuresDeclarees.compareTo(BigDecimal.ZERO) == 0)) {
        statut = 4;
      }
    }
    else
    {
      statut = 4;
    }
    return statut;
  }
  
  public static int definirStatutUtPourCasGeneralApresGestionPansMensuelEtSupra(ChronologiePeriodes periodesDecalantes, Periode periodeUt, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    int statut = 2;
    
    ChronologiePeriodes periodeDecalantesSansPansNonRemuneree = (ChronologiePeriodes)periodesDecalantes.copier(new FilltrePeriodeTravailCalculPANSNonRemuneree());
    if (periodeDecalantesSansPansNonRemuneree.estVide())
    {
      statut = 3;
    }
    else if (estActualiseMaintienEuropeen(periodesDecalantes, periodeUt, attribution))
    {
      BigDecimal totalGainsJustifiees = BigDecimal.ZERO;
      BigDecimal totalGainsDeclares = BigDecimal.ZERO;
      BigDecimal totalHeuresJustifiees = BigDecimal.ZERO;
      BigDecimal totalHeuresDeclarees = BigDecimal.ZERO;
      BigDecimal totalGainsDeclaresCES = BigDecimal.ZERO;
      BigDecimal totalHeuresDeclareesCES = BigDecimal.ZERO;
      boolean pansAuForfait = false;
      boolean unHorsCESOuDSMTravail = true;
      boolean unCESavecDSMTravail = false;
      boolean existePans = false;
      boolean psmSeuleSurMois = false;
      boolean presencePansSupraMensuelEnAttenteDeRegule = false;
      boolean pansMensuelSansJustificatif = false;
      boolean presencePM = false;
      ChronologiePeriodes periodesDeclarees = null;
      ChronologiePeriodes periodesJustifiees = null;
      ChronologiePeriodes periodesCES = null;
      ChronologiePeriodes periodesPANS = null;
      ChronologiePeriodes periodesPANSNonInstallees = null;
      ChronologiePeriodes chronoPansMensuel = null;
      ChronologiePeriodes chronoPansSupraMensuel = null;
      ChronologiePeriodes chronoPansNonRemuneree = null;
      
      periodesDeclarees = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculDeclaree());
      
      periodesJustifiees = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculJustifiee()).copier(new FiltrePeriodeTravailCalculHorsCES());
      
      unHorsCESOuDSMTravail = (!periodesJustifiees.estVide()) || (!periodesDeclarees.estVide());
      
      periodesJustifiees = (ChronologiePeriodes)periodesJustifiees.copier(new FiltrePeriodeTravailCalculHorsPANS()).copier(new FiltrePeriodeTravailCalculHorsPANSNonInstallee());
      
      periodesCES = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculCES());
      
      periodesPANS = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculPANS());
      
      chronoPansMensuel = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculPANSMensuel());
      
      chronoPansSupraMensuel = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculPANSSupraMensuel());
      
      periodesPANSNonInstallees = (ChronologiePeriodes)periodesDecalantes.copier(new FiltrePeriodeTravailCalculPANSNonInstallee());
      
      chronoPansNonRemuneree = (ChronologiePeriodes)periodesDecalantes.copier(new FiltreNegation(new FilltrePeriodeTravailCalculPANSNonRemuneree()));
      psmSeuleSurMois = periodesJustifiees.estVide();
      
      unCESavecDSMTravail = (!periodesCES.estVide()) && (!periodesDeclarees.estVide());
      
      periodesCES.iterer();
      while (periodesCES.encoreSuivant())
      {
        PeriodeTravail periodeCES = (PeriodeTravail)periodesCES.elementSuivant();
        totalGainsDeclaresCES = totalGainsDeclaresCES.add(periodeCES.getGain());
        totalHeuresDeclareesCES = totalHeuresDeclareesCES.add(periodeCES.getNombreHeures());
      }
      periodesDeclarees.iterer();
      while (periodesDeclarees.encoreSuivant())
      {
        PeriodeTravail periodeDeclaree = (PeriodeTravail)periodesDeclarees.elementSuivant();
        totalGainsDeclares = totalGainsDeclares.add(periodeDeclaree.getGain());
        totalHeuresDeclarees = totalHeuresDeclarees.add(periodeDeclaree.getNombreHeures());
      }
      if ((unCESavecDSMTravail) && (totalGainsDeclares.compareTo(totalGainsDeclaresCES) < 0))
      {
        totalGainsDeclares = totalGainsDeclaresCES;
        totalHeuresDeclarees = totalHeuresDeclareesCES;
      }
      effectuerConversionHeureNonRenseigne(periodesJustifiees, periodeUt.getDebut(), attribution);
      
      periodesJustifiees.iterer();
      while (periodesJustifiees.encoreSuivant())
      {
        PeriodeTravail paec = (PeriodeTravail)periodesJustifiees.elementSuivant();
        totalGainsJustifiees = totalGainsJustifiees.add(paec.getGain());
        totalHeuresJustifiees = totalHeuresJustifiees.add(paec.getNombreHeures());
      }
      periodesPANS.iterer();
      while (periodesPANS.encoreSuivant())
      {
        Pans pansCalcul = (Pans)periodesPANS.elementSuivant();
        if ((pansCalcul.estForfait()) && (!determinerPriseEnCompteGainsSurPANS(periodeUt.getDebut())))
        {
          pansAuForfait = true;
        }
        else
        {
          totalGainsJustifiees = totalGainsJustifiees.add(pansCalcul.getGain());
          if (pansCalcul.getNombreHeures() != null) {
            totalHeuresJustifiees = totalHeuresJustifiees.add(pansCalcul.getNombreHeures());
          }
        }
        existePans = true;
      }
      periodesPANSNonInstallees.iterer();
      while (periodesPANSNonInstallees.encoreSuivant())
      {
        PansNonInstallee pans = (PansNonInstallee)periodesPANSNonInstallees.elementSuivant();
        totalGainsJustifiees = totalGainsJustifiees.add(pans.getGain());
        if (pans.getNombreHeures() != null) {
          totalHeuresJustifiees = totalHeuresJustifiees.add(pans.getNombreHeures());
        }
        existePans = true;
      }
      chronoPansMensuel.iterer();
      while (chronoPansMensuel.encoreSuivant())
      {
        PansMensuel pansMensuel = (PansMensuel)chronoPansMensuel.elementSuivant();
        presencePM = true;
        if ((pansMensuel.isGainsSurPeriodePresent()) || ((attribution.getDemandeur().getDernierJourAtteste() != null) && (attribution.getDemandeur().getDernierJourAtteste().estAvant(pansMensuel.getDateDebut())))) {
          existePans = true;
        } else {
          pansMensuelSansJustificatif = true;
        }
      }
      chronoPansSupraMensuel.iterer();
      while (chronoPansSupraMensuel.encoreSuivant())
      {
        PansSupraMensuel pansSupraMensuel = (PansSupraMensuel)chronoPansSupraMensuel.elementSuivant();
        if (!estUnePansConservee(pansSupraMensuel, attribution))
        {
          if (pansSupraMensuel.isGainsSurPeriodePresent()) {
            existePans = true;
          } else {
            presencePansSupraMensuelEnAttenteDeRegule = true;
          }
        }
        else {
          existePans = true;
        }
      }
      if (!chronoPansNonRemuneree.estVide()) {
        existePans = true;
      }
      BigDecimal cumulGainPrimes = calculGainPrimes(periodeUt, periodesDecalantes);
      
      totalGainsJustifiees = totalGainsJustifiees.add(totalGainsDeclaresCES).add(cumulGainPrimes);
      totalHeuresJustifiees = totalHeuresJustifiees.add(totalHeuresDeclareesCES);
      
      periodesJustifiees.iterer();
      PeriodeTravail periodeCourante = null;
      boolean estCategorieEmploiAnnexe1 = false;
      boolean trouve = false;
      while ((periodesJustifiees.encoreSuivant()) && (!trouve))
      {
        periodeCourante = (PeriodeTravail)periodesJustifiees.elementSuivant();
        if ((periodeCourante instanceof PeriodeActiviteEmploiCalcul))
        {
          estCategorieEmploiAnnexe1 = ActiviteReduite.estCategorieEmploiAnnexe1((PeriodeActiviteEmploiCalcul)periodeCourante);
          if (!estCategorieEmploiAnnexe1) {
            trouve = true;
          }
        }
      }
      if ((psmSeuleSurMois) && (presencePansSupraMensuelEnAttenteDeRegule) && (verifierPresenceGainDeclareEgaleZero(totalGainsDeclares, totalHeuresDeclarees))) {
        statut = 8;
      } else if (pansAuForfait) {
        statut = 3;
      } else if (((comparerGainsHeureJustifie(periodeUt.getDebut(), existePans, totalGainsJustifiees, totalGainsDeclares, totalHeuresJustifiees, totalHeuresDeclarees)) && (verifierPresenceGainHeureJustifiees(totalGainsJustifiees, totalHeuresJustifiees, existePans, periodeUt.getDebut(), estCategorieEmploiAnnexe1, pansMensuelSansJustificatif))) || (!unHorsCESOuDSMTravail))
      {
        if (presencePansSupraMensuelEnAttenteDeRegule) {
          statut = 8;
        } else {
          statut = 3;
        }
      }
      else if (estDSMCoherente(totalGainsDeclares, totalHeuresDeclarees, presencePM)) {
        statut = 4;
      } else if (presencePansSupraMensuelEnAttenteDeRegule) {
        statut = 10;
      }
    }
    else
    {
      statut = 4;
    }
    return statut;
  }
  
  private static boolean comparerGainsHeureJustifie(Damj datePivot, boolean pansSurMoisSeul, BigDecimal totalGainsJustifiees, BigDecimal totalGainsDeclares, BigDecimal totalHeuresJustifiees, BigDecimal totalHeuresDeclarees)
  {
    if (pansSurMoisSeul) {
      return totalGainsJustifiees.compareTo(totalGainsDeclares.multiply(PIVOT_DECLARE)) >= 0;
    }
    if (totalGainsDeclares.compareTo(BigDecimal.ZERO) == 0) {
      return totalHeuresJustifiees.compareTo(totalHeuresDeclarees.multiply(PIVOT_DECLARE)) >= 0;
    }
    return totalGainsJustifiees.compareTo(totalGainsDeclares.multiply(PIVOT_DECLARE)) >= 0;
  }
  
  private static boolean estUnePansConservee(PansSpec pansSupraMensuelle, AttributionSpec attribution)
  {
    boolean estPeriodeConservee = false;
    Chronologie chronoPeriodesConserveesLiq = ((Attribution)attribution).getListeActiviteConservee();
    chronoPeriodesConserveesLiq.iterer();
    while ((chronoPeriodesConserveesLiq.encoreSuivant()) && (!estPeriodeConservee))
    {
      TravailSpec periodeConserveeLiq = (TravailSpec)chronoPeriodesConserveesLiq.elementSuivant();
      if ((periodeConserveeLiq != null) && 
        (periodeConserveeLiq.getIdentifiant().equals(pansSupraMensuelle.getIdentifiant()))) {
        estPeriodeConservee = true;
      }
    }
    return estPeriodeConservee;
  }
  
  private static boolean verifierDeclareHeureOuGainAZero(BigDecimal totalGainsDeclares, BigDecimal totalHeuresDeclarees)
  {
    return (totalGainsDeclares.compareTo(BigDecimal.ZERO) == 0) || (totalHeuresDeclarees.compareTo(BigDecimal.ZERO) == 0);
  }
  
  private static boolean verifierPresenceGainDeclareEgaleZero(BigDecimal totalGainsDeclares, BigDecimal totalHeuresDeclarees)
  {
    return totalGainsDeclares.compareTo(BigDecimal.ZERO) == 0;
  }
  
  private static boolean estDSMCoherente(BigDecimal totalGainsDeclares, BigDecimal totalHeuresDeclarees, boolean presencePM)
  {
    if (presencePM) {
      return totalGainsDeclares.compareTo(BigDecimal.ZERO) == 0;
    }
    return verifierDeclareHeureOuGainAZero(totalGainsDeclares, totalHeuresDeclarees);
  }
}

/* Location:
 * Qualified Name:     DeterminerStatutCasGeneral
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */