package fr.unedic.cali.asu.cge01.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.asu.calcul.dom.DureeProlongation;
import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.dom.temps.ObjectChronoFinChomageSansRct;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeCarences;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodePreavis;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsMaintienEuropeenEessiASU;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCarence;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.Differe;
import fr.unedic.cali.asu.produits.liquidation.dom.ElementChomageSansRupture;
import fr.unedic.cali.asu.produits.liquidation.dom.Poursuite;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.autresdoms.cohab.dom.PeriodeSousPensionInvaliditeChainee;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.OutillageQuantites;
import fr.unedic.cali.calcul.RecuperationDonneesSecteurPublic;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EvenementFinPeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.EvenementLimiteIndemnisationChomageSansRCT;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.FinPeriodePensionInvaliditeChainee;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationPMVS;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationSanctionReduction;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeEvenementPersonnel;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.FormuleMontantAREFSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class FacadeCalculLigneSansTrancheImpl
  extends FacadeCalculLigneImpl
{
  private static FacadeCalculLigneSansTrancheImpl s_instance = new FacadeCalculLigneSansTrancheImpl();
  private static final int SEUIL_MOIS_NI = 3;
  
  public static FacadeCalculLigneSansTrancheImpl getInstance()
  {
    return s_instance;
  }
  
  public ConstituantsIndemnisation creationConstituantsIndemnisation(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    ElementChomageSansRupture elementChomageSansRupture = ((Attribution)attribution).getElementChomageSansRupture();
    if ((elementChomageSansRupture != null) && (estDemandeEnContexteDeChomageEnCoursDeSuspension(attribution))) {
      return creationConstituantsIndemnisationCsr(attribution);
    }
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    Collection collectionDurees = null;
    if ((attribution instanceof Poursuite)) {
      collectionDurees = new ArrayList(((Poursuite)attribution).getUniteTraitement().getConstituantsIndemnisationEnFinUT().getCollectionQuantiteDroit());
    } else {
      collectionDurees = new ArrayList(((Attribution)attribution).getListeDurees());
    }
    constituantsIndemnisation.setCollectionQuantiteDroit(collectionDurees);
    return constituantsIndemnisation;
  }
  
  protected ConstituantsIndemnisation creationConstituantsIndemnisationCsr(AttributionSpec pattribution)
    throws CoucheLogiqueException
  {
    Iterator iterator = null;
    QuantiteDroitSpec duree = null;
    
    Collection collectionDurees = new ArrayList(((Attribution)pattribution).getListeDurees());
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    
    boolean estUnContexteDeRupturePendantSuspension = estUnContexteDeRupturePendantSuspension(pattribution);
    
    iterator = collectionDurees.iterator();
    while (iterator.hasNext())
    {
      duree = (QuantiteDroitSpec)iterator.next();
      if ((!(duree instanceof DureeProlongation)) || (!estUnContexteDeRupturePendantSuspension))
      {
        List listeDureeProlongation = new ArrayList();
        listeDureeProlongation.add(duree);
        constituantsIndemnisation.ajouterQuantiteDroit(listeDureeProlongation, duree);
      }
    }
    if (((pattribution instanceof Reprise)) && (!estUnContexteDeRupturePendantSuspension))
    {
      Attribution attribution = (Attribution)pattribution;
      AttributionAssuranceSpec attributionPrecedente = attribution.getAttributionPrecedente();
      
      boolean estUneAttributionPrecedenteAvecContexteDeCSR = estDemandeEnContexteDeChomageEnCoursDeSuspension(attributionPrecedente);
      
      ElementChomageSansRupture elementChomageSansRupture = ((Attribution)pattribution).getElementChomageSansRupture();
      if ((elementChomageSansRupture != null) && (!elementChomageSansRupture.getDecisionProlongation())) {
        if ((elementChomageSansRupture.getDateRepriseActivite() != null) && (pattribution.getDateAttribution().estAvant(elementChomageSansRupture.getDateRepriseActivite())))
        {
          EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI();
          if ((etatAuDji != null) && (estUneAttributionPrecedenteAvecContexteDeCSR) && (etatAuDji.getReliquatDureeProlongation().getValeurEntiere() != 0))
          {
            List listeDureeProlongation = new ArrayList();
            DureeProlongation dureeProlongation = new DureeProlongation(etatAuDji.getReliquatDureeProlongation().getValeurEntiere());
            listeDureeProlongation.add(dureeProlongation);
            constituantsIndemnisation.ajouterQuantiteDroit(listeDureeProlongation, dureeProlongation);
          }
          else if (etatAuDji != null)
          {
            List listeDureeProlongation = new ArrayList();
            DureeProlongation dureeProlongation = new DureeProlongation(Math.min(182, etatAuDji.getReliquatDureeIndemnisationAvecMaintien().getValeurEntiere()));
            
            listeDureeProlongation.add(dureeProlongation);
            constituantsIndemnisation.ajouterQuantiteDroit(listeDureeProlongation, dureeProlongation);
          }
        }
      }
    }
    return constituantsIndemnisation;
  }
  
  public ConstituantsCalculActiviteReduiteSpec creationConstituantsCalculActiviteReduite(AttributionSpec pattribution, ContexteUT contexteUT, ConstituantsIndemnisation constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    int cumulAR = 0;
    int cumulMoisNi = 0;
    Attribution attribution = (Attribution)pattribution;
    if ((attribution instanceof Poursuite))
    {
      cumulAR = ((Poursuite)attribution).getUniteTraitement().getConstituantsCalculActiviteReduiteEnFinUT().getCumul();
      cumulMoisNi = ((Poursuite)attribution).getUniteTraitement().getConstituantsCalculActiviteReduiteEnFinUT().getCumulMoisNonIndemnise();
    }
    else
    {
      AttributionSpec attributionPrecedente = null;
      boolean aTrouveAttributionNonRadieePendantAvant = false;
      if (((attribution instanceof RepriseSpec)) || ((attribution instanceof RevisionSpec)))
      {
        attributionPrecedente = attribution.getAttributionPrecedente();
        if ((attributionPrecedente != null) && (attributionPrecedente.getCalendrierExecutionCalcul() != null) && (attributionPrecedente.getCalendrierExecutionCalcul().getDernierJourIndemnisable().lendemain().coincideAvec(attribution.getDateAttribution())) && (!attribution.estDemandeDrv()))
        {
          EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attributionPrecedente.getCalendrierExecutionCalcul().getEtatAuDJI();
          if ((etatAuDji != null) && (((etatAuDji.getCumulMoisnonIndemnise() < 3) && ((attribution instanceof RepriseSpec))) || ((attribution instanceof RevisionSpec)))) {
            cumulMoisNi = etatAuDji.getCumulMoisnonIndemnise();
          }
        }
        AttributionSpec attributionPrecedenteAUtiliserPourCumulAR = attributionPrecedente;
        if ((attributionPrecedente.getTypeExamen().equals("ASU_17")) || ((attribution.getAttributionPrecedente().getTypeExamen().equals("ASU_25")) && (!(attributionPrecedente instanceof RepriseSpec)))) {
          attributionPrecedenteAUtiliserPourCumulAR = OutilFinDroit.rechercherAttributionCorrespondantePecedente(attributionPrecedente.getDemande());
        } else if (attribution.getAttributionPrecedente().getTypeExamen().equals("ASU_25")) {
          attributionPrecedenteAUtiliserPourCumulAR = ((Attribution)attributionPrecedente).getAttributionPrecedente();
        }
        while (!aTrouveAttributionNonRadieePendantAvant) {
          if ((attributionPrecedenteAUtiliserPourCumulAR != null) && (attributionPrecedenteAUtiliserPourCumulAR.getCalendrierExecutionCalcul() != null) && (attributionPrecedenteAUtiliserPourCumulAR.getCalendrierExecutionCalcul().getEtatAuDJI() != null))
          {
            aTrouveAttributionNonRadieePendantAvant = true;
            EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)attributionPrecedenteAUtiliserPourCumulAR.getCalendrierExecutionCalcul().getEtatAuDJI();
            cumulAR = etatAuDji.getCumulMoisActiviteReduite();
            
            boolean existeAttributionPrecedenteAvecCumulAr = existeAttributionPrecedenteAvecCumulAr(attribution, contexteUT);
            if (existeAttributionPrecedenteAvecCumulAr) {
              cumulAR--;
            }
          }
          else if (!(attributionPrecedenteAUtiliserPourCumulAR instanceof OdSpec))
          {
            attributionPrecedenteAUtiliserPourCumulAR = ((Attribution)attributionPrecedenteAUtiliserPourCumulAR).getAttributionPrecedente();
          }
          else
          {
            aTrouveAttributionNonRadieePendantAvant = true;
          }
        }
      }
      BigDecimal cumulMoisARMigre = ((AttributionAssuranceSpec)pattribution).getCumulMoisActiviteReduite();
      if (cumulMoisARMigre != null) {
        cumulAR = cumulMoisARMigre.intValue();
      }
    }
    ConstituantsCalculActiviteReduiteAsu constituantsCalculActiviteReduite = new ConstituantsCalculActiviteReduiteAsu(cumulAR, attribution.getElementBaseIndemnisation().getSjr(), attribution.getSJC());
    
    constituantsCalculActiviteReduite.setCumulMoisNonIndemnise(cumulMoisNi);
    
    return constituantsCalculActiviteReduite;
  }
  
  public void initialiseElementBaseIndemnisationCourante(ConstituantsIndemnisation constituantsIndemnisation, AttributionSpec pattribution, Periode periodeUT)
    throws CoucheLogiqueException
  {
    if (constituantsIndemnisation.getElementBaseIndemnisationCourant() == null)
    {
      Attribution attribution = (Attribution)pattribution;
      ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
      ElementBaseIndemnisation ebiAttrib = attribution.getElementBaseIndemnisation();
      
      Reglement reglementApplicable = ebiAttrib.getReglementApplicable();
      if (reglementApplicable != null) {
        elementBaseIndemnisationCourant.setReglementApplicable(reglementApplicable);
      }
      Quantite affiliationRequisePourPRA = ebiAttrib.getAffiliationRequisePourPRA();
      if (affiliationRequisePourPRA != null) {
        elementBaseIndemnisationCourant.setAffiliationRequisePourPRA(affiliationRequisePourPRA);
      }
      SalaireReference salaireReference = ebiAttrib.getSalaireReference();
      if (salaireReference != null) {
        elementBaseIndemnisationCourant.setSalaireReference(salaireReference);
      }
      BigDecimal nombreHeureTravaillesEtendu = ebiAttrib.getNombreHeureTravaillesEtendu();
      if (nombreHeureTravaillesEtendu != null) {
        elementBaseIndemnisationCourant.setNombreHeureTravaillesEtendu(nombreHeureTravaillesEtendu);
      }
      BigDecimal nombreHeuresTravailleesPlafonnees = ebiAttrib.getNombreHeuresTravailleesPlafonnees();
      if (nombreHeuresTravailleesPlafonnees != null) {
        elementBaseIndemnisationCourant.setNombreHeuresTravailleesPlafonnees(nombreHeuresTravailleesPlafonnees);
      }
      Periode prc = ebiAttrib.getPrc();
      if (prc != null) {
        elementBaseIndemnisationCourant.setPrc(prc);
      }
      elementBaseIndemnisationCourant.setNbJoursEmploiSurPrc(ebiAttrib.getNbJoursEmploiSurPrc());
      elementBaseIndemnisationCourant.setCoefficientHoraireJour(ebiAttrib.getCoefficientHoraireJour());
      
      constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
      if (attribution.getElementBaseIndemnisation().getCoefficientSaisonnier() != null) {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(attribution.getElementBaseIndemnisation().getCoefficientSaisonnier());
      } else {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(BigDecimal.ONE);
      }
      if (attribution.getElementBaseIndemnisation().getCoefficientTempsPartiel() != null) {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(attribution.getElementBaseIndemnisation().getCoefficientTempsPartiel());
      } else {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(BigDecimal.ONE);
      }
      elementBaseIndemnisationCourant.setSjr((Sjr)attribution.getElementBaseIndemnisation().getSjr().copie());
      elementBaseIndemnisationCourant.setSjc((Sjc)attribution.getSJC().copie());
      elementBaseIndemnisationCourant.setSjrInitial((Sjr)attribution.getElementBaseIndemnisation().getSjr().copie());
      elementBaseIndemnisationCourant.setSjcInitial((Sjc)attribution.getSJC().copie());
      elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
      
      elementBaseIndemnisationCourant.setListePensionInvalidite(ebiAttrib.getListePensionInvalidite());
      determinerMontantPensionInvaliditeADeduire(elementBaseIndemnisationCourant, attribution.getDemandeur(), recupererPremierJourExecutableNcp(pattribution).veille(), attribution.getDateAttribution());
      
      PeriodeAvantageVieillesse periodeAvCourante = recupererPeriodeAv(attribution, null);
      BigDecimal montantAV = new BigDecimal(0);
      Damj dateRevalorisation = pattribution.getDateAttribution();
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(recupererPremierJourExecutableNcp(pattribution));
        dateRevalorisation = Damj.max(pattribution.getDateAttribution(), periodeAvCourante.getDateDebut());
      }
      elementBaseIndemnisationCourant.setDateMaintienEuropeen(OutilsMaintienEuropeenEessiASU.rechercherDateMaintienEuropeen(pattribution, periodeUT, constituantsIndemnisation));
      
      Sjr sjrrp = RevalorisationSalaire.revaloriserSjr(attribution.getElementBaseIndemnisation(), attribution.getProduitMontantRetenu(), dateRevalorisation);
      
      BigDecimal coeffAV = montantAV.divide(sjrrp.getSalaire(), 10, 4);
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrrp.getSalaire()));
      
      elementBaseIndemnisationCourant.setTypeCaractereSaisonnierRetenu(attribution.getElementBaseIndemnisation().getTypeCaractereSaisonnierRetenu());
      
      elementBaseIndemnisationCourant.setIsConditionCaractereSaisonnierParRythme(attribution.getElementBaseIndemnisation().isConditionCaractereSaisonnierParRythme());
      
      elementBaseIndemnisationCourant.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
      elementBaseIndemnisationCourant.setDureeInitialeMaintien(attribution.getDureeTheorique());
      elementBaseIndemnisationCourant.setListeCarences(attribution.getListeCarences());
      elementBaseIndemnisationCourant.setConventionGestion(attribution.getConventionGestion());
      elementBaseIndemnisationCourant.setCapitalRetenuCourant(attribution.isCapitalRetenuCourant());
      elementBaseIndemnisationCourant.setMontantRetenuCourant(attribution.isMontantRetenuCourant());
      if ((attribution.getListeDurees() != null) && (!attribution.getListeDurees().isEmpty()))
      {
        QuantiteDroit durees = null;
        Iterator iterDuree = attribution.getListeDurees().iterator();
        while (iterDuree.hasNext())
        {
          durees = (QuantiteDroit)iterDuree.next();
          elementBaseIndemnisationCourant.getListeDurees().add(durees.copie());
        }
      }
      elementBaseIndemnisationCourant.setDureeProlongationTheorique(attribution.getDureeProlongationTheorique());
      elementBaseIndemnisationCourant.setElementChomageSansRupture(attribution.getElementChomageSansRupture());
      elementBaseIndemnisationCourant.setProduitMontantRetenu(attribution.getProduitMontantRetenu());
      elementBaseIndemnisationCourant.setSeuilMensuelPansConservees(attribution.getSeuilMensuelPansConservees());
      elementBaseIndemnisationCourant.setMaintienEuropeen(attribution.getMaintienEuropeen());
      elementBaseIndemnisationCourant.setSjc(attribution.getSJC());
      elementBaseIndemnisationCourant.setReglementApplicableMontantRetenu(attribution.getReglementApplicable());
      elementBaseIndemnisationCourant.setReglementMontantRetenu(attribution.getReglementApplicable().getReglement());
      elementBaseIndemnisationCourant.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
      
      FormuleMontantSpec formuleMontant = null;
      ElementBaseIndemnisationAREF elementBaseIndemnisationAREF = null;
      
      QuantiteIndemnisationSpec duree = OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(constituantsIndemnisation.getCollectionQuantiteDroit());
      if (duree != null) {
        formuleMontant = pattribution.getFormuleMontant(duree.getCodeFormuleMontant());
      } else {
        formuleMontant = pattribution.getFormuleMontant(constituantsIndemnisation.getCodeFormuleMontant());
      }
      if ((formuleMontant instanceof FormuleMontantAREFSpec))
      {
        elementBaseIndemnisationAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
        constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationAREF);
      }
    }
  }
  
  protected PeriodeAvantageVieillesse recupererPeriodeAv(AttributionSpec attribution, Damj date)
    throws CoucheLogiqueException
  {
    if (date != null) {
      return RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(((Attribution)attribution).getDemandeur(), date);
    }
    return RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(((Attribution)attribution).getDemandeur(), recupererPremierJourExecutableNcp(attribution));
  }
  
  public void miseAJourConstituantsIndemnisationADate(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj date, ChronologiePeriodes chronologiePeriodesSanctions)
    throws CoucheLogiqueException
  {
    ElementBaseIndemnisation elementBaseIndemnisationCourant = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    determinerMontantPensionInvaliditeADeduire(elementBaseIndemnisationCourant, attribution.getDemandeur(), date.veille(), attribution.getDateAttribution());
    
    elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal(0));
    elementBaseIndemnisationCourant.setMontantAvantageVieillesse(new BigDecimal(0));
    
    PeriodeAvantageVieillesse periodeAvCourante = recupererPeriodeAv(attribution, date.veille());
    if (periodeAvCourante != null)
    {
      Damj dateDepart = Damj.max(attribution.getDateAttribution(), periodeAvCourante.getDateDebut());
      
      Sjr sjrDepart = RevalorisationSalaire.revaloriserSjr(((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation(), ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getProduitMontantRetenu(), dateDepart);
      
      BigDecimal coeffAV = periodeAvCourante.getQuantiteEuro().getValeur().divide(sjrDepart.getSalaire(), 10, 4);
      
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      
      Sjr sjrCourant = RevalorisationSalaire.revaloriserSjr(((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation(), ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getProduitMontantRetenu(), date.veille());
      
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrCourant.getSalaire()));
      
      elementBaseIndemnisationCourant.setDateEffetAV(date.veille());
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(RecuperationSanctionReduction.recuperationCoefficientSanctionReductionADate(chronologiePeriodesSanctions, date));
  }
  
  public ConstituantsCalculActiviteReduiteSpec miseAjourConstituantsCalculActiviteReduite(AttributionSpec pattribution, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, Damj dateDeMiseAjour, ConstituantsIndemnisation constituantIndemnisation)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)pattribution;
    ConstituantsCalculActiviteReduiteAsu constituantsCalculActiviteReduiteProduit = (ConstituantsCalculActiviteReduiteAsu)constituantsCalculActiviteReduite;
    
    constituantsCalculActiviteReduiteProduit.setSjr(RevalorisationSalaire.revaloriserSjr(attribution, dateDeMiseAjour));
    
    constituantsCalculActiviteReduiteProduit.setSjc(RevalorisationSalaire.revaloriserSjc(attribution.getSJC(), dateDeMiseAjour));
    return constituantsCalculActiviteReduiteProduit;
  }
  
  public Damj recupererDateFinDroitTheorique(CalendrierExecutionCalculSpec calendrierExecutionCalcul, AttributionSpec pattribution)
    throws CoucheLogiqueException
  {
    ElementChomageSansRupture elementChomageSansRupture = ((Attribution)pattribution).getElementChomageSansRupture();
    if ((elementChomageSansRupture != null) && (estDemandeEnContexteDeChomageEnCoursDeSuspension(pattribution)) && (!elementChomageSansRupture.estUnContexteDeRupturePendantSuspension())) {
      return recupererDateFinDroitTheoriqueCsr(calendrierExecutionCalcul, pattribution);
    }
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)pattribution.getDemande(), 2)) {
      return ((Attribution)pattribution).getDateLimiteIndemnisation();
    }
    Damj dateFinDroitTheorique = null;
    EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)calendrierExecutionCalcul.getEtatAuDJI();
    BigDecimal reliquatDureeIndemnisation = null;
    if (etatAuDji != null)
    {
      if ((etatAuDji.getReliquatDureeIndemnisation() != null) && (etatAuDji.getReliquatDureeIndemnisation().getValeur() != null))
      {
        reliquatDureeIndemnisation = etatAuDji.getReliquatDureeIndemnisation().getValeur();
        dateFinDroitTheorique = calendrierExecutionCalcul.getDernierJourIndemnisable().deplacerVersAvant(new DureeCalendaire(0, 0, reliquatDureeIndemnisation.intValue()));
      }
      else
      {
        dateFinDroitTheorique = calendrierExecutionCalcul.getDernierJourIndemnisable();
      }
    }
    else
    {
      Attribution attribution = (Attribution)pattribution;
      dateFinDroitTheorique = pattribution.getPji().deplacerVersAvant(new DureeCalendaire(0, 0, attribution.getDureeIndemnisationTheorique().getValeurEntiere() - 1));
    }
    return dateFinDroitTheorique;
  }
  
  public void traitementPeriodeSegmentante(AttributionSpec attribution, ObjetChronoPeriode periode, ConstituantsIndemnisation constituantsIndemnisation, UniteTraitement ut, PeriodeAnalyseSpec pa, ArretProduitAvecRaison arretProduitAvecRaison, ChronologiePeriodes periodesAnalyses)
    throws ApplicativeException
  {
    if (((periode instanceof PeriodeSousPensionInvaliditeChainee)) && (periode.getDateDebut().estApresOuCoincideAvec(attribution.getPji())))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
      
      elementBaseIndemnisation.setMontantPensionInvaliditeADeduire(elementBaseIndemnisation.getMontantPensionInvaliditeADeduire().add(((PeriodeSousPensionInvaliditeChainee)periode).getMontant().getValeur()));
    }
    else if (((periode instanceof FinPeriodePensionInvaliditeChainee)) && (((pa != null) && (pa.getDateDebut().equals(periode.getDateDebut()))) || ((pa == null) && (periode.getDateDebut().estContenueDans(ut.getPeriode())))))
    {
      ElementBaseIndemnisation elementBaseIndemnisation = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
      elementBaseIndemnisation.setMontantPensionInvaliditeADeduire(elementBaseIndemnisation.getMontantPensionInvaliditeADeduire().subtract(((FinPeriodePensionInvaliditeChainee)periode).getQuantiteEuro().getValeur()));
      
      ut.ajouterEvenement(new EvenementFinPeriodePensionInvalidite(periode.getDateDebut().veille()));
    }
    else
    {
      super.traitementPeriodeSegmentante(attribution, periode, constituantsIndemnisation, ut, pa, arretProduitAvecRaison, periodesAnalyses);
    }
  }
  
  protected void determinerMontantPensionInvaliditeADeduire(ElementBaseIndemnisation ebi, IndividuSpec individu, Damj date, Damj dateAttribution)
    throws CoucheLogiqueException
  {
    ebi.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(ebi, individu, date, dateAttribution));
  }
  
  public ChronologiePeriodes recupererPeriodesProduit(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    ChronologiePeriodes periodesIndividuelles = null;
    IndividuSpec individu = null;
    
    periodesIndividuelles = new ChronologiePeriodes();
    individu = attribution.getDemandeur();
    
    ChronologiePeriodes chronologiePeriodesISLR = recupererPeriodeISLRAAjouter(individu, attribution);
    if ((chronologiePeriodesISLR != null) && (!chronologiePeriodesISLR.estVide())) {
      periodesIndividuelles.ajouter(chronologiePeriodesISLR);
    }
    periodesIndividuelles.ajouter(OutillagePeriodes.genererAnniversaire50Ans(individu));
    periodesIndividuelles.ajouter(OutillagePeriodes.genererAnniversaire55Ans(individu));
    periodesIndividuelles.ajouter(OutillagePeriodes.genererAnniversaire60Ans(individu));
    periodesIndividuelles.ajouter(OutillagePeriodes.genererPeriodeRetraite(individu));
    if (individu.getDernierJourAtteste() != null) {
      periodesIndividuelles.ajouter(OutillagePeriodes.genererLendemainDja(individu));
    }
    RecuperationDonneesSecteurPublic.recupererDemandeClassementSP(periodesIndividuelles, attribution);
    
    RecuperationDonneesSecteurPublic.rechercherAdmissionSecteurPublic(periodesIndividuelles, attribution);
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), 2)) {
      periodesIndividuelles.ajouter(new ObjetChronoPeriodeLimiteIndemnisationPMVS(((Attribution)attribution).getDateLimiteIndemnisation().lendemain(), attribution.getRsod()));
    }
    ElementChomageSansRupture elementChomageSansRupture = ((Attribution)attribution).getElementChomageSansRupture();
    if ((elementChomageSansRupture != null) && (estDemandeEnContexteDeChomageEnCoursDeSuspension(attribution))) {
      return recupererPeriodesProduitCsr(attribution, periodesIndividuelles);
    }
    return periodesIndividuelles;
  }
  
  protected ChronologiePeriodes recupererPeriodesProduitCsr(AttributionSpec attribution, ChronologiePeriodes periodesIndividuelles)
    throws CoucheLogiqueException
  {
    boolean contexteRupturePendantSuspension = false;
    ElementChomageSansRupture elementChomageSansRupture = ((Attribution)attribution).getElementChomageSansRupture();
    if (!estUnContexteDeRupturePendantSuspension(attribution))
    {
      if (elementChomageSansRupture != null) {
        contexteRupturePendantSuspension = elementChomageSansRupture.estUnContexteDeRupturePendantSuspension();
      }
      if (elementChomageSansRupture != null)
      {
        Damj dateFinProduit = null;
        
        Damj dateRepriseActivite = elementChomageSansRupture.getDateRepriseActivite();
        if (dateRepriseActivite != null) {
          dateFinProduit = dateRepriseActivite;
        }
        boolean estDecisionProlongation = elementChomageSansRupture.getDecisionProlongation();
        if (estDecisionProlongation)
        {
          Damj dateDecisionProlongation = elementChomageSansRupture.getDateMaxIndeminisation();
          if ((dateRepriseActivite == null) || ((dateDecisionProlongation != null) && (dateDecisionProlongation.lendemain().estAvant(dateRepriseActivite)))) {
            dateFinProduit = dateDecisionProlongation.lendemain();
          }
        }
        if ((dateFinProduit != null) && (!contexteRupturePendantSuspension)) {
          periodesIndividuelles.ajouter(new ObjectChronoFinChomageSansRct(dateFinProduit));
        }
      }
    }
    else
    {
      Collection listeDelaiReport = ((AttributionAssuranceSpec)attribution).getListeCarences();
      if ((listeDelaiReport != null) && (!listeDelaiReport.isEmpty()))
      {
        CarencePrefixeAFixer pmc = (CarencePrefixeAFixer)OutilCarence.trouverCarence(listeDelaiReport, "PMC_NI");
        CarencePrefixeAFixer islr = (CarencePrefixeAFixer)OutilCarence.trouverCarence(listeDelaiReport, "ISLR");
        CarencePrefixeAFixer differe = (CarencePrefixeAFixer)OutilCarence.trouverCarence(listeDelaiReport, "Différé");
        if (pmc != null)
        {
          pmc.setPeriodeApplicationCarence(new Periode(pmc.getDateFinPeriodeOrigine().lendemain(), pmc.getQuantiteInitial().getValeurEntiere()));
          if (islr != null)
          {
            islr.setPeriodeApplicationCarence(new Periode(pmc.getPeriodeApplicationCarence().getFin().lendemain(), islr.getQuantiteInitial().getValeurEntiere()));
            if (differe != null) {
              differe.setPeriodeApplicationCarence(new Periode(islr.getPeriodeApplicationCarence().getFin().lendemain(), differe.getQuantiteInitial().getValeurEntiere()));
            }
          }
          else if (differe != null)
          {
            differe.setPeriodeApplicationCarence(new Periode(pmc.getPeriodeApplicationCarence().getFin().lendemain(), differe.getQuantiteInitial().getValeurEntiere()));
          }
        }
        else if (islr != null)
        {
          islr.setPeriodeApplicationCarence(new Periode(islr.getDateFinPeriodeOrigine().lendemain(), islr.getQuantiteInitial().getValeurEntiere()));
          if (differe != null) {
            differe.setPeriodeApplicationCarence(new Periode(islr.getPeriodeApplicationCarence().getFin().lendemain(), differe.getQuantiteInitial().getValeurEntiere()));
          }
        }
        else if (differe != null)
        {
          differe.setPeriodeApplicationCarence(new Periode(OutilsChomageSansRCT.getDateFinSuspension((DemandeAssuranceSpec)attribution.getDemande()).lendemain(), differe.getQuantiteInitial().getValeurEntiere()));
        }
        Iterator itListeDelaiReports = listeDelaiReport.iterator();
        while (itListeDelaiReports.hasNext())
        {
          CarenceSpec carence = (CarenceSpec)itListeDelaiReports.next();
          if ("Différé".equals(carence.getTypeCarence()))
          {
            Periode periodeCarence = ((Differe)carence).getPeriodeApplicationCarence();
            int nbJoursDiffere = ((Differe)carence).getQuantiteInitial().getValeurEntiere();
            if ((periodeCarence != null) && (nbJoursDiffere > 0))
            {
              ChronologiePeriodes chronologiePeriodesGAEC = OutillagePeriodes.recupererPeriodesGAEC(attribution.getDemandeur(), attribution.getDateAttribution(), null);
              
              Qualification qualification = new Qualification();
              QualificationPeriodes periodesQualifie = qualification.qualificationPeriodesPourAvant(chronologiePeriodesGAEC, attribution);
              
              ChronologiePeriodes chronologiePeriodeMaladie = (ChronologiePeriodes)periodesQualifie.getPeriodesSuspensives().copier(new FiltrePeriodeEvenementPersonnel());
              
              Damj dateDebutDiffere = periodeCarence.getDebut();
              dateDebutDiffere = rechercheTrouMaladie(dateDebutDiffere, chronologiePeriodeMaladie);
              
              DureeCalendaire decalage = new DureeCalendaire(0, 0, nbJoursDiffere - 1);
              periodesIndividuelles.ajouter(new ObjetChronoPeriodeCarences(dateDebutDiffere, dateDebutDiffere.deplacerVersAvant(decalage), 1));
            }
          }
          else if ("ISLR".equals(carence.getTypeCarence()))
          {
            Periode periodeCarence = ((CarencePrefixeAFixer)carence).getPeriodeApplicationCarence();
            if (periodeCarence != null) {
              periodesIndividuelles.ajouter(new ObjetChronoPeriodeCarences(periodeCarence.getDebut(), periodeCarence.getFin(), 2));
            }
          }
          else if ("PMC_NI".equals(carence.getTypeCarence()))
          {
            Periode periodeCarence = ((CarencePrefixeAFixer)carence).getPeriodeApplicationCarence();
            if (periodeCarence != null) {
              periodesIndividuelles.ajouter(new ObjetChronoPeriodePreavis(periodeCarence.getDebut(), periodeCarence.getFin()));
            }
          }
        }
      }
    }
    return periodesIndividuelles;
  }
  
  protected Damj recupererDateFinDroitTheoriqueCsr(CalendrierExecutionCalculSpec calendrierExecutionCalcul, AttributionSpec pattribution)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)pattribution;
    ElementChomageSansRupture element = attribution.getElementChomageSansRupture();
    
    Damj dateFinDroitTheorique = pattribution.getPji().deplacerVersAvant(new DureeCalendaire(0, 0, attribution.getDureeProlongationTheorique().getValeurEntiere() - 1));
    if (attribution.getElementChomageSansRupture().getDecisionProlongation())
    {
      if ((element.getDateMaxIndeminisation() != null) && (element.getDateMaxIndeminisation().estAvant(dateFinDroitTheorique))) {
        dateFinDroitTheorique = element.getDateMaxIndeminisation();
      }
    }
    else if (attribution.getDureeProlongationTheorique() != null) {
      dateFinDroitTheorique = pattribution.getPji().deplacerVersAvant(new DureeCalendaire(0, 0, attribution.getDureeProlongationTheorique().getValeurEntiere() - 1));
    }
    if ((attribution.getElementChomageSansRupture().getDateRepriseActivite() != null) && (element.getDateRepriseActivite().estAvant(dateFinDroitTheorique))) {
      dateFinDroitTheorique = element.getDateRepriseActivite();
    }
    boolean positionnementEffectue = false;
    if (((CalendrierExecutionCalculPeriodique)calendrierExecutionCalcul).getChronologieUnitesTraitements() != null)
    {
      Iterator iterateurUT = ((CalendrierExecutionCalculPeriodique)calendrierExecutionCalcul).getChronologieUnitesTraitements().iterer();
      while ((iterateurUT.hasNext()) && (!positionnementEffectue))
      {
        UniteTraitement ut = (UniteTraitement)iterateurUT.next();
        if (dateFinDroitTheorique.estContenueDans(ut.getPeriode()))
        {
          ut.ajouterEvenement(new EvenementLimiteIndemnisationChomageSansRCT(dateFinDroitTheorique));
          positionnementEffectue = true;
        }
      }
    }
    return dateFinDroitTheorique;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculLigneSansTrancheImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */