package fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class MajCiTranche
{
  private static final int CINQUANTE_ANS = 50;
  
  public static ConstituantsIndemnisation miseAJourConstituantsIndemnisation(AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour)
    throws CoucheLogiqueException
  {
    QuantiteDroitSpec dureeDroit = null;
    Collection collectionDurees = null;
    Iterator iterator = null;
    String codeFormuleMontant = null;
    
    codeFormuleMontant = constituantsIndemnisation.getCodeFormuleMontant();
    if (codeFormuleMontant != null) {
      miseAJourParametres(attribution, constituantsIndemnisation, dateDeMiseAjour);
    }
    collectionDurees = constituantsIndemnisation.getCollectionQuantiteDroit();
    if (collectionDurees != null)
    {
      iterator = collectionDurees.iterator();
      while (iterator.hasNext())
      {
        dureeDroit = (QuantiteDroitSpec)iterator.next();
        if ((dureeDroit instanceof QuantiteIndemnisationSpec)) {
          miseAJourParametres(attribution, constituantsIndemnisation, dateDeMiseAjour);
        }
      }
    }
    return constituantsIndemnisation;
  }
  
  private static void miseAJourParametres(AttributionSpec paramAttribution, ConstituantsIndemnisation constituantsIndemnisation, Damj dateDeMiseAjour)
    throws CoucheLogiqueException
  {
    ParametresIndemnisation parametresIndemnisation = null;
    BigDecimal tauxAvantageViellesse = null;
    ElementBaseIndemnisation elementBaseIndemnisation = null;
    Sjr nouveauSjr = null;
    Sjc nouveauSjc = null;
    
    TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(paramAttribution);
    Attribution attribution = (Attribution)paramAttribution;
    
    parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    
    elementBaseIndemnisation = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    tauxAvantageViellesse = parametresIndemnisation.getTauxAvantageViellesse(paramAttribution.getDemandeur().getAgeALaDate(dateDeMiseAjour));
    if (tauxAvantageViellesse != null) {
      ((ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).setTauxAvantageVieillesse(tauxAvantageViellesse);
    }
    nouveauSjr = RevalorisationSalaire.revaloriserSjrTranche(attribution, dateDeMiseAjour, tranche);
    
    nouveauSjc = RevalorisationSalaire.revaloriserSjc(tranche.getSjc(), dateDeMiseAjour);
    if (nouveauSjr.getSalaire().doubleValue() != elementBaseIndemnisation.getSjr().getSalaire().doubleValue()) {
      elementBaseIndemnisation.setMontantAvantageVieillesse(elementBaseIndemnisation.getCoefficientAvantageVieillesse().multiply(nouveauSjr.getSalaire()));
    }
    elementBaseIndemnisation.getSjr().setSalaire(nouveauSjr.getSalaire());
    
    elementBaseIndemnisation.getSjc().setSalaire(nouveauSjc.getSalaire());
    if ((elementBaseIndemnisation.getCoefficientSaisonnier() != null) && 
      (elementBaseIndemnisation.getCoefficientSaisonnier().intValue() != 1) && (paramAttribution.getDemandeur().getAgeALaDate(dateDeMiseAjour).getAnnees() >= 50)) {
      if ((elementBaseIndemnisation.getTypeCaractereSaisonnierRetenu() == 1) && (elementBaseIndemnisation.isConditionCaractereSaisonnierParRythme())) {
        elementBaseIndemnisation.setCoefficientSaisonnier(new BigDecimal("1.00"));
      }
    }
    if ((elementBaseIndemnisation.getAvecPrecompteCRC() == null) && 
      (tranche.getCompetenceFinanciere() == 2) && ((tranche.getCompetenceAdministrative() != 1) || ((((AttributionAssuranceSpec)paramAttribution).getConventionGestion() != null) && (!((AttributionAssuranceSpec)paramAttribution).getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisation.setAvecPrecompteCRC(new Boolean(false));
    }
  }
}

/* Location:
 * Qualified Name:     MajCiTranche
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */