package fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.dom.ActiviteProratisee;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.liquidation.outilsaffiliation.ZoneMemeExerciceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActionFormation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormation;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeIndemnisationCaf;
import fr.unedic.cali.autresdoms.ga.dom.spec.AppartenanceSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;

public class PostTraitementJustificationAffiliation
{
  public static void postTraiter(Demande p_demande)
  {
    JustificationAffiliationSpec justif = ((DossierExamenAssuranceSpec)p_demande.getDossierExamen()).getJustificationAffiliation();
    if (justif != null)
    {
      ProduitAsuSpec produitAffecte = (ProduitAsuSpec)((DossierAffectation)p_demande.getDossierAffectation()).getProduit();
      Convertisseur convertisseurUniteAffiliation = produitAffecte.determinerConvertisseurUniteAffiliation();
      
      traiterAffiliationZme(justif, convertisseurUniteAffiliation);
    }
  }
  
  public static void traiterAffiliationZme(JustificationAffiliationSpec p_justif, Convertisseur p_convertisseurUniteAffiliation)
  {
    Unite uniteAffi = p_justif.getUniteJustification();
    for (Iterator iter = p_justif.getChronoZmes().iterer(); iter.hasNext();)
    {
      ZoneMemeExerciceSpec zme = (ZoneMemeExerciceSpec)iter.next();
      boolean chevauchePnds = zme.chevauchePnds();
      if (chevauchePnds)
      {
        zme.setQteAppartenanceZmeJustification(new Quantite(new BigDecimal("0"), uniteAffi));
      }
      else if (zme.getQuantiteAffiliation(uniteAffi) != null)
      {
        Quantite quantiteAppartenanceZmeHeures = zme.getQuantiteAffiliation(uniteAffi).ajouter(zme.getQuantiteAssimilation(uniteAffi));
        if (zme.getQuantiteAssimilationFevrier(uniteAffi) != null) {
          quantiteAppartenanceZmeHeures = quantiteAppartenanceZmeHeures.ajouter(zme.getQuantiteAssimilationFevrier(uniteAffi));
        }
        zme.setQteAppartenanceZmeJustification(quantiteAppartenanceZmeHeures);
      }
      else
      {
        Quantite quantiteAppartenanceZmeHeures = zme.getQuantiteAffiliation(UniteAffiliation.HEURE_TRAVAIL).ajouter(zme.getQuantiteAssimilation(UniteAffiliation.HEURE_TRAVAIL));
        if (zme.getQuantiteAssimilationFevrier(UniteAffiliation.HEURE_TRAVAIL) != null) {
          quantiteAppartenanceZmeHeures = quantiteAppartenanceZmeHeures.ajouter(zme.getQuantiteAssimilationFevrier(UniteAffiliation.HEURE_TRAVAIL));
        }
        Quantite quantiteAppartenanceZmeUniteCherchee = p_convertisseurUniteAffiliation.convertir(quantiteAppartenanceZmeHeures, uniteAffi);
        
        zme.setQteAppartenanceZmeJustification(quantiteAppartenanceZmeUniteCherchee);
      }
      traiterActivitesProratisees(zme.getListeActivitesProratisees(), chevauchePnds);
    }
  }
  
  private static void traiterActivitesProratisees(List p_listeActivites, boolean p_zmeChevauchePnds)
  {
    for (Iterator iter = p_listeActivites.iterator(); iter.hasNext();)
    {
      ActiviteProratisee activite = (ActiviteProratisee)iter.next();
      enrichirActiviteProratisee(activite, p_zmeChevauchePnds);
    }
  }
  
  private static void enrichirActiviteProratisee(ActiviteProratisee p_activite, boolean p_zmeChevauchePnds)
  {
    if ((p_activite.getPeriodeOrigine() instanceof PeriodeFormationAssimilable))
    {
      p_activite.setNaturePeriode("Formation assimilable");
      
      p_activite.setRaisonSociale(((PeriodeFormationAssimilable)p_activite.getPeriodeOrigine()).getNomOrganismeFormation());
    }
    else if ((p_activite.getPeriodeOrigine() instanceof PeriodeFormation))
    {
      p_activite.setNaturePeriode("Formation non assimilable");
      
      p_activite.setRaisonSociale(((PeriodeFormation)p_activite.getPeriodeOrigine()).getNomOrganismeFormation());
    }
    else
    {
      AppartenanceSpec pasOrigine = p_activite.getPeriodeOrigine();
      if ((pasOrigine instanceof ActiviteSalarie))
      {
        StringBuffer sbReglement = new StringBuffer();
        sbReglement.append(((ActiviteSalarie)pasOrigine).getReglement().getLibelleCourt());
        if (p_zmeChevauchePnds) {
          sbReglement.append("/PNDS");
        }
        p_activite.setNaturePeriode(sbReglement.toString());
        
        p_activite.setRaisonSociale(((ActiviteSalarie)pasOrigine).getEntreprise().getLibelleEntreprise());
      }
      else if ((pasOrigine instanceof ActionFormation))
      {
        p_activite.setNaturePeriode("Action de formation");
        
        p_activite.setRaisonSociale(((ActionFormation)pasOrigine).getNomOrganismeFormation());
      }
      else if ((pasOrigine instanceof PeriodeEvenementPersonnel))
      {
        PeriodeEvenementPersonnel periode = (PeriodeEvenementPersonnel)pasOrigine;
        if (periode.getTypePep() == 2) {
          p_activite.setNaturePeriode("Maladie (IJSS)");
        } else if (periode.getTypePep() == 3) {
          p_activite.setNaturePeriode("Congé adoption maternité");
        }
      }
      else if ((pasOrigine instanceof PeriodeIndemnisationCaf))
      {
        p_activite.setNaturePeriode("Indemnisation CAF");
      }
    }
  }
}

/* Location:
 * Qualified Name:     PostTraitementJustificationAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */