package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.dom.DuoAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.ConstitutionMontantsBrutsSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieDroitOptionApresARE14;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSr;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.PoursuiteIndemnisationSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pivot.DemandePivot;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import org.apache.commons.lang.StringUtils;

public class AlimentationBasePivot
{
  private static final String STRING_VIDE = "";
  private static final int LONGUEUR_CODE_PAYS_ACTIVITE = 3;
  private static final int LONGUEUR_CODE_ACTIVITE_HORS_FRANCE = 2;
  private static final String VRAI = "1";
  private static final String FAUX = "0";
  private static AlimentationBasePivot instance = null;
  
  public static AlimentationBasePivot getInstance()
  {
    if (instance == null) {
      instance = new AlimentationBasePivot();
    }
    return instance;
  }
  
  public void alimenterDonneesProduit(DossierExamenSpec dossierExamen, DemandePivot demandePivot)
    throws ApplicativeException
  {
    Demande demandeAssurance = (Demande)dossierExamen.getDemande();
    
    fr.unedic.cali.dom.pivot.Decision decision = demandePivot.getDecision();
    
    fr.unedic.cali.dom.pivot.Attribution attribution = demandePivot.getAttribution();
    if (!(dossierExamen instanceof PoursuiteIndemnisationSpec)) {
      renseignerDecision(decision, demandeAssurance);
    }
    if (attribution != null) {
      renseignerAttribution(demandePivot.getAttribution(), demandeAssurance);
    }
    alimentationSpecificitesAspSurProduitCge(demandeAssurance, attribution, dossierExamen, decision);
    if (attribution != null) {
      fr.unedic.cali.asu.liquidation.outilsfonctionnels.AlimentationBasePivot.alimentationMontantAllocationJournaliereBrut(dossierExamen, attribution);
    }
  }
  
  public void alimentationSpecificitesAspSurProduitCge(Demande demandeAssurance, fr.unedic.cali.dom.pivot.Attribution attributionPivot, DossierExamenSpec dossierExamen, fr.unedic.cali.dom.pivot.Decision decisionPivot)
    throws CoucheLogiqueException
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeAssurance, 6))
    {
      if (attributionPivot != null)
      {
        AttributionAssuranceSpec attributionAssurance = (AttributionAssuranceSpec)dossierExamen;
        attributionPivot.setDateFinDelaiDecheance(attributionAssurance.getDateLimiteIndemnisation());
        if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeAssurance, 9)) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeAssurance, "AREENTRCSP")) && (attributionAssurance.getConstitutionMontantsBruts() != null))
        {
          attributionPivot.setFinPrcSjrRetenu(null);
          attributionPivot.setMontantSjrRetenuPlafonne(attributionAssurance.getConstitutionMontantsBruts().getSjrMontantMaxAsp());
          
          attributionPivot.setFlagReadmission(2);
        }
      }
      ProduitAsuSpec produitANotifier = OutilAsp.getInstance().recupererProduitReglementaire(demandeAssurance);
      decisionPivot.setCodeProduit(produitANotifier.getNom());
    }
  }
  
  protected void renseignerAttribution(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande)
    throws CoucheLogiqueException
  {
    renseignerDroitCourant(attribution, demande);
    
    renseignerDroitRetenu(attribution, demande);
  }
  
  public void alimenterCodeSousProduit(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande)
  {
    AttributionAssuranceSpec decision = (AttributionAssuranceSpec)demande.getDossierExamen();
    
    String codeSousProduitRetourne = decision.determinerCodeSousProduitPourSigma();
    
    attribution.setCodeSousProduitCourant(codeSousProduitRetourne);
    switch (decision.getNatureDecision())
    {
    case 10: 
    case 12: 
    case 32: 
    case 40: 
      attribution.setCodeSousProduitRetenu(codeSousProduitRetourne);
      break;
    case 3: 
    case 11: 
    case 13: 
    case 15: 
    case 26: 
    case 27: 
    case 34: 
      if (decision.getAttributionPrecedente() != null)
      {
        AttributionSpec attributionPrec = decision.getAttributionPrecedente();
        attribution.setCodeSousProduitRetenu(attributionPrec.determinerCodeSousProduitPourSigma());
      }
      break;
    }
  }
  
  private void renseignerDroitCourant(fr.unedic.cali.dom.pivot.Attribution attributionPivot, Demande demande)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)demande.getDossierExamen();
    if ((decision.getConstitutionQuantiteAffiliation() != null) && (decision.getConstitutionQuantiteAffiliation().getArticle3() != null)) {
      attributionPivot.setReferenceReglementaireAffiliationDroitCourant(decision.getConstitutionQuantiteAffiliation().getArticle3().toUpperCase());
    }
    if ((decision instanceof Od)) {
      attributionPivot.setPlus100trimestres(determineAuMoins100Trimestres(demande));
    }
    attributionPivot.setDateEffetAttribution(decision.getConstitutionDateAttribution().getDateAttribution());
    
    attributionPivot.setPji(decision.getConstitutionPointDepartIndemnisation().getPji());
    
    ReglementApplicableSpec reglementApplicable = decision.getConstitutionReglementApplicable();
    if (reglementApplicable != null)
    {
      attributionPivot.setReglementApplicableCourant(reglementApplicable.getReglement().getNomReglement().toUpperCase());
      if ((reglementApplicable instanceof ConstitutionReglementApplicable))
      {
        ConstitutionReglementApplicable constitution = (ConstitutionReglementApplicable)reglementApplicable;
        attributionPivot.setEstDroitInterimaire(constitution.isDroitInterimaire() ? "1" : "0");
      }
    }
    if ((decision.getConstitutionDurees() != null) && (decision.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique() != null)) {
      attributionPivot.setDureeTheoriqueDroitCourant(decision.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique().getValeurEntiere());
    }
    if ((decision.getConstitutionMontantsBruts() != null) && (decision.getConstitutionMontantsBruts().getCapitalInitialBrut() != null)) {
      attributionPivot.setCapitalOdCourante(decision.getConstitutionMontantsBruts().getCapitalInitialBrut().getValeur());
    }
    attributionPivot.setTypeChomageSaisonnier(determineTypeChomageSaisonnier(decision));
    
    attributionPivot.setCapitalDroitPrecedentSp(determineCapitalPrecedentSp(demande));
    if ((!demande.estEnReExamen()) && ((demande.estUneDemandeAntecedentFinDroitSp()) || (decision.getConstitutionDurees() != null))) {
      attributionPivot.setDateTheoriqueFinDroit(fr.unedic.cali.asu.outilsfonctionnels.AlimentationBasePivot.determineDateTheoriqueFinDroit((AttributionAssuranceSpec)decision));
    }
    attributionPivot.setDateFinDelaiDecheance(determineDateFinDelaiDecheance(attributionPivot.getDateTheoriqueFinDroit()));
    if (decision.getConstitutionSjr() != null)
    {
      boolean sjrForce = false;
      BigDecimal zero = BigDecimal.ZERO;
      if ((demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getTermePrc() != null)) {
        sjrForce = true;
      }
      Prc prcDroitCourant = decision.getConstitutionSjr().getSjrip().getPrc();
      if (prcDroitCourant != null)
      {
        attributionPivot.setDateDebutPrcDroitCourant(prcDroitCourant.getDateDebut());
        
        attributionPivot.setDateFinPrcDroitCourant(prcDroitCourant.getDateFin());
        
        attributionPivot.setMontantSalaireReferenceSjrCourant(!sjrForce ? prcDroitCourant.getSrip() : zero);
      }
      attributionPivot.setNbJoursDiviseurSjrCourant(!sjrForce ? determineDiviseurPrc(decision) : zero);
      
      attributionPivot.setMontantSjrCourantNonPlafonne(!sjrForce ? decision.getConstitutionSjr().getSjrip().getSjrInitial().getValeur() : zero);
      
      attributionPivot.setMontantSjrCourantCalculePlafonne(!sjrForce ? decision.getConstitutionSjr().getSjrip().getSjrip() : zero);
      
      attributionPivot.setMontantSjrCourantPlafonne(decision.getConstitutionSjr().getSjrrp().getSalaire());
      
      attributionPivot.setNbHeuresTravailleesA8A10SjrCourant(0);
      
      attributionPivot.setMontantSalaireReferenceA10FNA(!sjrForce ? decision.getConstitutionSjr().getJustificationSjr().getJustificationSr().getSalaireReferenceNonPlafonne() : zero);
    }
    if ((decision.getConstitutionSjc() != null) && (decision.getConstitutionSjc().getSjcip() != null))
    {
      attributionPivot.setDateEffetSjc(decision.getConstitutionSjc().getSjcip().getDateEffet());
      
      attributionPivot.setMontantSjc(decision.getConstitutionSjc().getSjcip().getSjcip());
    }
    attributionPivot.setCoeffTempsPartielSjrCourant(determinerCoeffTempsPartielDroitRetenu(decision));
    
    attributionPivot.setCoeffSaisonnierCalcSjrCourant(determineCoefficientSaisonnierCalcule(decision));
    if (decision.getConstitutionDelais() != null)
    {
      attributionPivot.setNbJoursIccp(decision.getConstitutionDelais().getNbJoursCarenceICCP());
      
      attributionPivot.setUniteDureeIccp("C");
      
      attributionPivot.setDateDebutIccp(decision.getConstitutionDelais().getDebutCarenceICCP());
      
      attributionPivot.setDateFinIccp(decision.getConstitutionDelais().getTermeCarenceICCP());
      
      ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
      if ((decision.getConstitutionReglementApplicable() != null) && (decision.getConstitutionReglementApplicable().getReglement().equals(produit.getReglement("A4"))))
      {
        if (decision.getConstitutionDelais().getCumulMontantICCPA4Origine() != null) {
          attributionPivot.setMontantCarenceIccp(decision.getConstitutionDelais().getCumulMontantICCPA4Origine().getValeurMontant());
        }
      }
      else if (decision.getConstitutionDelais().getMontantICCPOrigine() != null) {
        attributionPivot.setMontantCarenceIccp(decision.getConstitutionDelais().getMontantICCPOrigine().getValeurMontant());
      }
      attributionPivot.setNbJoursIslr(decision.getConstitutionDelais().getNbJoursCarenceISLR());
      
      attributionPivot.setUniteDureeIslr("C");
      
      attributionPivot.setDateDebutIslr(decision.getConstitutionDelais().getDebutCarenceISLR());
      
      attributionPivot.setDateFinIslr(decision.getConstitutionDelais().getTermeCarenceISLR());
      
      attributionPivot.setNbJoursDiffere(decision.getConstitutionDelais().getNbJoursCarenceDiffere());
      
      attributionPivot.setUniteDureeDiffere("C");
      
      attributionPivot.setDateDebutDiffere(decision.getConstitutionDelais().getDebutCarenceDiffere());
      
      attributionPivot.setDateFinDiffere(decision.getConstitutionDelais().getTermeCarenceDiffere());
    }
    if (((decision instanceof fr.unedic.cali.asu.produits.liquidation.dom.Attribution)) && (((fr.unedic.cali.asu.produits.liquidation.dom.Attribution)decision).isRegimeFinancementParticulierCaCae())) {
      attributionPivot.setRegimeParticulier("A");
    } else {
      attributionPivot.setRegimeParticulier("");
    }
    if ((decision.getFaitGenerateur() != null) && (decision.getFaitGenerateur().getPeriodeFaitGenerateur() != null) && (decision.getFaitGenerateur().getPeriodeFaitGenerateur().isRegimeAlsaceMoselle())) {
      attributionPivot.setComplementSs("A");
    }
    CompetenceSpec competence = decision.getCompetence();
    if ((competence != null) && (competence.getIdFctEmployeurCompetent() != null)) {
      attributionPivot.setFctEmployeurCompetent(OutilActiviteSalarie.formaterIdentifiantPeriodeGaec(competence.getIdFctEmployeurCompetent(), 17));
    }
    alimenterCodesStatutFNA(demande.getFaitGenerateur(), attributionPivot);
    
    alimenterCodeSousProduit(attributionPivot, demande);
    
    alimenterConventionGestion(attributionPivot, demande);
    
    alimenterDonneesFNA(attributionPivot, demande, decision);
  }
  
  public void alimenterConventionGestion(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande)
  {
    AttributionAssuranceSpec attributionAssurance = demande.getAttribution();
    if (attributionAssurance != null)
    {
      ConventionGestionSpec conventionGestion = attributionAssurance.getConventionGestion();
      if ((conventionGestion != null) && ("2".equals(conventionGestion.getSignataire())))
      {
        attribution.setNumeroConvention(conventionGestion.getNumeroConventionGestion());
        attribution.setCodeAffectationConvention(conventionGestion.getCodeAffectation());
        attribution.setIdExterneEmployeurSp(attributionAssurance.getCompetence().getIdExterneEmployeurSp());
      }
      else
      {
        attribution.setNumeroConvention("");
        attribution.setCodeAffectationConvention("");
        attribution.setIdExterneEmployeurSp("");
      }
    }
  }
  
  private void alimenterCodesStatutFNA(FaitGenerateurSpec faitGenerateur, fr.unedic.cali.dom.pivot.Attribution attribution)
  {
    if ((faitGenerateur != null) && (faitGenerateur.getPeriodeFaitGenerateur() != null))
    {
      int pohf = faitGenerateur.getPeriodeFaitGenerateur().getContrat().getPohf();
      
      attribution.setCodePaysActivite(StringUtils.leftPad(Integer.toString(faitGenerateur.getPeriodeFaitGenerateur().getContrat().getPays()), 3, "0"));
      String pohfS;
      String pohfS;
      if (pohf != 0) {
        pohfS = StringUtils.leftPad(Integer.toString(pohf), 2, "0");
      } else {
        pohfS = "";
      }
      attribution.setCodeActiviteHorsFrance(pohfS);
    }
  }
  
  private void renseignerDroitRetenu(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.produits.liquidation.dom.Attribution decision = (fr.unedic.cali.asu.produits.liquidation.dom.Attribution)demande.getDossierExamen();
    
    BigDecimal zero = BigDecimal.ZERO;
    if ((decision.getConstitutionQuantiteAffiliation() != null) && (decision.getConstitutionQuantiteAffiliation().getArticle3() != null)) {
      attribution.setReferenceReglementaireAffiliationDroitRetenu(decision.getConstitutionQuantiteAffiliation().getArticle3().toUpperCase());
    }
    if (decision.getConstitutionReglementApplicable() != null) {
      attribution.setReglementApplicableRetenu(decision.getConstitutionReglementApplicable().getReglement().getNomReglement().toUpperCase());
    }
    ProduitAsuSpec produit = (ProduitAsuSpec)decision.getProduit();
    if (produit != null) {
      attribution.setCoeffSaisonnierForceSjrCourant(((ProduitAsuSpec)decision.getProduit()).recupererCoefficientSaisonnierMontantRetenu(decision));
    }
    if ((decision.getNatureDecision() == 11) || (decision.getNatureDecision() == 26))
    {
      if (decision.getConstitutionProduitResultant() != null)
      {
        if ((produit != null) && (produit.estTrancheActivee(demande)))
        {
          TrancheExecutable tranche = (TrancheExecutable)decision.getListTranchesExecutables().get(0);
          attribution.setFinPrcSjrRetenu(tranche.getSjr().getDateDepart());
        }
        else
        {
          attribution.setFinPrcSjrRetenu(decision.getElementBaseIndemnisation().getSjr().getDateDepart());
        }
        if (decision.getConstitutionProduitResultant().getDureeTheorique() != null) {
          attribution.setDureeTheoriqueDroitRetenu(decision.getConstitutionProduitResultant().getDureeTheorique().getValeurEntiere());
        }
        if (decision.getConstitutionProduitResultant().getCapitalDroitPrecedent() != null) {
          attribution.setCapitalOdPrecedente(decision.getConstitutionProduitResultant().getCapitalDroitPrecedent().getValeur());
        }
        if (decision.getConstitutionProduitResultant().getTypeMontantRetenu() == 1)
        {
          if ((produit != null) && (produit.estTrancheActivee(demande)))
          {
            TrancheExecutable tranche = (TrancheExecutable)decision.getListTranchesExecutables().get(0);
            attribution.setMontantSjrRetenuPlafonne(tranche.getSjr().getSalaire());
          }
          else
          {
            attribution.setMontantSjrRetenuPlafonne(decision.getElementBaseIndemnisation().getSjr().getSalaire());
          }
        }
        else {
          attribution.setMontantSjrRetenuPlafonne(decision.getConstitutionProduitResultant().getSjrrpProduitPrecedent().getSalaire());
        }
        attribution.setFlagReadmission(determinerFlagReadmission(decision));
        
        attribution.setMontantInitialCapitalMax(determinerMontantJournalierCapitalMax(decision));
      }
    }
    else
    {
      if (decision.getNatureDecision() == 12)
      {
        attribution.setFlagReadmission(determinerFlagReadmission(decision));
        
        attribution.setMontantInitialCapitalMax(determinerMontantJournalierCapitalMax(decision));
      }
      if ((decision.getConstitutionProduitResultant() != null) && (decision.getConstitutionProduitResultant().getCapitalDroitPrecedent() != null)) {
        attribution.setCapitalOdPrecedente(decision.getConstitutionProduitResultant().getCapitalDroitPrecedent().getValeur());
      } else {
        attribution.setCapitalOdPrecedente(zero);
      }
      if ((decision.getConstitutionDurees() != null) && (decision.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique() != null)) {
        attribution.setDureeTheoriqueDroitRetenu(decision.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique().getValeurEntiere());
      }
      if (decision.getConstitutionSjr() != null)
      {
        Prc prcCourante = decision.getConstitutionSjr().getSjrip().getPrc();
        if (prcCourante != null) {
          attribution.setFinPrcSjrRetenu(decision.getConstitutionSjr().getSjrip().getPrc().getDateFin());
        }
        attribution.setMontantSjrRetenuPlafonne(decision.getConstitutionSjr().getSjrip().getSjrip());
      }
    }
  }
  
  protected void renseignerDecision(fr.unedic.cali.dom.pivot.Decision decision, Demande demande)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    renseigneAffiliation(decision, dossierExamen);
    
    renseignerDonneesPmc(decision, dossierExamen);
  }
  
  private BigDecimal determineCoefficientSaisonnierCalcule(DossierExamen dossier)
  {
    if (dossier.getConstitutionCoefficientSaisonnier() != null) {
      return dossier.getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu();
    }
    return null;
  }
  
  private BigDecimal determineCapitalPrecedentSp(Demande demande)
  {
    Quantite qte = demande.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    return qte != null ? qte.getValeur() : null;
  }
  
  private BigDecimal determineDiviseurPrc(DossierExamen dossier)
  {
    BigDecimal div = null;
    if (dossier.getConstitutionSjr().getSjrip().getPrc() != null) {
      div = dossier.getConstitutionSjr().getSjrip().getPrc().getDiviseur();
    }
    return div;
  }
  
  private Damj determineDateFinDelaiDecheance(Damj djiTheorique)
  {
    int troisAns = 3;
    Damj dateFin = null;
    DureeCalendaire delaiDecheance = new DureeCalendaire(3, 0, 0);
    if (djiTheorique != null) {
      dateFin = djiTheorique.deplacerVersAvant(delaiDecheance);
    }
    return dateFin;
  }
  
  private BigDecimal determinerCoeffTempsPartielDroitRetenu(DossierExamen dossier)
  {
    BigDecimal coeffTempsPartiel = BigDecimal.ONE;
    BigDecimal coeff = null;
    ConstitutionCoefficientTempsPartiel coeffTP = dossier.getConstitutionCoefficientTempsPartiel();
    if ((coeffTP != null) && (coeffTP.getCoefficientTempsPartielRetenu() != null)) {
      coeff = coeffTP.getCoefficientTempsPartielRetenu();
    }
    if (coeff != null) {
      coeffTempsPartiel = coeff;
    }
    return coeffTempsPartiel;
  }
  
  private String determineNomPourPivotUniteAffiliation(String unite)
    throws CoucheLogiqueException
  {
    String nomUnite = "";
    String uniteVide = "";
    if ((unite != null) && (!uniteVide.equals(unite))) {
      if ((unite.equals("heure de travail")) || (unite.equals("heure")))
      {
        nomUnite = "H";
      }
      else if ((unite.equals("jour d'affiliation")) || (unite.equals("jour")) || (unite.equals("jour travaillés")))
      {
        nomUnite = "J";
      }
      else if (unite.equals("embarquement administratif"))
      {
        nomUnite = "E";
      }
      else if (unite.equals("vacation"))
      {
        nomUnite = "V";
      }
      else
      {
        OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "unité durée affiliation non mappée, unité reçue : ", nomUnite.getClass().getName() });
        throw new UnsupportedOperationException("Alimentation Base pivot - Unité non mappée : " + nomUnite);
      }
    }
    return nomUnite;
  }
  
  protected void alimenterQuantitesAppartenance(DuoAppartenance quantiteAppartenance, fr.unedic.cali.dom.pivot.Decision decision, DossierExamen dossier)
  {
    if (((dossier instanceof RejetSpec)) || ((dossier instanceof RepriseSpec)))
    {
      DossierAffectation dossierAffectationAdmission = ((Demande)dossier.getDossierAffecte().getDemande()).getDossierAffectationAdmission();
      if ((dossierAffectationAdmission != null) && (dossierAffectationAdmission.getDossierExamen() != null))
      {
        DossierExamenAssuranceSpec dossierExamenAdmission = (DossierExamenAssuranceSpec)dossierAffectationAdmission.getDossierExamen();
        ConditionQuantiteAffiliationSpec capa07 = dossierExamenAdmission.getConditionQuantiteAffiliation();
        FaitGenerateurSpec capa04 = dossierExamenAdmission.getFaitGenerateur();
        if ((capa07 != null) && (!capa07.estSatisfait()))
        {
          quantiteAppartenance.setQuantiteAppartenancePrincipale(capa07.getQuantiteAppartenance());
          quantiteAppartenance.setQuantiteAppartenanceSecondaire(capa07.getQuantiteAppartenanceSecondaire());
          if (capa07.getJustificationAffiliation() != null)
          {
            Periode pra = capa07.getJustificationAffiliation().getPeriodeRechercheAffiliation();
            if (pra != null)
            {
              decision.setDateDebutPra(pra.getDebut());
              decision.setDateFinPra(pra.getFin());
            }
          }
        }
        else if ((capa04 != null) && (!capa04.estSatisfait()))
        {
          quantiteAppartenance.setQuantiteAppartenancePrincipale(capa04.getNombreJoursFaitGenerateur());
        }
        else
        {
          ValidationProduit vlp = dossierAffectationAdmission.getValidationProduit();
          if ((vlp != null) && (vlp.isEstProduitValide()))
          {
            quantiteAppartenance.setQuantiteAppartenancePrincipale(vlp.getQuantiteAcquise());
            quantiteAppartenance.setQuantiteAppartenanceSecondaire(vlp.getQuantiteAcquiseSecondaire());
            
            Periode pra = vlp.getPeriodePra();
            if (pra != null)
            {
              decision.setDateDebutPra(pra.getDebut());
              decision.setDateFinPra(pra.getFin());
            }
          }
        }
      }
    }
    else
    {
      ConstitutionQuantiteAffiliation cepa09 = dossier.getConstitutionQuantiteAffiliation();
      if (cepa09 != null)
      {
        quantiteAppartenance.setQuantiteAppartenancePrincipale(cepa09.getQuantiteAcquise());
        quantiteAppartenance.setQuantiteAppartenanceSecondaire(cepa09.getQuantiteAcquiseSecondaire());
        
        Periode pra = cepa09.getPeriodePRA();
        if (pra != null)
        {
          decision.setDateDebutPra(pra.getDebut());
          decision.setDateFinPra(pra.getFin());
        }
      }
    }
  }
  
  protected void renseigneAffiliation(fr.unedic.cali.dom.pivot.Decision decision, DossierExamen dossier)
    throws CoucheLogiqueException
  {
    int valeurTotale1 = 0;
    int valeurTotale2 = 0;
    String uniteVide = "";
    String nomUnite1 = "";
    String nomUnite2 = "";
    DuoAppartenance quantiteAppartenance = new DuoAppartenance();
    
    alimenterQuantitesAppartenance(quantiteAppartenance, decision, dossier);
    if (quantiteAppartenance.getQuantiteAppartenancePrincipale() != null)
    {
      valeurTotale1 = quantiteAppartenance.getQuantiteAppartenancePrincipale().getValeur().intValue();
      nomUnite1 = quantiteAppartenance.getQuantiteAppartenancePrincipale().getUnite().getNom();
    }
    if ((nomUnite1 != null) && (!uniteVide.equals(nomUnite1)))
    {
      decision.setValeurQuantiteAffiliation(valeurTotale1);
      decision.setUniteAffiliation(determineNomPourPivotUniteAffiliation(nomUnite1));
    }
    if (quantiteAppartenance.getQuantiteAppartenanceSecondaire() != null)
    {
      valeurTotale2 = quantiteAppartenance.getQuantiteAppartenanceSecondaire().getValeur().intValue();
      nomUnite2 = quantiteAppartenance.getQuantiteAppartenanceSecondaire().getUnite().getNom();
    }
    if ((nomUnite2 != null) && (!uniteVide.equals(nomUnite2)))
    {
      decision.setValeurQuantiteAffiliation2(valeurTotale2);
      decision.setUniteAffiliation2(determineNomPourPivotUniteAffiliation(nomUnite2));
    }
    DossierAffectation dossierAffectationAdmission = ((Demande)dossier.getDossierAffecte().getDemande()).getDossierAffectationAdmission();
    if ((dossierAffectationAdmission != null) && (dossierAffectationAdmission.getDossierExamen() != null))
    {
      DossierExamenAssuranceSpec dossierExamenAdmission = (DossierExamenAssuranceSpec)dossierAffectationAdmission.getDossierExamen();
      ConditionQuantiteAffiliationSpec capa07 = dossierExamenAdmission.getConditionQuantiteAffiliation();
      if (capa07 != null)
      {
        if (capa07.getJustificationAffiliation() != null)
        {
          Pra pra = (Pra)capa07.getJustificationAffiliation().getPeriodeRechercheAffiliation();
          
          Quantite affiRequise1 = null;
          Quantite affiRequise2 = null;
          Collection<?> listeQtesRequises = pra.getListeQuantitesAffiliationRequises().values();
          Iterator<?> iter = listeQtesRequises.iterator();
          while (iter.hasNext())
          {
            Quantite quantiteRequise = (Quantite)iter.next();
            if (affiRequise1 == null) {
              affiRequise1 = quantiteRequise;
            } else if (affiRequise2 == null) {
              affiRequise2 = quantiteRequise;
            }
          }
          if (affiRequise2 == null)
          {
            if (affiRequise1 != null)
            {
              decision.setValeurQuantiteAffiliationRequise(affiRequise1.getValeur().intValue());
              decision.setUniteAffiliationRequise(determineNomPourPivotUniteAffiliation(affiRequise1.getUnite().getNom()));
            }
          }
          else if (affiRequise2.getUnite().getCode().equals("18"))
          {
            decision.setValeurQuantiteAffiliationRequise(affiRequise2.getValeur().intValue());
            decision.setUniteAffiliationRequise(determineNomPourPivotUniteAffiliation(affiRequise2.getUnite().getNom()));
            
            decision.setValeurQuantiteAffiliationRequise2(affiRequise1.getValeur().intValue());
            decision.setUniteAffiliationRequise2(determineNomPourPivotUniteAffiliation(affiRequise1.getUnite().getNom()));
          }
          else
          {
            decision.setValeurQuantiteAffiliationRequise(affiRequise1.getValeur().intValue());
            decision.setUniteAffiliationRequise(determineNomPourPivotUniteAffiliation(affiRequise1.getUnite().getNom()));
            
            decision.setValeurQuantiteAffiliationRequise2(affiRequise2.getValeur().intValue());
            decision.setUniteAffiliationRequise2(determineNomPourPivotUniteAffiliation(affiRequise2.getUnite().getNom()));
          }
          if (pra.getDureeInitiale() != null) {
            decision.setPeriodeTheoriqueRechercheAffiliation(pra.getDureeInitiale().getValeur().intValue());
          }
        }
        alimenterEtatPnds(decision, capa07);
      }
    }
  }
  
  private void alimenterEtatPnds(fr.unedic.cali.dom.pivot.Decision decision, ConditionQuantiteAffiliationSpec capa07)
  {
    if ((capa07 instanceof ConditionQuantiteAffiliation)) {
      decision.setEtatPndsPourCalculAffiliation(((ConditionQuantiteAffiliation)capa07).getEtatPndsPourCalculAffi());
    }
  }
  
  private String determineAuMoins100Trimestres(Demande demande)
  {
    String val;
    String val;
    if ((demande.getDemandeur().getDateCentTrimestres() != null) && (demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(demande.getFaitGenerateur().getDateFaitGenerateur()))) {
      val = "O";
    } else {
      val = "N";
    }
    return val;
  }
  
  protected String determineTypeChomageSaisonnier(DossierExamen dossier)
  {
    String type = "";
    int val = 0;
    if (!dossier.getDossierAffecte().getProduit().getNom().equalsIgnoreCase("ASU_CVE13_01"))
    {
      if (dossier.getConstitutionCaractereSaisonnier() != null) {
        val = dossier.getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
      }
      if ((val == 0) || (val == -1)) {
        type = "";
      } else {
        type = String.valueOf(val);
      }
    }
    return type;
  }
  
  private int determinerFlagReadmission(fr.unedic.cali.asu.produits.liquidation.dom.Decision decision)
  {
    if (decision.getNatureDecision() == 12) {
      return 2;
    }
    if (decision.getConstitutionProduitResultant().getTypeCapitalRetenu() == 1) {
      return decision.getConstitutionProduitResultant().getTypeMontantRetenu() == 1 ? 2 : 3;
    }
    return decision.getConstitutionProduitResultant().getTypeMontantRetenu() == 1 ? 4 : 1;
  }
  
  private BigDecimal determinerMontantJournalierCapitalMax(fr.unedic.cali.asu.produits.liquidation.dom.Decision decision)
  {
    if (decision.getNatureDecision() == 12) {
      return decision.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur();
    }
    return decision.getConstitutionProduitResultant().getTypeCapitalRetenu() == 1 ? decision.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur() : decision.getConstitutionProduitResultant().getMontantDroitPrecedent().getValeur();
  }
  
  private void renseignerDonneesPmc(fr.unedic.cali.dom.pivot.Decision decision, DossierExamen dossier)
    throws CoucheLogiqueException
  {
    if ((dossier.getConstitutionDelais() != null) && (dossier.getConstitutionDelais().getTermePMC() != null))
    {
      decision.setDateFinPmc(dossier.getConstitutionDelais().getTermePMC());
      if (dossier.getConstitutionDelais().getTypePmc() == 1) {
        decision.setTypePmc(0);
      } else if (dossier.getConstitutionDelais().getTypePmc() == 2) {
        decision.setTypePmc(1);
      }
    }
  }
  
  private void alimenterDonneesFNA(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande, fr.unedic.cali.asu.produits.liquidation.dom.Decision decision)
    throws CoucheLogiqueException
  {
    if (decision.getConstitutionDurees() != null) {
      attribution.setNbJourEcretementPlafDuree(new BigDecimal(decision.getConstitutionDurees().getJoursEcretementSurPlafonnementDuree()));
    }
    attribution.setEstDroitOption(demande.estDroitOptionReadmission() ? "O" : "N");
    
    ActiviteSalarie fctRetenue = null;
    if (demande.getAttribution() != null)
    {
      OdAssuranceSpec ouvertureDroit = demande.getAttribution().getOuvertureDroit();
      
      ValidationProduit validationProduit = ((DossierAffectation)ouvertureDroit.getDossierAffecte()).getValidationProduit();
      if (validationProduit != null) {
        fctRetenue = validationProduit.getPeriodeValidationProduit();
      }
    }
    if ((fctRetenue != null) && (StrategieDroitOptionApresARE14.estApprenti(fctRetenue))) {
      attribution.setEstDroitApprenti("O");
    } else {
      attribution.setEstDroitApprenti("N");
    }
    attribution.setAuMoinsUneActiviteConservee("N");
    Collection<SjrActiviteConservee> listeSjrActiviteConservee = null;
    
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demande);
    if ((strategieActiviteConservee.persisterListeActivitesConserveesCapa12()) && (decision.getConditionActiviteConservee() != null)) {
      listeSjrActiviteConservee = decision.getConditionActiviteConservee().getCollectionSjrActiviteConservee();
    } else if ((decision.getConstitutionSjc() != null) && (decision.getConstitutionSjc().getSjcip() != null)) {
      listeSjrActiviteConservee = decision.getConstitutionSjc().getSjcip().getCollectionSjrActiviteConservee();
    }
    if (listeSjrActiviteConservee != null)
    {
      int nombreActiviteConservees = listeSjrActiviteConservee.size();
      if (nombreActiviteConservees >= 1) {
        attribution.setAuMoinsUneActiviteConservee("O");
      }
    }
  }
}

/* Location:
 * Qualified Name:     AlimentationBasePivot
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */