package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDuree;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class DeterminationDureeEffective
  implements OutilFonctionnel
{
  public static DeterminationDureeEffective getInstance()
  {
    return new DeterminationDureeEffective();
  }
  
  public DureeIndemnisation determinerDureeEffective(Demande demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    DureeIndemnisation dureeIndemnisation = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la (re)détermination de la durée effective." });
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    Quantite qteDureeTheorique = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    
    Damj pji = dossierExamenCourant.getConstitutionPointDepartIndemnisation().getPji();
    
    dureeIndemnisation = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation();
    if (((demande.estUneDemandeFinDroit()) || (demande.estUneDemandeFinancement())) && (qteDureeTheorique.getValeurEntiere() == 0)) {
      dureeIndemnisation.setDureeEffective(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    } else if (dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().isDureeNulle()) {
      dureeIndemnisation.setDureeEffective(qteDureeTheorique);
    } else {
      dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourAdmission(demande.getDemandeur(), pji, qteDureeTheorique, DureeReglementaire.UNITE_DEFAUT, true));
    }
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourReprise(Demande demande)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    
    Quantite qteDureeTheorique = dureeIndemnisation.getDureeTheorique();
    if ((demande.estUneDemandeFinDroitAsp()) && (qteDureeTheorique.getValeurEntiere() == 0)) {
      dureeIndemnisation.setDureeEffective(new Quantite(0, DureeReglementaire.UNITE_DEFAUT));
    } else {
      dureeIndemnisation.setDureeEffective(calculerDureeEffectivePourReprise(demande, qteDureeTheorique));
    }
    return dureeIndemnisation;
  }
  
  public Quantite calculerDureeEffectivePourReprise(Demande demande, Quantite dureeTheorique)
    throws ApplicativeException
  {
    List listeAttribution = new ArrayList();
    listeAttribution.add(demande.getAttribution());
    AppelAvant.executerAvant(listeAttribution, null);
    Damj pji = null;
    if (demande.getAttribution().getPjiEffectif() == null) {
      pji = demande.getAttribution().getDateAttribution();
    } else {
      pji = demande.getAttribution().getPjiEffectif();
    }
    return ConstitutionDuree.calculerDureeEffectivePourReprise(demande.getDemandeur(), pji, dureeTheorique, DureeReglementaire.UNITE_DEFAUT, true);
  }
  
  public Quantite determinerDureeEffectivePourComparaisonCapitaux(Demande demande, Damj pointDeDepartUnique, boolean bornerRetraite)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    DureeIndemnisation dureeIndemnisation = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination des durées réglementaires." });
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    Quantite qteDureeTheorique = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    
    dureeIndemnisation = dossierExamenCourant.getConstitutionDurees().getDureeIndemnisation();
    if (bornerRetraite == true)
    {
      if (qteDureeTheorique.getValeurEntiere() != 0) {
        dureeIndemnisation.setDureeEffective(ConstitutionDuree.calculerDureeEffectivePourAdmission(demande.getDemandeur(), pointDeDepartUnique, qteDureeTheorique, DureeReglementaire.UNITE_DEFAUT, true));
      }
      return dureeIndemnisation.getDureeEffective();
    }
    return qteDureeTheorique;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourAdmissionCsr(Demande demande)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    Quantite dureeEffectivePourAdmissionClassique = determinerDureeEffective(demande).getDureeEffective();
    Unite uniteQuantiteDuree = Unite.getParCode("4");
    
    BigDecimal dureeEffectiveBornee = bornerDureeEffective(demande, dureeEffectivePourAdmissionClassique.getValeur(), true, null);
    controleDuree(dureeEffectiveBornee, demande);
    Quantite dureeEffectiveBorneeQuantite = new Quantite(dureeEffectiveBornee, uniteQuantiteDuree);
    dureeIndemnisation.setDureeEffective(dureeEffectiveBorneeQuantite);
    DonneesTemporaires donneesTemporaire = demande.getDonneesTemporaires();
    dureeIndemnisation.setEstAccordPlusDe182jCsr(donneesTemporaire.isAccordPoursuite182JoursChomageTotalSansRupture());
    
    dureeIndemnisation.setDateMaxiIndemnisationCsr(donneesTemporaire.getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture());
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourAdmissionPmvs(Demande demande)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    
    Quantite dureeEffectivePourAdmissionClassique = determinerDureeEffective(demande).getDureeEffective();
    return bornerDureeEffectiveADateLimitePmvs(dossierExamen, dureeEffectivePourAdmissionClassique, dureeIndemnisation);
  }
  
  private DureeIndemnisation bornerDureeEffectiveADateLimitePmvs(DossierExamen dossierExamen, Quantite dureeEfective, DureeIndemnisation dureeIndemnisation)
    throws CoucheLogiqueException
  {
    int dureeEffectiveBornee = dureeEfective.getValeurEntiere();
    Damj dateLimiteIndemnisation = ((AttributionAssuranceSpec)dossierExamen).getDateLimiteIndemnisation();
    if (dateLimiteIndemnisation != null)
    {
      Damj dateDebutIndemnisation = dossierExamen.getConstitutionPointDepartIndemnisation().getPji();
      Damj dateFinIndemnisation = dateLimiteIndemnisation;
      Periode periodeIndemnisationMax = new Periode(dateDebutIndemnisation, dateFinIndemnisation);
      int dureeMaxIndemnisation = periodeIndemnisationMax.getDuree();
      if (dureeEffectiveBornee > dureeMaxIndemnisation) {
        dureeEffectiveBornee = dureeMaxIndemnisation;
      }
    }
    dureeIndemnisation.setDureeEffective(new Quantite(dureeEffectiveBornee, UniteAffiliation.JOUR));
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourReprisePmvs(Demande demande)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    Quantite quantiteReliquat = demande.getReliquat().getQuantiteReliquat();
    Quantite dureeEffectivePourRepriseClassique = calculerDureeEffectivePourReprise(demande, quantiteReliquat);
    
    return bornerDureeEffectiveADateLimitePmvs(dossierExamen, dureeEffectivePourRepriseClassique, dureeIndemnisation);
  }
  
  public DureeIndemnisation determinerDureeEffectivePourRepriseCsr(Demande demande, ResultatExecutionCalculSpec resultatCalcul)
    throws ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = dossierExamen.getConstitutionDurees().getDureeIndemnisation();
    Quantite quantiteReliquat = demande.getReliquat().getQuantiteReliquat();
    Quantite dureeEffectivePourRepriseClassique = calculerDureeEffectivePourReprise(demande, quantiteReliquat);
    Unite uniteQuantiteDuree = Unite.getParCode("4");
    
    BigDecimal dureeEffectiveCalculee = bornerDureeEffective(demande, dureeEffectivePourRepriseClassique.getValeur(), false, resultatCalcul);
    
    controleDuree(dureeEffectiveCalculee, demande);
    
    Quantite dureeEffectiveBornee = new Quantite(dureeEffectiveCalculee, uniteQuantiteDuree);
    dureeIndemnisation.setDureeEffective(dureeEffectiveBornee);
    DonneesTemporaires donneesTemporaire = demande.getDonneesTemporaires();
    dureeIndemnisation.setEstAccordPlusDe182jCsr(donneesTemporaire.isAccordPoursuite182JoursChomageTotalSansRupture());
    
    dureeIndemnisation.setDateMaxiIndemnisationCsr(donneesTemporaire.getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture());
    return dureeIndemnisation;
  }
  
  public BigDecimal bornerDureeEffective(Demande demande, BigDecimal dureeEffectiveClassique, boolean estPourDroitCourant, ResultatExecutionCalculSpec pResultatCalcul)
    throws ApplicativeException
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    Damj dateMaximumPoursuiteIndemnisation = demande.getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture();
    boolean accordPoursuite = demande.getDonneesTemporaires().isAccordPoursuite182JoursChomageTotalSansRupture();
    boolean estDateLimIndemnisationCsrSaisie = dateMaximumPoursuiteIndemnisation != null;
    boolean estEnContexteDeChomageSansRuptureDeContrat = OutilsChomageSansRCT.estDemandeEnContexteDeChomageSansRuptureDeContrat(demande);
    BigDecimal dureeEffectiveCalculee = null;
    Damj dateAttribution = dossierExamen.getDateAttribution();
    if ((estEnContexteDeChomageSansRuptureDeContrat) && (!accordPoursuite))
    {
      BigDecimal reliquatProlongation = new BigDecimal(182);
      if (!estPourDroitCourant)
      {
        ResultatExecutionCalculSpec resultatCalcul = pResultatCalcul;
        if (resultatCalcul == null)
        {
          AttributionAssuranceSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
          if (attributionPrecedente == null) {
            attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreAttributionStandardAssurance(true, true, false, true, demande));
          }
          resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionPrecedente, demande.getDateRecherche().veille(), true, true);
        }
        Quantite reliquatDureeProlongation = resultatCalcul.getReliquatDureeProlongation();
        if (reliquatDureeProlongation != null) {
          reliquatProlongation = reliquatDureeProlongation.getValeur();
        }
      }
      dureeEffectiveCalculee = reliquatProlongation;
    }
    else if ((estEnContexteDeChomageSansRuptureDeContrat) && (accordPoursuite) && (estDateLimIndemnisationCsrSaisie))
    {
      int dureePeriode = trouverDureeEntreDate(dateAttribution, dateMaximumPoursuiteIndemnisation);
      dureeEffectiveCalculee = new BigDecimal(dureePeriode);
    }
    else
    {
      dureeEffectiveCalculee = dureeEffectiveClassique;
    }
    return dureeEffectiveClassique.min(dureeEffectiveCalculee).setScale(0);
  }
  
  public void controleDuree(BigDecimal dureeEffectiveBornee, Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateMaximumPoursuiteIndemnisation = demande.getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture();
    boolean accordPoursuite = demande.getDonneesTemporaires().isAccordPoursuite182JoursChomageTotalSansRupture();
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierExamen();
    Damj dateAttribution = dossierExamen.getDateAttribution();
    if (dureeEffectiveBornee.intValue() == 0) {
      if (!accordPoursuite) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ERR_DUREE_182_J_CSR_EPUISEE", new Object[] { dateAttribution });
      } else if (dateMaximumPoursuiteIndemnisation != null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ERR_DATE_MAX_INDEMN_CSR_AVANT_ATTRIB", new Object[] { dateMaximumPoursuiteIndemnisation, dateAttribution });
      }
    }
  }
  
  private int trouverDureeEntreDate(Damj date1, Damj date2)
  {
    int dureePeriode = 0;
    if (date1.estAvant(date2))
    {
      Periode periode = new Periode(date1, date2);
      dureePeriode = periode.getDuree();
    }
    else
    {
      dureePeriode = 0;
    }
    return dureePeriode;
  }
  
  public int bornerDureeEffectiveADateLimiteIndemnisation(Demande demande, int dureeEffectiveNonBornee)
  {
    int dureeEffectiveBornee = dureeEffectiveNonBornee;
    Attribution attribution = (Attribution)demande.getDossierExamen();
    if (attribution.getConstitutionDateLimiteIndemnisation() != null)
    {
      Damj dateDebutIndemnisation = attribution.getDateAttribution();
      
      Damj dateFinIndemnisation = attribution.getDateLimiteIndemnisation();
      if (dateFinIndemnisation != null)
      {
        Periode periodeIndemnisationMax = new Periode(dateDebutIndemnisation, dateFinIndemnisation);
        int dureeMaxIndemnisation = periodeIndemnisationMax.getDuree();
        if (dureeEffectiveNonBornee > dureeMaxIndemnisation) {
          dureeEffectiveBornee = dureeMaxIndemnisation;
        }
      }
    }
    return dureeEffectiveBornee;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourRevisionCsr(Demande demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    DureeIndemnisation dureeIndemnisation = determinerDureeEffective(demande);
    
    Demande demandeOrigine = demande.getDemandeOrigine();
    
    DureeIndemnisation dureeIndemnisationOrigine = ((DossierExamen)demandeOrigine.getDossierExamen()).getConstitutionDurees().getDureeIndemnisation();
    if (dureeIndemnisationOrigine != null)
    {
      dureeIndemnisation.setEstAccordPlusDe182jCsr(dureeIndemnisationOrigine.isEstAccordPlusDe182jCsr());
      dureeIndemnisation.setDateMaxiIndemnisationCsr(dureeIndemnisationOrigine.getDateMaxiIndemnisationCsr());
    }
    return dureeIndemnisation;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */