package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.DeterminationCarenceAsu;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSuspensionChomageSansRCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreFinActivite;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSansConflit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourNumeroGamme;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionPourCompetence;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;

public class OutilChronologiePourDelaisReports
  implements OutilFonctionnel
{
  public static Chronologie determinerChronologieActivitesPourDifferes(DemandeAssuranceSpec p_demande)
  {
    Attribution attributionCourante = (Attribution)((Demande)p_demande).getAttribution();
    Periode periodeReference = attributionCourante.getConstitutionDelais().getPeriodeReference91jours();
    
    Chronologie chronoActivitesPourDifferes = determinerChronologieActivitesPourDelaisReports(p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), periodeReference);
    
    return chronoActivitesPourDifferes;
  }
  
  public static Chronologie determinerChronologieActivitesPourDelaisReports(Chronologie p_chronologiePasseProfessionnel, Periode p_periodeReference)
  {
    Chronologie chronoActivitesPourDelaisReports = null;
    if (p_periodeReference != null)
    {
      FiltresTemporel filtres = new FiltresTemporel();
      
      filtres.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
      filtres.ajouterFiltre(new FiltreFinDansBornes(p_periodeReference));
      
      filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
      filtres.ajouterFiltre(new FiltrePeriodesSansConflit());
      filtres.ajouterFiltre(new FiltreFinActivite());
      
      filtres.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieSuspensionChomageSansRCT()));
      
      chronoActivitesPourDelaisReports = p_chronologiePasseProfessionnel.copier(filtres);
    }
    return chronoActivitesPourDelaisReports;
  }
  
  public static ChronologiePeriodes determinerChronologiePeriodesIndemnisation(DemandeAssuranceSpec p_demande)
    throws ApplicativeException
  {
    ChronologiePeriodes chronoPeriodesIndemnisationRetour = null;
    
    Chronologie chronoActivitesParticipantesDifferes = determinerChronologieActivitesPourDifferes(p_demande);
    
    Periode periodeReferencePeriodesIndemnisation = null;
    if ((chronoActivitesParticipantesDifferes != null) && (!chronoActivitesParticipantesDifferes.estVide()))
    {
      ActiviteSalarie activiteSalarieCourante = null;
      Damj debutPeriodeReferencePeriodesIndemnisation = null;
      Damj termePeriodeReferencePeriodesIndemnisation = null;
      chronoActivitesParticipantesDifferes.iterer();
      while (chronoActivitesParticipantesDifferes.encoreSuivant())
      {
        activiteSalarieCourante = (ActiviteSalarie)chronoActivitesParticipantesDifferes.elementSuivant();
        if ((debutPeriodeReferencePeriodesIndemnisation == null) || (activiteSalarieCourante.getDateDebut().estAvant(debutPeriodeReferencePeriodesIndemnisation))) {
          debutPeriodeReferencePeriodesIndemnisation = activiteSalarieCourante.getDateDebut();
        }
        if ((termePeriodeReferencePeriodesIndemnisation == null) || (activiteSalarieCourante.getDateFin().estApres(termePeriodeReferencePeriodesIndemnisation))) {
          termePeriodeReferencePeriodesIndemnisation = activiteSalarieCourante.getDateFin();
        }
      }
      periodeReferencePeriodesIndemnisation = new Periode(debutPeriodeReferencePeriodesIndemnisation, termePeriodeReferencePeriodesIndemnisation);
    }
    if (periodeReferencePeriodesIndemnisation != null) {
      chronoPeriodesIndemnisationRetour = determinerChronologiePeriodesIndemnisationSurPeriodeReference(p_demande, periodeReferencePeriodesIndemnisation);
    }
    return chronoPeriodesIndemnisationRetour;
  }
  
  private static ChronologiePeriodes determinerChronologiePeriodesIndemnisationSurPeriodeReference(DemandeAssuranceSpec p_demande, Periode p_periodeReference)
    throws ApplicativeException
  {
    ChronologiePeriodes chronoPeriodesIndemnisationRetour = null;
    
    Chronologie chronoAttributionsPrecedentes = new ChronologieDebuts();
    
    FiltreET filtre = new FiltreET();
    filtre.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    filtre.ajouterFiltre(new FiltreAttributionSurDecisions());
    
    FiltreOU filtreOU = new FiltreOU();
    filtreOU.ajouterFiltre(new FiltreNegation(new FiltreDemandePourNumeroGamme(1)));
    
    FiltreET filtreAttributionAssuranceRAC = new FiltreET();
    filtreAttributionAssuranceRAC.ajouterFiltre(new FiltreDemandePourNumeroGamme(1));
    filtreAttributionAssuranceRAC.ajouterFiltre(new FiltreDecisionPourCompetence(1, 0));
    filtreOU.ajouterFiltre(filtreAttributionAssuranceRAC);
    
    filtre.ajouterFiltre(filtreOU);
    chronoAttributionsPrecedentes.ajouter(OutilRecherche.rechercherDecisionsPrecedentes(p_demande.getChronologieDemandesSansCourante(), p_demande.getDossierExamen(), filtre));
    
    chronoPeriodesIndemnisationRetour = DeterminationCarenceAsu.determinerPeriodesPriseEnCompteActiviteReduiteSurPeriodeReference(chronoAttributionsPrecedentes, p_periodeReference);
    
    return chronoPeriodesIndemnisationRetour;
  }
}

/* Location:
 * Qualified Name:     OutilChronologiePourDelaisReports
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */