package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDelaiAttente;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieISLR;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDelaiAttenteSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieFormuleISLRSpec;
import fr.unedic.cali.asu.cge01.liquidation.parcours.ResultatDeterminationDelaisReports;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConteneurISLRSpec;
import fr.unedic.cali.asu.dom.ConteneurPMCSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.PreavisMesureConservatoireNonIndemnisableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionISLR;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionPMC;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseDelaiReport;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.ConteneurISLR;
import fr.unedic.cali.asu.produits.liquidation.dom.ConteneurPMC;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class OutilDeterminationDelaisReports
  implements OutilFonctionnel
{
  private static final BigDecimal ZERO = BigDecimal.ZERO;
  private static final int NBRE_JOURS_SEMAINE = 7;
  
  public static Collection<CarencePrefixeAFixer> determinerCollectionDelaisReportsReliquats(DemandeAssuranceSpec demande, Collection<?> listeDelaisReportsAttributionPrecedente)
    throws ApplicativeException
  {
    Collection<CarencePrefixeAFixer> collectionDelaisReportsRetour = new ArrayList();
    
    Damj dateAttribution = ((DossierExamen)demande.getDossierExamen()).getDateAttribution();
    Attribution attributionPrecedente = (Attribution)demande.getDemandeOrigine().getDossierExamen();
    boolean estUnJourDelaiAttenteConsommeAttributionPrecedente = attributionPrecedente.isUnJourDiffereConsomme();
    Damj pjiAttributionPrecedente = attributionPrecedente.getConstitutionElementsActifs().getConstitutionPointDepartIndemnisation().getPji();
    if (listeDelaisReportsAttributionPrecedente != null)
    {
      Iterator<?> itDelaisReportsAttributionPrecedente = listeDelaisReportsAttributionPrecedente.iterator();
      while (itDelaisReportsAttributionPrecedente.hasNext())
      {
        CarencePrefixeAFixer delaiReportAttributionPrecedente = (CarencePrefixeAFixer)itDelaisReportsAttributionPrecedente.next();
        String typeCarence = delaiReportAttributionPrecedente.getTypeCarence();
        ObjetChronoPeriode origineReliquat = null;
        Quantite reliquat = delaiReportAttributionPrecedente.getReliquat();
        if (delaiReportAttributionPrecedente.getReliquat().getValeur().intValue() > ZERO.intValue())
        {
          if (typeCarence.equals("Différé")) {
            reliquat = getReliquatDelaiAttente(demande, dateAttribution, estUnJourDelaiAttenteConsommeAttributionPrecedente, pjiAttributionPrecedente, delaiReportAttributionPrecedente, reliquat);
          } else if (estNonSpecificiteCSP(demande)) {
            origineReliquat = delaiReportAttributionPrecedente.getOrigineReliquat();
          }
          if (reliquat != null) {
            OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsRetour, OutilDelaiReport.creerDelaiReport(typeCarence, origineReliquat, reliquat, true));
          }
        }
      }
    }
    OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsRetour, creerDelaiReportReliquatPMCIndemnisable(demande));
    
    return collectionDelaisReportsRetour;
  }
  
  private static Quantite getReliquatDelaiAttente(DemandeAssuranceSpec demande, Damj dateAttribution, boolean estUnJourDelaiAttenteConsommeAttributionPrecedente, Damj pjiAttributionPrecedente, CarencePrefixeAFixer delaiReportAttributionPrecedente, Quantite reliquatCourant)
    throws CoucheLogiqueException
  {
    Quantite reliquat = reliquatCourant;
    
    Boolean forcageDelai = null;
    if (demande.getDonneesTemporaires() != null) {
      forcageDelai = demande.getDonneesTemporaires().isDelaiAttenteForce();
    }
    if (forcageDelai != null)
    {
      reliquat = null;
    }
    else if (!estUnJourDelaiAttenteConsommeAttributionPrecedente)
    {
      reliquat = new QuantiteJour(new BigDecimal(7));
    }
    else
    {
      CritereStrategie critereStrategie = new CritereStrategie();
      critereStrategie.setDatePivot(demande.getDateAttribution());
      Damj dateFinApplicationDiffere = null;
      if (delaiReportAttributionPrecedente.getPeriodeApplicationCarence() != null) {
        dateFinApplicationDiffere = delaiReportAttributionPrecedente.getPeriodeApplicationCarence().getFin();
      }
      StrategieDelaiAttenteSpec strategie = (StrategieDelaiAttenteSpec)FabriqueStrategieDelaiAttente.getInstance().getStrategie(critereStrategie);
      
      reliquat = strategie.calculerReliquatDiffere(dateAttribution, pjiAttributionPrecedente, dateFinApplicationDiffere, reliquat, delaiReportAttributionPrecedente);
    }
    return reliquat;
  }
  
  private static boolean estNonSpecificiteCSP(DemandeAssuranceSpec demande)
  {
    return (!OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, "ARECOURCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)demande, 10));
  }
  
  private static PreavisMesureConservatoireIndemnisable creerDelaiReportReliquatPMCIndemnisable(DemandeAssuranceSpec demande)
  {
    PreavisMesureConservatoireIndemnisable pmcIndemnisableReliquat = null;
    
    Attribution attributionPrecedente = (Attribution)demande.getDemandeOrigine().getDossierExamen();
    if (attributionPrecedente.getConstitutionDelais() != null)
    {
      Damj dateDebutPMCIndemnisable = attributionPrecedente.getConstitutionDelais().getDebutPMC();
      Damj dateFinPMCIndemnisable = attributionPrecedente.getConstitutionDelais().getTermePMC();
      if ((dateDebutPMCIndemnisable != null) && (attributionPrecedente.getConstitutionDelais().getTypePmc() == 2))
      {
        pmcIndemnisableReliquat = new PreavisMesureConservatoireIndemnisable();
        pmcIndemnisableReliquat.setOrigine(new ObjetChronoPeriodeConcrete(dateDebutPMCIndemnisable.veille(), dateDebutPMCIndemnisable.veille()));
        pmcIndemnisableReliquat.setPeriodeApplicationCarence(new Periode(dateDebutPMCIndemnisable, dateFinPMCIndemnisable));
        pmcIndemnisableReliquat.setQuantiteInitial(new QuantiteJour(new BigDecimal(pmcIndemnisableReliquat.getPeriodeApplicationCarence().getDuree())));
      }
    }
    return pmcIndemnisableReliquat;
  }
  
  public static ConteneurPMCSpec determinerPMCPourActivite(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie)
    throws CoucheLogiqueException
  {
    ConteneurPMCSpec conteneurPMCCourant = ConteneurPMC.createInstance();
    
    boolean presencePmcForcee = (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null) && (demande.getDonneesTemporaires().getFinPmc() != null);
    
    boolean levagePmc = demande.getDonneesTemporaires().isLeveePmc();
    if (presencePmcForcee)
    {
      if (activiteSalarie.getIdentifiant().equalsIgnoreCase(demande.getDonneesTemporaires().getIndentifiantFctPMC())) {
        determinerPMCForce(demande, conteneurPMCCourant);
      }
    }
    else if (!levagePmc)
    {
      conteneurPMCCourant.setDemande(demande);
      ConstitutionPMC.determinerPMC(activiteSalarie, conteneurPMCCourant);
    }
    return conteneurPMCCourant;
  }
  
  public static ConteneurPMCSpec determinerPmcCsr(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    ConteneurPMCSpec conteneurPMCCourant = ConteneurPMC.createInstance();
    TravailSpec periodeDebutCarence = trouverPeriodeActiviteTerminantLeContrat(demande.getDemandeur(), (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeFctARetenirRuptureContratTravail());
    
    Preavis preavis = definirPreavis(demande);
    if ((preavis != null) && (preavis.getPeriodeNonEffectueeNonPayee() != null))
    {
      PreavisMesureConservatoireNonIndemnisableSpec pmc = conteneurPMCCourant.creerPMCNonIndemnisable((ActiviteSalarie)periodeDebutCarence, new Periode(preavis.getPeriodeNonEffectueeNonPayee().getDebut(), preavis.getPeriodeNonEffectueeNonPayee().getFin()));
      
      conteneurPMCCourant.setCarencePmc(pmc);
    }
    return conteneurPMCCourant;
  }
  
  public static ConteneurISLRSpec determinerIslrCsr(DemandeAssuranceSpec demande)
  {
    ConteneurISLRSpec conteneurISLRCourant = ConteneurISLR.createInstance();
    ActiviteSalarie periodeDebutCarence = trouverPeriodeActiviteTerminantLeContrat(demande.getDemandeur(), (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeFctARetenirRuptureContratTravail());
    
    conteneurISLRCourant.setActiviteSalarieOrigine(periodeDebutCarence);
    conteneurISLRCourant.setNombreJoursDiffere(getNbJoursCarence(demande));
    
    return conteneurISLRCourant;
  }
  
  private static int getNbJoursCarence(DemandeAssuranceSpec demande)
  {
    if (demande.getDonneesTemporaires().getQuantiteJoursDiffereChomageTotalSansRupture() != null) {
      return demande.getDonneesTemporaires().getQuantiteJoursDiffereChomageTotalSansRupture().getNombreJours();
    }
    return 0;
  }
  
  private static Preavis definirPreavis(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Preavis preavis = null;
    
    ActiviteSalarie periodeValidationProduit = OutilsChomageSansRCT.trouverDernierSinistre(demande);
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeValidationProduit));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeValidationProduit.getDateFin()));
    
    Chronologie chronoMemeActiviteGaecApresDate = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
    Chronologie chronoPeriodesRuptureContrat = chronoMemeActiviteGaecApresDate.copier(filtres);
    if (!chronoPeriodesRuptureContrat.estVide())
    {
      ActiviteSalarie activiteSalarie = (ActiviteSalarie)chronoPeriodesRuptureContrat.premierElement();
      if (activiteSalarie.getContrat().getPreavis() != null) {
        preavis = activiteSalarie.getContrat().getPreavis();
      }
    }
    return preavis;
  }
  
  public static ActiviteSalarie trouverPeriodeActiviteTerminantLeContrat(IndividuSpec demandeur, ActiviteSalarie periodeActivite)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(periodeActivite));
    filtres.ajouterFiltre(new FiltreDebutApresDate(periodeActivite.getDateFin()));
    
    Chronologie chronoPeriodesTerminantASChomageSansRCT = demandeur.getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (chronoPeriodesTerminantASChomageSansRCT.estVide()) {
      return periodeActivite;
    }
    return (ActiviteSalarie)chronoPeriodesTerminantASChomageSansRCT.dernierElement();
  }
  
  private static void determinerPMCForce(DemandeAssuranceSpec demande, ConteneurPMCSpec conteneurPMC)
  {
    ActiviteSalarie activiteSalariePMCForce = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(demande.getDonneesTemporaires().getIndentifiantFctPMC());
    if (activiteSalariePMCForce != null) {
      ConstitutionPMC.ajouterPmcForcee(activiteSalariePMCForce, demande.getDonneesTemporaires().isPmcIndemnisable(), demande.getDonneesTemporaires().getFinPmc(), conteneurPMC);
    }
  }
  
  public static void determinerMontantDiffereISLR(ConteneurISLRSpec conteneurISLR, Damj dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    try
    {
      ActiviteSalarie activiteSalarieCourante = conteneurISLR.getActiviteSalarieOrigine();
      activiteSalarieCourante.setQuantiteEuroIslr(ConstitutionISLR.getInstance().calculeISLR(activiteSalarieCourante.getListeIndemnites(), activiteSalarieCourante.getCodeMotifFin(), activiteSalarieCourante.getCategorieEmploiParticulier(), dateFaitGenerateurOuDernierSinistre));
    }
    catch (CoucheLogiqueException clex)
    {
      if (clex.getMessage().equals("ASU_PR_CALI_L_CEPA05_AUTRES_INDEMNITES_LEGALES")) {
        conteneurISLR.setAutresIndemnitesLegales(true);
      } else {
        throw clex;
      }
    }
  }
  
  public static void determinerNombreJoursDiffereISLR(ConteneurISLRSpec conteneurISLR, BaseDelaiReport baseDelaiReportISLR, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie activiteSalarieCourante = baseDelaiReportISLR.getPeriodeActiviteSalarieOrigine();
    
    boolean isTransactionEnCours = activiteSalarieCourante.getContrat().isTransactionEnCours();
    
    Damj datePivot = conteneurISLR.getDatePivotPourRecupererFormuleISLR();
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(datePivot);
    critere.setProduit(demande.getDossierAffectation() != null ? demande.getDossierAffectation().getProduit() : null);
    StrategieSpec strategie = FabriqueStrategieISLR.getInstance().getStrategie(critere);
    FormuleDelaiReportSpec formuleCarenceIslr = ((StrategieFormuleISLRSpec)strategie).getFormuleISLR();
    if (isTransactionEnCours)
    {
      conteneurISLR.setNombreJoursDiffere(formuleCarenceIslr.recupererPlafondISLR(baseDelaiReportISLR));
      conteneurISLR.setPresenceTransaction(true);
    }
    else
    {
      QuantiteEuro quantiteEuroIslr = baseDelaiReportISLR.getQuantiteEuroIslr();
      if ((quantiteEuroIslr != null) && (quantiteEuroIslr.getValeurMontant().compareTo(ZERO) > 0))
      {
        QuantiteJour resultatFormuleIslr = (QuantiteJour)formuleCarenceIslr.appliquerFormule(baseDelaiReportISLR);
        if ((resultatFormuleIslr != null) && (resultatFormuleIslr.getNombreJours() > 0)) {
          conteneurISLR.setNombreJoursDiffere(resultatFormuleIslr.getNombreJours());
        }
      }
    }
  }
  
  public static CarencePrefixeAFixer determinerDiffereICCPConservatoireForce(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    CarencePrefixeAFixer differeICCPConservatoire = null;
    if (((demande.getDossierExamen() instanceof Reprise)) && (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire() != null)) {
      differeICCPConservatoire = construireDiffereICCPConservatoire(demande);
    }
    return differeICCPConservatoire;
  }
  
  private static CarencePrefixeAFixer construireDiffereICCPConservatoire(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    CarencePrefixeAFixer differeICCPConservatoire = null;
    
    QuantiteJour quantiteJoursICCPConservatoire = demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire();
    if (quantiteJoursICCPConservatoire.getValeur().intValue() > 0)
    {
      int nombreJoursSemaine = ((QuantiteJourTravailDansSemaineSpec)quantiteJoursICCPConservatoire).getNombreJoursSemaine();
      BigDecimal nominateur1 = quantiteJoursICCPConservatoire.getValeur().setScale(0, 0);
      BigDecimal nominateur2 = new BigDecimal(Integer.toString(7));
      BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursSemaine));
      BigDecimal resultatFormule = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      QuantiteJour quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0));
      
      Damj dateFinPeriodeOrigineDiffereICCPConservatoire = determinerDateFinPeriodeOrigineDiffereICCPConservatoire(demande);
      
      differeICCPConservatoire = OutilDelaiReport.creerDelaiReport("ICCP", new ObjetChronoPeriodeConcrete(dateFinPeriodeOrigineDiffereICCPConservatoire, dateFinPeriodeOrigineDiffereICCPConservatoire), quantiteJourCalculee);
    }
    return differeICCPConservatoire;
  }
  
  private static Damj determinerDateFinPeriodeOrigineDiffereICCPConservatoire(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeAssurance = (Demande)demande;
    Damj dateFinPeriodeOrigineDiffereICCPConservatoire = demandeAssurance.getAttribution().getDateAttribution().veille();
    if (demandeAssurance.getDonneesTemporaires().getDateDepartICCP() != null) {
      dateFinPeriodeOrigineDiffereICCPConservatoire = demandeAssurance.getDonneesTemporaires().getDateDepartICCP().veille();
    } else if ((demande.getModeLiquidation() != null) && ((demande.getModeLiquidation().equals("S")) || (demande.getModeLiquidation().equals("C")))) {
      dateFinPeriodeOrigineDiffereICCPConservatoire = controleIccpConservatoireLiquidationSimplifiee(demandeAssurance, dateFinPeriodeOrigineDiffereICCPConservatoire);
    }
    return dateFinPeriodeOrigineDiffereICCPConservatoire;
  }
  
  private static Damj controleIccpConservatoireLiquidationSimplifiee(Demande demandeAssurance, Damj dateFinPeriodeOrigineDiffereICCPConservatoire)
    throws CoucheLogiqueException
  {
    Damj dateFinPeriode = dateFinPeriodeOrigineDiffereICCPConservatoire;
    if ((demandeAssurance.getEntretien() != null) && (demandeAssurance.getEntretien().isAExerceActiviteSalarie()))
    {
      dateFinPeriode = demandeAssurance.getEntretien().getDateFinContrat();
      if (dateFinPeriode.lendemain().estApres(demandeAssurance.getAttribution().getDateAttribution())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_POINT_DEPART_ICCP_CONSERVATOIRE", new String[] { dateFinPeriode.toString() });
      }
    }
    return dateFinPeriode;
  }
  
  public static int determinerDelaiAttenteCsr(DemandeAssuranceSpec demande, ResultatDeterminationDelaisReports resultat)
    throws ApplicativeException
  {
    return determinerDelaiAttente(demande, resultat);
  }
  
  public static int determinerDelaiAttente(DemandeAssuranceSpec demande, ResultatDeterminationDelaisReports resultat)
    throws ApplicativeException
  {
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(demande.getDateExamen());
    int nbreJoursDelaiAttente = 0;
    StrategieDelaiAttenteSpec strategieDelaiAttente = (StrategieDelaiAttenteSpec)FabriqueStrategieDelaiAttente.getInstance().getStrategie(critereStrategie);
    
    boolean creationDelaiAttente = strategieDelaiAttente.determinerApplicabiliteDelaiAttente(demande, resultat);
    if (creationDelaiAttente) {
      nbreJoursDelaiAttente = 7;
    }
    return nbreJoursDelaiAttente;
  }
  
  public static ConteneurPMCSpec determinerPmcPapPourActivite(DemandeAssuranceSpec demande, ActiviteSalarie pasPap, BigDecimal montantPreavis)
  {
    Sjr sjr = ((DossierExamen)demande.getDossierExamen()).getConstitutionSjr().getSjrrp();
    
    BigDecimal dureePmc = montantPreavis.divide(sjr.getSalaire(), 0, 0);
    
    Damj debut = pasPap.getDateFin().lendemain();
    Damj fin = debut.deplacerVersAvant(new DureeCalendaire(0, 0, dureePmc.intValue() - 1));
    
    Periode periodePmc = new Periode(debut, fin);
    
    ConteneurPMCSpec conteneurPMC = ConteneurPMC.createInstance();
    conteneurPMC.setDemande(demande);
    
    PreavisMesureConservatoireNonIndemnisableSpec pmc = conteneurPMC.creerPMCNonIndemnisable(pasPap, periodePmc);
    conteneurPMC.setCarencePmc(pmc);
    
    return conteneurPMC;
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationDelaisReports
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */