package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.OutilJustificationSjrSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationDiviseurPeriodeParticipante;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafonds;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafondsDetailParExerciceEtEmployeur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafondsParEmployeur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPlafondsParExerciceEtEmployeur;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSr;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSrPeriodeActiviteRetenue;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationSrPeriodeRemunerationParticipante;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.spec.RemunerationSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;

public class OutilJustificationSjr
  implements OutilJustificationSjrSpec
{
  private static OutilJustificationSjr instance = new OutilJustificationSjr();
  
  public static OutilJustificationSjr getInstance()
  {
    return instance;
  }
  
  public void justifierDiviseurDonneeDiviseurMinimal(JustificationDiviseur justificationDiviseur, int diviseurMinimal)
  {
    justificationDiviseur.setDiviseurMinimal(diviseurMinimal);
  }
  
  public void justifierDiviseurDonneePremiereValeurFormule(JustificationDiviseur justificationDiviseur, int premiereValeurFormule)
  {
    justificationDiviseur.setPremiereValeurFormule(premiereValeurFormule);
  }
  
  public void justifierDiviseurDonneePrimoDemandeurA3A4A5(JustificationDiviseur justificationDiviseur, boolean estPrimoDemandeurA3A4A5)
  {
    justificationDiviseur.setPrimoDemandeurA3A4A5(estPrimoDemandeurA3A4A5);
  }
  
  public void justifierDiviseurPeriodeParticipanteHeures(JustificationDiviseur justificationDiviseur, Reglement reglementApplicable, ActiviteSalarie activiteSalarie, int nombreHeuresTotal)
  {
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(activiteSalarie.getPeriode());
    
    justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(activiteSalarie);
    justifDiviseurPeriodeParticipanteCourante.setNombreHeuresTotal(nombreHeuresTotal);
    
    Reglement reglementAppartenanceCourant = activiteSalarie.getReglement();
    if (reglementA4ouA5(reglementApplicable, reglementAppartenanceCourant)) {
      justifDiviseurPeriodeParticipanteCourante.setNombreHeuresDroitAConges(nombreHeuresTotal);
    }
    justificationDiviseur.getListePeriodesParticipantes().ajouter(justifDiviseurPeriodeParticipanteCourante);
  }
  
  private boolean reglementA4ouA5(Reglement reglementApplicable, Reglement reglementAppartenanceCourant)
  {
    boolean estReglementIdentique = reglementApplicable.estNomReglementIdentique(reglementAppartenanceCourant.getNomReglement());
    
    boolean estReglementA4 = reglementApplicable.estNomReglementIdentique("A4");
    boolean estReglementA5 = reglementApplicable.estNomReglementIdentique("A5");
    return (estReglementIdentique) && ((estReglementA4) || (estReglementA5));
  }
  
  public void justifierDiviseurPeriodeParticipanteJoursAbsence(JustificationDiviseur justificationDiviseur, Periode periode, ObjetChronoPeriode objetChronoPeriodeParticipante, BigDecimal nombreJours)
  {
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periode);
    
    justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(objetChronoPeriodeParticipante);
    justifDiviseurPeriodeParticipanteCourante.setNombreJourAbsence(nombreJours);
    justificationDiviseur.getListePeriodesParticipantes().ajouter(justifDiviseurPeriodeParticipanteCourante);
  }
  
  public void justifierDiviseurPeriodeParticipanteJoursAbsenceNatureMultiple(JustificationDiviseur justificationDiviseur, Periode periode, Chronologie chronoPeriodes, BigDecimal nombreJours)
  {
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periode);
    
    justifDiviseurPeriodeParticipanteCourante.renseignerNatureMultiplePeriode((ChronologiePeriodes)chronoPeriodes);
    justifDiviseurPeriodeParticipanteCourante.setNombreJourAbsence(nombreJours);
    justificationDiviseur.getListePeriodesParticipantes().ajouter(justifDiviseurPeriodeParticipanteCourante);
  }
  
  public void justifierDiviseurPeriodeParticipanteJoursDeductibles(JustificationDiviseur justificationDiviseur, Periode periode, ObjetChronoPeriode objetChronoPeriodeParticipante, int nombreJours)
  {
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periode);
    
    justifDiviseurPeriodeParticipanteCourante.renseignerNaturePeriode(objetChronoPeriodeParticipante);
    justifDiviseurPeriodeParticipanteCourante.setNombreJoursDeductibles(nombreJours);
    justificationDiviseur.getListePeriodesParticipantes().ajouter(justifDiviseurPeriodeParticipanteCourante);
  }
  
  public void justifierDiviseurPeriodeParticipanteJoursDeductiblesNatureMultiple(JustificationDiviseur justificationDiviseur, Periode periode, Chronologie chronoPeriodes, int nombreJours)
  {
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periode);
    
    justifDiviseurPeriodeParticipanteCourante.renseignerNatureMultiplePeriode((ChronologiePeriodes)chronoPeriodes);
    justifDiviseurPeriodeParticipanteCourante.setNombreJoursDeductibles(nombreJours);
    justificationDiviseur.getListePeriodesParticipantes().ajouter(justifDiviseurPeriodeParticipanteCourante);
  }
  
  public void justifierDiviseurPeriodeParticipanteJoursInappartenance(JustificationDiviseur justificationDiviseur, Periode periodeInappartenance, ChronologiePeriodes chronoPeriodes)
  {
    JustificationDiviseurPeriodeParticipante justifDiviseurPeriodeParticipanteCourante = new JustificationDiviseurPeriodeParticipante(periodeInappartenance);
    
    justifDiviseurPeriodeParticipanteCourante.setNombreJoursInappartenance(periodeInappartenance.getDuree());
    if (chronoPeriodes.estVide())
    {
      justifDiviseurPeriodeParticipanteCourante.setNature(10);
    }
    else
    {
      justifDiviseurPeriodeParticipanteCourante.renseignerNatureMultiplePeriode(chronoPeriodes);
      justifDiviseurPeriodeParticipanteCourante.completerNatureMultiplePeriodeInactivite(chronoPeriodes);
    }
    justificationDiviseur.getListePeriodesParticipantes().ajouter(justifDiviseurPeriodeParticipanteCourante);
  }
  
  public void justifierPlafondsDetailParExerciceEtEmployeur(JustificationPlafondsParEmployeur justificationPlafondsParEmployeur, Periode periodeMoisCivil, BigDecimal cptpApplicable, BigDecimal plafondMensuel)
  {
    JustificationPlafondsDetailParExerciceEtEmployeur justificationPlafondsDetailParExerciceEtEmployeurCourant = new JustificationPlafondsDetailParExerciceEtEmployeur(periodeMoisCivil);
    
    justificationPlafondsDetailParExerciceEtEmployeurCourant.setCptp(cptpApplicable);
    justificationPlafondsDetailParExerciceEtEmployeurCourant.setPlafond(plafondMensuel);
    justificationPlafondsParEmployeur.getListeDetailsPlafondsParExerciceEtEmployeur().add(justificationPlafondsDetailParExerciceEtEmployeurCourant);
  }
  
  public JustificationPlafondsParExerciceEtEmployeur initialiserJustificationPlafondsParExerciceEtEmployeur(JustificationPlafonds justificationPlafonds)
  {
    JustificationPlafondsParExerciceEtEmployeur justificationPlafondsParExerciceCourant = new JustificationPlafondsParExerciceEtEmployeur();
    justificationPlafonds.getListePlafondsParExerciceEtEmployeur().add(justificationPlafondsParExerciceCourant);
    return justificationPlafondsParExerciceCourant;
  }
  
  public JustificationPlafondsParEmployeur initialiserJustificationPlafondsParEmployeur(JustificationPlafondsParExerciceEtEmployeur justificationPlafondsParExerciceEtEmployeur)
  {
    JustificationPlafondsParEmployeur justificationPlafondsParEmployeurCourant = new JustificationPlafondsParEmployeur();
    justificationPlafondsParExerciceEtEmployeur.getListePlafondsParEmployeur().add(justificationPlafondsParEmployeurCourant);
    return justificationPlafondsParEmployeurCourant;
  }
  
  public void justifierPlafondsParExerciceEtEmployeur(JustificationPlafondsParExerciceEtEmployeur justificationPlafondsParExerciceEtEmployeur, String exercice, BigDecimal sommeSrPlafonne, BigDecimal plafondParExercice, BigDecimal srPlafonneParExercice)
  {
    justificationPlafondsParExerciceEtEmployeur.setExercice(exercice);
    justificationPlafondsParExerciceEtEmployeur.setSommeSrPlafonne(sommeSrPlafonne);
    justificationPlafondsParExerciceEtEmployeur.setPlafondParExercice(plafondParExercice);
    justificationPlafondsParExerciceEtEmployeur.setSrPlafonneParExercice(srPlafonneParExercice);
  }
  
  public void justifierPlafondsParEmployeur(JustificationPlafondsParEmployeur justificationPlafondsParEmployeur, String raisonSociale, BigDecimal srNonPlafonne, BigDecimal plafond, BigDecimal srPlafonne)
  {
    justificationPlafondsParEmployeur.setRaisonSociale(raisonSociale);
    justificationPlafondsParEmployeur.setSrNonPlafonne(srNonPlafonne);
    justificationPlafondsParEmployeur.setPlafond(plafond);
    justificationPlafondsParEmployeur.setSrPlafonne(srPlafonne);
  }
  
  public void justifierSrMontant(JustificationSr justificationSr, int typeMontant, BigDecimal montant)
  {
    switch (typeMontant)
    {
    case 2: 
      justificationSr.setSalaireReferenceNonPlafonne(montant);
      break;
    case 1: 
      justificationSr.setSalaireReferencePlafonnne(montant);
      break;
    case 3: 
      justificationSr.setTotalSalairesRetenus(montant);
      break;
    case 4: 
      justificationSr.setTotalPrimesNormalesRetenues(montant);
      break;
    case 5: 
      justificationSr.setTotalPrimesExceptionnellesRetenues(montant);
      break;
    }
  }
  
  public JustificationSrPeriodeActiviteRetenue initialiserJustificationSrPeriodeActiviteRetenue(JustificationSr justificationSr, ActiviteSalarie activiteSalarie)
  {
    JustificationSrPeriodeActiviteRetenue justificationSrPeriodeActiviteCourante = new JustificationSrPeriodeActiviteRetenue(activiteSalarie.getPeriode());
    
    justificationSrPeriodeActiviteCourante.setRaisonSociale(activiteSalarie.getEntreprise().getLibelleEntreprise());
    justificationSrPeriodeActiviteCourante.setReglement(activiteSalarie.getReglement().getNomReglement());
    justificationSr.getListeActivitesSalarieesRetenues().ajouter(justificationSrPeriodeActiviteCourante);
    
    return justificationSrPeriodeActiviteCourante;
  }
  
  public void justifierSrPeriodeRemunerationParticipante(JustificationSrPeriodeActiviteRetenue justificationSrPeriodeActiviteRetenue, Damj dateDebutPeriodeJustifiee, Damj dateFinPeriodeJustifiee, RemunerationSpec remuneration, int typeRemuneration, BigDecimal montant)
  {
    JustificationSrPeriodeRemunerationParticipante justificationSrPeriodeRemunerationCourante = new JustificationSrPeriodeRemunerationParticipante(dateDebutPeriodeJustifiee, dateFinPeriodeJustifiee);
    
    justificationSrPeriodeRemunerationCourante.setPeriodeRemunerationParticipante(remuneration);
    justificationSrPeriodeRemunerationCourante.setMontantRetenu(montant);
    justificationSrPeriodeActiviteRetenue.getListePeriodeRemunerationParticipante().ajouter(justificationSrPeriodeRemunerationCourante);
  }
}

/* Location:
 * Qualified Name:     OutilJustificationSjr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */