package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.parametres.Parametres;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.mnt.dom.ConditionActiviteMaintien;
import fr.unedic.cali.asu.mnt.dom.ConditionAppartenanceMaintien;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.asu.produits.liquidation.dom.Novation;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreContratPaysValidesPourMaintien;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationCaf;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;
import java.util.Vector;

public class RechercheConditionActiviteMaintien
  implements OutilFonctionnel
{
  static final BigDecimal NOMBRE_JOUR_UNE_ANNEE = new BigDecimal("365");
  
  private static ChronologiePeriodes determinerChronoActivitesSalariees(ChronologiePeriodes chronoPasseProfessionnel, Periode periodeReference)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltreContratPaysValidesPourMaintien());
    filtres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    return (ChronologiePeriodes)chronoPasseProfessionnel.copier(filtres);
  }
  
  private static ChronologiePeriodes determinerChronoPeriodesAssimilablesAvecLimite(ChronologiePeriodes chronoPasseProfessionnel, Periode periodeReference)
  {
    FiltresTemporel listeFiltres = new FiltresTemporel();
    
    listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeReference));
    
    FiltrePeriodesSurFiltresExclusifs filtreExclusif = new FiltrePeriodesSurFiltresExclusifs();
    
    filtreExclusif.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    
    filtreExclusif.ajouterFiltre(new FiltrePeriodeIndemnisationCaf());
    listeFiltres.ajouterFiltre(filtreExclusif);
    
    return (ChronologiePeriodes)chronoPasseProfessionnel.copier(listeFiltres);
  }
  
  public static ConditionActiviteMaintien verifierActivite(DemandeMaintien demandeMaintien)
    throws CoucheLogiqueException
  {
    ConditionActiviteMaintien condition = new ConditionActiviteMaintien();
    condition.setEtatSatisfait(false);
    
    ChronologiePeriodes passeProfessionnel = demandeMaintien.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    Reglement reglementDroitMaintenu = demandeMaintien.getReglementDroitMaintenu();
    
    Convertisseur convertisseurUniteAffiliation = demandeMaintien.getProduitMaintenu().determinerConvertisseurUniteAffiliation();
    
    Periode periodeReference = determinerPeriodeReferenceActivite(demandeMaintien);
    
    ChronologiePeriodes chronoActivitesRetenues = determinerChronoActivitesSalariees(passeProfessionnel, periodeReference);
    
    Quantite activiteDiscontinueCalculee = calculerActivite(chronoActivitesRetenues, periodeReference, reglementDroitMaintenu, convertisseurUniteAffiliation);
    
    Quantite activiteAVerifier = activiteDiscontinueCalculee;
    condition.setQuantiteActiviteDiscontinueCalculee(activiteDiscontinueCalculee);
    
    Quantite activiteDiscontinueRequise = Parametres.getQuantiteActiviteRequisePourMaintien(reglementDroitMaintenu);
    condition.setQuantiteActiviteDiscontinueRequise(activiteDiscontinueRequise);
    if ((demandeMaintien.getDonneesForcees().getQuantiteActiviteCinqAns() != null) && (!demandeMaintien.getDonneesForcees().estActiviteContinue()))
    {
      Quantite activiteDiscontinueImposee = demandeMaintien.getDonneesForcees().getQuantiteActiviteCinqAns();
      activiteAVerifier = activiteDiscontinueImposee;
      condition.setQuantiteActiviteDiscontinueImposee(activiteDiscontinueImposee);
    }
    if (activiteAVerifier.compareTo(activiteDiscontinueRequise) >= 0)
    {
      condition.setEtatSatisfait(true);
    }
    else
    {
      Quantite activiteContinueCalculee = calculerActiviteConsecutive(chronoActivitesRetenues, periodeReference, reglementDroitMaintenu, convertisseurUniteAffiliation);
      
      activiteAVerifier = activiteContinueCalculee;
      condition.setQuantiteActiviteContinueCalculee(activiteContinueCalculee);
      
      Quantite activiteContinueRequise = Parametres.getQuantiteActiviteConsecutiveRequisePourMaintien(reglementDroitMaintenu);
      condition.setQuantiteActiviteContinueRequise(activiteContinueRequise);
      if ((demandeMaintien.getDonneesForcees().getQuantiteActiviteCinqAns() != null) && (demandeMaintien.getDonneesForcees().estActiviteContinue()))
      {
        Quantite activiteContinueImposee = demandeMaintien.getDonneesForcees().getQuantiteActiviteCinqAns();
        activiteAVerifier = activiteContinueImposee;
        condition.setQuantiteActiviteContinueImposee(activiteContinueImposee);
      }
      if (activiteAVerifier.compareTo(activiteContinueRequise) >= 0)
      {
        condition.setEtatSatisfait(true);
      }
      else
      {
        condition.setCodeMotifEchec(984);
        condition.setEtatSatisfait(false);
      }
    }
    return condition;
  }
  
  private static Periode determinerPeriodeReferenceActivite(DemandeMaintien demande)
    throws CoucheLogiqueException
  {
    Periode periode = new Periode();
    Demande demandeMaintenue = (Demande)demande.getDemandeMaintenue();
    Damj dateFaitGenerateur;
    Damj dateFaitGenerateur;
    if ((demandeMaintenue.getDossierExamen() instanceof Novation)) {
      dateFaitGenerateur = demande.getFGDDroitMaintenu().getDateFaitGenerateur();
    } else {
      dateFaitGenerateur = demandeMaintenue.getDateFaitGenerateurOuDernierSinistre();
    }
    if (dateFaitGenerateur != null)
    {
      periode.setFin(dateFaitGenerateur);
      periode.setDebut(dateFaitGenerateur.deplacerVersArriere(Parametres.DUREE_PERIODE_RECHERCHE_ACTIVITE_MAINTIEN));
    }
    return periode;
  }
  
  public static ConditionAppartenanceMaintien verifierAppartenance(DemandeMaintien demandeMaintien)
  {
    ConditionAppartenanceMaintien condition = new ConditionAppartenanceMaintien();
    
    Periode periodeReference = determinerPeriodeReferenceAppartenance(demandeMaintien);
    
    Quantite appartenanceCalculee = calculerAppartenance(demandeMaintien.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation(), periodeReference);
    
    Quantite appartenanceAVerifier = appartenanceCalculee;
    condition.setQuantiteAppartenanceCalculee(appartenanceCalculee);
    
    Quantite appartenanceRequise = Parametres.QUANTITE_APPARTENANCE_REQUISE_MAINTIEN;
    condition.setQuantiteAppartenanceRequise(appartenanceRequise);
    
    Convertisseur convertisseurUniteAffiliation = demandeMaintien.getProduitMaintenu().determinerConvertisseurUniteAffiliation();
    
    Quantite appartenanceImposee = demandeMaintien.getDonneesForcees().getQuantiteAppartenance();
    if ((appartenanceImposee != null) && (appartenanceImposee.getValeur().compareTo(BigDecimal.ZERO) > 0))
    {
      if (appartenanceImposee.getUnite().getNom().equalsIgnoreCase("annee"))
      {
        appartenanceImposee = new Quantite(appartenanceImposee.getValeur().multiply(NOMBRE_JOUR_UNE_ANNEE), Unite.getParCode("11"));
      }
      else if (appartenanceImposee.getUnite().getNom().equalsIgnoreCase("heure de travail"))
      {
        appartenanceImposee = convertisseurUniteAffiliation.convertir(appartenanceImposee, Unite.getParCode("11"));
      }
      else if (appartenanceImposee.getUnite().getNom().equalsIgnoreCase("heure"))
      {
        Quantite quantiteAConvertir = new Quantite(appartenanceImposee.getValeur(), Unite.getParCode("18"));
        appartenanceImposee = convertisseurUniteAffiliation.convertir(quantiteAConvertir, Unite.getParCode("11"));
      }
      else if (appartenanceImposee.getUnite().getNom().equalsIgnoreCase("jour"))
      {
        appartenanceImposee = new Quantite(appartenanceImposee.getValeur(), UniteAffiliation.JOUR);
      }
      appartenanceAVerifier = appartenanceImposee;
    }
    condition.setQuantiteAppartenanceImposee(appartenanceImposee);
    if (appartenanceAVerifier.compareTo(appartenanceRequise) >= 0)
    {
      condition.setEtatSatisfait(true);
    }
    else
    {
      condition.setCodeMotifEchec(983);
      condition.setEtatSatisfait(false);
    }
    return condition;
  }
  
  private static Periode determinerPeriodeReferenceAppartenance(DemandeMaintien demandeMaintien)
  {
    Periode periode = new Periode();
    
    IndividuSpec allocataire = demandeMaintien.getDemandeur();
    periode.setDebut(allocataire.getDateNaissance().deplacerVersAvant(Parametres.AGE_DEBUT_PASSE_PROFESSIONNEL_MAINTIEN));
    periode.setFin(demandeMaintien.getFGDDroitMaintenu().getDateFaitGenerateur());
    
    return periode;
  }
  
  private static Quantite calculerActivite(ChronologiePeriodes chronoActivitesRetenues, Periode periodeReference, Reglement reglementApplicable, Convertisseur convertisseurUniteAffiliation)
  {
    Quantite quantiteActivite;
    Quantite quantiteActivite;
    if (reglementApplicable.estNomReglementIdentique("A4"))
    {
      List listePeriodesDecoupees = OutillageChronologiePeriodes.decouper(periodeReference, chronoActivitesRetenues);
      quantiteActivite = determinerQuantiteActiviteSalarieeAvecAffi(listePeriodesDecoupees, chronoActivitesRetenues, UniteAffiliation.HEURE_TRAVAIL, convertisseurUniteAffiliation);
    }
    else
    {
      quantiteActivite = determinerQuantiteActiviteSalarieeAvecDuree(chronoActivitesRetenues, periodeReference);
    }
    return quantiteActivite;
  }
  
  private static Quantite calculerActiviteConsecutive(ChronologiePeriodes chronoActivitesRetenues, Periode periodeReference, Reglement reglementApplicable, Convertisseur convertisseurUniteAffiliation)
  {
    Quantite quantiteActivite = null;
    boolean activiteConsecutiveNonTrouve = true;
    Vector periodesConsecutives = new Vector();
    
    List<?> listePeriodesDecoupees = OutillageChronologiePeriodes.decouper(periodeReference, chronoActivitesRetenues);
    Iterator<?> iterPeriodesDecoupees = listePeriodesDecoupees.iterator();
    while ((iterPeriodesDecoupees.hasNext()) && (activiteConsecutiveNonTrouve))
    {
      Periode periodeUnitaireCourante = (Periode)iterPeriodesDecoupees.next();
      if (periodeUnitaireCourante.inter(chronoActivitesRetenues) != 0) {
        if (periodesConsecutives.isEmpty())
        {
          periodesConsecutives.add(periodeUnitaireCourante);
        }
        else
        {
          Periode dernierElementConsecutif = (Periode)periodesConsecutives.lastElement();
          if (!dernierElementConsecutif.finitAuDebutDe(periodeUnitaireCourante)) {
            periodesConsecutives = new Vector();
          }
          periodesConsecutives.add(periodeUnitaireCourante);
        }
      }
      if (reglementApplicable.estNomReglementIdentique("A4")) {
        quantiteActivite = determinerQuantiteActiviteSalarieeAvecAffi(periodesConsecutives, chronoActivitesRetenues, UniteAffiliation.getParCode("18"), convertisseurUniteAffiliation);
      } else {
        quantiteActivite = determinerQuantiteActiviteSalarieeAvecAffi(periodesConsecutives, chronoActivitesRetenues, UniteAffiliation.getParCode("11"), convertisseurUniteAffiliation);
      }
      if (quantiteActivite.compareTo(Parametres.getQuantiteActiviteConsecutiveRequisePourMaintien(reglementApplicable)) >= 0) {
        activiteConsecutiveNonTrouve = false;
      }
    }
    return quantiteActivite;
  }
  
  private static Quantite calculerAppartenance(ChronologiePeriodes passeProfessionnel, Periode periodeReference)
  {
    ChronologiePeriodes chronoActivitesRetenues = determinerChronoActivitesSalariees(passeProfessionnel, periodeReference);
    
    Quantite quantiteAppartenanceCalculee = determinerQuantiteActiviteSalarieeAvecDuree(chronoActivitesRetenues, periodeReference);
    
    Quantite quantiteAssimilableCalculee = determinerQuantiteAssimilable(passeProfessionnel, periodeReference);
    quantiteAppartenanceCalculee = quantiteAppartenanceCalculee.ajouter(quantiteAssimilableCalculee);
    
    return quantiteAppartenanceCalculee;
  }
  
  private static Quantite determinerQuantiteActiviteSalarieeAvecDuree(ChronologiePeriodes chronoActivitesRetenues, Periode periodeReference)
  {
    int nombreJoursActiviteDansPeriodeRef = periodeReference.inter(chronoActivitesRetenues);
    
    return new Quantite(nombreJoursActiviteDansPeriodeRef, Unite.getParCode("11"));
  }
  
  private static Quantite determinerQuantiteActiviteSalarieeAvecAffi(List listePeriodesDecoupees, ChronologiePeriodes chronoActivitesRetenues, Unite uniteRecherche, Convertisseur convertisseurUniteAffiliation)
  {
    Damj borneMax = null;
    
    ChronologiePeriodes chronoPeriode = new ChronologiePeriodes();
    if (!listePeriodesDecoupees.isEmpty())
    {
      int derniereIndice = listePeriodesDecoupees.size() - 1;
      borneMax = ((Periode)listePeriodesDecoupees.get(derniereIndice)).getFin();
    }
    for (Iterator iterPeriodesDecoupees = listePeriodesDecoupees.iterator(); iterPeriodesDecoupees.hasNext();)
    {
      Periode periodeUnitaire = (Periode)iterPeriodesDecoupees.next();
      Iterator iterActivitesRetenues = chronoActivitesRetenues.iterer();
      Iterator iterPMA;
      while (iterActivitesRetenues.hasNext())
      {
        ActiviteSalarie pas = (ActiviteSalarie)iterActivitesRetenues.next();
        Periode periodePas = pas.getPeriode();
        if (periodeUnitaire.chevauche(periodePas)) {
          for (iterPMA = pas.getListePeriodesMesureActivite().iterer(); iterPMA.hasNext();)
          {
            PeriodeMesureActivite pma = (PeriodeMesureActivite)iterPMA.next();
            Damj dateFin;
            Damj dateFin;
            if (pma.getDateFin().estApresOuCoincideAvec(borneMax)) {
              dateFin = borneMax;
            } else {
              dateFin = pma.getDateFin();
            }
            PeriodeMesureActivite periodePma = new PeriodeMesureActivite(pma.getDateDebut(), dateFin);
            ajouterPeriodeSurChronoPourFusion(chronoPeriode, periodePma, periodeUnitaire, uniteRecherche, pma, convertisseurUniteAffiliation);
          }
        }
      }
    }
    BigDecimal total;
    BigDecimal total;
    if (uniteRecherche.getCode().equals("11")) {
      total = determinerQuantiteActiviteSalarieeAvecUniteJours(chronoPeriode);
    } else {
      total = determinerQuantiteActiviteSalarieeAvecUniteHeures(chronoPeriode, uniteRecherche);
    }
    return new Quantite(total.intValue(), uniteRecherche);
  }
  
  private static Quantite determinerQuantiteAssimilable(ChronologiePeriodes passeProfessionnel, Periode periodeReference)
  {
    ChronologiePeriodes chronoPeriodesAssimilablesAvecLimite = determinerChronoPeriodesAssimilablesAvecLimite(passeProfessionnel, periodeReference);
    
    int nombreJoursAssimilableAveclimiteDansPeriodeRef = periodeReference.inter(chronoPeriodesAssimilablesAvecLimite);
    Quantite quantiteAssimilableRetenue = new Quantite(nombreJoursAssimilableAveclimiteDansPeriodeRef, Unite.getParCode("11"));
    if (quantiteAssimilableRetenue.getValeurEntiere() > 0) {
      quantiteAssimilableRetenue = quantiteAssimilableRetenue.min(Parametres.QUANTITE_LIMITE_ASSIMILATION_MAINTIEN);
    }
    return quantiteAssimilableRetenue;
  }
  
  private static Quantite proratiser(Quantite pquantiteAffiliation, Periode activite, PeriodeMesureActivite periodePas, Convertisseur convertisseurUniteAffiliation)
  {
    BigDecimal num2 = new BigDecimal(activite.getDuree());
    BigDecimal denom1 = new BigDecimal(periodePas.getDuree());
    Quantite quantiteAffiliation = convertisseurUniteAffiliation.convertir(pquantiteAffiliation, UniteAffiliation.JOUR);
    BigDecimal num1 = quantiteAffiliation.getValeur();
    BigDecimal resultat = Mathematiques.proratiser(num1, num2, denom1);
    
    Quantite quantiteJour = new Quantite(resultat.intValue(), UniteAffiliation.JOUR);
    
    return convertisseurUniteAffiliation.convertir(quantiteJour, pquantiteAffiliation.getUnite());
  }
  
  private static void ajouterPeriodeSurChronoPourFusion(ChronologiePeriodes chrono, PeriodeMesureActivite periodePma, Periode periodeUnitaire, Unite uniteRecherche, PeriodeMesureActivite pma, Convertisseur convertisseurUniteAffiliation)
  {
    if (periodeUnitaire.chevauche(periodePma.getPeriode()))
    {
      if (uniteRecherche.getCode().equals("11"))
      {
        if (periodeUnitaire.getDebut().estApres(periodePma.getDateDebut())) {
          periodePma.setDateDebut(periodeUnitaire.getDebut());
        }
        if (periodeUnitaire.getFin().estAvant(periodePma.getDateFin())) {
          periodePma.setDateFin(periodeUnitaire.getFin());
        }
      }
      else
      {
        Quantite quantiteAffiliation = pma.getQuantiteAffiliation(uniteRecherche);
        if (quantiteAffiliation != null)
        {
          if ((!periodePma.getDateDebut().estApresOuCoincideAvec(periodeUnitaire.getDebut())) || (!periodePma.getDateFin().estAvantOuCoincideAvec(periodeUnitaire.getFin()))) {
            quantiteAffiliation = proratiser(quantiteAffiliation, periodeUnitaire, periodePma, convertisseurUniteAffiliation);
          }
          periodePma.ajouterQuantiteAffiliation(quantiteAffiliation);
        }
        else
        {
          if (periodeUnitaire.getDebut().estApres(periodePma.getDateDebut())) {
            periodePma.setDateDebut(periodeUnitaire.getDebut());
          }
          if (periodeUnitaire.getFin().estAvant(periodePma.getDateFin())) {
            periodePma.setDateFin(periodeUnitaire.getFin());
          }
          quantiteAffiliation = new Quantite(periodePma.getDuree(), UniteAffiliation.JOUR);
          
          quantiteAffiliation = convertisseurUniteAffiliation.convertir(quantiteAffiliation, UniteAffiliation.HEURE_TRAVAIL);
          periodePma.ajouterQuantiteAffiliation(quantiteAffiliation);
        }
      }
      chrono.ajouter(periodePma);
    }
  }
  
  private static BigDecimal determinerQuantiteActiviteSalarieeAvecUniteHeures(ChronologiePeriodes chrono, Unite uniteRecherche)
  {
    BigDecimal total = new BigDecimal("0");
    if ((chrono != null) && (!chrono.estVide()))
    {
      Iterator it = chrono.iterer();
      while (it.hasNext())
      {
        PeriodeMesureActivite objetPeriode = (PeriodeMesureActivite)it.next();
        Quantite quantiteAffiliation = objetPeriode.getQuantiteAffiliation(uniteRecherche);
        if (quantiteAffiliation != null)
        {
          total = total.add(quantiteAffiliation.getValeur());
          chrono.supprimer();
        }
      }
    }
    return total;
  }
  
  private static BigDecimal determinerQuantiteActiviteSalarieeAvecUniteJours(ChronologiePeriodes chrono)
  {
    BigDecimal total = new BigDecimal("0");
    if ((chrono != null) && (!chrono.estVide()))
    {
      ChronologiePeriodes chronoPeriodeFusion = chrono.fusionnerChevauchementPeriodes();
      Iterator it = chronoPeriodeFusion.iterer();
      while (it.hasNext())
      {
        ObjetChronoPeriode objetPeriode = (ObjetChronoPeriode)it.next();
        total = total.add(new BigDecimal(objetPeriode.getDuree()));
      }
    }
    return total;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionActiviteMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */