package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.OutilQuantiteAffiliation;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.ParcoursRechercheAlertesNonBloquantes;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteContenuDansPra;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class RechercheConditionQuantiteAffiliation
{
  private static final Damj DATE_LIMITE_PRIME_500_EUROS = new Damj(2010, 3, 31);
  
  public static RechercheConditionQuantiteAffiliation getInstance()
  {
    return new RechercheConditionQuantiteAffiliation();
  }
  
  public ConditionQuantiteAffiliation rechercheConditionQuantiteAffiliation(Demande demande, IndividuSpec individu)
    throws ApplicativeException
  {
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    DossierExamen dossierExamen = (DossierExamen)dossierAffectation.getDossierExamen();
    ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
    
    ConditionQuantiteAffiliation conditionQuantiteAffiliation = dossierExamen.createConditionQuantiteAffiliation();
    
    boolean contexteDemandeSousJacenteRevision = OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demande.getListContexteDemande(), "ARESJREV");
    if ((contexteDemandeSousJacenteRevision) || (dossierExamen.getConditionFaitGenerateur().estSatisfait()))
    {
      if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
      {
        conditionQuantiteAffiliation.setEtatSatisfait(true);
        conditionQuantiteAffiliation.setQuantiteAppartenance(validationProduit.getQuantiteAcquise());
        conditionQuantiteAffiliation.setQuantiteAppartenanceSecondaire(validationProduit.getQuantiteAcquiseSecondaire());
      }
      else
      {
        conditionQuantiteAffiliation.setEtatSatisfait(false);
        conditionQuantiteAffiliation.setCodeMotifEchec(71);
        ActiviteSalarie dossierAffectationSinistre;
        ActiviteSalarie dossierAffectationSinistre;
        if (demande.getDonneesTemporaires().getIdentifiantPeriodeFctARetenir() != null) {
          dossierAffectationSinistre = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeFctARetenir();
        } else {
          dossierAffectationSinistre = (ActiviteSalarie)dossierAffectation.getSinistre();
        }
        Quantite[] appartenance = RechercheQuantiteAppartenance.getInstance().determinerAppartenanceInsuffisante(demande, dossierAffectationSinistre, false, conditionQuantiteAffiliation, dossierExamen);
        
        OutilQuantiteAffiliation outilAffi = OutilQuantiteAffiliation.getInstance();
        conditionQuantiteAffiliation.setQuantiteAppartenance(outilAffi.arrondirQuantiteEntiere(appartenance[0]));
        conditionQuantiteAffiliation.setQuantiteAppartenanceSecondaire(outilAffi.arrondirQuantiteEntiere(appartenance[1]));
        if (!contexteDemandeSousJacenteRevision)
        {
          Damj dateFaitGenerateur = dossierExamen.getConditionFaitGenerateur().getDateFaitGenerateur();
          if (dateFaitGenerateur.estAvantOuCoincideAvec(DATE_LIMITE_PRIME_500_EUROS)) {
            ParcoursRechercheAlertesNonBloquantes.getInstance().estEnContexteObtentionPrimeMalgreRejetAffi(demande, appartenance);
          }
        }
      }
    }
    else {
      conditionQuantiteAffiliation.setEtatSatisfait(true);
    }
    leverAlerteA11MNB1(demande, individu);
    
    return conditionQuantiteAffiliation;
  }
  
  private static void leverAlerteA11MNB1(DemandeSpec demande, IndividuSpec individu)
  {
    String codeAlerteNonBloquante1 = "A11MNB1";
    
    DossierAffectation dossierAffectation = (DossierAffectation)demande.getDossierAffectation();
    ValidationProduit validationProduit = dossierAffectation.getValidationProduit();
    if ((validationProduit != null) && (validationProduit.isEstProduitValide()))
    {
      Periode pra = validationProduit.getPeriodePra();
      if (pra != null)
      {
        Chronologie chronoPAS = individu.getChronoPeriodePasseProfessionnelLiquidation();
        
        FiltreTemporel filtreContenuDansPra = new FiltreActiviteContenuDansPra(pra);
        
        FiltresTemporel filtrePna = new FiltresTemporel();
        filtrePna.ajouterFiltre(filtreContenuDansPra);
        filtrePna.ajouterFiltre(new FiltrePeriodesAttestees(false));
        Chronologie listePna = chronoPAS.copier(filtrePna);
        if (!listePna.estVide()) {
          demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante1, convertirChronoToCollectionObjetAlerteNB(listePna));
        }
      }
    }
  }
  
  private static Collection convertirChronoToCollectionObjetAlerteNB(Chronologie p_chrono)
  {
    Collection retour = null;
    Iterator it;
    if (p_chrono != null)
    {
      retour = new ArrayList();
      for (it = p_chrono.iterer(); it.hasNext();)
      {
        Temporel temp = (Temporel)it.next();
        retour.add(new ObjetAlertesNonBloquantes(temp.getDateDebut(), temp.getDateFin(), 2));
      }
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */