package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DomSimulationAffiliation;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.DureeCalendaire;
import java.util.Collection;

public class SimuRechercheReglementApplicable
  extends RechercheReglementApplicable
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  private JustificationAffiliationSpec justificationAffiliation = null;
  
  public static RechercheReglementApplicable getInstance()
  {
    return new SimuRechercheReglementApplicable();
  }
  
  public ValidationProduit rechercherValidationProduit(Demande demande, boolean avecPeriodeNonAttestee, DomSimulationAffiliation domSimulationAffiliation)
    throws ApplicativeException
  {
    if ((demande == null) || (demande.getDemandeur() == null)) {
      return null;
    }
    DureeCalendaire ageDernierSinistre = domSimulationAffiliation.getIndividu().getAgeALaDate(domSimulationAffiliation.getActivite().getDateFin());
    
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setActiviteSalarie(domSimulationAffiliation.getActivite());
    donneesEntreeDeterminationListePra.setDemande(demande);
    donneesEntreeDeterminationListePra.setAgeIndividu(ageDernierSinistre);
    donneesEntreeDeterminationListePra.setDateBornePRA(domSimulationAffiliation.getDatePra());
    donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_QUANTITE_APPARTENANCE);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE"));
    
    donneesEntreeDeterminationListePra.setDateFgd(domSimulationAffiliation.getDateFgd());
    
    Collection<Pra> listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    if ((listePra == null) || (listePra.isEmpty())) {
      return null;
    }
    Reglement reglementPropose = domSimulationAffiliation.getActivite().getReglement();
    
    ValidationProduit validationProduit = premierExamen(demande, listePra, reglementPropose, avecPeriodeNonAttestee, domSimulationAffiliation.getProduitAppelant(), true);
    if (validationProduit == null)
    {
      if (determineConditionPram(demande, domSimulationAffiliation.getActivite(), reglementPropose, avecPeriodeNonAttestee, domSimulationAffiliation.getProduitAppelant())) {
        validationProduit = deuxiemeExamen(demande, listePra, reglementPropose, avecPeriodeNonAttestee, domSimulationAffiliation.getProduitAppelant());
      }
    }
    else {
      justificationAffiliation = validationProduit.getJustificationCalculAffiliation();
    }
    if (validationProduit != null) {
      validationProduit.setPeriodeValidationProduit(domSimulationAffiliation.getActivite());
    }
    return validationProduit;
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return justificationAffiliation;
  }
  
  public ValidationProduit determinerAppartenanceInsuffisante(Demande demande, boolean avecPeriodeNonAttestee, DomSimulationAffiliation domSimulationAffiliation)
    throws ApplicativeException
  {
    QuantitesAppartenance qteAppartenaceDeuxiemeExamen = null;
    if ((demande == null) || (demande.getDemandeur() == null)) {
      return null;
    }
    DureeCalendaire ageDernierSinistre = domSimulationAffiliation.getIndividu().getAgeALaDate(domSimulationAffiliation.getActivite().getDateFin());
    
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setActiviteSalarie(domSimulationAffiliation.getActivite());
    donneesEntreeDeterminationListePra.setDemande(demande);
    donneesEntreeDeterminationListePra.setAgeIndividu(ageDernierSinistre);
    donneesEntreeDeterminationListePra.setDateBornePRA(domSimulationAffiliation.getDatePra());
    donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_QUANTITE_APPARTENANCE);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(false);
    donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(false);
    donneesEntreeDeterminationListePra.setDateFgd(domSimulationAffiliation.getDateFgd());
    Collection<Pra> listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    if ((listePra == null) || (listePra.isEmpty())) {
      return null;
    }
    Reglement reglementPropose = domSimulationAffiliation.getActivite().getReglement();
    Pra praQteRequiseLaPlusPetite = RechercheQuantiteAppartenance.getInstance().recherchePraDontQteRequiseLaPlusPetite(listePra);
    QuantitesAppartenance qteAppartenacePremierExamen = RechercheQuantiteAppartenance.getInstance().premierExamen(demande, praQteRequiseLaPlusPetite, reglementPropose, avecPeriodeNonAttestee);
    if (determineConditionPram(demande, domSimulationAffiliation.getActivite(), reglementPropose, avecPeriodeNonAttestee, domSimulationAffiliation.getProduitAppelant())) {
      qteAppartenaceDeuxiemeExamen = RechercheQuantiteAppartenance.getInstance().deuxiemeExamen(demande, praQteRequiseLaPlusPetite, reglementPropose, avecPeriodeNonAttestee, false);
    }
    if (qteAppartenaceDeuxiemeExamen != null) {
      qteAppartenacePremierExamen = qteAppartenaceDeuxiemeExamen;
    }
    ConditionQuantiteAffiliation conditionQuantiteAffiliation = new ConditionQuantiteAffiliation();
    RechercheQuantiteAppartenance.getInstance().justificationAffiliation(conditionQuantiteAffiliation, qteAppartenacePremierExamen, (DossierExamen)demande.getDossierExamen(), praQteRequiseLaPlusPetite, true);
    
    justificationAffiliation = conditionQuantiteAffiliation.getJustificationAffiliation();
    
    ValidationProduit validationProduit = null;
    if (qteAppartenacePremierExamen != null)
    {
      validationProduit = new ValidationProduit();
      validationProduit.setPeriodePra(praQteRequiseLaPlusPetite);
      validationProduit.setReglementApplicable(domSimulationAffiliation.getActivite().getReglement());
      validationProduit.setCatEmploiPart(domSimulationAffiliation.getActivite().getCategorieEmploiParticulier());
      validationProduit.setQuantiteAcquise(new Quantite(Mathematiques.arrondiASup(qteAppartenacePremierExamen.getQuantiteAppartenance(qteAppartenacePremierExamen.getUniteAppartenancePrincipale()).getValeur(), 10), qteAppartenacePremierExamen.getUniteAppartenancePrincipale()));
      
      validationProduit.setQuantiteAssimilationAcquise(new Quantite(Mathematiques.arrondiASup(qteAppartenacePremierExamen.getQuantiteAssimilation(qteAppartenacePremierExamen.getUniteAppartenancePrincipale()).getValeur(), 10), qteAppartenacePremierExamen.getUniteAppartenancePrincipale()));
      if (qteAppartenacePremierExamen.getUniteAppartenanceSecondaire() != null)
      {
        validationProduit.setQuantiteAcquiseSecondaire(new Quantite(Mathematiques.arrondiASup(qteAppartenacePremierExamen.getQuantiteAppartenance(qteAppartenacePremierExamen.getUniteAppartenanceSecondaire()).getValeur(), 10), qteAppartenacePremierExamen.getUniteAppartenanceSecondaire()));
        
        validationProduit.setQuantiteAssimilationAcquiseSecondaire(new Quantite(Mathematiques.arrondiASup(qteAppartenacePremierExamen.getQuantiteAssimilation(qteAppartenacePremierExamen.getUniteAppartenanceSecondaire()).getValeur(), 10), qteAppartenacePremierExamen.getUniteAppartenanceSecondaire()));
      }
    }
    return validationProduit;
  }
}

/* Location:
 * Qualified Name:     SimuRechercheReglementApplicable
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */