package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.dom.ParametresCalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.AlerteAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ParametresAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.CalculAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.ParametresCalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.QuantitesAppartenanceSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class OutilCalculAppartenance
  implements CalculAppartenanceSpec
{
  ProduitAsuSpec produit;
  
  public OutilCalculAppartenance(ProduitAsuSpec produit)
  {
    this.produit = produit;
  }
  
  public QuantitesAppartenanceSpec calculer(DemandeSpec pDemande, Periode periode, Chronologie passeProfessionnel, Reglement reglement, ParametresCalculAppartenanceSpec pParametresCalculAppartenance)
    throws ApplicativeException
  {
    Demande demande = (Demande)pDemande;
    
    Chronologie chronosAttributionsEnCoursPmvsDansPra = DetectionContexteParticulierLiquidation.getInstance().detectionContexteSuiteOdPmvs(demande, periode, pDemande.getDateExamen());
    
    QuantitesAppartenance quantitesAppartenances = new QuantitesAppartenance();
    List<AlerteAffiliation> listeAlertesAffiliation = new ArrayList();
    
    ParametresCalculAppartenance parametresCalculAppartenance = (ParametresCalculAppartenance)pParametresCalculAppartenance;
    
    Quantite quantiteAffiliationForcee = demande.getDonneesTemporaires().getQuantiteAffiliation();
    if ((quantiteAffiliationForcee != null) && (parametresCalculAppartenance.isPrendreEnCompteDonneesForcees()))
    {
      Quantite zero = new Quantite(new BigDecimal(0), quantiteAffiliationForcee.getUnite());
      
      quantitesAppartenances = new QuantitesAppartenance();
      
      JustificationAffiliation justification = new JustificationAffiliation();
      justification.setQuantiteAffiliation(quantiteAffiliationForcee);
      justification.setPeriodeRechercheAffiliation(periode);
      justification.setEstAffiliationPlafonnee(false);
      justification.setPlafondAssimilation(zero);
      justification.setQuantiteAssimilation(zero);
      justification.setQuantiteDernierJourFevrier(zero);
      justification.setTopConflits(false);
      
      quantitesAppartenances.putQuantiteAffiliation(quantiteAffiliationForcee);
      quantitesAppartenances.putQuantiteAssimilation(zero);
      quantitesAppartenances.putJustificationAffiliation(justification, quantiteAffiliationForcee.getUnite());
    }
    else
    {
      CalculAffiliationSpec outilCalculAffiliation = getOutilCalculAffiliation();
      
      ParametresAffiliation parametres = new ParametresAffiliation();
      parametres.setListeContexte(demande.getListContexteDemande());
      parametres.setEffectuerImputationAffiliationPmvs(parametresCalculAppartenance.isEffectuerImputationAffiliationPmvs());
      parametres.setChronologieAttributionEnCoursPmvsDansPra(chronosAttributionsEnCoursPmvsDansPra);
      parametres.setComptabiliserAffiliationDernierJourFevrier(parametresCalculAppartenance.isPrendreEnCompteDernierJourFevrier());
      parametres.setDateExamen(pDemande.getDateExamen());
      parametres.setIndividu(pDemande.getDemandeur());
      parametres.setPra((Pra)periode);
      parametres.setProduit(produit);
      parametres.setNePasSanctionnerPnds(parametresCalculAppartenance.isNePasSanctionnerPnds());
      parametres.setReinitialiserCalculPeriodeElementaires(parametresCalculAppartenance.isReinitialiserCalculPeriodesElementaires());
      parametres.setComptabiliserAssimilation(parametresCalculAppartenance.isComptabiliserAssimilation());
      parametres.setContexteAppel(parametresCalculAppartenance.getContexteAppel());
      
      boolean estContexteEtudeCapa09 = ("couvertureChomageInvolontaire".equals(parametres.getContexteAppel())) || ("inopposabiliteChomageInvolontaire".equals(parametres.getContexteAppel()));
      if ((estContexteEtudeCapa09) && (2 == demande.getObjectifCourant().getType())) {
        parametres.setDateFaitGenerateur(demande.getDateFaitGenerateurOdPrecedente());
      } else {
        parametres.setDateFaitGenerateur(demande.getDateFaitGenerateurOuDernierSinistre());
      }
      List<Unite> listeUniteEtude = parametresCalculAppartenance.getListeUnitesReglement();
      
      Iterator<Unite> itUnites = listeUniteEtude.iterator();
      while (itUnites.hasNext())
      {
        Unite uniteEtudeCourante = (Unite)itUnites.next();
        
        parametres.setUniteCalcul(uniteEtudeCourante);
        
        JustificationAffiliation justification = outilCalculAffiliation.calculerAffiliation(passeProfessionnel, parametres);
        
        priseEnCompteAlerteAffiliationPotentiellementManquante(listeAlertesAffiliation, justification);
        
        quantitesAppartenances.putJustificationAffiliation(justification, uniteEtudeCourante);
        quantitesAppartenances.putQuantiteAffiliation(justification.getQuantiteAffiliation());
        quantitesAppartenances.putQuantiteAssimilation(justification.getQuantiteAssimilation());
        
        demande.setPeriodesAffiliation(justification.getChronologieActivitesParticipantes());
      }
      priseEnCompteAlertePNDS(pDemande, periode);
    }
    if (!listeAlertesAffiliation.isEmpty())
    {
      demande.setListeAlertesAffiliation(listeAlertesAffiliation);
      
      Collection<ObjetAlertesNonBloquantes> listePeriodesAlerte = new ArrayList();
      ObjetAlertesNonBloquantes alerteNonBloquante = new ObjetAlertesNonBloquantes(periode.getDebut(), periode.getFin(), 9);
      
      listePeriodesAlerte.add(alerteNonBloquante);
      pDemande.getAlertesNonBloquantes().put("ALERTE_AFFILIATION", listePeriodesAlerte);
    }
    return quantitesAppartenances;
  }
  
  private void priseEnCompteAlerteAffiliationPotentiellementManquante(List listeAlertes, JustificationAffiliation justification)
  {
    if ((justification != null) && (justification.getListPeriodeElementaire() != null))
    {
      Iterator it = justification.getListPeriodeElementaire().iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        if ((periodeElementaire.getIntensite().intValue() > 0) && (periodeElementaire.getQuantiteRetenue().getValeurEntiere() == 0))
        {
          AlerteAffiliation alerteAffiliation = OutilAlerteAffiliation.getInstance().genererAlerteAffiliation(periodeElementaire, "1", new String[] { justification.getUniteJustification().toString() });
          
          listeAlertes.add(alerteAffiliation);
        }
      }
    }
  }
  
  private void priseEnCompteAlertePNDS(DemandeSpec demande, Periode periode)
    throws ApplicativeException
  {
    Chronologie chronologiePnds = ((Demande)demande).getChronologiePNDS(periode);
    
    String codeAlerteNonBloquante = "A11MNB9";
    
    Collection listePnds = new ArrayList();
    for (Iterator iterPnds = chronologiePnds.iterer(); iterPnds.hasNext();)
    {
      ObjetChronoPeriode pnds = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pnds.getDateDebut(), pnds.getDateFin(), 7);
      
      listePnds.add(objetAlerteNonBloquante);
    }
    demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listePnds);
  }
  
  public CalculAffiliationSpec getOutilCalculAffiliation()
  {
    return new OutilCalculAffiliation();
  }
}

/* Location:
 * Qualified Name:     OutilCalculAppartenance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */