package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementJustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.dom.ElementZoneMemeExercice;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.dom.PlafonnementAffiliation;
import fr.unedic.cali.asu.dom.ZoneMemeExercice;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class OutilJustificationAffiliation
  implements TraitementJustificationAffiliationSpec
{
  private static final int NOMBRE_DECIMAL = 2;
  private static final int NOMBRE_DECIMAL_COEFFICIENT = 4;
  private static final BigDecimal UN = new BigDecimal("1");
  
  public void ajouterAffiliationAssimilee(JustificationAffiliation p_justificationAffiliation, AffiliationAssimilee p_affiliationAssimilee)
  {
    if (p_affiliationAssimilee != null) {
      p_justificationAffiliation.ajouterAffiliationAssimilee(p_affiliationAssimilee);
    }
  }
  
  public void ajouterAffiliationSupplementaire(JustificationAffiliation p_justificationAffiliation, AffiliationSupplementaire p_affiliationSupplementaire)
  {
    if (p_affiliationSupplementaire != null) {
      p_justificationAffiliation.ajouterAffiliationSupplementaire(p_affiliationSupplementaire);
    }
  }
  
  public void ajouterPeriodeElementaire(JustificationAffiliation p_justificationAffiliation, PeriodeElementaire p_periodeElementaire)
  {
    if (p_periodeElementaire != null) {
      p_justificationAffiliation.ajouterPeriodeElementaire(p_periodeElementaire);
    }
  }
  
  public void ajouterZoneMemeExercice(JustificationAffiliation p_justificationAffiliation, ZoneMemeExercice p_zoneMemeExercice)
  {
    if (p_zoneMemeExercice != null) {
      p_justificationAffiliation.ajouterZoneMemeExercice(p_zoneMemeExercice);
    }
  }
  
  public void ajouterPlafonnementAffiliation(JustificationAffiliation p_justificationAffiliation, PlafonnementAffiliation p_plafonnementAffiliation)
  {
    if (p_plafonnementAffiliation != null)
    {
      p_justificationAffiliation.ajouterPlafonnementAffiliation(p_plafonnementAffiliation);
      if ((p_plafonnementAffiliation.getCoefficientReducteurAffiliation().floatValue() < 1.0F) || (p_plafonnementAffiliation.getCoefficientReducteurAffiliationSupplementaire().floatValue() < 1.0F)) {
        p_justificationAffiliation.setEstAffiliationPlafonnee(true);
      }
    }
  }
  
  public PlafonnementAffiliation trouverPlafonnementAffiliation(JustificationAffiliation p_justificationAffiliation, Damj p_dateRecherche)
  {
    PlafonnementAffiliation plafonnementAffiliation = null;
    if ((p_dateRecherche != null) && (p_justificationAffiliation.getListPlafonnementAffiliation() != null))
    {
      Iterator it = p_justificationAffiliation.getListPlafonnementAffiliation().iterator();
      while (it.hasNext())
      {
        PlafonnementAffiliation plafondCourant = (PlafonnementAffiliation)it.next();
        if (p_dateRecherche.estContenueDans(plafondCourant.getMoisCivil())) {
          return plafondCourant;
        }
      }
    }
    return plafonnementAffiliation;
  }
  
  public void consoliderJustificationAffiliation(JustificationAffiliation p_justificationAffiliation)
  {
    Collection listeAffiliationAssimilee = p_justificationAffiliation.getCollectionAffiliationAssimilee();
    if (listeAffiliationAssimilee != null)
    {
      Iterator it = listeAffiliationAssimilee.iterator();
      while (it.hasNext())
      {
        AffiliationAssimilee affiliationAssimilee = (AffiliationAssimilee)it.next();
        
        Quantite quantite = arrondirQuantite(affiliationAssimilee.getQuantiteAssimilation());
        affiliationAssimilee.setQuantiteAssimilation(null);
        affiliationAssimilee.setQuantiteAssimilation(quantite);
      }
    }
    Collection listeAffiliationSupplementaire = p_justificationAffiliation.getCollectionAffiliationSupplementaire();
    if (listeAffiliationSupplementaire != null)
    {
      Iterator it = listeAffiliationSupplementaire.iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        
        Quantite quantite = arrondirQuantite(affiliationSupplementaire.getQuantiteInitiale());
        affiliationSupplementaire.setQuantiteInitiale(null);
        affiliationSupplementaire.setQuantiteInitiale(quantite);
        
        quantite = arrondirQuantite(affiliationSupplementaire.getQuantiteRetenue());
        affiliationSupplementaire.setQuantiteRetenue(null);
        affiliationSupplementaire.setQuantiteRetenue(quantite);
      }
    }
    Collection listePeriodesElementaires = p_justificationAffiliation.getCollectionPeriodeElementaire();
    if (listePeriodesElementaires != null)
    {
      Iterator it = listePeriodesElementaires.iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        
        Quantite quantite = arrondirQuantite(periodeElementaire.getQuantiteInitialeHeure());
        periodeElementaire.setQuantiteInitialeHeure(null);
        periodeElementaire.setQuantiteInitialeHeure(quantite);
        
        quantite = arrondirQuantite(periodeElementaire.getQuantitePlafonnee());
        periodeElementaire.setQuantitePlafonnee(null);
        periodeElementaire.setQuantitePlafonnee(quantite);
        
        quantite = arrondirQuantite(periodeElementaire.getQuantiteRetenue());
        periodeElementaire.setQuantiteRetenue(null);
        periodeElementaire.setQuantiteRetenue(quantite);
      }
    }
    Collection listeZoneMemeExercice = p_justificationAffiliation.getCollectionZoneMemeExercice();
    if (listeZoneMemeExercice != null)
    {
      Iterator it = listeZoneMemeExercice.iterator();
      while (it.hasNext())
      {
        ZoneMemeExercice zoneMemeExercice = (ZoneMemeExercice)it.next();
        
        Quantite quantite = arrondirQuantite(zoneMemeExercice.getQuantiteAffiliationRetenue());
        zoneMemeExercice.setQuantiteAffiliationRetenue(null);
        zoneMemeExercice.setQuantiteAffiliationRetenue(quantite);
        
        quantite = arrondirQuantite(zoneMemeExercice.getQuantiteAssimilationRetenue());
        zoneMemeExercice.setQuantiteAssimilationRetenue(null);
        zoneMemeExercice.setQuantiteAssimilationRetenue(quantite);
        if (zoneMemeExercice.getListElementZoneMemeExercice() != null)
        {
          Iterator itlisteElementZME = zoneMemeExercice.getListElementZoneMemeExercice().iterator();
          while (itlisteElementZME.hasNext())
          {
            ElementZoneMemeExercice elementZoneMemeExercice = (ElementZoneMemeExercice)itlisteElementZME.next();
            quantite = arrondirQuantite(elementZoneMemeExercice.getQuantiteAffiliation());
            elementZoneMemeExercice.setQuantiteAffiliation(null);
            elementZoneMemeExercice.setQuantiteAffiliation(quantite);
          }
        }
      }
    }
    Collection listePlafonnementAffiliation = p_justificationAffiliation.getCollectionPlafonnementAffiliation();
    if (listePlafonnementAffiliation != null)
    {
      Iterator it = listePlafonnementAffiliation.iterator();
      while (it.hasNext())
      {
        PlafonnementAffiliation plafonnementAffiliation = (PlafonnementAffiliation)it.next();
        
        BigDecimal valeur = arrondirCoefficient(plafonnementAffiliation.getCoefficientReducteurAffiliation());
        plafonnementAffiliation.setCoefficientReducteurAffiliation(null);
        plafonnementAffiliation.setCoefficientReducteurAffiliation(valeur);
        
        valeur = arrondirCoefficient(plafonnementAffiliation.getCoefficientReducteurAffiliationSupplementaire());
        plafonnementAffiliation.setCoefficientReducteurAffiliationSupplementaire(null);
        plafonnementAffiliation.setCoefficientReducteurAffiliationSupplementaire(valeur);
      }
    }
    Quantite quantite = arrondirQuantite(p_justificationAffiliation.getQuantiteAffiliation());
    p_justificationAffiliation.setQuantiteAffiliation(null);
    p_justificationAffiliation.setQuantiteAffiliation(quantite);
    
    quantite = arrondirQuantite(p_justificationAffiliation.getQuantiteAssimilation());
    p_justificationAffiliation.setQuantiteAssimilation(null);
    p_justificationAffiliation.setQuantiteAssimilation(quantite);
    
    quantite = arrondirQuantite(p_justificationAffiliation.getQuantiteDernierJourFevrier());
    p_justificationAffiliation.setQuantiteDernierJourFevrier(null);
    p_justificationAffiliation.setQuantiteDernierJourFevrier(quantite);
    
    quantite = arrondirQuantite(p_justificationAffiliation.getPlafondAssimilation());
    p_justificationAffiliation.setPlafondAssimilation(null);
    p_justificationAffiliation.setPlafondAssimilation(quantite);
    
    listePlafonnementAffiliation = p_justificationAffiliation.getCollectionPlafonnementAffiliation();
    if (listePlafonnementAffiliation != null)
    {
      Collection listePlafonnementsASupprimer = new ArrayList();
      Iterator it = listePlafonnementAffiliation.iterator();
      while (it.hasNext())
      {
        PlafonnementAffiliation plafonnementAffiliation = (PlafonnementAffiliation)it.next();
        if ((UN.compareTo(plafonnementAffiliation.getCoefficientReducteurAffiliationSupplementaire()) == 0) && (UN.compareTo(plafonnementAffiliation.getCoefficientReducteurAffiliation()) == 0)) {
          listePlafonnementsASupprimer.add(plafonnementAffiliation);
        }
      }
      it = listePlafonnementsASupprimer.iterator();
      while (it.hasNext()) {
        p_justificationAffiliation.supprimerPlafonnementAffiliation((PlafonnementAffiliation)it.next());
      }
    }
    listePeriodesElementaires = p_justificationAffiliation.getCollectionPeriodeElementaire();
    Periode pra = p_justificationAffiliation.getPeriodeRechercheAffiliation();
    if (listePeriodesElementaires != null)
    {
      Collection periodesASupprimer = new ArrayList();
      Iterator it = listePeriodesElementaires.iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        if (!periodeElementaire.getPeriode().chevauche(pra)) {
          periodesASupprimer.add(periodeElementaire);
        }
      }
      it = periodesASupprimer.iterator();
      while (it.hasNext()) {
        p_justificationAffiliation.supprimerPeriodeElementaire((PeriodeElementaire)it.next());
      }
    }
  }
  
  protected Quantite arrondirQuantite(Quantite p_quantite)
  {
    if (p_quantite != null)
    {
      BigDecimal valeurArrondie = p_quantite.getValeur().setScale(2, definirStrategieArrondi());
      return new Quantite(valeurArrondie, p_quantite.getUnite());
    }
    return p_quantite;
  }
  
  protected BigDecimal arrondirCoefficient(BigDecimal p_valeur)
  {
    return p_valeur.setScale(4, definirStrategieArrondi());
  }
  
  public int definirStrategieArrondi()
  {
    return 5;
  }
  
  public void justifierListeAffiliationAssimilee(JustificationAffiliation p_justification, List p_listeAffiliationAssimilee)
  {
    if (p_listeAffiliationAssimilee != null)
    {
      Iterator it = p_listeAffiliationAssimilee.iterator();
      while (it.hasNext())
      {
        AffiliationAssimilee affiliationAssimilee = (AffiliationAssimilee)it.next();
        ajouterAffiliationAssimilee(p_justification, affiliationAssimilee);
      }
    }
  }
  
  public void justifierListeAffiliationSupplementaire(JustificationAffiliation p_justification, List p_listeAffiliationSupplementaire)
  {
    if (p_listeAffiliationSupplementaire != null)
    {
      Iterator it = p_listeAffiliationSupplementaire.iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        ajouterAffiliationSupplementaire(p_justification, affiliationSupplementaire);
      }
    }
  }
  
  public void justifierListePeriodesElementaires(JustificationAffiliation p_justification, List p_listePeriodesElementaires)
  {
    if (p_listePeriodesElementaires != null)
    {
      Iterator it = p_listePeriodesElementaires.iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        ajouterPeriodeElementaire(p_justification, periodeElementaire);
      }
    }
  }
}

/* Location:
 * Qualified Name:     OutilJustificationAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */