package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.fabrique.FabriqueCorpsReglePeriodesSuspensionsNonAssimilables;
import fr.pe.cali.reglementaire.regles.assurance.affiliation.outils.spec.IOutilPeriodeNonAssimilable;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.dom.ParametresAffiliation;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.affiliation.spec.TraitementPeriodeElementaireSpec;
import fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels.affiliation.OutilFonctionnelAffiliationJoursTravailles;
import fr.unedic.cali.asu.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.dom.PeriodeElementaire;
import fr.unedic.cali.asu.liquidation.pnds.OutilDeterminationPNDS;
import fr.unedic.cali.asu.outilsfonctionnels.filtre.FiltrePeriodeElementairePlafonnementAffiliation;
import fr.unedic.cali.asu.parametres.OutilAccesListeUnitesReglement;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeIntensite;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pnds.PeriodeNonDeclareeSanction;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;

public class OutilTraitementPeriodeElementaire
  implements TraitementPeriodeElementaireSpec
{
  private static final int NOMBRE_JOUR_SEMAINE = 7;
  
  public void constituerPeriodesElementaires(Chronologie chronologiePeriodes, ParametresAffiliation parametres, ComportementAffiliationSpec comportement)
    throws ApplicativeException
  {
    if (chronologiePeriodes != null)
    {
      Iterator it = chronologiePeriodes.iterer();
      while (it.hasNext())
      {
        ActiviteSalarie activite = (ActiviteSalarie)it.next();
        constituerPeriodesElementaires(activite, parametres, comportement);
      }
    }
  }
  
  protected void constituerPeriodesElementaires(ActiviteSalarie activiteSalarie, ParametresAffiliation parametres, ComportementAffiliationSpec comportement)
    throws ApplicativeException
  {
    if ((activiteSalarie.getListePeriodeElementaire() == null) || (parametres.isReinitialiserCalculPeriodeElementaires()))
    {
      constituerPeriodesElementairesInitiales(activiteSalarie, parametres.getContexteAppel(), parametres.getProduit());
      
      constituerPeriodesElementaireSanctionnees(activiteSalarie, parametres);
      
      constituerAffiliationSupplementaire(activiteSalarie, parametres, comportement);
    }
  }
  
  protected void constituerPeriodesElementairesInitiales(ActiviteSalarie activiteSalarie, String contexteAppel, ProduitSpec produit)
  {
    traiterPeriodeMesureActivite(activiteSalarie, contexteAppel, produit);
    
    traiterPeriodeIntensite(activiteSalarie);
    
    traiterMoisCivils(activiteSalarie);
  }
  
  protected List traiterPeriodeMesureActivite(ActiviteSalarie activiteSalarie, String contexteAppel, ProduitSpec produit)
  {
    List listePeriodesElementairesInitialesPMA = new ArrayList();
    Unite uniteHeure = Unite.getParCode("18");
    
    Chronologie chronologiePMA = activiteSalarie.getListePeriodesMesureActivite();
    
    PeriodeMesureActivite pma = null;
    if (chronologiePMA != null)
    {
      Iterator it = chronologiePMA.iterer();
      PeriodeMesureActivite pmaPrecedente = null;
      while (it.hasNext())
      {
        pma = (PeriodeMesureActivite)it.next();
        
        PeriodeMesureActivite copiePma = (PeriodeMesureActivite)pma.copie();
        copiePma.initQuantiteAffiliation();
        
        PeriodeElementaire periodeElementaire = initialiserPeriodeElementaire(activiteSalarie, pma.getPeriode());
        
        periodeElementaire.setPresenceHeureComplementaire(pma.isPresenceHeureComplementaire());
        
        Iterator itQttAffiliation = copiePma.getListeQuantitesAffiliation().values().iterator();
        while (itQttAffiliation.hasNext())
        {
          Quantite quantite = (Quantite)itQttAffiliation.next();
          periodeElementaire.ajouterQuantiteAffiliationInitiale(quantite);
          if (uniteHeure.equals(quantite.getUnite())) {
            periodeElementaire.setQuantiteInitialeHeure(quantite);
          }
        }
        listePeriodesElementairesInitialesPMA.add(periodeElementaire);
        if (pmaPrecedente != null)
        {
          if (!pma.getDateDebut().equals(pmaPrecedente.getDateFin().lendemain()))
          {
            PeriodeElementaire periodeElementaireComplement = creerPeriodeElementaireComplement(pmaPrecedente.getDateFin().lendemain(), pma.getDateDebut().veille(), activiteSalarie, contexteAppel, produit);
            
            listePeriodesElementairesInitialesPMA.add(periodeElementaireComplement);
          }
        }
        else if (pma.getDateDebut().estApres(activiteSalarie.getDateDebut()))
        {
          PeriodeElementaire periodeElementaireComplement = creerPeriodeElementaireComplement(activiteSalarie.getDateDebut(), pma.getDateDebut().veille(), activiteSalarie, contexteAppel, produit);
          
          listePeriodesElementairesInitialesPMA.add(periodeElementaireComplement);
        }
        pmaPrecedente = pma;
      }
    }
    if (pma != null)
    {
      if (pma.getDateFin().estAvant(activiteSalarie.getDateFin()))
      {
        PeriodeElementaire periodeElementaireComplement = creerPeriodeElementaireComplement(pma.getDateFin().lendemain(), activiteSalarie.getDateFin(), activiteSalarie, contexteAppel, produit);
        
        listePeriodesElementairesInitialesPMA.add(periodeElementaireComplement);
      }
    }
    else
    {
      PeriodeElementaire periodeElementaireComplement = creerPeriodeElementaireComplement(activiteSalarie.getDateDebut(), activiteSalarie.getDateFin(), activiteSalarie, contexteAppel, produit);
      
      listePeriodesElementairesInitialesPMA.add(periodeElementaireComplement);
    }
    activiteSalarie.setListePeriodeElementaire(listePeriodesElementairesInitialesPMA);
    
    return listePeriodesElementairesInitialesPMA;
  }
  
  private PeriodeElementaire creerPeriodeElementaireComplement(Damj dateDebut, Damj dateFin, ActiviteSalarie activiteSalarie, String contexteAppel, ProduitSpec produit)
  {
    Periode periodeComplement = new Periode(dateDebut, dateFin);
    PeriodeElementaire periodeElementaireComplement = initialiserPeriodeElementaire(activiteSalarie, periodeComplement);
    
    List<Unite> listeUniteReglement = OutilAccesListeUnitesReglement.getInstance().recupererListeUnite(activiteSalarie.getReglement().getNomReglement(), false, contexteAppel, produit);
    
    Iterator<Unite> itUnite = listeUniteReglement.iterator();
    while (itUnite.hasNext())
    {
      Unite unite = (Unite)itUnite.next();
      periodeElementaireComplement.ajouterQuantiteAffiliationInitiale(new Quantite(new BigDecimal(0), unite));
    }
    return periodeElementaireComplement;
  }
  
  private PeriodeElementaire initialiserPeriodeElementaire(ActiviteSalarie activiteSalarie, Periode periode)
  {
    PeriodeElementaire periodeElementaire = creerInstancePeriodeElementaire();
    
    periodeElementaire.setPeriodePE(periode);
    periodeElementaire.setNature(1);
    periodeElementaire.setIdPeriodeActivite(activiteSalarie.getIdentifiant());
    periodeElementaire.setReglement(activiteSalarie.getReglement().getLibelleCourt());
    periodeElementaire.setRaisonSociale(activiteSalarie.getEntreprise().getLibelleEntreprise());
    periodeElementaire.setPeriodeActiviteSalariee(activiteSalarie.getPeriode());
    periodeElementaire.setActiviteSalarie(activiteSalarie);
    
    return periodeElementaire;
  }
  
  protected List traiterPeriodeIntensite(ActiviteSalarie activiteSalarie)
  {
    List listePeriodesElementairesInitialesIntensite = new ArrayList();
    
    List listePeriodeElementaireInitiales = activiteSalarie.getListePeriodeElementaire();
    
    Iterator itPE = listePeriodeElementaireInitiales.iterator();
    Chronologie listePeriodeIntensite = activiteSalarie.getListePeriodeIntensite();
    if ((listePeriodeIntensite != null) && (listePeriodeIntensite.getTaille() > 0)) {}
    while (itPE.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)itPE.next();
      
      Iterator it = listePeriodeIntensite.iterer();
      boolean poursuivreParcoursIntensite = true;
      while ((it.hasNext()) && (poursuivreParcoursIntensite))
      {
        PeriodeIntensite intensite = (PeriodeIntensite)it.next();
        Periode periodeIntensite = new Periode(intensite.getDateDebut(), intensite.getDateFin());
        if (periodeIntensite.chevauche(periodeElementaire.getPeriode()))
        {
          PeriodeElementaire periodeElementaireIntensite = proratiserPeriodeElementaire(periodeElementaire, periodeIntensite);
          listePeriodesElementairesInitialesIntensite.add(periodeElementaireIntensite);
          periodeElementaireIntensite.setPeriodeIntensite(intensite);
          if (periodeElementaireIntensite.getPeriodePE().equals(periodeElementaire.getPeriodePE())) {
            poursuivreParcoursIntensite = false;
          }
        }
      }
      continue;
      
      listePeriodesElementairesInitialesIntensite = listePeriodeElementaireInitiales;
    }
    activiteSalarie.setListePeriodeElementaire(listePeriodesElementairesInitialesIntensite);
    
    return listePeriodesElementairesInitialesIntensite;
  }
  
  protected List traiterMoisCivils(ActiviteSalarie activiteSalarie)
  {
    List listePeriodeElementaireInitiales = activiteSalarie.getListePeriodeElementaire();
    if (FiltrePeriodeElementairePlafonnementAffiliation.estActiviteParticipantAuPlafonnement(activiteSalarie))
    {
      Iterator itPeIntensite = listePeriodeElementaireInitiales.iterator();
      List listePeriodeElementaireInitialeMoisCivil = new ArrayList();
      while (itPeIntensite.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)itPeIntensite.next();
        ArrayList listeMoisCivilsPE = periodeElementaire.getPeriodePE().decouperEnMoisCivils();
        if (listeMoisCivilsPE.size() > 1)
        {
          Iterator itMoisCivil = listeMoisCivilsPE.iterator();
          while (itMoisCivil.hasNext())
          {
            Periode moisCivil = (Periode)itMoisCivil.next();
            
            PeriodeElementaire periodeElementaireMoisCivil = proratiserPeriodeElementaire(periodeElementaire, moisCivil);
            listePeriodeElementaireInitialeMoisCivil.add(periodeElementaireMoisCivil);
          }
        }
        else
        {
          listePeriodeElementaireInitialeMoisCivil.add(periodeElementaire);
        }
      }
      activiteSalarie.setListePeriodeElementaire(listePeriodeElementaireInitialeMoisCivil);
      
      return listePeriodeElementaireInitialeMoisCivil;
    }
    return listePeriodeElementaireInitiales;
  }
  
  protected void constituerPeriodesElementaireSanctionnees(ActiviteSalarie activiteSalarie, ParametresAffiliation parametres)
    throws ApplicativeException
  {
    if (!parametres.isNePasSanctionnerPnds())
    {
      PeriodeNonDeclareeSanction listePnds = OutilDeterminationPNDS.determinerPNDS(parametres.getIndividu(), activiteSalarie, activiteSalarie.getDateDebut(), activiteSalarie.getDateFin(), parametres.getDateExamen(), parametres.getDateExamen());
      
      constituerPeriodesElementaireSanctionnees(activiteSalarie, listePnds);
    }
  }
  
  protected void constituerPeriodesElementaireSanctionnees(ActiviteSalarie activiteSalarie, PeriodeNonDeclareeSanction listePnds)
    throws ApplicativeException
  {
    List listePeriodeElementaireInitiales = activiteSalarie.getListePeriodeElementaire();
    
    Iterator it = listePeriodeElementaireInitiales.iterator();
    List listePeriodeElementaireSanctionnees = new ArrayList();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      
      Iterator itPNDS = listePnds.getChronoPeriodePNDS().iterer();
      ObjetChronoPeriode pndsPrecedenteChevauchantPE = null;
      while (itPNDS.hasNext())
      {
        ObjetChronoPeriode pnds = (ObjetChronoPeriode)itPNDS.next();
        if (pnds.chevauche(periodeElementaire.getPeriodePE()))
        {
          Damj dateDebutPeriodeElementaire = null;
          Damj dateFinPeriodeElementaire = null;
          boolean creerPeriodeElementaire = false;
          if (pndsPrecedenteChevauchantPE != null)
          {
            dateDebutPeriodeElementaire = pndsPrecedenteChevauchantPE.getDateFin().lendemain();
            dateFinPeriodeElementaire = pnds.getDateDebut().veille();
            creerPeriodeElementaire = true;
          }
          else if (pnds.getDateDebut().estApres(periodeElementaire.getPeriodePE().getDebut()))
          {
            dateDebutPeriodeElementaire = periodeElementaire.getPeriodePE().getDebut();
            dateFinPeriodeElementaire = pnds.getDateDebut().veille();
            creerPeriodeElementaire = true;
          }
          if (creerPeriodeElementaire)
          {
            PeriodeElementaire periodeElementaireNonSanctionne = proratiserPeriodeElementaire(periodeElementaire, new Periode(dateDebutPeriodeElementaire, dateFinPeriodeElementaire));
            
            listePeriodeElementaireSanctionnees.add(periodeElementaireNonSanctionne);
          }
          PeriodeElementaire periodeElementaireSanctionne = proratiserPeriodeElementaire(periodeElementaire, pnds.periodeIntersection(periodeElementaire.getPeriodePE()));
          
          periodeElementaireSanctionne.setEstSanctionnee(true);
          listePeriodeElementaireSanctionnees.add(periodeElementaireSanctionne);
          
          pndsPrecedenteChevauchantPE = pnds;
        }
      }
      if (pndsPrecedenteChevauchantPE == null)
      {
        listePeriodeElementaireSanctionnees.add(periodeElementaire);
      }
      else if (pndsPrecedenteChevauchantPE.getDateFin().estAvant(periodeElementaire.getPeriodePE().getFin()))
      {
        Damj dateDebutPeriodeElementaire = null;
        Damj dateFinPeriodeElementaire = null;
        
        dateDebutPeriodeElementaire = pndsPrecedenteChevauchantPE.getDateFin().lendemain();
        dateFinPeriodeElementaire = periodeElementaire.getPeriodePE().getFin();
        
        PeriodeElementaire periodeElementaireNonSanctionne = proratiserPeriodeElementaire(periodeElementaire, new Periode(dateDebutPeriodeElementaire, dateFinPeriodeElementaire));
        
        listePeriodeElementaireSanctionnees.add(periodeElementaireNonSanctionne);
      }
    }
    activiteSalarie.setListePeriodeElementaire(listePeriodeElementaireSanctionnees);
  }
  
  protected void constituerAffiliationSupplementaire(ActiviteSalarie activiteSalarie, ParametresAffiliation parametres, ComportementAffiliationSpec comportement)
  {
    List listePeriodeElementaireAvecSuspension = new ArrayList();
    List listeAffiliationSupplementaire = new ArrayList();
    
    List listePeriodeElementaires = activiteSalarie.getListePeriodeElementaire();
    Iterator it = listePeriodeElementaires.iterator();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      
      List listeAffiliationSupplementairePourPeriodeElementaire = new ArrayList();
      
      FiltresTemporel filtreET = new FiltresTemporel();
      filtreET.ajouterFiltre(new FiltreIncident());
      filtreET.ajouterFiltre(new FiltreChevauchePeriode(periodeElementaire.getPeriodePE()));
      Chronologie periodesSuspension = activiteSalarie.getListePeriodesIncident().copier(filtreET);
      if ((periodesSuspension.estVide()) || (periodeElementaire.isEstSanctionnee()))
      {
        periodeElementaire.setIntensite(new BigDecimal(1));
        listePeriodeElementaireAvecSuspension.add(periodeElementaire);
      }
      else
      {
        int nombreJoursSuspensionSurPeriodeElementaire = 0;
        
        Iterator itSuspension = periodesSuspension.iterer();
        while (itSuspension.hasNext())
        {
          IncidentSpec incident = (IncidentSpec)itSuspension.next();
          if (estSuspensionAssimilable(incident, parametres))
          {
            AffiliationSupplementaire affiliationSupplementaire = creerAffliationSupplementaire(activiteSalarie, incident, periodeElementaire, listePeriodeElementaires, comportement);
            
            listeAffiliationSupplementairePourPeriodeElementaire.add(affiliationSupplementaire);
            
            nombreJoursSuspensionSurPeriodeElementaire = (int)(nombreJoursSuspensionSurPeriodeElementaire + affiliationSupplementaire.getPeriode().getDuree() * affiliationSupplementaire.getIntensite().floatValue());
          }
        }
        listeAffiliationSupplementaire.addAll(listeAffiliationSupplementairePourPeriodeElementaire);
        
        List listePeriodesElementaireDecoupees = determinerPeriodeElementaireSelonAffiliationSupplementaire(periodeElementaire, listeAffiliationSupplementairePourPeriodeElementaire, nombreJoursSuspensionSurPeriodeElementaire);
        
        listePeriodeElementaireAvecSuspension.addAll(listePeriodesElementaireDecoupees);
      }
    }
    activiteSalarie.setListePeriodeElementaire(listePeriodeElementaireAvecSuspension);
    activiteSalarie.setListePeriodeAffiliationSupplementaire(listeAffiliationSupplementaire);
  }
  
  protected List determinerPeriodeElementaireSelonAffiliationSupplementaire(PeriodeElementaire periodeElementaireSource, List listeAffiliationSupplementaire, float nombreJoursSuspensionSurPeriodeElementaire)
  {
    List resultat = new ArrayList();
    if (listeAffiliationSupplementaire.size() == 0)
    {
      periodeElementaireSource.setIntensite(new BigDecimal(1));
      
      resultat.add(periodeElementaireSource);
    }
    else
    {
      float nombreJourActiviteSurPeriodeElementaire = periodeElementaireSource.getPeriodePE().getDuree() - nombreJoursSuspensionSurPeriodeElementaire;
      
      Iterator it = listeAffiliationSupplementaire.iterator();
      AffiliationSupplementaire affiliationSupplementairePrecedente = null;
      boolean poursuivreDecoupage = true;
      while ((it.hasNext()) && (poursuivreDecoupage))
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        if (periodeElementaireSource.getPeriodePE().estContenueDans(affiliationSupplementaire.getPeriodeAffiliationSupplementaire()))
        {
          periodeElementaireSource.setIntensite(new BigDecimal(1.0F - affiliationSupplementaire.getIntensite().floatValue()));
          
          resultat.add(periodeElementaireSource);
          poursuivreDecoupage = false;
        }
        else
        {
          if (affiliationSupplementairePrecedente == null)
          {
            if (affiliationSupplementaire.getPeriode().getDebut().estApres(periodeElementaireSource.getPeriodePE().getDebut()))
            {
              Damj dateDebutPeriode = periodeElementaireSource.getPeriodePE().getDebut();
              Damj dateFinPeriode = affiliationSupplementaire.getPeriode().getDebut().veille();
              Periode periode = new Periode(dateDebutPeriode, dateFinPeriode);
              PeriodeElementaire periodeElementaireDecoupee = proratiserPeriodeElementaire(periodeElementaireSource, periode, nombreJourActiviteSurPeriodeElementaire);
              
              periodeElementaireDecoupee.setIntensite(new BigDecimal(1));
              
              resultat.add(periodeElementaireDecoupee);
            }
          }
          else
          {
            Damj dateDebutPeriode = affiliationSupplementairePrecedente.getPeriode().getFin().lendemain();
            Damj dateFinPeriode = affiliationSupplementaire.getPeriode().getDebut().veille();
            if (dateDebutPeriode.estAvantOuCoincideAvec(dateFinPeriode))
            {
              Periode periode = new Periode(dateDebutPeriode, dateFinPeriode);
              PeriodeElementaire periodeElementaireDecoupee = proratiserPeriodeElementaire(periodeElementaireSource, periode, nombreJourActiviteSurPeriodeElementaire);
              
              periodeElementaireDecoupee.setIntensite(new BigDecimal(1));
              
              resultat.add(periodeElementaireDecoupee);
            }
          }
          if (!affiliationSupplementaire.estTauxPlein())
          {
            Periode periode = affiliationSupplementaire.getPeriode();
            PeriodeElementaire periodeElementaireDecoupee = proratiserPeriodeElementaire(periodeElementaireSource, periode, nombreJourActiviteSurPeriodeElementaire);
            
            periodeElementaireDecoupee.setIntensite(new BigDecimal(1.0F - affiliationSupplementaire.getIntensite().floatValue()));
            
            reduireQuantitesSelonIntensitePeriode(periodeElementaireDecoupee);
            
            resultat.add(periodeElementaireDecoupee);
          }
        }
        affiliationSupplementairePrecedente = affiliationSupplementaire;
      }
      if (!periodeElementaireSource.getPeriodePE().getFin().estContenueDans(affiliationSupplementairePrecedente.getPeriode()))
      {
        Damj dateDebutPeriode = affiliationSupplementairePrecedente.getPeriode().getFin().lendemain();
        Damj dateFinPeriode = periodeElementaireSource.getPeriodePE().getFin();
        Periode periode = new Periode(dateDebutPeriode, dateFinPeriode);
        PeriodeElementaire periodeElementaireDecoupee = proratiserPeriodeElementaire(periodeElementaireSource, periode, nombreJourActiviteSurPeriodeElementaire);
        
        periodeElementaireDecoupee.setIntensite(new BigDecimal(1));
        
        resultat.add(periodeElementaireDecoupee);
      }
    }
    return resultat;
  }
  
  protected void reduireQuantitesSelonIntensitePeriode(PeriodeElementaire periodeElementaire)
  {
    BigDecimal intensite = periodeElementaire.getIntensite();
    
    periodeElementaire.setQuantiteInitialeHeure(appliquerCoefficientSurQuantite(periodeElementaire.getQuantiteInitialeHeure(), intensite));
    
    periodeElementaire.setQuantitePlafonnee(appliquerCoefficientSurQuantite(periodeElementaire.getQuantitePlafonnee(), intensite));
    
    periodeElementaire.setQuantiteRetenue(appliquerCoefficientSurQuantite(periodeElementaire.getQuantiteRetenue(), intensite));
    
    Iterator it = periodeElementaire.getListQuantiteAffiliationInitiales().iterator();
    while (it.hasNext())
    {
      Quantite quantite = (Quantite)it.next();
      periodeElementaire.ajouterQuantiteAffiliationInitiale(appliquerCoefficientSurQuantite(quantite, intensite));
    }
  }
  
  private Quantite appliquerCoefficientSurQuantite(Quantite quantite, BigDecimal coefficient)
  {
    if (quantite != null)
    {
      BigDecimal valeur = quantite.getValeur();
      BigDecimal valeurAvecCoefficient = valeur.multiply(coefficient);
      return new Quantite(valeurAvecCoefficient, quantite.getUnite());
    }
    return null;
  }
  
  protected PeriodeElementaire trouverPeriodeElementaireEnCoursALaDate(List listePeriodesElementaires, Damj date)
  {
    Iterator it = listePeriodesElementaires.iterator();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      if (periodeElementaire.getPeriodePE().contient(date)) {
        return periodeElementaire;
      }
    }
    return null;
  }
  
  protected AffiliationSupplementaire creerAffliationSupplementaire(ActiviteSalarie activiteSalarie, IncidentSpec incident, PeriodeElementaire periodeElementaireReference, List listePeriodesElementaires, ComportementAffiliationSpec comportement)
  {
    Unite uniteJour = Unite.getParCode("11");
    Unite uniteHeure = Unite.getParCode("18");
    
    AffiliationSupplementaire affiliationSupplementaire = creerInstanceAffiliationSupplementaire();
    
    affiliationSupplementaire.setIdPeriodeActivite(activiteSalarie.getIdentifiant());
    affiliationSupplementaire.setIntensite(incident.getIntensite());
    affiliationSupplementaire.setNature(2);
    affiliationSupplementaire.setPeriodeActiviteSalariee(activiteSalarie.getPeriode());
    affiliationSupplementaire.setPeriodeAffiliationSupplementaire(incident.getPeriode().periodeIntersection(periodeElementaireReference.getPeriode()));
    
    affiliationSupplementaire.setRaisonSociale(activiteSalarie.getEntreprise().getLibelleEntreprise());
    affiliationSupplementaire.setReglement(activiteSalarie.getReglement().getLibelleCourt());
    
    PeriodeElementaire periodeElementaireVeilleSuspension = trouverPeriodeElementaireEnCoursALaDate(listePeriodesElementaires, incident.getDateDebut().veille());
    
    Quantite quantiteInitiale = null;
    int dureePeriode = affiliationSupplementaire.getPeriode().getDuree();
    
    Quantite quantiteJour = null;
    if (periodeElementaireVeilleSuspension != null) {
      quantiteJour = periodeElementaireVeilleSuspension.getQuantiteAffiliationInitiale(uniteJour);
    }
    if ((quantiteJour == null) && ((periodeElementaireVeilleSuspension == null) || (periodeElementaireVeilleSuspension.getPeriodeIntensite() == null))) {
      quantiteJour = new Quantite(dureePeriode, uniteJour);
    }
    if (quantiteJour != null)
    {
      BigDecimal dureeIncidentSelonIntensite = new BigDecimal(dureePeriode).multiply(affiliationSupplementaire.getIntensite());
      
      Quantite dureeIncident = new Quantite(dureeIncidentSelonIntensite, uniteJour);
      quantiteInitiale = comportement.getConvertisseurUnite().convertir(dureeIncident, uniteHeure);
    }
    else
    {
      float horaireSalarie = periodeElementaireVeilleSuspension.getPeriodeIntensite().getHorairesSalarie().floatValue();
      affiliationSupplementaire.setHoraireSalarie(new BigDecimal(horaireSalarie));
      
      float quantite = horaireSalarie * dureePeriode * affiliationSupplementaire.getIntensite().floatValue() / 7.0F;
      quantiteInitiale = new Quantite(new BigDecimal(quantite), uniteHeure);
    }
    affiliationSupplementaire.setQuantiteInitiale(quantiteInitiale);
    return affiliationSupplementaire;
  }
  
  protected boolean estSuspensionAssimilable(IncidentSpec incident, ParametresAffiliation parametres)
  {
    FabriqueCorpsReglePeriodesSuspensionsNonAssimilables fabriquePeriodeAssimilable = FabriqueCorpsReglePeriodesSuspensionsNonAssimilables.getInstance();
    CriteresFabriqueReglementaire criteresFabriquePeriodeAssimilable = new CriteresFabriqueReglementaire();
    criteresFabriquePeriodeAssimilable.setCodeProduit(parametres.getProduit().getNomUnique());
    criteresFabriquePeriodeAssimilable.setDate(parametres.getDateFaitGenerateur());
    
    return fabriquePeriodeAssimilable.recupererOutilCorpsRegle(criteresFabriquePeriodeAssimilable).estAssimilable(incident, new OutilFonctionnelAffiliationJoursTravailles(parametres.getIndividu()));
  }
  
  public List consoliderPeriodesElementaire(Unite unite, List listePeriodesElementaires, ComportementAffiliationSpec comportement)
  {
    Iterator it = listePeriodesElementaires.iterator();
    while (it.hasNext())
    {
      PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
      determinerQuantiteARetenir(unite, periodeElementaire, comportement);
    }
    return listePeriodesElementaires;
  }
  
  protected void determinerQuantiteARetenir(Unite unite, PeriodeElementaire periodeElementaire, ComportementAffiliationSpec comportement)
  {
    Quantite quantiteARetenir = null;
    Unite uniteHeure = Unite.getParCode("18");
    if (periodeElementaire.isEstSanctionnee())
    {
      quantiteARetenir = new Quantite(0, unite);
    }
    else
    {
      if (unite.getCode().equals(uniteHeure.getCode())) {
        quantiteARetenir = determinerQuantiteHeureARetenir(periodeElementaire);
      } else {
        quantiteARetenir = periodeElementaire.getQuantiteAffiliationInitiale(unite);
      }
      boolean presenceHeureComplementaire = periodeElementaire.isPresenceHeureComplementaire();
      if (presenceHeureComplementaire)
      {
        Quantite plusGrandeQuantite = determinerPlusGrandeQuantiteAffiliation(periodeElementaire, unite, false, comportement);
        Quantite plusGrandeQuantiteUniteRecherche = comportement.getConvertisseurUnite().convertir(plusGrandeQuantite, unite);
        
        Quantite quantiteHeureComplementaire = determinerQuantiteHeureARetenir(periodeElementaire);
        Quantite quantiteHeureComplementaireUniteRecherche = comportement.getConvertisseurUnite().convertir(quantiteHeureComplementaire, unite);
        quantiteARetenir = plusGrandeQuantiteUniteRecherche.ajouter(quantiteHeureComplementaireUniteRecherche);
      }
      else if (quantiteARetenir == null)
      {
        quantiteARetenir = determinerPlusGrandeQuantiteAffiliation(periodeElementaire, unite, true, comportement);
      }
    }
    if (quantiteARetenir == null) {
      quantiteARetenir = new Quantite(0, unite);
    }
    periodeElementaire.setQuantiteRetenue(quantiteARetenir);
  }
  
  private Quantite determinerQuantiteHeureARetenir(PeriodeElementaire periodeElementaire)
  {
    Quantite quantiteARetenir = periodeElementaire.getQuantiteAffiliationInitiale(Unite.getParCode("18"));
    
    Quantite quantitePlafonnee = periodeElementaire.getQuantitePlafonnee();
    if (quantitePlafonnee != null) {
      quantiteARetenir = quantitePlafonnee;
    }
    return quantiteARetenir;
  }
  
  private Quantite determinerPlusGrandeQuantiteAffiliation(PeriodeElementaire periodeElementaire, Unite unite, boolean priseEnCompteHeure, ComportementAffiliationSpec comportement)
  {
    Quantite quantiteARetenir = null;
    
    Unite uniteHeure = Unite.getParCode("18");
    Iterator itQuantiteAffiliation = periodeElementaire.getListQuantiteAffiliationInitiales().iterator();
    
    Quantite quantiteConvertieARetenir = null;
    while (itQuantiteAffiliation.hasNext())
    {
      Quantite quantiteAffiliation = (Quantite)itQuantiteAffiliation.next();
      
      boolean uniteCouranteHeure = quantiteAffiliation.getUnite().getCode().equals(uniteHeure.getCode());
      if (uniteCouranteHeure) {
        quantiteAffiliation = determinerQuantiteHeureARetenir(periodeElementaire);
      }
      if ((priseEnCompteHeure) || (!uniteCouranteHeure))
      {
        Quantite quantiteConvertieCourante = comportement.getConvertisseurUnite().convertir(quantiteAffiliation, unite);
        if ((quantiteConvertieARetenir == null) || (quantiteConvertieCourante.compareTo(quantiteConvertieARetenir) > 0))
        {
          quantiteConvertieARetenir = quantiteConvertieCourante;
          quantiteARetenir = quantiteAffiliation;
        }
      }
    }
    return quantiteARetenir;
  }
  
  public List recupererListAffiliationSupplementaire(Chronologie chronologiePeriodes)
  {
    if (chronologiePeriodes != null)
    {
      List resultat = new ArrayList();
      Iterator it = chronologiePeriodes.iterer();
      while (it.hasNext())
      {
        ActiviteSalarie activiteSalarie = (ActiviteSalarie)it.next();
        List listePeriodeAffiliationSupplementaire = activiteSalarie.getListePeriodeAffiliationSupplementaire();
        if (listePeriodeAffiliationSupplementaire != null)
        {
          Iterator itList = listePeriodeAffiliationSupplementaire.iterator();
          while (itList.hasNext())
          {
            AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)itList.next();
            resultat.add(affiliationSupplementaire.copie());
          }
        }
      }
      return resultat;
    }
    return null;
  }
  
  public List recupererListPeriodeElementaire(Chronologie chronologiePeriodes)
  {
    if (chronologiePeriodes != null)
    {
      List resultat = new ArrayList();
      Iterator it = chronologiePeriodes.iterer();
      while (it.hasNext())
      {
        ActiviteSalarie activiteSalarie = (ActiviteSalarie)it.next();
        List listePeriodeElementaires = activiteSalarie.getListePeriodeElementaire();
        if (listePeriodeElementaires != null)
        {
          Iterator itList = listePeriodeElementaires.iterator();
          while (itList.hasNext())
          {
            PeriodeElementaire periodeElementaire = (PeriodeElementaire)itList.next();
            resultat.add(periodeElementaire.copie());
          }
        }
      }
      return resultat;
    }
    return null;
  }
  
  protected List projeterPeriodeElementaireSurPeriode(Periode periodeRechercheAffiliation, List listePeriodeElementaire)
  {
    if (listePeriodeElementaire != null)
    {
      List resultat = new ArrayList();
      Iterator it = listePeriodeElementaire.iterator();
      while (it.hasNext())
      {
        PeriodeElementaire periodeElementaire = (PeriodeElementaire)it.next();
        if (periodeRechercheAffiliation.contient(periodeElementaire.getPeriodePE()))
        {
          resultat.add(periodeElementaire);
        }
        else
        {
          Periode periodeIncluseDansPRA = periodeRechercheAffiliation.periodeIntersection(periodeElementaire.getPeriodePE());
          
          resultat.add(proratiserPeriodeElementaire(periodeElementaire, periodeIncluseDansPRA));
        }
      }
      return resultat;
    }
    return null;
  }
  
  protected List projeterAffiliationSupplementaireSurPeriode(Periode periodeRechercheAffiliation, List listePeriodeAffiliationSupplementaire)
  {
    if (listePeriodeAffiliationSupplementaire != null)
    {
      List resultat = new ArrayList();
      Iterator it = listePeriodeAffiliationSupplementaire.iterator();
      while (it.hasNext())
      {
        AffiliationSupplementaire affiliationSupplementaire = (AffiliationSupplementaire)it.next();
        if (periodeRechercheAffiliation.contient(affiliationSupplementaire.getPeriodeAffiliationSupplementaire()))
        {
          resultat.add(affiliationSupplementaire);
        }
        else
        {
          Periode periodeIncluseDansPRA = periodeRechercheAffiliation.periodeIntersection(affiliationSupplementaire.getPeriodeAffiliationSupplementaire());
          
          resultat.add(proratiserAffiliationSupplementaire(affiliationSupplementaire, periodeIncluseDansPRA));
        }
      }
      return resultat;
    }
    return null;
  }
  
  protected void proratiserPeriodeElementaire(PeriodeElementaire periodeElementaireSource, Periode periode, PeriodeElementaire periodeElementaireCible)
  {
    proratiserPeriodeElementaire(periodeElementaireSource, periode, periodeElementaireCible, periodeElementaireSource.getPeriodePE().getDuree());
  }
  
  protected void proratiserPeriodeElementaire(PeriodeElementaire periodeElementaireSource, Periode periode, PeriodeElementaire periodeElementaireCible, float dureePeriodeInitiale)
  {
    if (!periode.contient(periodeElementaireSource.getPeriodePE()))
    {
      periodeElementaireSource.copieElements(periodeElementaireCible);
      
      periodeElementaireCible.setPeriodePE(periode.periodeIntersection(periodeElementaireSource.getPeriodePE()));
      
      int nombreJoursIntersection = periode.inter(periodeElementaireSource.getPeriodePE());
      
      periodeElementaireCible.setQuantiteInitialeHeure(OutilQuantiteAffiliation.getInstance().proratiserQuantite(periodeElementaireSource.getQuantiteInitialeHeure(), dureePeriodeInitiale, nombreJoursIntersection));
      
      periodeElementaireCible.setQuantitePlafonnee(OutilQuantiteAffiliation.getInstance().proratiserQuantite(periodeElementaireSource.getQuantitePlafonnee(), dureePeriodeInitiale, nombreJoursIntersection));
      
      periodeElementaireCible.setQuantiteRetenue(OutilQuantiteAffiliation.getInstance().proratiserQuantite(periodeElementaireSource.getQuantiteRetenue(), dureePeriodeInitiale, nombreJoursIntersection));
      
      Iterator it = periodeElementaireSource.getListQuantiteAffiliationInitiales().iterator();
      while (it.hasNext())
      {
        Quantite quantite = (Quantite)it.next();
        periodeElementaireCible.ajouterQuantiteAffiliationInitiale(OutilQuantiteAffiliation.getInstance().proratiserQuantite(quantite, dureePeriodeInitiale, nombreJoursIntersection));
      }
    }
    else
    {
      periodeElementaireSource.copieElements(periodeElementaireCible);
    }
  }
  
  protected PeriodeElementaire proratiserPeriodeElementaire(PeriodeElementaire periodeElementaireSource, Periode periode)
  {
    PeriodeElementaire periodeElementaireCible = creerInstancePeriodeElementaire();
    
    proratiserPeriodeElementaire(periodeElementaireSource, periode, periodeElementaireCible);
    
    return periodeElementaireCible;
  }
  
  protected PeriodeElementaire proratiserPeriodeElementaire(PeriodeElementaire periodeElementaireSource, Periode periode, float dureeInitialePeriode)
  {
    PeriodeElementaire periodeElementaireCible = creerInstancePeriodeElementaire();
    
    proratiserPeriodeElementaire(periodeElementaireSource, periode, periodeElementaireCible, dureeInitialePeriode);
    
    return periodeElementaireCible;
  }
  
  protected void proratiserAffiliationSupplementaire(AffiliationSupplementaire periodeAffiliationSupplementaireSource, Periode periode, AffiliationSupplementaire periodeAffiliationSupplementaireCible)
  {
    if (!periode.contient(periodeAffiliationSupplementaireSource.getPeriodeAffiliationSupplementaire()))
    {
      periodeAffiliationSupplementaireSource.copieElements(periodeAffiliationSupplementaireCible);
      
      periodeAffiliationSupplementaireCible.setPeriodeAffiliationSupplementaire(periode.periodeIntersection(periodeAffiliationSupplementaireSource.getPeriodeAffiliationSupplementaire()));
      
      int nombreJoursIntersection = periode.inter(periodeAffiliationSupplementaireSource.getPeriodeAffiliationSupplementaire());
      int dureeInitialePeriode = periodeAffiliationSupplementaireSource.getPeriodeAffiliationSupplementaire().getDuree();
      
      periodeAffiliationSupplementaireCible.setQuantiteInitiale(OutilQuantiteAffiliation.getInstance().proratiserQuantite(periodeAffiliationSupplementaireSource.getQuantiteInitiale(), dureeInitialePeriode, nombreJoursIntersection));
      
      periodeAffiliationSupplementaireCible.setQuantiteRetenue(OutilQuantiteAffiliation.getInstance().proratiserQuantite(periodeAffiliationSupplementaireSource.getQuantiteRetenue(), dureeInitialePeriode, nombreJoursIntersection));
    }
    else
    {
      periodeAffiliationSupplementaireSource.copieElements(periodeAffiliationSupplementaireCible);
    }
  }
  
  protected AffiliationSupplementaire proratiserAffiliationSupplementaire(AffiliationSupplementaire periodeAffiliationSupplementaireSource, Periode periode)
  {
    AffiliationSupplementaire periodeAffiliationSupplementaireCible = creerInstanceAffiliationSupplementaire();
    
    proratiserAffiliationSupplementaire(periodeAffiliationSupplementaireSource, periode, periodeAffiliationSupplementaireCible);
    
    return periodeAffiliationSupplementaireCible;
  }
  
  /**
   * @deprecated
   */
  protected List decouperPeriodeElementaireSelonPeriodeIntensite(PeriodeElementaire periodeElementaire, ChronologiePeriodes chronologie)
  {
    List resultat = new ArrayList();
    if (chronologie != null)
    {
      Iterator it = chronologie.iterer();
      PeriodeElementaire periodeElementaireAFractionner = periodeElementaire;
      while (it.hasNext())
      {
        PeriodeIntensite objetPeriode = (PeriodeIntensite)it.next();
        Damj dateFractionnement = objetPeriode.getDateFin();
        List periodesElementairesFractionnees = decouperPeriodeElementaire(periodeElementaireAFractionner, dateFractionnement);
        
        resultat.add(periodesElementairesFractionnees.get(0));
        
        periodeElementaireAFractionner = (PeriodeElementaire)periodesElementairesFractionnees.get(1);
        
        periodeElementaireAFractionner.setPeriodeIntensite(objetPeriode);
      }
      resultat.add(periodeElementaireAFractionner);
    }
    else
    {
      resultat.add(periodeElementaire);
    }
    return resultat;
  }
  
  protected List decouperPeriodeElementaire(PeriodeElementaire periodeElementaire, Damj dateDecoupage)
  {
    List resultat = new ArrayList();
    
    Periode periodePE = periodeElementaire.getPeriodePE();
    if ((dateDecoupage.estApresOuCoincideAvec(periodePE.getDebut())) && (dateDecoupage.estAvant(periodePE.getFin())))
    {
      Periode periodeDecoupageGauche = new Periode(periodePE.getDebut(), dateDecoupage);
      Periode periodeDecoupageDroite = new Periode(dateDecoupage.lendemain(), periodePE.getFin());
      
      PeriodeElementaire periodeElementaireGauche = proratiserPeriodeElementaire(periodeElementaire, periodeDecoupageGauche);
      PeriodeElementaire periodeElementaireDroite = proratiserPeriodeElementaire(periodeElementaire, periodeDecoupageDroite);
      
      resultat.add(periodeElementaireGauche);
      resultat.add(periodeElementaireDroite);
    }
    else
    {
      resultat.add(periodeElementaire);
    }
    return resultat;
  }
  
  protected PeriodeElementaire creerInstancePeriodeElementaire()
  {
    return new PeriodeElementaire();
  }
  
  protected AffiliationSupplementaire creerInstanceAffiliationSupplementaire()
  {
    return new AffiliationSupplementaire();
  }
}

/* Location:
 * Qualified Name:     OutilTraitementPeriodeElementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */