package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.competence;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.ResultatDeterminationCompetence;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.dom.AntecedentSpec;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;

public class DeterminationCompetenceAsp
  extends DeterminationCompetenceCge
{
  public static DeterminationCompetenceCge getInstance()
  {
    return new DeterminationCompetenceAsp();
  }
  
  public ResultatDeterminationCompetence determinationCompetencesProduitCourant(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    ResultatDeterminationCompetence resultatDeterminationCompetence = new ResultatDeterminationCompetence();
    if (demandeCourante.getDonneesTemporaires().getCompetenceFinanciere() == null)
    {
      determinerChargeIndemnisationDroitCourant(demandeCourante, resultatDeterminationCompetence);
      determinerCompetenceFinanciere(demandeCourante, resultatDeterminationCompetence);
      determinerCompetenceAdministrativeDroitCourant(demandeCourante, resultatDeterminationCompetence);
    }
    else
    {
      determinerCompetencesSelonForcage(demandeCourante, resultatDeterminationCompetence);
    }
    return resultatDeterminationCompetence;
  }
  
  protected void determinerCompetencesSelonForcage(Demande demandeCourante, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {
    DonneesTemporaires donneesForcees = demandeCourante.getDonneesTemporaires();
    String competenceFinanciereForcee = donneesForcees.getCompetenceFinanciere();
    String employeurSPForce = donneesForcees.getEmployeurSecteurPublicCompetent();
    String etablissementFinanceurForce = donneesForcees.getNumeroConventionPE();
    
    determinerCompetenceFinanciereEtAdministrativeSelonForcage(resultatDeterminationCompetence, competenceFinanciereForcee, employeurSPForce, etablissementFinanceurForce, donneesForcees.getCodeAffectationConvention(), demandeCourante.getDateExamen());
    
    alimenterPCRCForceContexteSecteurPublic(resultatDeterminationCompetence, demandeCourante);
  }
  
  protected void determinerCompetenceFinanciereEtAdministrativeSelonForcage(ResultatDeterminationCompetence resultatDeterminationCompetence, String competenceFinanciereForcee, String libelleEmployeurForce, String etablissementFinanceurForce, String codeAffectationForce, Damj dateDepot)
    throws CoucheLogiqueException
  {
    boolean estCompetenceFinanciereForceRAC = 1 == Integer.parseInt(competenceFinanciereForcee);
    if (estCompetenceFinanciereForceRAC)
    {
      resultatDeterminationCompetence.setCompetenceFinanciere(1);
      resultatDeterminationCompetence.setCompetenceAdministrative(1);
    }
    else
    {
      resultatDeterminationCompetence.setCompetenceFinanciere(2);
      if (libelleEmployeurForce != null)
      {
        resultatDeterminationCompetence.setLibelleEmployeurCompetent(libelleEmployeurForce);
        resultatDeterminationCompetence.setCompetenceAdministrative(2);
      }
      else
      {
        resultatDeterminationCompetence.setCompetenceAdministrative(1);
        ConteneurConventionGestion conteneur = new ConteneurConventionGestion(etablissementFinanceurForce, codeAffectationForce, dateDepot, null);
        ConventionGestion conventionGestion = recupererConventionGestion(conteneur);
        OutilDeterminationCompetence.alimenterConventionGestion(resultatDeterminationCompetence, conventionGestion);
      }
    }
  }
  
  protected ConventionGestion recupererConventionGestion(ConteneurConventionGestion conteneur)
    throws CoucheLogiqueException
  {
    return (ConventionGestion)OutilConventionGestion.getInstance().trouverConventionGestion(conteneur);
  }
  
  public void determinerChargeIndemnisationDroitCourant(Demande demande, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)demande.getDossierAffectationAdmission().getSinistre();
    ChronologiePeriodes chronologiePeriodes = new ChronologiePeriodes();
    chronologiePeriodes.ajouter(dernierSinistre);
    resultatDeterminationCompetence.setActiviteParticipantes(chronologiePeriodes);
    int champApplicationFg = dernierSinistre.getChampApplicationRenseigne();
    
    int competenceAE = getCompetenceAE(dernierSinistre, champApplicationFg);
    
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)demande.getDossierExamen();
    AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)attributionCourante.getOuvertureDroit();
    if (((attributionPrecedente instanceof AntecedentSpec)) && (((Demande)((AntecedentSpec)attributionPrecedente).getDemande()).getSaisieAntecedent().getContexteDemande().intValue() == 9))
    {
      int competence = competenceAE;
      resultatDeterminationCompetence.setChargeIndemnisationDroitCourant(competence);
    }
    else if ((demande.getReliquat() != null) && (demande.getReliquat().isReliquatValide()))
    {
      int competence = 1;
      resultatDeterminationCompetence.setChargeIndemnisationDroitCourant(competence);
    }
    else if (competenceAE == 1)
    {
      resultatDeterminationCompetence.setChargeIndemnisationDroitCourant(1);
    }
    else
    {
      super.determinerChargeIndemnisationDroitCourant(demande, resultatDeterminationCompetence);
    }
  }
  
  private int getCompetenceAE(ActiviteSalarie dernierSinistre, int champApplicationFg)
    throws CoucheLogiqueException
  {
    int competenceAE = 0;
    if (champApplicationFg == 1)
    {
      if ((!dernierSinistre.getEntreprise().isEstSecteurPublic()) || (dernierSinistre.getEntreprise().isEstEmployeurAdherantATitreIrrevocable())) {
        competenceAE = 1;
      } else {
        competenceAE = 2;
      }
    }
    else if ((champApplicationFg == 3) || (champApplicationFg == 4)) {
      competenceAE = 2;
    } else if (champApplicationFg == 14) {
      competenceAE = 1;
    } else {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CALI_CHAMP_APPLICATION_ASP");
    }
    return competenceAE;
  }
  
  protected void determinerEmployeurCompetentSecteurPublic(Demande demande, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)demande.getDossierAffectationAdmission().getSinistre();
    resultatDeterminationCompetence.setLibelleEmployeurCompetent(dernierSinistre.getEntreprise().getLibelleEntreprise());
  }
  
  protected void determinerRegimeFinancementSecteurPrive(Demande demande, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {}
  
  public void determinerCompetenceAdministrativeDroitCourant(Demande demande, ResultatDeterminationCompetence resultatDeterminationCompetence)
  {
    resultatDeterminationCompetence.setCompetenceAdministrative(resultatDeterminationCompetence.getChargeIndemnisationDroitCourant());
    
    alimenterPCRCForceContexteSecteurPublic(resultatDeterminationCompetence, demande);
  }
  
  protected void alimenterPCRCForceContexteSecteurPublic(ResultatDeterminationCompetence resultatDeterminationCompetence, Demande demande)
  {
    if (resultatDeterminationCompetence.getCompetenceAdministrative() == 2) {
      resultatDeterminationCompetence.setEstPCRCForce(demande.getDonneesTemporaires().isEstPCRCForceDroitCourant());
    }
  }
  
  protected void determinerChargeIndemnisationDroitExecutable(Demande demande, ResultatDeterminationCompetence resultatDeterminationCompetence)
    throws CoucheLogiqueException
  {
    resultatDeterminationCompetence.setCompetenceFinanciere(resultatDeterminationCompetence.getChargeIndemnisationDroitCourant());
  }
}

/* Location:
 * Qualified Name:     DeterminationCompetenceAsp
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */