package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionCumulActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieConditionCumulActiviteConserveeSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsTrancheCalcul;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPansConservees;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.produits.liquidation.dom.TrancheExecutable;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class StrategieConditionCumulActiviteConserveeApres
  extends RechercheConditionCumulActiviteConservee
  implements StrategieConditionCumulActiviteConserveeSpec
{
  public BigDecimal determinerMontantRemunerationBrutePansConserveeSurMoisCivil(DemandeSpec p_demande, Chronologie p_chronoActivitesConservees)
    throws CoucheLogiqueException
  {
    return determinerMontantRemunerationBrutePansConserveeSurMoisCivil(p_demande.getDateExamen(), p_chronoActivitesConservees);
  }
  
  public BigDecimal determinerMontantRemunerationBrutePansConserveeSurMoisCivil(Damj p_dateExamen, Chronologie p_chronoActivitesConservees)
    throws CoucheLogiqueException
  {
    Periode periodeAnneeCivilePrecedente = determinerAnneeCivilePrecedantDate(p_dateExamen);
    Periode periodeAnneeCivileEnCours = determinerDebutAnneeCivileDateExamen(p_dateExamen.veille());
    RechercheConditionCumulActiviteConservee rechercheConditionCumulActiviteConservee = RechercheConditionCumulActiviteConservee.getInstance();
    return rechercheConditionCumulActiviteConservee.determinerMontantRemunerationMensuellePansConservees(periodeAnneeCivilePrecedente, periodeAnneeCivileEnCours, p_chronoActivitesConservees);
  }
  
  public BigDecimal determinerMontantRemunerationBrutePansConserveeSurPRC(DemandeSpec p_demande, Chronologie p_chronoActivitesConservees)
    throws CoucheLogiqueException
  {
    Damj termePRC = ((DossierExamen)((Demande)p_demande).getDossierExamen()).getConstitutionSjr().getSjrip().getDateEffet();
    return determinerMontantRemunerationBrutePansConserveeSurPRC(termePRC, p_chronoActivitesConservees);
  }
  
  public BigDecimal determinerMontantRemunerationBrutePansConserveeSurPRC(Damj p_termePRC, Chronologie p_chronoActivitesConservees)
    throws CoucheLogiqueException
  {
    Periode periodeAnneeCivilePrecedente = determinerAnneeCivilePrecedantDate(p_termePRC);
    Periode periodeAnneeCivileEnCours = determinerDebutAnneeCivileDateExamen(p_termePRC);
    RechercheConditionCumulActiviteConservee rechercheConditionCumulActiviteConservee = RechercheConditionCumulActiviteConservee.getInstance();
    return rechercheConditionCumulActiviteConservee.determinerMontantRemunerationMensuellePansConservees(periodeAnneeCivilePrecedente, periodeAnneeCivileEnCours, p_chronoActivitesConservees);
  }
  
  public BigDecimal recupererMontantRemunerationBrutePansConservee(ConteneurConditionActiviteConservee p_conteneurConditionActiviteConservee, DemandeSpec p_demande)
  {
    if (p_conteneurConditionActiviteConservee.getSeuilMensuelPansConditionActiviteConservee() != null) {
      return p_conteneurConditionActiviteConservee.getSeuilMensuelPansConditionActiviteConservee();
    }
    return new BigDecimal(0);
  }
  
  public BigDecimal determinerMontantRemunerationBrutePansConserve(AttributionSpec p_attribution, Chronologie p_chronoPansConservees)
  {
    if ((p_attribution instanceof Reprise)) {
      return ((Reprise)p_attribution).getSeuilMensuelPansConservees();
    }
    if (!OutilsTrancheCalcul.estTrancheActive(p_attribution)) {
      return ((Attribution)p_attribution).getSeuilMensuelPansConservees();
    }
    TrancheExecutable tranche = OutilsTrancheCalcul.recupererTrancheInitiale(p_attribution);
    return tranche.getSeuilMensuelPansConservees();
  }
  
  public JustificationPansConservees determinerRemunerationBrutePansConserveeSurPRC(DemandeSpec p_demande, Chronologie p_chronoActivitesConservees)
    throws CoucheLogiqueException
  {
    Damj termePRC = ((DossierExamen)((Demande)p_demande).getDossierExamen()).getConstitutionSjr().getSjrip().getDateEffet();
    
    Periode periodeAnneeCivilePrecedente = determinerAnneeCivilePrecedantDate(termePRC);
    Periode periodeAnneeCivileEnCours = determinerDebutAnneeCivileDateExamen(termePRC);
    
    return determinerRemunerationMensuellePansConservees(periodeAnneeCivilePrecedente, periodeAnneeCivileEnCours, p_chronoActivitesConservees);
  }
}

/* Location:
 * Qualified Name:     StrategieConditionCumulActiviteConserveeApres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */