package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.RechercheConditionFaitGenerateurSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.autresdoms.ga.outilsfonctionnels.OutilPasseProfessionel;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeRejetMandataire;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesDeclarees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAsp;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;

public class StrategieConditionFaitGenerateurDemandeClassique
  implements RechercheConditionFaitGenerateurSpec
{
  public ConditionFaitGenerateur creerDomConditionFaitGenerateur(Demande demande)
  {
    return ((DossierExamen)demande.getDossierExamen()).createConditionFaitGenerateur();
  }
  
  public FiltrePeriodesSurFiltresExclusifs filtreActiviteSalarieNonSalarieOuDnJ()
  {
    FiltrePeriodesSurFiltresExclusifs filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    
    FiltresTemporel filtresTravailSalarieNonSalarie = new FiltresTemporel();
    filtresTravailSalarieNonSalarie.ajouterFiltre(new FiltrePeriodesCertifiees());
    filtresExclusifs.ajouterFiltre(filtresTravailSalarieNonSalarie);
    
    FiltresTemporel filtresDeclareTravail = new FiltresTemporel();
    filtresDeclareTravail.ajouterFiltre(new FiltrePeriodesDeclarees());
    filtresDeclareTravail.ajouterFiltre(new FiltreTravailSpec());
    filtresExclusifs.ajouterFiltre(filtresDeclareTravail);
    return filtresExclusifs;
  }
  
  public Chronologie determinerChronoParticipantesDansDelai(Demande demande, DelaiRechercheProduit periodeDelaiForclusion, FiltreTemporel filtre)
  {
    Chronologie chronoActivitesParticipantesDansDelai = null;
    
    Chronologie chronoActivitesParticipantes = OutilPasseProfessionel.trouverChronoPasseProfessionelAvecFiltrageDNJ(demande.getDemandeur()).copier(filtre);
    
    chronoActivitesParticipantes = chronoActivitesParticipantes.copier(new FiltreFinAvantOuCoincideAvecDate(demande.getDateExamen()));
    if (periodeDelaiForclusion != null) {
      chronoActivitesParticipantesDansDelai = chronoActivitesParticipantes.copier(new FiltreFinDansBornes(periodeDelaiForclusion));
    }
    return chronoActivitesParticipantesDansDelai;
  }
  
  protected Chronologie determinerChronoActivitesHorsChampRejetMandataireDansDelai(Chronologie chronoActivitesParticipantesDansDelai)
  {
    Chronologie chronoActivitesHorsChampDansDelai = null;
    if (chronoActivitesParticipantesDansDelai != null)
    {
      FiltreTemporel filtrePeriodeRejetMandataire = new FiltrePeriodeActiviteSalarieeRejetMandataire();
      chronoActivitesHorsChampDansDelai = chronoActivitesParticipantesDansDelai.copier(filtrePeriodeRejetMandataire);
    }
    return chronoActivitesHorsChampDansDelai;
  }
  
  public Chronologie determinerChronoActivitesHorsDeFrance(Chronologie chronoActivitesParticipantesDansDelai)
  {
    Chronologie chronoActivitesHorsDeFrance = null;
    if (chronoActivitesParticipantesDansDelai != null)
    {
      FiltrePeriodesSurFiltresExclusifs filtresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
      FiltreTemporel filtreActiviteHorsDeFrance = new FiltrePeriodeActiviteSalarieeE301NonFrontalier();
      filtresExclusifs.ajouterFiltre(filtreActiviteHorsDeFrance);
      
      chronoActivitesHorsDeFrance = chronoActivitesParticipantesDansDelai.copier(filtresExclusifs);
    }
    return chronoActivitesHorsDeFrance;
  }
  
  public boolean traiterEchecB41AbsenceFaitGenerateurDeDroit(ConditionFaitGenerateur faitGenerateur, TravailSpec dernierSinistre)
  {
    boolean echecCondition = false;
    if (dernierSinistre == null)
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(41);
      echecCondition = true;
    }
    return echecCondition;
  }
  
  public boolean traiterEchecB50B62ActiviteHorsChamps(ConditionFaitGenerateur faitGenerateur, Chronologie chronoActivitesParticipantesDansDelai)
  {
    boolean echecCondition = false;
    
    Chronologie chronoActivitesHorsChampDansDelai = determinerChronoActivitesHorsChampRejetMandataireDansDelai(chronoActivitesParticipantesDansDelai);
    if ((chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsChampDansDelai != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsChampDansDelai.getTaille()))
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(42);
      echecCondition = true;
    }
    return echecCondition;
  }
  
  public boolean traiterEchecActiviteHorsDeFrance(ConditionFaitGenerateur faitGenerateur, Chronologie chronoActivitesParticipantesDansDelai)
  {
    Chronologie chronoActivitesHorsDeFrance = determinerChronoActivitesHorsDeFrance(chronoActivitesParticipantesDansDelai);
    boolean echecCondition = false;
    if ((chronoActivitesParticipantesDansDelai != null) && (chronoActivitesHorsDeFrance != null) && (chronoActivitesParticipantesDansDelai.getTaille() > 0) && (chronoActivitesParticipantesDansDelai.getTaille() == chronoActivitesHorsDeFrance.getTaille()))
    {
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(47);
      echecCondition = true;
    }
    return echecCondition;
  }
  
  public int trouverCodeMotifEchecDelaiForclusion(Demande demande, DelaiRechercheProduit periodeDelaiForclusion)
  {
    boolean delaiForclusionAllonge = (periodeDelaiForclusion != null) && (demande.getDonneesTemporaires() != null) && (demande.getDonneesTemporaires().getAllongementDelaiForclusion() != null) && (demande.getDonneesTemporaires().getAllongementDelaiForclusion().getJours() != 0);
    
    return delaiForclusionAllonge ? 45 : 44;
  }
  
  public ConditionFaitGenerateur rechercherConditionFaitGenerateur(Demande demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur faitGenerateur = creerDomConditionFaitGenerateur(demande);
    
    DelaiRechercheProduit periodeDelaiForclusion = ((DossierAffectation)demande.getDossierAffectation()).getDelaiRecherche();
    int codeMotifEchecDelaiForclusion = trouverCodeMotifEchecDelaiForclusion(demande, periodeDelaiForclusion);
    TravailSpec dernierSinistre = determinerDernierSinistre(demande);
    
    FiltrePeriodesSurFiltresExclusifs filtresExclusifs = filtreActiviteSalarieNonSalarieOuDnJ();
    Chronologie chronoActivitesParticipantesDansDelai = determinerChronoParticipantesDansDelai(demande, periodeDelaiForclusion, filtresExclusifs);
    
    boolean echecCondition = traiterEchecB41AbsenceFaitGenerateurDeDroit(faitGenerateur, dernierSinistre);
    if (echecCondition) {
      traiterEchecActiviteHorsDeFrance(faitGenerateur, chronoActivitesParticipantesDansDelai);
    }
    if (echecCondition) {
      traiterEchecB50B62ActiviteHorsChamps(faitGenerateur, chronoActivitesParticipantesDansDelai);
    }
    if (!echecCondition)
    {
      DelaiRechercheProduit periodeValiditeFgd = determinerPeriodeValiditeFGD(demande, dernierSinistre);
      echecCondition = verifierEchecExistenceFGD(demande, faitGenerateur, dernierSinistre, periodeValiditeFgd, periodeDelaiForclusion, codeMotifEchecDelaiForclusion);
    }
    if (!echecCondition) {
      echecCondition = verifierEchecDelaisForclusionSurFCTRetenue(demande, faitGenerateur, dernierSinistre, periodeDelaiForclusion, codeMotifEchecDelaiForclusion);
    }
    if ((!echecCondition) && (!demande.estUneDemandeFinancement())) {
      verifierMotifRuptureAsrOuAtp(dernierSinistre, demande);
    }
    return faitGenerateur;
  }
  
  protected TravailSpec determinerDernierSinistre(Demande demande)
    throws CoucheLogiqueException
  {
    return ((DossierAffectation)demande.getDossierAffectation()).getSinistre();
  }
  
  protected void verifierMotifRuptureAsrOuAtp(TravailSpec dernierSinistre, Demande demande)
    throws CoucheLogiqueException
  {
    if (((dernierSinistre instanceof ActiviteSalarie)) && (Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin()) == 42)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB24");
    }
    if (((dernierSinistre instanceof ActiviteSalarie)) && (Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin()) == 43)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DECISION_CTP_IMPOSSIBLE");
    }
    if (leverBlocageAeCSP(dernierSinistre, demande)) {
      if (((dernierSinistre instanceof ActiviteSalarie)) && (Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin()) == 48)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DECISION_CSP_IMPOSSIBLE", new String[] { "PAP" });
      } else {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DECISION_CSP_IMPOSSIBLE", new String[] { "CSP" });
      }
    }
  }
  
  protected boolean leverBlocageAeCSP(TravailSpec dernierSinistre, Demande demande)
  {
    boolean retour = false;
    if ((dernierSinistre instanceof ActiviteSalarie))
    {
      if (((Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin()) == 44) || (Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin()) == 48)) && (estNonContexteCSP(demande))) {
        retour = true;
      }
      if (retour)
      {
        EvenementReferenceExamenSpec ere = demande.getEvenementReferenceExamen();
        if ("ASU_29".equals(ere.getTypeExamen())) {
          retour = traitementRechargement(dernierSinistre, demande, retour);
        }
      }
    }
    return retour;
  }
  
  private boolean traitementRechargement(TravailSpec dernierSinistre, Demande demande, boolean retourIntermediaire)
  {
    boolean retour = retourIntermediaire;
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionSuivante(demande.getChronologieDemandesAssuranceSansCourante(), dernierSinistre.getDateFin(), new FiltreAttributionAsp());
    if (attribution != null)
    {
      TravailSpec sinistreAsp = ((DossierAffecte)attribution.getDossierAffecte()).getSinistre();
      if (sinistreAsp.equals(dernierSinistre)) {
        retour = false;
      }
    }
    return retour;
  }
  
  protected boolean estNonContexteCSP(Demande demande)
  {
    boolean estContexteEntreeOuEnCoursCspPap = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"));
    
    boolean estContexteSortieCsp = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPARE")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPDC"));
    
    boolean estContexteSortiePap = (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTPAPARE")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTPAPDC"));
    
    return (!estContexteEntreeOuEnCoursCspPap) && (!estContexteSortieCsp) && (!estContexteSortiePap);
  }
  
  private boolean verifierEchecExistenceFGD(Demande demande, ConditionFaitGenerateur faitGenerateur, TravailSpec dernierSinistre, DelaiRechercheProduit periodeValiditeFgd, DelaiRechercheProduit periodeDelaiForclusion, int codeMotifEchecDelaisForclusion)
    throws CoucheLogiqueException
  {
    boolean echecCondition = false;
    if ((dernierSinistre == null) || (periodeValiditeFgd == null) || (!dernierSinistre.getDateFin().estContenueDans(periodeValiditeFgd)))
    {
      echecCondition = traiterAbsenceDernierOuHorsPeriodeValidite(faitGenerateur, periodeValiditeFgd, periodeDelaiForclusion, codeMotifEchecDelaisForclusion);
    }
    else if (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).estAtteste()))
    {
      faitGenerateur.setEtatSatisfait(true);
      faitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dernierSinistre);
      faitGenerateur.setAgeIndividuDateFG(demande.getDemandeur().getAgeALaDate(dernierSinistre.getDateFin()));
    }
    else if ((demande.getFormulaire().getPresenceAe() != null) && (!"".equalsIgnoreCase(demande.getFormulaire().getPresenceAe())))
    {
      if (demande.getFormulaire().getPresenceAe().equalsIgnoreCase("I"))
      {
        faitGenerateur.setEtatSatisfait(false);
        faitGenerateur.setCodeMotifEchec(46);
        echecCondition = true;
      }
      else if (demande.getFormulaire().getPresenceAe().equalsIgnoreCase("O"))
      {
        lancerAlerteA11MB1(dernierSinistre);
      }
    }
    else
    {
      lancerAlerteA11MB1(dernierSinistre);
    }
    return echecCondition;
  }
  
  private boolean traiterAbsenceDernierOuHorsPeriodeValidite(ConditionFaitGenerateur faitGenerateur, DelaiRechercheProduit periodeValiditeFgd, DelaiRechercheProduit periodeDelaiForclusion, int codeMotifEchecDelaisForclusion)
  {
    if ((periodeValiditeFgd != null) && (periodeValiditeFgd.getDebut().coincideAvec(periodeDelaiForclusion.getDebut())) && (periodeValiditeFgd.getFin().coincideAvec(periodeDelaiForclusion.getFin()))) {
      faitGenerateur.setCodeMotifEchec(codeMotifEchecDelaisForclusion);
    } else {
      faitGenerateur.setCodeMotifEchec(41);
    }
    faitGenerateur.setEtatSatisfait(false);
    boolean echecCondition = true;
    return echecCondition;
  }
  
  public static void lancerAlerteA11MB1(TravailSpec dernierSinistre)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB1", new String[] { dernierSinistre.getDateDebut().toString(), dernierSinistre.getDateFin().toString() });
  }
  
  private boolean verifierEchecDelaisForclusionSurFCTRetenue(Demande demande, ConditionFaitGenerateur faitGenerateur, TravailSpec dernierSinistre, DelaiRechercheProduit periodeDelaiForclusion, int codeMotifEchecDelaisForclusion)
    throws CoucheLogiqueException
  {
    boolean echecCondition = false;
    
    ActiviteSalarie fctRetenueValidationProduit = null;
    ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    if (validationProduit != null) {
      fctRetenueValidationProduit = validationProduit.getPeriodeValidationProduit();
    }
    boolean affectationProduitSecoursSurControleOriginePas = ((DossierAffectation)demande.getDossierAffectation()).getJustificationAffectation() == 6;
    if ((fctRetenueValidationProduit != null) && (periodeDelaiForclusion != null) && (!fctRetenueValidationProduit.getDateFin().estContenueDans(periodeDelaiForclusion)))
    {
      faitGenerateur.setEtatSatisfait(false);
      
      faitGenerateur.setCodeMotifEchec(codeMotifEchecDelaisForclusion);
      echecCondition = true;
    }
    else if ((affectationProduitSecoursSurControleOriginePas) || ((fctRetenueValidationProduit != null) && (!fctRetenueValidationProduit.estAtteste())))
    {
      echecCondition = verifierEchecSurFctNonAtteste(demande, faitGenerateur, dernierSinistre, echecCondition);
    }
    return echecCondition;
  }
  
  private boolean verifierEchecSurFctNonAtteste(Demande demande, ConditionFaitGenerateur faitGenerateur, TravailSpec dernierSinistre, boolean echecCondition)
    throws CoucheLogiqueException
  {
    boolean retour = echecCondition;
    if (demande.getFormulaire().getPresenceAe().equalsIgnoreCase("I"))
    {
      if (dernierSinistre != null) {
        faitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dernierSinistre);
      }
      faitGenerateur.setEtatSatisfait(false);
      faitGenerateur.setCodeMotifEchec(46);
      retour = true;
    }
    else if (demande.getFormulaire().getPresenceAe().equalsIgnoreCase("O"))
    {
      verifierDnjOuPas(demande);
    }
    return retour;
  }
  
  protected void verifierDnjOuPas(Demande demande)
    throws CoucheLogiqueException
  {
    TravailSpec derniereFctEtudiee = ((DossierAffectation)demande.getDossierAffectation()).getDerniereFctEtudiee();
    boolean estDeclareeNonJustifiee = ((derniereFctEtudiee instanceof DeclareSpec)) && (!((DeclareSpec)derniereFctEtudiee).estJustifie());
    boolean estCertifieeNonSalariee = ((derniereFctEtudiee instanceof CertifieSpec)) && (!(derniereFctEtudiee instanceof ActiviteSalarie));
    boolean estSalarieeNonAttestee = ((derniereFctEtudiee instanceof ActiviteSalarie)) && (!((ActiviteSalarie)derniereFctEtudiee).estAtteste());
    if ((estDeclareeNonJustifiee) || (estCertifieeNonSalariee) || (estSalarieeNonAttestee)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB2", new String[] { derniereFctEtudiee.getDateFin().toString() });
    }
  }
  
  protected DelaiRechercheProduit determinerPeriodeValiditeFGD(Demande demande, TravailSpec dernierSinistre)
  {
    return ((DossierAffectation)demande.getDossierAffectation()).getDelaiRecherche();
  }
}

/* Location:
 * Qualified Name:     StrategieConditionFaitGenerateurDemandeClassique
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */