package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationCoefficientTempsPartiel;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class ConstitutionCoefficientTempsPartiel
  extends ParcoursCali
  implements ParcoursAssurance
{
  private BigDecimal m_coefficientTempsPartiel = new BigDecimal("1");
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution du coefficient saisonnier.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA11 = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    DonneesTemporaires donneestemporaires = demandeCourante.getDonneesTemporaires();
    
    Reglement reglementApplicable = dossierExamenCourant.getReglementApplicable().getReglement();
    if (donneestemporaires.getCoefficientTempsPartiel() != null)
    {
      m_coefficientTempsPartiel = donneestemporaires.getCoefficientTempsPartiel();
    }
    else if ((reglementApplicable.estNomReglementIdentique("RG")) || (reglementApplicable.estNomReglementIdentique("OP")) || (reglementApplicable.estNomReglementIdentique("A2a")) || (reglementApplicable.estNomReglementIdentique("A6")))
    {
      Periode prtp = DelaiRecherche.getInstance().determinerPrc(demandeCourante);
      
      Chronologie chronologiePrs = ConstructionChronologie.determinerChronoActivitesPrtp(demandeCourante, prtp);
      if (!chronologiePrs.estVide())
      {
        Chronologie chronologiePeriodeHoraireStable = DeterminationCoefficientTempsPartiel.getInstance().determinerChronoPeriodesIntensiteADate(prtp, chronologiePrs, (ProduitAsuSpec)dossierExamenCourant.getDossierAffecte().getProduit(), demandeCourante.getDateExamen());
        
        m_coefficientTempsPartiel = DeterminationCoefficientTempsPartiel.getInstance().determinerCoefficientTempsPartiel(chronologiePeriodeHoraireStable);
      }
    }
    fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientTempsPartiel cepa11 = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
    
    cepa11.setCoefficientTempsPartielRetenu(m_coefficientTempsPartiel);
    
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Résultat : ", resultatCEPA11 });
    
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA11;
  }
  
  private DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
}

/* Location:
 * Qualified Name:     ConstitutionCoefficientTempsPartiel
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */