package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDelaiReport;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationDelaisReports;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDelaiAttente;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieDelaiAttenteSpec;
import fr.unedic.cali.asu.cge01.liquidation.parcours.fabrique.FabriqueDeterminationDelaisReports;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class ConstitutionDelaisReportsReprise
  extends ConstitutionDelaisReportsAbstrait
{
  protected ResultatDeterminationDelaisReports determinerCollectionDelaisReports(Contexte contexte)
    throws ApplicativeException
  {
    Collection collectionDelaisReportsRetour = new ArrayList();
    ResultatDeterminationDelaisReports resultat = new ResultatDeterminationDelaisReports();
    
    collectionDelaisReportsRetour = determinerCollectionReliquatDelaisReport(contexte, collectionDelaisReportsRetour);
    
    collectionDelaisReportsRetour = determinerCollectionDelaisReportCourant(contexte, collectionDelaisReportsRetour);
    
    resultat.getListeDelaisReports().addAll(collectionDelaisReportsRetour);
    
    return resultat;
  }
  
  protected Collection determinerCollectionReliquatDelaisReport(Contexte contexte, Collection collectionDelaisReportsRetour)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    Collection collectionDelaisReportsEffectifsDroitPrecedent = trouverCollectionDelaisReportsEffectifsDroitPrecedent(contexte);
    Iterator<CarencePrefixeAFixer> i;
    if (!demande.getDemandeOrigine().getEvenementReferenceExamen().getTypeExamen().equals("ASU_17"))
    {
      Collection<CarencePrefixeAFixer> collectionDelaisReportsReliquats = OutilDeterminationDelaisReports.determinerCollectionDelaisReportsReliquats(demande, collectionDelaisReportsEffectifsDroitPrecedent);
      if (collectionDelaisReportsReliquats != null) {
        for (i = collectionDelaisReportsReliquats.iterator(); i.hasNext();)
        {
          CarencePrefixeAFixer delaiReportCourant = (CarencePrefixeAFixer)i.next();
          OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsRetour, delaiReportCourant);
        }
      }
    }
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(demande.getDateExamen());
    StrategieDelaiAttenteSpec strategieDelaiAttente = (StrategieDelaiAttenteSpec)FabriqueStrategieDelaiAttente.getInstance().getStrategie(critereStrategie);
    
    strategieDelaiAttente.alimenterListeCarencesForcees(demande, collectionDelaisReportsRetour);
    return collectionDelaisReportsRetour;
  }
  
  protected Collection determinerCollectionDelaisReportCourant(Contexte contexte, Collection collectionDelaisReportsRetour)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Collection<CarencePrefixeAFixer> collectionDelaisReports = new ArrayList();
    
    ParcoursDeterminationDelaisReports parcoursDeterminationDelaisReports = FabriqueDeterminationDelaisReports.getParcoursDeterminationDelaisReports(demande);
    if (parcoursDeterminationDelaisReports != null)
    {
      ResultatDeterminationDelaisReports resultatDeterminationDelaisReports = (ResultatDeterminationDelaisReports)parcoursDeterminationDelaisReports.effectuerParcours(contexte);
      
      collectionDelaisReports = resultatDeterminationDelaisReports.getListeDelaisReports();
    }
    if (collectionDelaisReports != null) {
      for (CarencePrefixeAFixer delaiReportCourant : collectionDelaisReports) {
        OutilDelaiReport.ajouterDelaiReportDansCollection(collectionDelaisReportsRetour, delaiReportCourant);
      }
    }
    return collectionDelaisReportsRetour;
  }
  
  protected Collection trouverCollectionDelaisReportsEffectifsDroitPrecedent(Contexte contexte)
  {
    return ((DomLiquidationAssurance)contexte.getDonnees()).getResultatExecutionCalculDroitPrecedent().getListeCarencesEffectives();
  }
  
  protected boolean alimenterCarencesSurCEP(ConstitutionDelais constitutionDelais, Demande demande, ResultatExecutionCalculSpec resultatAvantCalcul)
  {
    boolean activiteAvecPresenceAutreTransactionRetenuDansAvant = false;
    if ((resultatAvantCalcul != null) && (resultatAvantCalcul.getListeCarencesEffectives() != null))
    {
      List<CarencePrefixeAFixer> listeCarences = resultatAvantCalcul.getListeCarencesEffectives();
      for (CarencePrefixeAFixer delaiReportCourant : listeCarences)
      {
        if ((!delaiReportCourant.isReliquatCarence()) || (delaiReportCourant.getPeriodeApplicationCarence().getFin().estApresOuCoincideAvec(demande.getDossierAffectation().getDossierExamen().getDateAttribution()))) {
          traiterCarencePourAlimenterSurCEP(constitutionDelais, delaiReportCourant, demande);
        }
        if ((delaiReportCourant.getOrigine() != null) && (constitutionDelais.getActivitePresenceAutreTransaction() != null) && (delaiReportCourant.getOrigine().equals(constitutionDelais.getActivitePresenceAutreTransaction()))) {
          activiteAvecPresenceAutreTransactionRetenuDansAvant = true;
        }
      }
    }
    return activiteAvecPresenceAutreTransactionRetenuDansAvant;
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelaisReportsReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */