package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.outilsfonctionnels.AccesValeursParametres;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ConstitutionProduitResultantSPFinDroit
  extends ConstitutionProduitResultantClassiqueFinDroit
{
  private static final BigDecimal CONSTANTE_ARRONDI = new BigDecimal("0.5");
  
  public Resultat demarrerParcours(Contexte p_contexte)
    throws CoucheLogiqueException, ApplicativeException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    
    verifieContexteDonneesForceesPresentes(demandeCourante);
    
    Resultat resultat = constitutionProduitResultant(p_contexte);
    
    miseAJourDom(demandeCourante);
    return resultat;
  }
  
  private void miseAJourDom(Demande p_demande)
  {
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    
    dossierExamenCourant.getConstitutionProduitResultant().setDureeDroitPrecedent(m_dureeIntermediaireDroitPrecedent);
  }
  
  protected void affectationDemandeOrigine(Demande p_demandeCourante, DomLiquidationAssurance p_dom)
    throws CoucheLogiqueException
  {}
  
  private void verifieContexteDonneesForceesPresentes(Demande p_demandeCourante)
    throws CoucheLogiqueException
  {
    Quantite capitalDroitPrecedentSP = p_demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    Quantite sjrDroitPrecedentSP = p_demandeCourante.getDonneesTemporaires().getSjrSP();
    Damj termePrcDroitPrecedentSP = p_demandeCourante.getDonneesTemporaires().getTermePrcSp();
    BigDecimal coefSaisonnierDroitprecedentSP = p_demandeCourante.getDonneesTemporaires().getCoefficientSaisonnierSp();
    BigDecimal coefTPDroitprecedentSP = p_demandeCourante.getDonneesTemporaires().getCoefficientTempsPartielSp();
    if (capitalDroitPrecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_CAPITAL_RELIQUAT");
    }
    if (sjrDroitPrecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_SJR_SECTEUR_PUBLIC");
    }
    if (termePrcDroitPrecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_TERME_PRC_SP");
    }
    if (coefTPDroitprecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABS_COEFF_SAISONNIER_SP");
    }
    if (coefSaisonnierDroitprecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_COEFF_TP_SP");
    }
    TravailSpec dernierSinistre = ((DossierAffectation)p_demandeCourante.getDossierAffectation()).getSinistre();
    if (dernierSinistre != null)
    {
      Damj dateFCT = dernierSinistre.getDateFin();
      if ((dateFCT != null) && 
        (termePrcDroitPrecedentSP.compareTo(dateFCT) > 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_INCOHERENCE_PRC_FCT_FORCEE_SP");
      }
      if ((dernierSinistre instanceof ActiviteSalarie))
      {
        ActiviteSalarie periode = (ActiviteSalarie)dernierSinistre;
        if ((periode.getDernierJourTravaillePaye() != null) && 
          (termePrcDroitPrecedentSP.compareTo(periode.getDernierJourTravaillePaye()) > 0)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_INCOH_PRC_DJTP_FORCEE_SP");
        }
      }
    }
    Quantite plafondSjr = AccesValeursParametres.getPlafondSjr(termePrcDroitPrecedentSP);
    if ((plafondSjr != null) && (sjrDroitPrecedentSP.compareTo(plafondSjr) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_INCOH_SJR_PLAFOND_FORCE_SP");
    }
  }
  
  protected void verifierCapitalPrecedentSP(Quantite p_duree, MontantAsuSpec p_montant, Quantite p_capital)
    throws CoucheLogiqueException
  {
    BigDecimal capitalCalculeInferieur = p_duree.getValeur().subtract(CONSTANTE_ARRONDI).multiply(p_montant.getMontantPrecompteEffectif().getValeur());
    BigDecimal capitalCalculeSuperieur = p_duree.getValeur().add(CONSTANTE_ARRONDI).multiply(p_montant.getMontantPrecompteEffectif().getValeur());
    if ((p_capital.getValeur().compareTo(capitalCalculeSuperieur) >= 0) || (p_capital.getValeur().compareTo(capitalCalculeInferieur) < 1))
    {
      BigDecimal capitalCalcule = p_duree.getValeur().multiply(p_montant.getMontantPrecompteEffectif().getValeur());
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_CAPITAL_SP", new Object[] { capitalCalcule.toString() });
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultantSPFinDroit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */