package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.parcours.conteneurs.ConteneurParcoursRevisionAutomatique;
import fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.fabriques.FabriqueStrategieRevisionAutomatique;
import fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.strategies.spec.StrategieRevisionAutomatiqueSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinCroissante;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;

public abstract class ConstitutionRevisionAutomatiqueFinDroit
  extends ParcoursCali
  implements ParcoursAssurance
{
  private StrategieRevisionAutomatiqueSpec m_strategieRevision = null;
  
  public Resultat demarrerParcours(ConteneurParcoursRevisionAutomatique conteneur)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultat = new Resultat(0);
    
    Chronologie activitesAReviser = trouverChronoActiviteAReviser(conteneur.getDemandeCourante());
    if ((activitesAReviser != null) && (!activitesAReviser.estVide()))
    {
      activitesAReviser.setComparateur(new ComparateurTemporelSurDateFinCroissante());
      conteneur.getAttributionAReviser().getConstitutionSjr().setSjrRevise(Boolean.FALSE);
      
      Damj dateFgd = conteneur.getAttributionAReviser().getDateFaitGenerateurDroit();
      ConteneurAccesDecorReglementaire conteneurAccesDecor = new ConteneurAccesDecorReglementaire();
      conteneurAccesDecor.setDemande(conteneur.getDemandeCourante());
      conteneurAccesDecor.setDateRecherche(dateFgd);
      DecorReglementaire decorReglementaire = AccesDecorReglementaire.getInstance().getDecor(conteneurAccesDecor);
      boolean coordCee = conteneur.getDemandeCourante().getDonneesTemporaires().isEstCoordCee();
      CriteresQualification critereQualification = null;
      if ((conteneur.getAttributionAReviser() instanceof Reprise)) {
        critereQualification = new CriteresQualification(decorReglementaire, ((Demande)conteneurAccesDecor.getDemande()).getFaitGenerateurOuDernierSinistre(), coordCee);
      } else {
        critereQualification = new CriteresQualification(decorReglementaire, conteneur.getAttributionAReviser().getFaitGenerateur().getPeriodeFaitGenerateur(), coordCee);
      }
      AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(critereQualification, (Individu)conteneur.getDemandeCourante().getDemandeur());
      
      activitesAReviser.iterer();
      while (activitesAReviser.encoreSuivant())
      {
        TravailSpec prochaineActiviteAReviser = (TravailSpec)activitesAReviser.elementSuivant();
        conteneur.setActiviteConserveeAReviser(prochaineActiviteAReviser);
        
        initialiserStrategiePourRevisionAutomatique(prochaineActiviteAReviser.getDateFin());
        if (estActiviteAEtudier(conteneur))
        {
          Demande demandeAReviserTemporaire = creerDemandeAReviser(conteneur);
          conteneur.setDemandeRevision(demandeAReviserTemporaire);
          
          recupererStrategiePourRevisionAutomatique().mettreAJourDemandeRevision(conteneur);
          
          Contexte contexteAReviser = creerContextePourRevision(conteneur);
          conteneur.setContexteRevision(contexteAReviser);
          
          alimenterDonneesForceesDemandeAReviser(conteneur);
          
          recupererStrategiePourRevisionAutomatique().reviserActiviteConservee(conteneur);
        }
      }
    }
    return resultat;
  }
  
  private boolean estActiviteAEtudier(ConteneurParcoursRevisionAutomatique p_conteneurParcoursRevisionAutomatique)
  {
    return recupererStrategiePourRevisionAutomatique().estFCTATraiter(p_conteneurParcoursRevisionAutomatique);
  }
  
  protected FabriqueStrategieRevisionAutomatique recupererFabriquePourRevisionAutomatique()
  {
    return new FabriqueStrategieRevisionAutomatique();
  }
  
  private void initialiserStrategiePourRevisionAutomatique(Damj p_dateFCTActiviteConserveePerdue)
    throws CoucheLogiqueException
  {
    FabriqueStrategieRevisionAutomatique fabrique = recupererFabriquePourRevisionAutomatique();
    CritereStrategie criteres = new CritereStrategie();
    criteres.setDatePivot(p_dateFCTActiviteConserveePerdue);
    m_strategieRevision = ((StrategieRevisionAutomatiqueSpec)fabrique.getStrategie(criteres));
  }
  
  protected StrategieRevisionAutomatiqueSpec recupererStrategiePourRevisionAutomatique()
  {
    return m_strategieRevision;
  }
  
  private Contexte creerContextePourRevision(ConteneurParcoursRevisionAutomatique p_conteneur)
  {
    return recupererStrategiePourRevisionAutomatique().creerContextePourRevision(p_conteneur);
  }
  
  protected Demande creerDemandeAReviser(ConteneurParcoursRevisionAutomatique conteneur)
    throws ApplicativeException
  {
    StrategieRevisionAutomatiqueSpec strategie = recupererStrategiePourRevisionAutomatique();
    return strategie.creerDemandeAReviser(conteneur);
  }
  
  private void alimenterDonneesForceesDemandeAReviser(ConteneurParcoursRevisionAutomatique p_conteneur)
  {
    recupererStrategiePourRevisionAutomatique().alimenterDonneesForceesDemandeAReviser(p_conteneur);
  }
  
  protected abstract Chronologie trouverChronoActiviteAReviser(Demande paramDemande)
    throws ApplicativeException;
}

/* Location:
 * Qualified Name:     ConstitutionRevisionAutomatiqueFinDroit
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */