package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ResultatRechercheConditionChomageInvolontaire;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.strategies.spec.StrategieConditionChomageInvolontaireAre14Spec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieConditionChomageInvolontaire;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionChomageInvolontaire;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class DeterminationConditionChomageInvolontaireReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 2;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCapr09 = new Resultat(1);
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    CritereStrategie critereStrategie = new CritereStrategie();
    critereStrategie.setDatePivot(demande.getDateExamen());
    critereStrategie.setDemande(demande);
    StrategieConditionChomageInvolontaireAre14Spec strategieConditionChomageInvolontaire = (StrategieConditionChomageInvolontaireAre14Spec)FabriqueStrategieConditionChomageInvolontaire.getInstance().getStrategie(critereStrategie);
    
    ResultatRechercheConditionChomageInvolontaire resultat = strategieConditionChomageInvolontaire.rechercheConditionChomageInvolontairePourReprise(demande);
    ConditionChomageInvolontaire conditionChomageInvolontaire = ((DossierExamen)demande.getDossierExamen()).getConditionsAttributionActives().createConditionChomageInvolontaire();
    
    alimenterCap(resultat, conditionChomageInvolontaire, demande);
    if (conditionChomageInvolontaire.estSatisfait())
    {
      resultatCapr09.setEtat(0);
    }
    else
    {
      resultatCapr09.setEtat(1);
      resultatCapr09.setMessageErreur(Integer.toString(conditionChomageInvolontaire.getCodeMotifEchec()));
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCapr09;
  }
  
  private static void alimenterCap(ResultatRechercheConditionChomageInvolontaire resultat, ConditionChomageInvolontaire conditionChomageInvolontaire, Demande demande)
    throws CoucheLogiqueException
  {
    conditionChomageInvolontaire.setCodeMotifEchec(resultat.getResultatElementDroit().getCodeMotifEchec());
    conditionChomageInvolontaire.setEtatSatisfait(resultat.getResultatElementDroit().estSatisfait());
    conditionChomageInvolontaire.setSituationConditionChomageInvolontaire(resultat.getSituationConditionChomageInvolontaire());
    conditionChomageInvolontaire.setIdentifiantActivitePortantDV(resultat.getIdentifiantActivitePortantDV());
    if ((!conditionChomageInvolontaire.estSatisfait()) && (conditionChomageInvolontaire.getCodeMotifEchec() != 93)) {
      conditionChomageInvolontaire.setDateDepartDelai121j(GestionDemandeDv122eJour.calculerPointDepart(demande, demande));
    }
    conditionChomageInvolontaire.setDureeAeDv(resultat.getDureeAeDV());
    conditionChomageInvolontaire.setIntensiteHoraireSalarieAeDv(resultat.getIntensiteHoraireAeDV());
    Quantite quantiteAffiPrincipaleIno = resultat.getQuantiteAffiliationPrincipaleInopposabilite();
    Quantite quantiteAffiSecondaireIno = resultat.getQuantiteAffiliationSecondaireInopposabilite();
    if (quantiteAffiPrincipaleIno != null) {
      conditionChomageInvolontaire.setQuantiteAffiliationPrincipaleInopposabilite(new Quantite(Mathematiques.arrondiASup(quantiteAffiPrincipaleIno.getValeur(), 2), quantiteAffiPrincipaleIno.getUnite()));
    }
    if (quantiteAffiSecondaireIno != null) {
      conditionChomageInvolontaire.setQuantiteAffiliationSecondaireInopposabilite(new Quantite(Mathematiques.arrondiASup(quantiteAffiSecondaireIno.getValeur(), 2), quantiteAffiSecondaireIno.getUnite()));
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionChomageInvolontaireReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */