package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionCumulActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.produits.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCva10P02;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Iterator;

public class DeterminationConditionCumulActiviteConservee
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final QuantiteEuro QUANTITE_EURO_ZERO = new QuantiteEuro("0");
  
  public Resultat demarrer(Contexte contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCAPA12 = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    boolean estReglementApplicableA4 = reglementApplicableCourant.equals(produit.getReglement("A4"));
    
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demandeCourante);
    
    ConditionActiviteConservee conditionActiviteConservee = dossierExamenCourant.createConditionActiviteConservee();
    if ((estReglementApplicableA4) && (!strategieActiviteConservee.traiterActivitesConserveesA4()))
    {
      conditionActiviteConservee.setEtatSatisfait(true);
    }
    else
    {
      Collection<SjrActiviteConservee> collectionGlobaleActivitesConservees = strategieActiviteConservee.recupererListeActivitesConservees(demandeCourante);
      
      Chronologie chronoGlobaleActivitesConservees = null;
      Damj termePrc = null;
      boolean miseAJourDom = false;
      boolean persisterCepa10 = false;
      if (strategieActiviteConservee.persisterListeActivitesConserveesCapa12())
      {
        miseAJourDom = true;
        persisterCepa10 = false;
      }
      else if (estReglementApplicableA4)
      {
        miseAJourDom = true;
        persisterCepa10 = true;
        
        Periode periodePrc = OutilGestionActivitesConservees.getInstance().recupererPeriodePrc(demandeCourante);
        termePrc = periodePrc.getFin();
      }
      else
      {
        miseAJourDom = false;
        persisterCepa10 = false;
      }
      chronoGlobaleActivitesConservees = mettreAJourDomListeActivitesConservees(miseAJourDom, persisterCepa10, dossierExamenCourant, termePrc, collectionGlobaleActivitesConservees);
      if (estConditionSatisfaite(demandeCourante, produit))
      {
        conditionActiviteConservee.setEtatSatisfait(true);
      }
      else
      {
        RechercheConditionCumulActiviteConservee rechercheConditionCumulActiviteConservee = RechercheConditionCumulActiviteConservee.getInstance();
        
        rechercheConditionCumulActiviteConservee.leverAlerteA11MB7SurOriginePasConservee(chronoGlobaleActivitesConservees);
        
        ConteneurConditionActiviteConservee conteneurConditionActiviteConservee = rechercheConditionCumulActiviteConservee.rechercherConditionCumulActiviteConservee(demandeCourante, chronoGlobaleActivitesConservees);
        
        rechercheConditionCumulActiviteConservee.mapperConteneurVersConditionActiviteConservee(conteneurConditionActiviteConservee, conditionActiviteConservee);
      }
      filtrerActiviteConserveAPersister(demandeCourante, chronoGlobaleActivitesConservees, persisterCepa10);
    }
    if (conditionActiviteConservee.estSatisfait())
    {
      resultatCAPA12.setEtat(0);
    }
    else
    {
      resultatCAPA12.setEtat(1);
      resultatCAPA12.setMessageErreur(Integer.toString(conditionActiviteConservee.getCodeMotifEchec()));
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Résultat", resultatCAPA12 });
    
    OutilTrace.tracerFinParcours();
    
    return resultatCAPA12;
  }
  
  private boolean estConditionSatisfaite(Demande demandeCourante, ProduitSpec produit)
  {
    return (ProduitAsuCva10P02.getInstance().getCode() == produit.getCode()) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demandeCourante, 9));
  }
  
  protected void filtrerActiviteConserveAPersister(Demande demandeCourante, Chronologie chronoGlobaleActivitesConservees, boolean persisterCepa10)
  {
    ConditionActiviteConservee conditionActiviteConservee = ((DossierExamen)demandeCourante.getDossierExamen()).getConditionActiviteConservee();
    ConstitutionSjc constitutionSjc = ((DossierExamen)demandeCourante.getDossierExamen()).getConstitutionSjc();
    
    ChronologiePeriodes passePro = demandeCourante.getDemandeur().getChronoPeriodePasseProfessionnel();
    Chronologie periodesAjout = new ChronologiePeriodes();
    Iterator<?> actConsIterator;
    if ((passePro != null) && (chronoGlobaleActivitesConservees != null) && (!passePro.estVide()) && (!chronoGlobaleActivitesConservees.estVide())) {
      for (actConsIterator = chronoGlobaleActivitesConservees.iterer(); actConsIterator.hasNext();)
      {
        TravailSpec chrono = (TravailSpec)actConsIterator.next();
        Chronologie memeContrat = passePro.copier(new FiltreActiviteSalarieSurMemeContratGAEC(chrono));
        if ((memeContrat != null) && (!memeContrat.estVide())) {
          for (emploiSurMemeContratGaec = memeContrat.iterer(); emploiSurMemeContratGaec.hasNext();)
          {
            TravailSpec periode = (TravailSpec)emploiSurMemeContratGaec.next();
            if ((!chronoGlobaleActivitesConservees.contientElement(periode)) && (!periodesAjout.contientElement(periode))) {
              periodesAjout.ajouter(periode);
            }
          }
        }
      }
    }
    Iterator<?> emploiSurMemeContratGaec;
    if (!periodesAjout.estVide())
    {
      Collection<SjrActiviteConservee> listeActivitesConserveesRetournee = OutilGestionActivitesConservees.getInstance().mapperChronoEnListeActivitesConservees(periodesAjout);
      
      Iterator<SjrActiviteConservee> it = listeActivitesConserveesRetournee.iterator();
      while (it.hasNext())
      {
        SjrActiviteConservee sjrActiviteConserveeCourante = (SjrActiviteConservee)it.next();
        chronoGlobaleActivitesConservees.ajouter(sjrActiviteConserveeCourante.getPeriodeActiviteConservee());
        if (persisterCepa10) {
          constitutionSjc.getSjcip().ajouterSjrActiviteConservee(sjrActiviteConserveeCourante);
        } else {
          conditionActiviteConservee.ajouterSjrActiviteConservee(sjrActiviteConserveeCourante);
        }
      }
    }
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition de cumul avec une activite conservee impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen courant est null: determination condition de cumul avec une activite conservee impossible.");
    }
    if ((dossierExamenCourant.getConstitutionSjr() == null) || (dossierExamenCourant.getConstitutionSjr().getSjrip() == null)) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le Sjrip est null: determination condition de cumul avec une activite conservee impossible.");
    }
  }
  
  private Chronologie mettreAJourDomListeActivitesConservees(boolean miseAJourDom, boolean persisterCepa10, DossierExamen dossierExamen, Damj termePrc, Collection<SjrActiviteConservee> collectionGlobaleActivitesConservees)
  {
    Chronologie chronoGlobaleActivitesConservees = new ChronologiePeriodes();
    
    ConditionActiviteConservee conditionActiviteConservee = null;
    ConstitutionSjc constitutionSjc = null;
    if (miseAJourDom) {
      if (persisterCepa10)
      {
        constitutionSjc = dossierExamen.createConstitutionSjc();
        constitutionSjc.createSjcip(termePrc, QUANTITE_EURO_ZERO, QUANTITE_EURO_ZERO);
      }
      else
      {
        conditionActiviteConservee = dossierExamen.getConditionActiviteConservee();
      }
    }
    SjrActiviteConservee sjrActiviteConserveeCourante = null;
    Iterator<SjrActiviteConservee> it = collectionGlobaleActivitesConservees.iterator();
    while (it.hasNext())
    {
      sjrActiviteConserveeCourante = (SjrActiviteConservee)it.next();
      chronoGlobaleActivitesConservees.ajouter(sjrActiviteConserveeCourante.getPeriodeActiviteConservee());
      if (miseAJourDom) {
        if (persisterCepa10) {
          constitutionSjc.getSjcip().ajouterSjrActiviteConservee(sjrActiviteConserveeCourante);
        } else {
          conditionActiviteConservee.ajouterSjrActiviteConservee(sjrActiviteConserveeCourante);
        }
      }
    }
    return chronoGlobaleActivitesConservees;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionCumulActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */