package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheConditionQuantiteAffiliation;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilPeriodesElementaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.parcours.DomCali;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.Hashtable;

public class DeterminationConditionQuantiteAffiliation
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultatCAPA07 = new Resultat();
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    IndividuSpec individu = ((DomCali)contexte.getDonnees()).getIndividu();
    
    DonneesTemporaires donneesForcees = demande.getDonneesTemporaires();
    
    boolean estDemandeElligileIPR = estDemandeEligibleASaisineIPR(demande);
    boolean estDecisionIprPrise = donneesForcees.isEstDesactivationPnds() != null;
    
    Quantite quantiteAffiForcee = donneesForcees.getQuantiteAffiliation();
    ConditionQuantiteAffiliation conditionQuantiteAffiliation;
    ConditionQuantiteAffiliation conditionQuantiteAffiliation;
    if ((estDemandeElligileIPR) && (!estDecisionIprPrise) && (quantiteAffiForcee == null))
    {
      conditionQuantiteAffiliation = traitementPourDetectionIPR(demande, individu);
    }
    else
    {
      ConditionQuantiteAffiliation conditionQuantiteAffiliation;
      if (estDemandeElligileIPR) {
        conditionQuantiteAffiliation = traitementIPR(demande, individu);
      } else {
        conditionQuantiteAffiliation = traitementStandard(demande, individu);
      }
    }
    if ((conditionQuantiteAffiliation != null) && (conditionQuantiteAffiliation.estSatisfait()))
    {
      resultatCAPA07.setEtat(0);
    }
    else
    {
      resultatCAPA07.setEtat(1);
      resultatCAPA07.setMessageErreur(Integer.toString(conditionQuantiteAffiliation.getCodeMotifEchec()));
    }
    return resultatCAPA07;
  }
  
  private boolean estDemandeEligibleASaisineIPR(Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateReactivationPNDS = GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS");
    boolean estDemandeElligible;
    boolean estDemandeElligible;
    if (demande.getDateExamen().estApresOuCoincideAvec(dateReactivationPNDS)) {
      estDemandeElligible = true;
    } else {
      estDemandeElligible = estDemandeEnContexteRechargement(demande);
    }
    return estDemandeElligible;
  }
  
  private boolean estDemandeEnContexteRechargement(Demande demande)
  {
    return OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE");
  }
  
  private ConditionQuantiteAffiliation traitementStandard(Demande pDemande, IndividuSpec pIndividu)
    throws ApplicativeException
  {
    return RechercheConditionQuantiteAffiliation.getInstance().rechercheConditionQuantiteAffiliation(pDemande, pIndividu);
  }
  
  private ConditionQuantiteAffiliation traitementIPR(Demande pDemande, IndividuSpec pIndividu)
    throws ApplicativeException
  {
    ConditionQuantiteAffiliation capa = traitementStandard(pDemande, pIndividu);
    
    Boolean desactivationPnd = pDemande.getDonneesTemporaires().isEstDesactivationPnds();
    if ((!capa.estSatisfait()) && (desactivationPnd != null) && (!desactivationPnd.booleanValue())) {
      capa.setEtatPndsPourCalculAffi("N");
    } else if ((capa.estSatisfait()) && (desactivationPnd != null) && (desactivationPnd.booleanValue())) {
      capa.setEtatPndsPourCalculAffi("V");
    }
    return capa;
  }
  
  private ConditionQuantiteAffiliation traitementPourDetectionIPR(Demande demande, IndividuSpec pIndividu)
    throws ApplicativeException
  {
    ConditionQuantiteAffiliation capa = traitementStandard(demande, pIndividu);
    if (!capa.estSatisfait())
    {
      ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
      
      Periode pra = null;
      if ((validationProduit != null) && (validationProduit.isEstProduitValide())) {
        pra = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getJustificationCalculAffiliation().getPeriodeRechercheAffiliation();
      }
      if (pra == null)
      {
        Damj dateFgPrecedent = demande.getDateFaitGenerateurOdPrecedente();
        Damj dateFin = demande.getDateExamen();
        Damj dateDebut = demande.getDateExamen().deplacerVersArriere(new DureeCalendaire(0, 36, 0));
        if (dateFgPrecedent != null) {
          dateDebut = Damj.max(dateDebut, dateFgPrecedent.lendemain());
        }
        pra = new Periode(dateDebut, dateFin);
      }
      Chronologie chronoPnds = demande.getChronologiePNDS(pra);
      if ((chronoPnds != null) && (!chronoPnds.estVide()))
      {
        OutilPeriodesElementaires.viderCachePeriodesElementaires(pIndividu);
        
        Demande copieDemande = (Demande)demande.copie();
        if (estDemandeEnContexteRechargement(demande)) {
          copieDemande.getDonneesTemporaires().setTypeContexteDemandeDonneesTemporaires("RECHARGE");
        }
        copieDemande.getDonneesTemporaires().setEstDesactivationPnds(Boolean.valueOf(true));
        try
        {
          lancerLiquidation(copieDemande);
          if (copieDemande.getAttribution() != null) {
            capa.setEtatPndsPourCalculAffi("P");
          }
          leverAlertesNonBloquantesBilanDroitOption(demande, copieDemande);
        }
        finally
        {
          OutilPeriodesElementaires.viderCachePeriodesElementaires(pIndividu);
          pIndividu.activerPNDS();
        }
      }
    }
    return capa;
  }
  
  private void lancerLiquidation(Demande pCopieDemande)
    throws ApplicativeException
  {
    Contexte contexte = new Contexte();
    DomLiquidationAssurance domLiq = new DomLiquidationAssurance();
    domLiq.setContexteService(pCopieDemande.getDemandeur().getContexteService());
    domLiq.setDemande(pCopieDemande);
    domLiq.setIdDemande(pCopieDemande.getIdentifiant());
    domLiq.setIndividu(pCopieDemande.getDemandeur());
    
    contexte.setDonnees(domLiq);
    
    ParcoursLiquidation parcoursLiquidationDemande = pCopieDemande.getGamme().getParcoursLiquidation(pCopieDemande);
    
    parcoursLiquidationDemande.effectuerParcours(contexte);
  }
  
  protected void leverAlertesNonBloquantesBilanDroitOption(Demande demande, Demande copieDemande)
  {
    Hashtable copieAlertesNonBloquantes = copieDemande.getAlertesNonBloquantes();
    String alerte = "BILAN_DROIT_OPTION";
    if ((copieAlertesNonBloquantes != null) && (copieAlertesNonBloquantes.get(alerte) != null) && (demande.getAlertesNonBloquantes() != null)) {
      demande.getAlertesNonBloquantes().put(alerte, copieAlertesNonBloquantes.get(alerte));
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */