package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationSjr;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.dom.Prc;
import fr.unedic.cali.asu.produits.liquidation.dom.Revision;
import fr.unedic.cali.asu.produits.liquidation.dom.Sjrip;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDemandeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class ParcoursConstitutionSjrRevision
  extends ParcoursConstitutionSjrAbstrait
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjr impossible.");
    }
    Revision dossierExamenCourant = (Revision)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen (révision) est null: constitution du Sjr impossible.");
    }
    if (dossierExamenCourant.getOuvertureDroit() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution maitre pour révision est nulle : constitution du Sjr impossible.");
    }
    Sjrip sjripAttributionMaitre = ((DossierExamen)dossierExamenCourant.getOuvertureDroit()).getConstitutionSjr().getSjrip();
    if (sjripAttributionMaitre == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le SJRIP de l'attribution maitre est null : constitution du Sjr impossible.");
    }
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Le règlement applicable est null: constitution du Sjr impossible.");
    }
  }
  
  protected void alimenterCEPCodeEmploiA2B(ConstitutionSjr p_constitutionSjr, DonneesEntreeDeterminationSjrSpec p_donneesEntreeDeterminationSjr) {}
  
  protected Chronologie determinerChronoActiviteSalariePrc(Demande p_demande, Periode p_periodePrc)
  {
    Chronologie chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesPrcPourRevision(p_demande, p_periodePrc);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des ActiviteSalarie chevauchant la Prc : ", chronologieActiviteSalarie });
    return chronologieActiviteSalarie;
  }
  
  protected JustificationPrc determinerEtJustifierPeriodePrc(Demande p_demande)
    throws ApplicativeException
  {
    Revision dossierExamenCourant = (Revision)p_demande.getDossierExamen();
    Sjrip sjripAttributionPrecedente = ((DossierExamen)dossierExamenCourant.getOuvertureDroit()).getConstitutionSjr().getSjrip();
    
    JustificationPrc justificationPrc = sjripAttributionPrecedente.getPrc().getJustification();
    return justificationPrc;
  }
  
  protected Sjrip verifierSjripForce(Demande p_demande, DonneesEntreeDeterminationSjrSpec p_donneesEntree)
    throws ApplicativeException
  {
    Sjrip sjripRetourne = null;
    
    Quantite sjrSaisi = p_donneesEntree.getDonneesEntreeDemande().getDonneeForceeSjrPerteActConservee();
    if (sjrSaisi != null)
    {
      BigDecimal resultatSjr = sjrSaisi.getValeur();
      
      Revision dossierExamenCourant = (Revision)p_demande.getDossierExamen();
      Sjrip sjripAttributionPrecedente = ((DossierExamen)dossierExamenCourant.getOuvertureDroit()).getConstitutionSjr().getSjrip();
      
      Damj termePrc = sjripAttributionPrecedente.getDateEffet();
      
      BigDecimal resultatPlafondSjr = null;
      if (sjripAttributionPrecedente.getPlafondSjr() == null) {
        resultatPlafondSjr = OutilDeterminationSjr.getInstance().determinerPlafondSjr(sjripAttributionPrecedente.getPrc().getDateFin(), p_donneesEntree);
      } else {
        resultatPlafondSjr = sjripAttributionPrecedente.getPlafondSjr().getValeur();
      }
      sjripRetourne = construireSjrip(termePrc, resultatPlafondSjr, resultatSjr);
    }
    return sjripRetourne;
  }
  
  protected Chronologie determinerChronoActivitePourConditionCoordEuropeenne(Prc p_prc, Chronologie p_chronoActiviteSalariePrc)
  {
    Chronologie chronoActivitePostE301Retour = null;
    
    Chronologie chronoActiviteE301Prc = p_chronoActiviteSalariePrc.copier(new FiltrePeriodeActiviteSalarieeE301NonFrontalier());
    if ((chronoActiviteE301Prc != null) && (!chronoActiviteE301Prc.estVide()))
    {
      chronoActiviteE301Prc.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
      ActiviteSalarie fctE301NonFrontalierPlusRecente = (ActiviteSalarie)chronoActiviteE301Prc.premierElement();
      
      Damj borneDebutActivitesPostE301 = fctE301NonFrontalierPlusRecente.getDateFin().lendemain();
      chronoActivitePostE301Retour = p_chronoActiviteSalariePrc.copier(new FiltreDebutApresDate(borneDebutActivitesPostE301));
    }
    return chronoActivitePostE301Retour;
  }
}

/* Location:
 * Qualified Name:     ParcoursConstitutionSjrRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */