package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.ContributionsParticulieres;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ContributionParticuliere;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuCaa14P02;
import fr.unedic.cali.dom.affectation.ProduitAsuCve13P01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;

public class ParcoursDetecterContributionParticuliere
  extends ParcoursCali
{
  public Resultat demarrer(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    ContributionParticuliere contributionParticuliere = new ContributionParticuliere();
    
    boolean boolContributionSpecifique = false;
    boolean boolContributionSuplementaire = false;
    if ((dossierExamenCourant instanceof OdAssuranceSpec))
    {
      String situation = ((ProduitAsuSpec)demandeCourante.getDossierAffectation().getProduit()).getSituationParticuliere((AttributionSpec)dossierExamenCourant);
      ((OdAssuranceSpec)dossierExamenCourant).setSituationParticuliere(situation);
    }
    if (ContributionsParticulieres.estDecisionPourAppelDetecContribPart((OdAssuranceSpec)dossierExamenCourant))
    {
      boolContributionSpecifique = estContributionSpecifique(dossierExamenCourant);
      boolContributionSuplementaire = estContributionSupplementaire(dossierExamenCourant);
    }
    if ((boolContributionSpecifique) && (boolContributionSuplementaire)) {
      contributionParticuliere.setTypeContributionParticuliere(3);
    } else if (boolContributionSpecifique) {
      contributionParticuliere.setTypeContributionParticuliere(2);
    } else if (boolContributionSuplementaire) {
      contributionParticuliere.setTypeContributionParticuliere(1);
    }
    if ((!boolContributionSpecifique) && (!boolContributionSuplementaire)) {
      contributionParticuliere.setTypeContributionParticuliere(0);
    }
    dossierExamenCourant.setContributionParticuliere(contributionParticuliere);
    
    return new Resultat();
  }
  
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit. : DetectionContributionParticuliere impossible");
    }
    if (DomLiquidationAssurance.getDemande(contexte).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Absence individu demandeur sur la demande : DetectionContributionParticuliere impossible");
    }
    if (DomLiquidationAssurance.getDemande(contexte).getDossierExamen() == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est null: DetectionContributionParticuliere impossible");
    }
  }
  
  private boolean estContributionSupplementaire(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = (Demande)dossierExamenCourant.getDemande();
    
    ActiviteSalarie sinistre = dossierExamenCourant.getFaitGenerateur().getPeriodeFaitGenerateur();
    ContratTravail contrat = sinistre.getContrat();
    int codeMotifFinContrat = sinistre.getContrat().getCodeMotifFin();
    Damj dateRCT = contrat.getDateRuptureContratTravail();
    Damj debutPreavis = null;
    if (contrat.getPreavis() != null) {
      debutPreavis = contrat.getPreavis().getDebut();
    }
    boolean estAdmissibleContributionSupplementaire = true;
    if (!ContributionParticuliere.estMotifAppelContribSuppl(codeMotifFinContrat)) {
      estAdmissibleContributionSupplementaire = false;
    }
    if ((estAdmissibleContributionSupplementaire) && (contrat.getNature() != 1)) {
      estAdmissibleContributionSupplementaire = false;
    }
    switch (sinistre.getMetier().getChampApplication())
    {
    case 2: 
    case 8: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    if ((estAdmissibleContributionSupplementaire) && (dateRCT != null))
    {
      if (demandeCourante.getDemandeur().getAgeALaDate(dateRCT).getAnnees() < 50) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    else if ((estAdmissibleContributionSupplementaire) && (debutPreavis != null))
    {
      if (demandeCourante.getDemandeur().getAgeALaDate(debutPreavis).getAnnees() < 50) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    else if ((estAdmissibleContributionSupplementaire) && (sinistre.getDateFin() != null))
    {
      DureeCalendaire ageFinSinistre = demandeCourante.getDemandeur().getAgeALaDate(sinistre.getDateFin());
      if (ageFinSinistre.getAnnees() < 50) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    if ("98000".equals(sinistre.getEntreprise().getCodePostalEntreprise())) {
      estAdmissibleContributionSupplementaire = false;
    }
    if (sinistre.getMetier().getChampApplication() == 4) {
      estAdmissibleContributionSupplementaire = false;
    }
    switch (sinistre.getMetier().getCategorieEmploiParticulier())
    {
    case 23: 
    case 29: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    switch (contrat.getPohf())
    {
    case 3: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 10: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    switch (sinistre.getMetier().getCategorieEmploiParticulier())
    {
    case 22: 
    case 23: 
    case 37: 
    case 38: 
      estAdmissibleContributionSupplementaire = false;
      break;
    }
    if (sinistre.getDateDebut().estApres(ContributionParticuliereSpec.DATE_CRTL_EXCLU_EMPL_PAS))
    {
      DureeCalendaire ageDebutSinistre = demandeCourante.getDemandeur().getAgeALaDate(sinistre.getDateDebut());
      if (ageDebutSinistre.getAnnees() > 45) {
        estAdmissibleContributionSupplementaire = false;
      }
    }
    if ((estAdmissibleContributionSupplementaire) && (demandeCourante.getFaitGenerateur() != null) && (demandeCourante.getFaitGenerateur().getDateFaitGenerateur().estApresOuCoincideAvec(ContributionParticuliereSpec.DATE_CTRL_FAIT_GENERATEUR_CONT_SUPPL))) {
      estAdmissibleContributionSupplementaire = false;
    }
    return estAdmissibleContributionSupplementaire;
  }
  
  private boolean estContributionSpecifique(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    boolean estAdmissibleContributionSpecifique = true;
    
    Demande demandeCourante = (Demande)dossierExamenCourant.getDemande();
    
    ActiviteSalarie sinistre = dossierExamenCourant.getFaitGenerateur().getPeriodeFaitGenerateur();
    ContratTravail contrat = sinistre.getContrat();
    int codeMotifFinContrat = sinistre.getContrat().getCodeMotifFin();
    if (contrat.getNature() != 1) {
      estAdmissibleContributionSpecifique = false;
    }
    if (!ContributionParticuliere.estMotifAppelContribSpecifique(codeMotifFinContrat)) {
      estAdmissibleContributionSpecifique = false;
    }
    switch (sinistre.getMetier().getCategorieEmploiParticulier())
    {
    case 23: 
    case 29: 
      estAdmissibleContributionSpecifique = false;
      break;
    }
    if ((sinistre.getMetier().getChampApplication() == 3) || (sinistre.getMetier().getChampApplication() == 4)) {
      estAdmissibleContributionSpecifique = false;
    }
    if ("98000".equals(sinistre.getEntreprise().getCodePostalEntreprise())) {
      estAdmissibleContributionSpecifique = false;
    }
    switch (contrat.getPohf())
    {
    case 3: 
    case 4: 
    case 5: 
    case 6: 
    case 7: 
    case 8: 
    case 9: 
    case 10: 
      estAdmissibleContributionSpecifique = false;
      break;
    }
    if (estAdmissibleContributionSpecifique) {
      verifierContributionNonProposition(dossierExamenCourant);
    }
    String me2c = demandeCourante.getTopContribution();
    boolean propositionPapOk = (demandeCourante.estTopPropositionPAP() != null) && (demandeCourante.estTopPropositionPAP().booleanValue());
    if (("O".equals(me2c)) || ("C".equals(me2c)) || (propositionPapOk)) {
      estAdmissibleContributionSpecifique = false;
    }
    if (((FormulaireAsu)demandeCourante.getFormulaire()).isDroitAuCongeReclassement()) {
      estAdmissibleContributionSpecifique = false;
    }
    if (sinistre.getDateFin().estAvantOuCoincideAvec(ContributionParticuliereSpec.DATE_CTRL_FCT_CONT_SPE)) {
      estAdmissibleContributionSpecifique = false;
    }
    return estAdmissibleContributionSpecifique;
  }
  
  protected void verifierContributionNonProposition(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    ActiviteSalarie sinistre = dossierExamenCourant.getFaitGenerateur().getPeriodeFaitGenerateur();
    
    Damj dateEngagementProcedure = sinistre.getDateEngagementProcedureLicenciement();
    if (dateEngagementProcedure == null) {
      dateEngagementProcedure = sinistre.getDateFin();
    }
    if (sinistre.getCodeMotifFin() == 47) {
      verifierContributionNonPropositionPap(dossierExamenCourant);
    } else if (dateEngagementProcedure.estApresOuCoincideAvec(ProduitAsuCaa14P02.getInstance().getPeriodeValidite().getDebut())) {
      verifierContributionNonPropositionCsp(dossierExamenCourant);
    } else {
      verifierContributionNonPropositionCrpCtp(dossierExamenCourant, dateEngagementProcedure);
    }
  }
  
  private void verifierContributionNonPropositionCrpCtp(DossierExamen dossierExamenCourant, Damj dateEngagementProcedure)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)dossierExamenCourant;
    Attribution attributionOrigine = (Attribution)attribution.getOuvertureDroit();
    
    Entreprise entreprise = attributionOrigine.getFaitGenerateur().getPeriodeFaitGenerateur().getEntreprise();
    Damj fGD = attribution.getDateFaitGenerateurDroit();
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)dossierExamenCourant.getDemande();
    String me2c = demande.getTopContribution();
    
    boolean montantCTPForceRenseigne = false;
    BigDecimal montantCTP = ((Demande)attribution.getDemande()).getDonneesTemporaires().getMontantContributionPourNonCTP();
    if ((montantCTP != null) && (montantCTP.compareTo(new BigDecimal(0)) != 0)) {
      montantCTPForceRenseigne = true;
    }
    int codeBassin = 0;
    if (entreprise != null) {
      codeBassin = entreprise.getCodeBassinCTP();
    }
    if ((codeBassin != 0) && (codeBassin != 3)) {
      traiterBassinEmploiCTP(dateEngagementProcedure, fGD, me2c, montantCTPForceRenseigne);
    } else {
      traiterBassinEmploiNonCTP(fGD, demande, me2c, montantCTPForceRenseigne);
    }
  }
  
  private void traiterBassinEmploiCTP(Damj dateEngagementProcedure, Damj fGD, String me2c, boolean montantCTPForceRenseigne)
    throws CoucheLogiqueException
  {
    if (dateEngagementProcedure.estAvantOuCoincideAvec(ProduitAsuCve13P01.getInstance().getPeriodeValidite().getFin())) {
      if (("N".equals(me2c)) || ("O".equals(me2c))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB7", new String[] { fGD.toString() });
      } else if (("T".equals(me2c)) && (!montantCTPForceRenseigne)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB8", new String[] { fGD.toString() });
      }
    }
  }
  
  private void traiterBassinEmploiNonCTP(Damj fGD, DemandeAssuranceSpec demande, String me2c, boolean montantCTPForceRenseigne)
    throws CoucheLogiqueException
  {
    if (("T".equals(me2c)) || ("C".equals(me2c)))
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB9", new String[] { fGD.toString() });
    }
    else if (montantCTPForceRenseigne)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB10", new String[] { fGD.toString() });
    }
    else if ("N".equals(me2c))
    {
      Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
      
      listePeriodes.add(objetAlerteNonBloquante);
      demande.getAlertesNonBloquantes().put("A16MNB3", listePeriodes);
    }
  }
  
  private void verifierContributionNonPropositionCsp(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    Attribution attribution = (Attribution)dossierExamenCourant;
    Damj fGD = attribution.getDateFaitGenerateurDroit();
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)dossierExamenCourant.getDemande();
    String me2c = demande.getTopContribution();
    
    Attribution attributionOrigine = (Attribution)attribution.getOuvertureDroit();
    Entreprise entreprise = attributionOrigine.getFaitGenerateur().getPeriodeFaitGenerateur().getEntreprise();
    boolean effectifSupperieurAMille = false;
    boolean motifRuptureJudiciaire = false;
    if ((entreprise != null) && ("04".equals(entreprise.getEffectif()))) {
      effectifSupperieurAMille = true;
    }
    if ((attributionOrigine.getFaitGenerateur().getPeriodeFaitGenerateur().getContrat().getCodeMotifFin() == 33) || (attributionOrigine.getFaitGenerateur().getPeriodeFaitGenerateur().getContrat().getCodeMotifFin() == 2)) {
      motifRuptureJudiciaire = true;
    }
    if (("T".equals(me2c)) || ("C".equals(me2c))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB12", new String[] { fGD.toString(), ProduitAsuCaa14P02.getInstance().getPeriodeValidite().getDebut().toString() });
    } else if ("N".equals(me2c)) {
      traiterNonPropositionCSP(attribution, effectifSupperieurAMille, motifRuptureJudiciaire);
    }
  }
  
  private void traiterNonPropositionCSP(Attribution attribution, boolean effectifSupperieurAMille, boolean motifRuptureJudiciaire)
  {
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)attribution.getDemande();
    Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
    
    ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
    
    listePeriodes.add(objetAlerteNonBloquante);
    if ((effectifSupperieurAMille) && (!motifRuptureJudiciaire))
    {
      demande.getAlertesNonBloquantes().put("A16MNB6", listePeriodes);
    }
    else
    {
      String deploiementInstruction = ((FormulaireAsu)attribution.getDemande().getFormulaire()).getDeploiementInstruction();
      boolean versionDeploiementOPIValide = (deploiementInstruction != null) && (!"N".equalsIgnoreCase(deploiementInstruction)) && (!"1".equalsIgnoreCase(deploiementInstruction)) && (!"2".equalsIgnoreCase(deploiementInstruction));
      if (versionDeploiementOPIValide) {
        demande.getAlertesNonBloquantes().put("A16MNB7", listePeriodes);
      } else {
        demande.getAlertesNonBloquantes().put("A16MNB5", listePeriodes);
      }
    }
  }
  
  private void verifierContributionNonPropositionPap(DossierExamen dossierExamenCourant)
    throws CoucheLogiqueException
  {
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)dossierExamenCourant.getDemande();
    
    Boolean propositionPap = demande.estTopPropositionPAP();
    if ((propositionPap != null) && (!propositionPap.booleanValue()))
    {
      Collection<ObjetAlertesNonBloquantes> listePeriodes = new ArrayList();
      
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(Damj.NUIT_DES_TEMPS, Damj.FIN_DES_TEMPS, 999);
      
      listePeriodes.add(objetAlerteNonBloquante);
      
      demande.getAlertesNonBloquantes().put("A16MNB9", listePeriodes);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursDetecterContributionParticuliere
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */