package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilChronologiePourDelaisReports;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilDeterminationMontantICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieFormuleICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.CriteresStrategieFormuleICCP;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeApres;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeAvant;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieFormuleICCPSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.BaseDelaiReport;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJourSpec;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.List;

public class ParcoursDeterminationDelaisReportsCasGeneral
  extends ParcoursDeterminationDelaisReports
{
  private Boolean iccpConservatoireBatimentAutorise = null;
  
  protected Chronologie determinerChronologieActivitesPourICCPISLR(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    boolean estDiffereICCPouISLRForce = ((demande.getDonneesTemporaires().getQuantiteJourICCP() != null) || (demande.getDonneesTemporaires().getQuantiteJourISLR() != null)) && (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null);
    Chronologie chronoActivitesParticipantes;
    if (estDiffereICCPouISLRForce)
    {
      Chronologie chronoActivitesParticipantes = OutilChronologiePourDelaisReports.determinerChronologieActivitesPourDifferes(demande);
      
      String identifiantActiviteSalarieForcee = demande.getDonneesTemporaires().getIndentifiantFctPMC();
      ActiviteSalarie activiteSalarieForcee = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantActiviteSalarieForcee);
      if (activiteSalarieForcee != null) {
        if ((chronoActivitesParticipantes != null) && ((chronoActivitesParticipantes.contientElement(activiteSalarieForcee)) || (activiteSalarieForcee.getContrat().estSuspensionChomageSansRCT())))
        {
          chronoActivitesParticipantes = new ChronologiePeriodes();
          chronoActivitesParticipantes.ajouter(activiteSalarieForcee);
        }
        else
        {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_ALERTE_DF_FCT_NON_UTILISABLE_DIFFERE", new Object[] { activiteSalarieForcee.getDateFin() });
        }
      }
    }
    else
    {
      chronoActivitesParticipantes = OutilChronologiePourDelaisReports.determinerChronologieActivitesPourDifferes(demande);
    }
    return chronoActivitesParticipantes;
  }
  
  protected BaseDelaiReport determinerBaseDelaiReportICCP(DemandeAssuranceSpec demande, ActiviteSalarie activiteSalarie, ChronologiePeriodes chronoPeriodesIndemnisation, boolean iccpConservatoireAutoriseBatiment)
    throws ApplicativeException
  {
    StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec strategiePriseEnCompteMontantICCPActiviteConservee = (StrategiePriseEnCompteMontantCarencesSurActiviteConserveeSpec)FabriqueStrategieGenerique.choisirStrategie(activiteSalarie.getDateFin(), "Prise en compte des montants ICCP et ISLR sur les activités conservées", new StrategiePriseEnCompteMontantCarencesSurActiviteConserveeAvant(), new StrategiePriseEnCompteMontantCarencesSurActiviteConserveeApres());
    
    ChronologiePeriodes chronoPeriodesIndemnisationPourActiviteCourante = strategiePriseEnCompteMontantICCPActiviteConservee.formaterPeriodesIndemnisation(chronoPeriodesIndemnisation, strategiePriseEnCompteMontantICCPActiviteConservee.estUneActiviteConservee(activiteSalarie, demande.getDemandeur()));
    
    BaseDelaiReport baseDelaiReportActiviteCourante = OutilDeterminationMontantICCP.determinerBaseDelaiReportICCPCasGeneral(demande, activiteSalarie, chronoPeriodesIndemnisationPourActiviteCourante);
    
    QuantiteJourTravailDansSemaineSpec quantiteJourIccp = (QuantiteJourTravailDansSemaineSpec)activiteSalarie.getQuantiteJourIccp();
    baseDelaiReportActiviteCourante.setQuantiteJourIccp(quantiteJourIccp);
    
    Attribution attributionCourante = (Attribution)((Demande)demande).getAttribution();
    boolean estEnContexteApprentissage = attributionCourante.isTopContratsRemuneresBaseSmic();
    baseDelaiReportActiviteCourante.setEstTopContratsRemuneresBaseSmic(estEnContexteApprentissage);
    
    Sjr sjrrp = recupererSjrrp(attributionCourante);
    baseDelaiReportActiviteCourante.setSjrrp(sjrrp);
    
    int nbreCongesPris = activiteSalarie.getContrat().getNbreJoursCongesPris();
    baseDelaiReportActiviteCourante.setNombreCongesPris(nbreCongesPris);
    
    baseDelaiReportActiviteCourante.setIccpConservatoireAutoriseBatiment((OutilActiviteSalarie.getInstance().estAeAvecCaisseProfessionnelDuBatiment(activiteSalarie)) && (iccpConservatoireAutoriseBatiment));
    
    baseDelaiReportActiviteCourante.setPeriodeActiviteSalarie(activiteSalarie.getPeriode());
    
    return baseDelaiReportActiviteCourante;
  }
  
  protected FormuleDelaiReportSpec determinerFormuleICCP(BaseDelaiReport baseDelaiReport, DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    CriteresStrategieFormuleICCP critere = new CriteresStrategieFormuleICCP();
    critere.setDatePivot(baseDelaiReport.getDateExamen());
    critere.setSousTypeObjectifCourant(baseDelaiReport.getSousTypeObjectif());
    StrategieFormuleICCPSpec strategie = (StrategieFormuleICCPSpec)FabriqueStrategieFormuleICCP.getInstance().getStrategie(critere);
    return strategie.getFormuleICCP(baseDelaiReport);
  }
  
  protected Damj recupererDatePivotPourFormuleISLR(DemandeSpec demandeCourante)
    throws CoucheLogiqueException
  {
    return ((Demande)demandeCourante).getDateFaitGenerateurOuDernierSinistrePourCarences();
  }
  
  protected boolean isICCPRenseignee(ActiviteSalarie activiteSalarie, Demande demande)
    throws ApplicativeException
  {
    BaseDelaiReport baseDelaiReportActiviteCourante = OutilDeterminationMontantICCP.determinerBaseDelaiReportICCPCasGeneral(demande, activiteSalarie, null);
    
    boolean estMontantICCPRenseigne = (baseDelaiReportActiviteCourante.getQuantiteEuroIccp() != null) && (baseDelaiReportActiviteCourante.getQuantiteEuroIccp().getValeur().compareTo(BigDecimal.ZERO) > 0);
    boolean estJourICCPRenseignee = (activiteSalarie.getQuantiteJourIccp() != null) && (activiteSalarie.getQuantiteJourIccp().getNombreJours() > 0);
    return (estMontantICCPRenseigne) || (estJourICCPRenseignee);
  }
  
  protected boolean auMoinsUneFctDuBatimentAvecICCP(Demande demande, List<Temporel> listeActivitePourICCP)
    throws ApplicativeException
  {
    boolean auMoinsUneFCTBatimentRenseignee = false;
    for (Temporel activiteCourante : listeActivitePourICCP) {
      if (((activiteCourante instanceof ActiviteSalarie)) && (OutilActiviteSalarie.getInstance().estAeAvecCaisseProfessionnelDuBatiment((ActiviteSalarie)activiteCourante)) && (isICCPRenseignee((ActiviteSalarie)activiteCourante, demande)))
      {
        auMoinsUneFCTBatimentRenseignee = true;
        break;
      }
    }
    return auMoinsUneFCTBatimentRenseignee;
  }
  
  protected boolean determinerCalculICCPConservatoireBatimentAutorise(Demande demande, List<Temporel> listeActivitePourICCP, ActiviteSalarie activiteCourante)
    throws ApplicativeException
  {
    boolean iccpAutorise = false;
    if ((iccpConservatoireBatimentAutorise == null) && (OutilActiviteSalarie.getInstance().estAeAvecCaisseProfessionnelDuBatiment(activiteCourante))) {
      iccpConservatoireBatimentAutorise = Boolean.valueOf(!auMoinsUneFctDuBatimentAvecICCP(demande, listeActivitePourICCP));
    }
    if (iccpConservatoireBatimentAutorise != null) {
      iccpAutorise = iccpConservatoireBatimentAutorise.booleanValue();
    }
    return iccpAutorise;
  }
}

/* Location:
 * Qualified Name:     ParcoursDeterminationDelaisReportsCasGeneral
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */