package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p02.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.AttributionGen;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RecuperationElementActiviteReduite;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.cge01.AttributionAssuranceCgeSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionEESSI;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.asu.produits.liquidation.dom.Competence;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.DureeReglementaireSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ElementChomageSansRuptureSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DeterminationDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.ResultatDeterminationDateLimiteIndemnisation;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvantSpec;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourTypeContexteDemande;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public abstract class Attribution
  extends AttributionGen
  implements AttributionAssuranceCgeSpec
{
  private static final long serialVersionUID = 1L;
  private transient ElementBaseIndemnisation ebi = null;
  private transient ElementBaseActiviteReduite ebac = null;
  private transient boolean isUnJourDiffereConsomme = false;
  private transient Damj pjiEffectif;
  private transient DemandeSpec demandeSuivantePourTraitementReliquat;
  private transient MaintienEuropeen maintienEuropeen = null;
  
  protected Attribution() {}
  
  public Attribution(DomPCSpec pc)
  {
    super(pc);
  }
  
  protected Attribution(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  protected Attribution(Damj dateEvenement, DossierExamen dossierExamen)
  {
    super(dateEvenement);
    copie(dossierExamen);
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    if ((getConstitutionSjr().getSjrip() != null) && (getConstitutionSjr().getSjrip().getPrc() != null)) {
      return getConstitutionSjr().getSjrip().getPrc().isTopContratsDeTypeParticulier();
    }
    return false;
  }
  
  public void jdoPreDelete()
  {
    super.jdoPreDelete();
    DomManager.supprimer(super.getCalendrierExecutionCalcul());
  }
  
  public void marquerGraphePersistant()
  {
    Demande demande = (Demande)getDemande();
    if ((demande != null) && (demande.getObjectifSatisfait() == null))
    {
      OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "Erreur technique : Il n'existe pas d'objectif satisfait alors que nous avons une attribution" });
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_TECHNIQUE_GRAPHE_INCOHERENT", "Erreur technique : Il n'existe pas d'objectif satisfait alors que nous avons une attribution");
    }
    super.marquerGraphePersistant();
    DomManager.persisterEnProfondeur(super.getCalendrierExecutionCalcul());
    DomManager.persisterEnProfondeur(getCalendrierExecutionAvant());
  }
  
  protected void verifierCoherenceReferenceExterne()
  {
    if ((getReferenceExterne() == null) && (!"ASU_21".equals(getDemande().getEvenementReferenceExamen().getTypeExamen())))
    {
      OutilTrace.ecrireTrace(Niveau.ERROR, new Object[0]);
      throw new ApplicativeRuntimeException("HG_PR_CALI_L_ERR_TECHNIQUE_GRAPHE_INCOHERENT", "Erreur technique : Le RSOD (reference externe) sur l'attribution est null");
    }
  }
  
  public boolean isUnJourDiffereConsomme()
  {
    return isUnJourDiffereConsomme;
  }
  
  public void setUnJourDiffereConsomme(boolean pIsUnJourDiffereConsomme)
  {
    isUnJourDiffereConsomme = pIsUnJourDiffereConsomme;
  }
  
  public Damj getPji()
  {
    Damj pji = null;
    if (pjiEffectif != null) {
      pji = pjiEffectif;
    } else if (getConstitutionPointDepartIndemnisation() != null) {
      pji = getConstitutionPointDepartIndemnisation().getPji();
    }
    return pji;
  }
  
  public Damj getPjiEffectif()
  {
    return pjiEffectif;
  }
  
  public void setPjiEffectif(Damj pPjiEffectif)
  {
    pjiEffectif = pPjiEffectif;
  }
  
  public boolean estPjiEffectif()
  {
    return pjiEffectif != null;
  }
  
  public void setCalendrierExecutionAvant(CalendrierExecutionAvantSpec calendrierAvant)
  {
    DomManager.supprimer(super.getCalendrierExecutionAvant(), calendrierAvant);
    super.setCalendrierExecutionAvant(calendrierAvant);
  }
  
  public void setCalendrierExecutionCalcul(CalendrierExecutionCalculSpec calendrier)
  {
    DomManager.supprimer(super.getCalendrierExecutionCalcul(), calendrier);
    super.setCalendrierExecutionCalcul(calendrier);
  }
  
  public void copieElements(ObjetMetierSpec objetMetier)
  {
    Attribution copie = (Attribution)objetMetier;
    super.copieElements(copie);
    
    copie.setUnJourDiffereConsomme(isUnJourDiffereConsomme());
    copie.setPjiEffectif(getPjiEffectif());
    copie.setReferenceExterne(getReferenceExterne());
    copie.setTopRenoncement(estTopeeRenoncement());
    copie.setNbJoursActiviteCourrierASS(getNbJoursActiviteCourrierASS());
    copie.setDemandeSuivantePourTraitementReliquat(getDemandeSuivantePourTraitementReliquat());
    copie.setCumulMoisActiviteReduite(getCumulMoisActiviteReduite());
  }
  
  public Reglement getRegime()
  {
    Reglement reglementApplicable = null;
    if (getReglementApplicable() != null) {
      reglementApplicable = getReglementApplicable().getReglement();
    }
    return reglementApplicable;
  }
  
  public Sjc getSJC()
  {
    Sjc sjcTemporaire;
    Sjc sjcTemporaire;
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null)) {
      sjcTemporaire = new Sjc(getConstitutionSjc().getSjcip().getSjcInitial().getValeur(), getConstitutionSjc().getSjcip().getDateEffet(), null);
    } else {
      sjcTemporaire = new Sjc(BigDecimal.ZERO, getConstitutionSjr().getSjrip().getDateEffet(), null);
    }
    return sjcTemporaire;
  }
  
  public List getListeDurees()
  {
    ArrayList listeDurees = new ArrayList();
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getListeDurees() != null))
    {
      Iterator iter = getConstitutionDurees().getListeDurees().iterator();
      while (iter.hasNext())
      {
        DureeReglementaire element = (DureeReglementaire)iter.next();
        listeDurees.add(element.creerDureeCalcul());
      }
    }
    return listeDurees;
  }
  
  public int getTypeCaractereSaisonnier()
  {
    if (getConstitutionCaractereSaisonnier() != null) {
      return getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
    }
    return -1;
  }
  
  public Damj getDateFaitGenerateur()
  {
    Damj dateRetour = null;
    if (getFaitGenerateur() != null) {
      dateRetour = getFaitGenerateur().getDateFaitGenerateur();
    }
    return dateRetour;
  }
  
  public String getNomReglementApplicable()
  {
    String nomRetour = null;
    if (getRegime() != null) {
      nomRetour = getRegime().getNomReglement();
    }
    return nomRetour;
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    return getDureeTheorique();
  }
  
  public Quantite getDureeTheorique()
  {
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation() != null)) {
      return getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    }
    return null;
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    return getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
  }
  
  public boolean estExecutable()
  {
    boolean estAttributionValide = (estNonClassementAdministratifValide()) && (!estEnReexamen()) && (estValidee());
    boolean estVisibleCalcul = (!estNeutralise()) && (getCompetence().getCompetenceAdministrative() == 1) && (!estTopeeRenoncement());
    boolean estExecutable = (!((DemandeAssuranceSpec)getDemande()).estUneDemandeFinDroit()) && (!((Demande)getDemande()).isEstNonExecutable());
    
    return (estAttributionValide) && (estVisibleCalcul) && (estExecutable);
  }
  
  private boolean estNonClassementAdministratifValide()
  {
    return (getDemande().getClassementAdministratif() == null) || (((getDemande().getClassementAdministratif() instanceof Prescription)) && (!((Prescription)getDemande().getClassementAdministratif()).isValidite()));
  }
  
  public boolean estMaintenue()
  {
    DemandeMaintien demandeMaintien = RechercherDemandeMaintien.rechercherDemandeMaintien(getDemande().getDemandeur(), this);
    
    return (demandeMaintien != null) && ((demandeMaintien.getDossierExamen() instanceof Accord)) && (!demandeMaintien.estEnReExamen());
  }
  
  public AttributionAssuranceSpec getAttributionMaitrePourRevision()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée, il n'y a pas de révision pour l'ARE 2003");
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    if (ebi == null) {
      ebi = RecuperationElementIndemnisation.recupererElementBaseIndemnisation(this);
    }
    return (ElementBaseIndemnisation)ebi.copie();
  }
  
  public void supprimerCacheElementBaseIndemnisation()
  {
    ebi = null;
  }
  
  protected ElementBaseIndemnisation getElementBaseIndemnisationPrive()
  {
    return ebi;
  }
  
  protected void setElementBaseIndemnisationPrive(ElementBaseIndemnisation ebi)
  {
    this.ebi = ebi;
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    if (ebac == null) {
      ebac = RecuperationElementActiviteReduite.recupererElementBaseActiviteReduite(this);
    }
    return ebac;
  }
  
  protected ElementBaseActiviteReduite getElementBaseActiviteReduitePrive()
  {
    return ebac;
  }
  
  protected void setElementBaseActiviteReduitePrive(ElementBaseActiviteReduite ebac)
  {
    this.ebac = ebac;
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    return ((ProduitAsuSpec)getProduitExecution()).getFormuleMontant(code);
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    ConventionGestionSpec conventionGestion = null;
    try
    {
      Demande demande = (Demande)getDemande();
      if ("ASU_23".equals(getDemande().getEvenementReferenceExamen().getTypeExamen()))
      {
        SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
        String etablissementFinanceur = demande.getSaisieAntecedent().getEtablissementFinanceur();
        if (etablissementFinanceur != null) {
          return OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(saisieAntecedent.getEtablissementFinanceur(), saisieAntecedent.getCodeAffectation(), demande.getDateDepot(), demande.getCommentaire()));
        }
      }
    }
    catch (CoucheLogiqueException c)
    {
      throw new RuntimeException(c);
    }
    if (getCompetence().getConventionGestion() != null)
    {
      ConventionGestionSpec conventionGestionOrigine = getCompetence().getConventionGestion();
      
      boolean precompteCrc = true;
      if (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("555", true, conventionGestionOrigine)) {
        precompteCrc = false;
      } else if (OutilConventionGestion.estConventionGestionFraisReel(conventionGestionOrigine)) {
        precompteCrc = conventionGestionOrigine.estPrecompteCRC();
      }
      conventionGestion = new ConventionGestion(conventionGestionOrigine.getNumeroConventionGestion(), conventionGestionOrigine.getCodeAffectation(), conventionGestionOrigine.isEstAideArce(), conventionGestionOrigine.isEstAideAdr(), conventionGestionOrigine.isEstAideCongeNonPaye(), conventionGestionOrigine.isEstAideFinDroit(), conventionGestionOrigine.isEstAideAllocationDeces(), conventionGestionOrigine.getSignataire(), precompteCrc, conventionGestionOrigine.getDebutValidite(), conventionGestionOrigine.getFinValidite(), conventionGestionOrigine.getLibelleAffectation(), conventionGestionOrigine.estIdExterneObligatoire());
    }
    return conventionGestion;
  }
  
  public Collection getAttributionLiees()
  {
    return null;
  }
  
  public boolean estTopeeRenoncement()
  {
    return super.isTopRenoncement();
  }
  
  public Damj getTermePrcActiviteConservee()
  {
    Damj termePrcSjr = null;
    if ((getConstitutionSjr() != null) && (getConstitutionSjr().getSjrip() != null)) {
      termePrcSjr = getConstitutionSjr().getSjrip().getDateEffet();
    }
    return termePrcSjr;
  }
  
  public Damj getDateExamen()
  {
    return getDemande().getDateExamen();
  }
  
  public IndividuSpec getDemandeur()
  {
    return getDemande().getDemandeur();
  }
  
  public GammeSpec getGamme()
  {
    return getDemande().getGamme();
  }
  
  public ProduitSpec getProduit()
  {
    return getDossierAffecte().getProduit();
  }
  
  public void setReexecutee(boolean estReexecute)
  {
    getDemande().setReexecutee(estReexecute);
  }
  
  public String getIdentifiantDemande()
  {
    return getDemande().getIdentifiant();
  }
  
  public boolean estEnReexamen()
  {
    return getDemande().estEnReExamen();
  }
  
  public boolean estMigree()
  {
    return getDemande().estMigree();
  }
  
  public boolean estMigreeEnSimplifiee()
  {
    return getDemande().estMigreeEnSimplifiee();
  }
  
  public Damj getDateFinAbonnement()
  {
    return getDemande().getDateFinAbonnement();
  }
  
  public boolean estNeutralise()
  {
    return getDemande().estNeutraliseeCalcul();
  }
  
  public String getTypeExamen()
  {
    return getDemande().getEvenementReferenceExamen().getTypeExamen();
  }
  
  public Collection getListeCarences()
  {
    Collection liste = new ArrayList();
    if ((getConstitutionDelais() != null) && (getConstitutionDelais().getListeCarences() != null)) {
      liste = getConstitutionDelais().getListeCarences();
    }
    return liste;
  }
  
  public int getCodeEmploiA2B()
  {
    return getConstitutionSjr().getCodeEmploiA2b();
  }
  
  public Quantite getDureeInitiale()
  {
    AttributionSpec attributionMaitre = getOuvertureDroitCapitalRetenu();
    if (attributionMaitre == this) {
      return getConstitutionElementsActifs().getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    }
    return ((AttributionAssuranceSpec)attributionMaitre).getDureeInitiale();
  }
  
  public boolean isCapitalRetenuCourant()
  {
    return true;
  }
  
  public boolean estDemandeSuiteExamenFilEau()
  {
    return false;
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    Demande demande = (Demande)getDemande();
    return demande.estDemandeSuiteFinDeDroit();
  }
  
  public MontantAsuSpec getMontantRecalcule(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    return recalculerMontantAttribution(dateRecalcul);
  }
  
  protected MontantAsuSpec recalculerMontantAttribution(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    GammeAsuSpec gamme = (GammeAsuSpec)getGamme();
    
    DonneesEntreesRecuperationMontant donneesEntrees = gamme.mapperDonneesEntreesRecuperationMontant(this);
    donneesEntrees.setDateCalculMontant(dateRecalcul);
    
    return DeterminationMontant.determinerMontant(donneesEntrees);
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return (ProduitAsuSpec)getDossierAffecte().getProduit();
  }
  
  public boolean estDemandeExpresse()
  {
    return ((Demande)getDemande()).estUneDemandeExpresse();
  }
  
  public DemandeSpec getDemandeSuivantePourTraitementReliquat()
  {
    return demandeSuivantePourTraitementReliquat;
  }
  
  public void setDemandeSuivantePourTraitementReliquat(DemandeSpec demandeSuivantePourTraitementReliquat)
  {
    this.demandeSuivantePourTraitementReliquat = demandeSuivantePourTraitementReliquat;
  }
  
  public String determinerCodeSousProduitPourSigma()
  {
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))) {
      return OutilAsp.getInstance().recupererProduitReglementaire(getDemande()).determinerCodeSousProduitPourSigma(this);
    }
    String codeSousProduitRetourne = "";
    Demande demande = (Demande)getDemande();
    if (demande.getDonneesTemporaires().isEstCoordCee()) {
      codeSousProduitRetourne = "03";
    } else if (isTopContratsRemuneresBaseSmic()) {
      codeSousProduitRetourne = "24";
    }
    return codeSousProduitRetourne;
  }
  
  public Quantite getDureeIndemnisationEffective()
  {
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation() != null)) {
      return getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    }
    return null;
  }
  
  public Damj getPremierJourIndemnisable()
  {
    return getConstitutionPointDepartIndemnisation().getPji();
  }
  
  public boolean estPresenceDiffere()
  {
    ConstitutionDelais constitutionDelais = getConstitutionDelais();
    if (constitutionDelais != null)
    {
      Collection collectionDelaisReports = constitutionDelais.getCollectionDelaisReports();
      Iterator iterateurC = collectionDelaisReports.iterator();
      while (iterateurC.hasNext()) {
        if ((iterateurC.next() instanceof Differe)) {
          return true;
        }
      }
    }
    return false;
  }
  
  public Damj getDateLimiteIndemnisation()
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)getDemande();
    Damj dateForcee = demande.getDonneesTemporaires().getDateLimiteIndemnisationDonneeForcee();
    
    boolean estDateLimiteForcee = dateForcee != null;
    boolean enCoursOuEntreeCSP = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, 6);
    if ((enCoursOuEntreeCSP) && (!estDateLimiteForcee)) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_LIMITE_ARE03_ARE06");
    }
    Damj dateLimiteIndem;
    Damj dateLimiteIndem;
    if (dateForcee != null) {
      dateLimiteIndem = dateForcee;
    } else {
      dateLimiteIndem = DeterminationDateLimiteIndemnisation.determinerDateLimiteIndemnisation((Demande)getDemande()).getDateLimiteIndemnisation();
    }
    return dateLimiteIndem;
  }
  
  public String getContexteDateLimiteIndemnisation()
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)getDemande();
    String contexteDateLimiteIndem;
    String contexteDateLimiteIndem;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))
    {
      Demande demandePrecedente = (Demande)OutilRecherche.rechercherDemandePrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, new FiltreDemandePourTypeContexteDemande("AREENTRCSP"));
      
      contexteDateLimiteIndem = demandePrecedente.getAttribution().getContexteDateLimiteIndemnisation();
    }
    else
    {
      contexteDateLimiteIndem = DeterminationDateLimiteIndemnisation.determinerDateLimiteIndemnisation((Demande)getDemande()).getContexteDateLimiteIndemnisation();
    }
    return contexteDateLimiteIndem;
  }
  
  public AttributionAssuranceSpec getAttributionFinancement()
  {
    return null;
  }
  
  public int getBassinEmploi()
  {
    return 0;
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if (maintienEuropeen == null) {
      maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
    }
    return maintienEuropeen;
  }
  
  public BigDecimal getNbJoursIccp()
  {
    BigDecimal jours = null;
    if (getConstitutionDelais() != null) {
      jours = new BigDecimal(getConstitutionDelais().getNbJoursCarenceICCP());
    }
    return jours;
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    throw new UnsupportedOperationException();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getDemande();
  }
  
  public Damj getDateEffetDecision()
  {
    return getDateAttribution();
  }
  
  public int getTypeMontantRetenu()
  {
    return 1;
  }
  
  public int getTypeCapitalRetenu()
  {
    return 1;
  }
  
  public AttributionAssuranceSpec rechercherAttributionPrecedenteDuMemeType()
  {
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = super.rechercherAttributionPrecedenteDuMemeType();
    }
    return attributionPrecedente;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec rechercherOuvertureDroitPrecedenteDuMemeType()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec odAssuranceSpec = (fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit();
    if ((odAssuranceSpec == null) || (getAttributionPrecedente() == null)) {
      odAssuranceSpec = super.rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    return odAssuranceSpec;
  }
  
  public Collection getListePensionInvalidite()
  {
    return null;
  }
  
  public boolean notifierEESSI()
  {
    return OutilGestionEESSI.getInstance().estAttributionAssuranceFrontaliere(this);
  }
  
  public Quantite getMontantJournalierBrut()
  {
    Quantite quantite;
    Quantite quantite;
    if (getNatureDecision() == 11) {
      quantite = getConstitutionProduitResultant().getMontantDroitPrecedent();
    } else {
      quantite = getConstitutionMontantsBruts().getMontantJournalierBrut();
    }
    return quantite;
  }
  
  public DureeRenouvellement getDureeRenouvellement()
  {
    return getConstitutionDurees().getDureeRenouvellement();
  }
  
  public DemandeMaintien getDemandeMaintien()
  {
    return getDemandeAssurance().getDemandeMaintien();
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    Sjr sjrTemporaire = null;
    if ((getConstitutionSjr() != null) && (getConstitutionSjr().getSjrip() != null)) {
      sjrTemporaire = new Sjr(getConstitutionSjr().getSjrip().getSjrInitial().getValeur(), getConstitutionSjr().getSjrip().getDateEffet(), null);
    }
    return sjrTemporaire;
  }
  
  public SalaireJournalierSpec getSalaireJournalierConserve()
  {
    return getSJC();
  }
  
  public Boolean estAvecPrecompteCRC()
  {
    Boolean crc = null;
    if ((getCompetence().getCompetenceAdministrative() == 2) && (((Competence)getCompetence()).isEstPCRCForce())) {
      crc = Boolean.TRUE;
    }
    return crc;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    BigDecimal coefficientSaisonnier = BigDecimal.ONE;
    if (getConstitutionCoefficientSaisonnier() != null) {
      coefficientSaisonnier = getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu();
    }
    return coefficientSaisonnier;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    if (getConstitutionCaractereSaisonnier() != null) {
      return getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu();
    }
    return -1;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    boolean retour = false;
    
    DureeCalendaire ageALAttribution = new DureeCalendaire(50);
    if (((Demande)getDemande()).getDonneesTemporaires().isCaractereSaisonnierForce())
    {
      if (((Demande)getDemande()).getDonneesTemporaires().getTypeCaractereSaisonnierForce() == 1) {
        if (ageALAttribution.compareTo(getDemandeur().getAgeALaDate(getDemande().getDateDeclenchementExamen())) > 0) {
          retour = true;
        } else {
          retour = getConstitutionCaractereSaisonnier().isActivite3Sur5();
        }
      }
    }
    else {
      retour = getConstitutionCaractereSaisonnier().isActivite3Sur5();
    }
    return retour;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    BigDecimal valeurCoefficientTempsPartiel = null;
    if (getConstitutionCoefficientTempsPartiel() != null) {
      valeurCoefficientTempsPartiel = getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu();
    }
    if (valeurCoefficientTempsPartiel == null) {
      valeurCoefficientTempsPartiel = BigDecimal.ONE;
    }
    return valeurCoefficientTempsPartiel;
  }
  
  public boolean estSjrBaseSmic()
  {
    return isTopContratsRemuneresBaseSmic();
  }
  
  public int getCategorieEmploiA2B()
  {
    return getConstitutionSjr().getCodeEmploiA2b();
  }
  
  public Quantite getMontantPreavis()
  {
    return null;
  }
  
  public Quantite getCapitalAServir()
  {
    Quantite retour = null;
    if (getConstitutionMontantsBruts() != null) {
      retour = getConstitutionMontantsBruts().getCapitalInitialBrut();
    }
    return retour;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    return getReglementApplicable();
  }
  
  public void viderCacheElementsChomageSansRupture() {}
  
  public ProduitSpec getProduitExecution()
  {
    if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))) {
      return OutilAsp.getInstance().recupererProduitReglementaire(getDemande());
    }
    return getProduit();
  }
  
  public boolean estDemandeDrv()
  {
    return "ASU_27".equals(getDemande().getEvenementReferenceExamen().getTypeExamen());
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    return getOuvertureDroit().getDateAttribution();
  }
  
  public Quantite getDureeTheoriquePourDelaiDecheance()
  {
    return ((AttributionAssuranceSpec)getOuvertureDroit()).getDureeTheorique();
  }
  
  public AttributionAssuranceSpec getAttributionAssociee()
  {
    Demande demande = (Demande)getDemande();
    if ((demande.getDonneesDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee() != null) && (demande.getDonneesDemandeAssociee().getDemandeAssociee().getAttribution() != null))
    {
      Demande demandeAssociee = demande.getDonneesDemandeAssociee().getDemandeAssociee();
      return demandeAssociee.getAttribution();
    }
    return null;
  }
  
  public Quantite getDureePostPrime()
  {
    ConstitutionDurees constitutionDurees = getConstitutionDurees();
    if (constitutionDurees != null)
    {
      DureeIndemnisation dureeIndemnisation = constitutionDurees.getDureeIndemnisation();
      if (dureeIndemnisation != null) {
        return dureeIndemnisation.getDureePostPrimeCspConstitutionDurees();
      }
    }
    return null;
  }
  
  public DureeReglementaireSpec getDureeReglementaire()
  {
    return getConstitutionDurees().getDureeIndemnisation();
  }
  
  public ElementChomageSansRuptureSpec getElementChomageSansRupture()
  {
    return null;
  }
  
  public CalendrierExecutionCalculSpec getCalendrierExecutionCalcul()
  {
    if ((((Demande)getDemande()).estUneDemandeFinDroit()) && (getDemande().estDecisionnee()) && (!getDemande().estEnReExamen()))
    {
      DemandeAssuranceSpec demande = (DemandeAssuranceSpec)OutilFinDroit.rechercherDemandePrecedenteCorrespondante(getDemande());
      CalendrierExecutionCalculSpec calendrier = null;
      if ((demande != null) && (demande.getAttribution().getCalendrierExecutionCalcul() != null)) {
        calendrier = new CalendrierExecutionCalcul(demande.getAttribution().getCalendrierExecutionCalcul());
      }
      setCalendrierExecutionCalcul(calendrier);
      return calendrier;
    }
    return super.getCalendrierExecutionCalcul();
  }
  
  protected MaintienEuropeen getMaintienEuropenPrive()
  {
    return maintienEuropeen;
  }
  
  protected void setMaintienEuropeenPrive(MaintienEuropeen maintienEuropeen)
  {
    this.maintienEuropeen = maintienEuropeen;
  }
}

/* Location:
 * Qualified Name:     Attribution
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */