package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.ConditionsAttributionAdmissionGen;
import fr.unedic.cali.dom.ElementDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConditionsAttributionAdmission
  extends ConditionsAttributionAdmissionGen
  implements ConditionsAttributionSpec
{
  private static final long serialVersionUID = -1491468849539844304L;
  
  public ConditionsAttributionAdmission() {}
  
  public ConditionsAttributionAdmission(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public List getListeConditionsAttribution()
  {
    List listeConditions = new ArrayList();
    listeConditions.add(super.getConditionRechercheEmploi());
    listeConditions.add(super.getConditionFaitGenerateur());
    listeConditions.add(super.getConditionChomageTotal());
    listeConditions.add(super.getConditionAge());
    listeConditions.add(super.getConditionQuantiteAffiliation());
    listeConditions.add(super.getConditionChomageInvolontaire());
    listeConditions.add(super.getConditionActiviteConservee());
    listeConditions.add(super.getConditionCumulPrestationFamiliale());
    listeConditions.add(super.getConditionMontantNonNul());
    return listeConditions;
  }
  
  public boolean estSatisfait()
  {
    for (Iterator iter = getListeConditionsAttribution().iterator(); iter.hasNext();)
    {
      ElementDroitSpec droit = (ElementDroitSpec)iter.next();
      if ((droit != null) && 
        (!(droit instanceof ConditionChomageInvolontaire)) && (!droit.estSatisfait())) {
        return false;
      }
    }
    return true;
  }
  
  public void setConditionFaitGenerateur(ConditionFaitGenerateur p_faitGenerateur)
  {
    DomManager.supprimer(super.getConditionFaitGenerateur(), p_faitGenerateur);
    super.setConditionFaitGenerateur(p_faitGenerateur);
  }
  
  public void setConditionAge(ConditionAge p_conditionAge)
  {
    DomManager.supprimer(super.getConditionAge(), p_conditionAge);
    super.setConditionAge(p_conditionAge);
  }
  
  public void setConditionQuantiteAffiliation(ConditionQuantiteAffiliation p_quantiteAffiliation)
  {
    DomManager.supprimer(super.getConditionQuantiteAffiliation(), p_quantiteAffiliation);
    super.setConditionQuantiteAffiliation(p_quantiteAffiliation);
  }
  
  public void setConditionChomageInvolontaire(ConditionChomageInvolontaire p_conditionChomageInvolontaire)
  {
    DomManager.supprimer(super.getConditionChomageInvolontaire(), p_conditionChomageInvolontaire);
    super.setConditionChomageInvolontaire(p_conditionChomageInvolontaire);
  }
  
  public void setConditionActiviteConservee(ConditionActiviteConservee p_activiteConservee)
  {
    DomManager.supprimer(super.getConditionActiviteConservee(), p_activiteConservee);
    super.setConditionActiviteConservee(p_activiteConservee);
  }
  
  public ConditionRechercheEmploi getConditionRechercheEmploi()
  {
    if (super.getConditionRechercheEmploi() == null) {
      super.setConditionRechercheEmploi(new ConditionRechercheEmploi());
    }
    return super.getConditionRechercheEmploi();
  }
  
  public void setConditionChomageTotal(ConditionChomageTotal p_total)
  {
    DomManager.supprimer(super.getConditionChomageTotal(), p_total);
    super.setConditionChomageTotal(p_total);
  }
  
  public void setConditionMontantNonNul(ConditionMontantNonNul p_nul)
  {
    DomManager.supprimer(super.getConditionMontantNonNul(), p_nul);
    super.setConditionMontantNonNul(p_nul);
  }
  
  public void setConditionRechercheEmploi(ConditionRechercheEmploi p_emploi)
  {
    DomManager.supprimer(super.getConditionRechercheEmploi(), p_emploi);
    super.setConditionRechercheEmploi(p_emploi);
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getConditionActiviteConservee());
    DomManager.supprimer(super.getConditionAge());
    DomManager.supprimer(super.getConditionChomageInvolontaire());
    DomManager.supprimer(super.getConditionChomageTotal());
    DomManager.supprimer(super.getConditionMontantNonNul());
    DomManager.supprimer(super.getConditionQuantiteAffiliation());
    DomManager.supprimer(super.getConditionRechercheEmploi());
    DomManager.supprimer(super.getConditionFaitGenerateur());
    DomManager.supprimer(super.getConditionCumulPrestationFamiliale());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getConditionActiviteConservee());
    DomManager.persisterEnProfondeur(super.getConditionAge());
    DomManager.persisterEnProfondeur(super.getConditionChomageInvolontaire());
    DomManager.persisterEnProfondeur(super.getConditionChomageTotal());
    DomManager.persisterEnProfondeur(super.getConditionMontantNonNul());
    DomManager.persisterEnProfondeur(super.getConditionQuantiteAffiliation());
    DomManager.persisterEnProfondeur(super.getConditionRechercheEmploi());
    DomManager.persisterEnProfondeur(super.getConditionFaitGenerateur());
    DomManager.persisterEnProfondeur(super.getConditionCumulPrestationFamiliale());
  }
  
  public ObjetMetierSpec copie()
  {
    ConditionsAttributionAdmission copie = new ConditionsAttributionAdmission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionsAttributionAdmission copie = (ConditionsAttributionAdmission)p_copie;
    
    super.copieElements(copie);
    copie.setConditionActiviteConservee(getConditionActiviteConservee() != null ? (ConditionActiviteConservee)getConditionActiviteConservee().copie() : null);
    
    copie.setConditionAge(getConditionAge() != null ? (ConditionAge)getConditionAge().copie() : null);
    copie.setConditionChomageInvolontaire(getConditionChomageInvolontaire() != null ? (ConditionChomageInvolontaire)getConditionChomageInvolontaire().copie() : null);
    
    copie.setConditionChomageTotal(getConditionChomageTotal() != null ? (ConditionChomageTotal)getConditionChomageTotal().copie() : null);
    copie.setConditionMontantNonNul(getConditionMontantNonNul() != null ? (ConditionMontantNonNul)getConditionMontantNonNul().copie() : null);
    copie.setConditionQuantiteAffiliation(getConditionQuantiteAffiliation() != null ? (ConditionQuantiteAffiliation)getConditionQuantiteAffiliation().copie() : null);
    
    copie.setConditionRechercheEmploi(getConditionRechercheEmploi() != null ? (ConditionRechercheEmploi)getConditionRechercheEmploi().copie() : null);
    
    copie.setConditionFaitGenerateur(getConditionFaitGenerateur() != null ? (ConditionFaitGenerateur)getConditionFaitGenerateur().copie() : null);
    copie.setConditionCumulPrestationFamiliale(getConditionCumulPrestationFamiliale() != null ? (ConditionCumulPrestationFamiliale)getConditionCumulPrestationFamiliale().copie() : null);
  }
  
  public void setConditionCumulPrestationFamiliale(ConditionCumulPrestationFamiliale p_conditionCumulPrestationFamiliale)
  {
    DomManager.supprimer(super.getConditionCumulPrestationFamiliale(), p_conditionCumulPrestationFamiliale);
    super.setConditionCumulPrestationFamiliale(p_conditionCumulPrestationFamiliale);
  }
  
  public void setConditionValiditeReliquat(ConditionValiditeReliquat p_conditionValiditeReliquat)
  {
    throw new UnsupportedOperationException("Cette méthode ne devrait pas être appeler dans le contexte d'admission");
  }
  
  public ConditionValiditeReliquat getConditionValiditeReliquat()
  {
    throw new UnsupportedOperationException("Cette méthode ne devrait pas être appeler dans le contexte d'admission");
  }
}

/* Location:
 * Qualified Name:     ConditionsAttributionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */