package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.ConditionsAttributionRepriseGen;
import fr.unedic.cali.dom.ElementDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConditionsAttributionReprise
  extends ConditionsAttributionRepriseGen
  implements ConditionsAttributionSpec
{
  private static final long serialVersionUID = -1852324814322704248L;
  
  public ConditionsAttributionReprise() {}
  
  public ConditionsAttributionReprise(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public List getListeConditionsAttribution()
  {
    List listeConditions = new ArrayList();
    listeConditions.add(super.getConditionRechercheEmploi());
    listeConditions.add(super.getConditionAge());
    listeConditions.add(super.getConditionChomageInvolontaire());
    listeConditions.add(super.getConditionMontantNonNul());
    listeConditions.add(super.getConditionCumulPrestationFamiliale());
    listeConditions.add(super.getConditionValiditeReliquat());
    return listeConditions;
  }
  
  public boolean estSatisfait()
  {
    for (Iterator iter = getListeConditionsAttribution().iterator(); iter.hasNext();)
    {
      ElementDroitSpec droit = (ElementDroitSpec)iter.next();
      if ((droit != null) && 
        (!(droit instanceof ConditionChomageInvolontaire)) && (!droit.estSatisfait())) {
        return false;
      }
    }
    return true;
  }
  
  public void setConditionAge(ConditionAge p_conditionAge)
  {
    DomManager.supprimer(super.getConditionAge(), p_conditionAge);
    super.setConditionAge(p_conditionAge);
  }
  
  public void setConditionValiditeReliquat(ConditionValiditeReliquat p_conditionValiditeReliquat)
  {
    DomManager.supprimer(super.getConditionValiditeReliquat(), p_conditionValiditeReliquat);
    super.setConditionValiditeReliquat(p_conditionValiditeReliquat);
  }
  
  public void setConditionChomageInvolontaire(ConditionChomageInvolontaire p_conditionChomageInvolontaire)
  {
    DomManager.supprimer(super.getConditionChomageInvolontaire(), p_conditionChomageInvolontaire);
    super.setConditionChomageInvolontaire(p_conditionChomageInvolontaire);
  }
  
  public ConditionRechercheEmploi getConditionRechercheEmploi()
  {
    if (super.getConditionRechercheEmploi() == null) {
      super.setConditionRechercheEmploi(new ConditionRechercheEmploi());
    }
    return super.getConditionRechercheEmploi();
  }
  
  public void setConditionMontantNonNul(ConditionMontantNonNul p_nul)
  {
    DomManager.supprimer(super.getConditionMontantNonNul(), p_nul);
    super.setConditionMontantNonNul(p_nul);
  }
  
  public void setConditionRechercheEmploi(ConditionRechercheEmploi p_emploi)
  {
    DomManager.supprimer(super.getConditionRechercheEmploi(), p_emploi);
    super.setConditionRechercheEmploi(p_emploi);
  }
  
  public void setConditionCumulPrestationFamiliale(ConditionCumulPrestationFamiliale p_conditionCumulPrestationFamiliale)
  {
    DomManager.supprimer(super.getConditionCumulPrestationFamiliale(), p_conditionCumulPrestationFamiliale);
    super.setConditionCumulPrestationFamiliale(p_conditionCumulPrestationFamiliale);
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getConditionAge());
    DomManager.supprimer(super.getConditionChomageInvolontaire());
    DomManager.supprimer(super.getConditionMontantNonNul());
    DomManager.supprimer(super.getConditionRechercheEmploi());
    DomManager.supprimer(super.getConditionCumulPrestationFamiliale());
    DomManager.supprimer(super.getConditionValiditeReliquat());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getConditionAge());
    DomManager.persisterEnProfondeur(super.getConditionChomageInvolontaire());
    DomManager.persisterEnProfondeur(super.getConditionMontantNonNul());
    DomManager.persisterEnProfondeur(super.getConditionRechercheEmploi());
    DomManager.persisterEnProfondeur(super.getConditionCumulPrestationFamiliale());
    DomManager.persisterEnProfondeur(super.getConditionValiditeReliquat());
  }
  
  public ObjetMetierSpec copie()
  {
    ConditionsAttributionReprise copie = new ConditionsAttributionReprise();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionsAttributionReprise copie = (ConditionsAttributionReprise)p_copie;
    
    super.copieElements(copie);
    copie.setConditionAge(getConditionAge() != null ? (ConditionAge)getConditionAge().copie() : null);
    copie.setConditionChomageInvolontaire(getConditionChomageInvolontaire() != null ? (ConditionChomageInvolontaire)getConditionChomageInvolontaire().copie() : null);
    
    copie.setConditionMontantNonNul(getConditionMontantNonNul() != null ? (ConditionMontantNonNul)getConditionMontantNonNul().copie() : null);
    copie.setConditionRechercheEmploi(getConditionRechercheEmploi() != null ? (ConditionRechercheEmploi)getConditionRechercheEmploi().copie() : null);
    
    copie.setConditionCumulPrestationFamiliale(getConditionCumulPrestationFamiliale() != null ? (ConditionCumulPrestationFamiliale)getConditionCumulPrestationFamiliale().copie() : null);
    
    copie.setConditionValiditeReliquat(getConditionValiditeReliquat() != null ? (ConditionValiditeReliquat)getConditionValiditeReliquat().copie() : null);
  }
}

/* Location:
 * Qualified Name:     ConditionsAttributionReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */