package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.liquidation.dom.spec.ConstitutionDelaisSpec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.ConstitutionDelaisGen;
import fr.unedic.cali.dom.ConstitutionDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;

public class ConstitutionDelais
  extends ConstitutionDelaisGen
  implements ConstitutionDroitSpec, ConstitutionDelaisSpec
{
  private static final long serialVersionUID = 3153329028047541328L;
  private transient QuantiteEuro mMontantICCPOrigine;
  private transient QuantiteEuro mCumulMontantICCPA4Origine;
  private transient Damj dateDebutDernierDelaiAttente;
  
  public ConstitutionDelais() {}
  
  public ConstitutionDelais(DomPCSpec pc)
  {
    super(pc);
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void ajouterEnsembleCarences(EnsembleCarences ensemble)
  {
    super.ajouterEnsembleCarences(ensemble);
  }
  
  public Collection getListeCarences()
  {
    Collection toutesLesCarences = new ArrayList();
    Iterator iterEnsembles = getListeEnsembleCarences().iterator();
    while (iterEnsembles.hasNext())
    {
      EnsembleCarences ensembleCarences = (EnsembleCarences)iterEnsembles.next();
      toutesLesCarences.addAll(ensembleCarences.getListeCarences());
    }
    toutesLesCarences.addAll(super.getCollectionDelaisReports());
    
    return Collections.unmodifiableCollection(toutesLesCarences);
  }
  
  public Collection getListeEnsembleCarences()
  {
    return getCollectionEnsembleCarences();
  }
  
  public void ajouterDelaiReport(Differe delaiReport)
  {
    if (delaiReport != null) {
      super.ajouterDelaisReports(delaiReport);
    }
  }
  
  public void setListeDelaisReports(Collection coll)
  {
    Collection nouvelleListe = coll;
    
    Collection collectionExistante = getCollectionDelaisReports();
    if (nouvelleListe == null) {
      nouvelleListe = new ArrayList();
    }
    Iterator iter = nouvelleListe.iterator();
    while (iter.hasNext())
    {
      Differe element = (Differe)iter.next();
      boolean existeDeja = false;
      
      Iterator iterExistant = collectionExistante.iterator();
      while (iterExistant.hasNext()) {
        if (((Differe)iterExistant.next()).estIdentiqueA(element)) {
          existeDeja = true;
        }
      }
      if (!existeDeja) {
        ajouterDelaiReport(element);
      }
    }
    Iterator iterExistant = collectionExistante.iterator();
    while (iterExistant.hasNext())
    {
      Differe element = (Differe)iterExistant.next();
      boolean existeToujours = false;
      Iterator iterNouveau = nouvelleListe.iterator();
      while (iterNouveau.hasNext()) {
        if (((Differe)iterNouveau.next()).estIdentiqueA(element)) {
          existeToujours = true;
        }
      }
      if (!existeToujours)
      {
        super.supprimerDelaisReports(element);
        DomManager.supprimer(element);
      }
    }
  }
  
  public void setListeEnsembleCarences(Collection coll)
  {
    Collection nouvelleListe = coll;
    Collection collectionExistante = getCollectionEnsembleCarences();
    if (nouvelleListe == null) {
      nouvelleListe = new ArrayList();
    }
    Iterator iter = nouvelleListe.iterator();
    while (iter.hasNext())
    {
      EnsembleCarences element = (EnsembleCarences)iter.next();
      boolean existeDeja = false;
      Iterator iterExistant = collectionExistante.iterator();
      while (iterExistant.hasNext()) {
        if (((EnsembleCarences)iterExistant.next()).estIdentiqueA(element)) {
          existeDeja = true;
        }
      }
      if (!existeDeja) {
        ajouterEnsembleCarences(element);
      }
    }
    Iterator iterExistant = collectionExistante.iterator();
    while (iterExistant.hasNext())
    {
      EnsembleCarences element = (EnsembleCarences)iterExistant.next();
      
      boolean existeToujours = false;
      Iterator iterNouveau = nouvelleListe.iterator();
      while (iterNouveau.hasNext()) {
        if (((EnsembleCarences)iterNouveau.next()).estIdentiqueA(element)) {
          existeToujours = true;
        }
      }
      if (!existeToujours)
      {
        super.supprimerEnsembleCarences(element);
        DomManager.supprimer(element);
      }
    }
  }
  
  public Collection getListeDelaisReports()
  {
    return super.getCollectionDelaisReports();
  }
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(getCollectionEnsembleCarences());
    DomManager.supprimer(getCollectionDelaisReports());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionEnsembleCarences());
    DomManager.persisterEnProfondeur(super.getCollectionDelaisReports());
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreStore() {}
  
  public ObjetMetierSpec copie()
  {
    ConstitutionDelais copie = new ConstitutionDelais();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    ConstitutionDelais copie = (ConstitutionDelais)pCopie;
    
    copie.setPeriodeReference91jours(getPeriodeReference91jours() != null ? new Periode(getPeriodeReference91jours().getDebut(), getPeriodeReference91jours().getFin()) : null);
    
    Collection listeEnsembleCarences = getListeEnsembleCarences();
    
    Iterator ensembleCarencesIterator = listeEnsembleCarences.iterator();
    while (ensembleCarencesIterator.hasNext())
    {
      EnsembleCarences element = (EnsembleCarences)ensembleCarencesIterator.next();
      if (element != null) {
        copie.ajouterEnsembleCarences((EnsembleCarences)element.copie());
      }
    }
    Collection listeDelaisReportsACloner = getListeDelaisReports();
    
    Iterator iter2 = listeDelaisReportsACloner.iterator();
    while (iter2.hasNext())
    {
      Differe element = (Differe)iter2.next();
      if (element != null) {
        copie.ajouterDelaiReport((Differe)element.copie());
      }
    }
    copie.setDebutCarenceDiffere(getDebutCarenceDiffere());
    copie.setDebutCarenceICCP(getDebutCarenceICCP());
    copie.setDebutCarenceISLR(getDebutCarenceISLR());
    copie.setNbJoursCarenceDiffere(getNbJoursCarenceDiffere());
    copie.setNbJoursCarenceICCP(getNbJoursCarenceICCP());
    copie.setNbJoursCarenceISLR(getNbJoursCarenceISLR());
    copie.setTermeCarenceDiffere(getTermeCarenceDiffere());
    copie.setTermeCarenceICCP(getTermeCarenceICCP());
    copie.setTermeCarenceISLR(getTermeCarenceISLR());
    copie.setDebutPMC(getDebutPMC());
    copie.setTermePMC(getTermePMC());
    copie.setNbJoursPMC(getNbJoursPMC());
    copie.setTypePmc(getTypePmc());
    copie.setMontantICCPOrigine(getMontantICCPOrigine());
    copie.setCumulMontantICCPA4Origine(getCumulMontantICCPA4Origine());
  }
  
  public Damj getDebutCarencePMC()
  {
    if (super.getTypePmc() == 1) {
      return super.getDebutPMC();
    }
    return null;
  }
  
  public Damj getDebutPmcIndemnisable()
  {
    if (super.getTypePmc() == 2) {
      return super.getDebutPMC();
    }
    return null;
  }
  
  public void setDebutCarencePMC(Damj debutPmc)
  {
    super.setTypePmc(1);
    super.setDebutPMC(debutPmc);
  }
  
  public void setDebutPmcIndemnisable(Damj debutPmc)
  {
    super.setTypePmc(2);
    super.setDebutPMC(debutPmc);
  }
  
  public int getNbJoursCarencePMC()
  {
    if (super.getTypePmc() == 1) {
      return super.getNbJoursPMC();
    }
    return 0;
  }
  
  public int getNbJoursPmcIndemnisable()
  {
    if (super.getTypePmc() == 2) {
      return super.getNbJoursPMC();
    }
    return 0;
  }
  
  public void setNbJoursCarencePMC(int nbJours)
  {
    super.setTypePmc(1);
    super.setNbJoursPMC(nbJours);
  }
  
  public void setNbJoursPmcIndemnisable(int nbJours)
  {
    super.setTypePmc(2);
    super.setNbJoursPMC(nbJours);
  }
  
  public Damj getTermeCarencePMC()
  {
    if (super.getTypePmc() == 1) {
      return super.getTermePMC();
    }
    return null;
  }
  
  public Damj getTermePmcIndemnisable()
  {
    if (super.getTypePmc() == 2) {
      return super.getTermePMC();
    }
    return null;
  }
  
  public void setTermeCarencePMC(Damj termePMC)
  {
    super.setTypePmc(1);
    super.setTermePMC(termePMC);
  }
  
  public void setTermePmcIndemnisable(Damj termePMC)
  {
    super.setTypePmc(2);
    super.setTermePMC(termePMC);
  }
  
  public void supprimerDelaisReports()
  {
    Iterator iter = super.getCollectionDelaisReports().iterator();
    while (iter.hasNext())
    {
      Differe delai = (Differe)iter.next();
      DomManager.supprimer(delai);
    }
    super.clearCollectionDelaisReports();
  }
  
  public QuantiteEuro getCumulMontantICCPA4Origine()
  {
    return mCumulMontantICCPA4Origine;
  }
  
  public void setCumulMontantICCPA4Origine(QuantiteEuro cumulMontantICCPA4Origine)
  {
    mCumulMontantICCPA4Origine = cumulMontantICCPA4Origine;
  }
  
  public QuantiteEuro getMontantICCPOrigine()
  {
    return mMontantICCPOrigine;
  }
  
  public void setMontantICCPOrigine(QuantiteEuro montantICCPOrigine)
  {
    mMontantICCPOrigine = montantICCPOrigine;
  }
  
  public void setDateDebutDernierDelaiAttente(Damj dateDebutDernierDelaiAttente)
  {
    this.dateDebutDernierDelaiAttente = dateDebutDernierDelaiAttente;
  }
  
  public Damj getDateDebutDernierDelaiAttente()
  {
    return dateDebutDernierDelaiAttente;
  }
  
  public void remplacerCollectionDelaisReports(Collection collectionACopier)
  {
    for (Iterator iter = super.getCollectionDelaisReports().iterator(); iter.hasNext();)
    {
      Differe element = (Differe)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionDelaisReports(collectionACopier);
  }
  
  public void remplacerCollectionEnsembleCarences(Collection collectionACopier)
  {
    for (Iterator i = super.getCollectionEnsembleCarences().iterator(); i.hasNext();)
    {
      EnsembleCarences objet = (EnsembleCarences)i.next();
      DomManager.supprimer(objet);
    }
    super.remplacerCollectionEnsembleCarences(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelais
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */