package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.ReadmissionGen;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.OdAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class Readmission
  extends ReadmissionGen
  implements ReadmissionSpec
{
  private static final long serialVersionUID = 8298219627744816394L;
  
  public Readmission() {}
  
  public Readmission(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Readmission(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Readmission(Damj dateEvenement, DossierExamenSpec dossierExamen)
  {
    super(dateEvenement, (DossierExamen)dossierExamen);
  }
  
  public ObjetMetierSpec copie()
  {
    Readmission copie = new Readmission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieObjet)
  {
    Readmission copie = (Readmission)copieObjet;
    
    super.copieElements(copie);
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    Quantite dureeEffective = null;
    if ((getConstitutionProduitResultant() != null) && (getConstitutionProduitResultant().getConstitutionDurees() != null)) {
      dureeEffective = getConstitutionProduitResultant().getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    }
    return dureeEffective;
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    return getDureeTheorique();
  }
  
  public Quantite getDureeTheorique()
  {
    if ((getNatureDecision() == 11) || (getNatureDecision() == 26)) {
      return getConstitutionProduitResultant().getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    }
    return getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
  }
  
  public List getListeDurees()
  {
    ArrayList listeDurees = new ArrayList();
    if ((getConstitutionProduitResultant() != null) && (getConstitutionProduitResultant().getConstitutionDurees() != null) && (getConstitutionProduitResultant().getConstitutionDurees().getListeDurees() != null))
    {
      Iterator iter = getConstitutionProduitResultant().getConstitutionDurees().getListeDurees().iterator();
      while (iter.hasNext())
      {
        DureeReglementaire element = (DureeReglementaire)iter.next();
        listeDurees.add(element.creerDureeCalcul());
      }
    }
    return listeDurees;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    if (getElementBaseIndemnisationPrive() == null)
    {
      if (getNatureDecision() == 11)
      {
        if (((Demande)getDemande()).estEnContexteDroitAnterieurSecteurPublicValide())
        {
          setElementBaseIndemnisationPrive(RecuperationElementIndemnisation.recupererElementBaseIndemnisation(((Demande)getDemande()).getDonneesTemporaires(), this));
        }
        else
        {
          Demande demandeOrigineRead = ((Demande)getDemande()).getDemandeOrigine();
          AttributionAssuranceSpec attributionPrecedente = demandeOrigineRead.getAttribution();
          
          setElementBaseIndemnisationPrive(attributionPrecedente.getElementBaseIndemnisation());
        }
      }
      else {
        setElementBaseIndemnisationPrive(super.getElementBaseIndemnisation());
      }
      if (((getDemande() != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)getDemande(), "AREENTRCSP"))) {
        getElementBaseIndemnisationPrive().setProduitAreActif(getProduit());
      } else if ((getProduit() instanceof ProduitSecurisationProfessionnelleSpec)) {
        getElementBaseIndemnisationPrive().setProduitAreActif(((ProduitSecurisationProfessionnelleSpec)getProduit()).recupererProduitAreActif(this));
      }
    }
    return (ElementBaseIndemnisation)getElementBaseIndemnisationPrive().copie();
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    if (getElementBaseActiviteReduitePrive() == null) {
      if (getNatureDecision() == 11)
      {
        Demande demandeOrigineRead = ((Demande)getDemande()).getDemandeOrigine();
        AttributionAssuranceSpec attributionPrecedente = demandeOrigineRead.getAttribution();
        setElementBaseActiviteReduitePrive(attributionPrecedente.getElementBaseActiviteReduite());
      }
      else
      {
        setElementBaseActiviteReduitePrive(super.getElementBaseActiviteReduite());
      }
    }
    return getElementBaseActiviteReduitePrive();
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    FormuleMontantSpec formuleRetour = null;
    if (getNatureDecision() == 11)
    {
      Demande demandeOrigineRead = ((Demande)getDemande()).getDemandeOrigine();
      AttributionAssuranceSpec attributionPrecedente = demandeOrigineRead.getAttribution();
      formuleRetour = ((ProduitAsuSpec)attributionPrecedente.getDossierAffecte().getProduit()).getFormuleMontant(code);
    }
    else
    {
      formuleRetour = super.getFormuleMontant(code);
    }
    return formuleRetour;
  }
  
  public boolean isCapitalRetenuCourant()
  {
    boolean estCapitalRetenuCourant = true;
    if (getNatureDecision() == 11) {
      estCapitalRetenuCourant = false;
    }
    return estCapitalRetenuCourant;
  }
  
  public MontantAsuSpec getMontantRecalcule(Damj dateRecalcul)
    throws CoucheLogiqueException
  {
    switch (getNatureDecision())
    {
    case 11: 
      if (getAttributionPrecedente() != null) {
        return getAttributionPrecedente().getMontantRecalcule(dateRecalcul);
      }
      return null;
    }
    return recalculerMontantAttribution(dateRecalcul);
  }
  
  public Quantite getDureeIndemnisationEffective()
  {
    if ((getNatureDecision() == 11) || (getNatureDecision() == 26)) {
      return getConstitutionElementsAdmission().getConstitutionProduitResultant().getDureeDroitPrecedent();
    }
    if ((getConstitutionDurees() != null) && (getConstitutionDurees().getDureeIndemnisation() != null)) {
      return getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    }
    return null;
  }
  
  public int getTypeMontantRetenu()
  {
    int montantRetenu = super.getTypeMontantRetenu();
    if (getNatureDecision() == 11) {
      montantRetenu = 2;
    }
    return montantRetenu;
  }
  
  public int getTypeCapitalRetenu()
  {
    int capitalRetenu = super.getTypeCapitalRetenu();
    if (getNatureDecision() == 11) {
      capitalRetenu = 2;
    }
    return capitalRetenu;
  }
  
  public OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    OdAssuranceSpec ouvertureDeDroit = this;
    
    Demande demande = (Demande)getDemande();
    if (demande.getObjectifDecisionne().getSousType() == 11)
    {
      AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
      if (attributionPrecedente == null) {
        attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
      }
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public SalaireJournalierSpec getSalaireJournalierInitial()
  {
    Demande demande = (Demande)getDemande();
    SalaireJournalierSpec salaireJournalierRetenu = null;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      salaireJournalierRetenu = super.getSalaireJournalierInitial();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      salaireJournalierRetenu = new Sjr(demande.getDonneesTemporaires().getSjrSP().getValeur(), demande.getDonneesTemporaires().getTermePrcSp(), null);
    } else {
      salaireJournalierRetenu = getAttributionPrecedente().getSalaireJournalierInitial();
    }
    return salaireJournalierRetenu;
  }
  
  public BigDecimal getCoefficientSaisonnier()
  {
    Demande demande = (Demande)getDemande();
    BigDecimal coefficientSaisonnier = BigDecimal.ONE;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      coefficientSaisonnier = super.getCoefficientSaisonnier();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      coefficientSaisonnier = demande.getDonneesTemporaires().getCoefficientSaisonnierSp();
    } else {
      coefficientSaisonnier = getAttributionPrecedente().getCoefficientSaisonnier();
    }
    return coefficientSaisonnier;
  }
  
  public int getNatureCoefficientSaisonnier()
  {
    Demande demande = (Demande)getDemande();
    int natureCoefficientSaisonnier = -1;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      natureCoefficientSaisonnier = super.getNatureCoefficientSaisonnier();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      natureCoefficientSaisonnier = demande.getDonneesTemporaires().getTypeCaractereSaisonnierForce();
    } else {
      natureCoefficientSaisonnier = getAttributionPrecedente().getNatureCoefficientSaisonnier();
    }
    return natureCoefficientSaisonnier;
  }
  
  public boolean a3ansActiviteEn5ans()
  {
    Demande demande = (Demande)getDemande();
    boolean a3ansActiviteEn5ans = false;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      a3ansActiviteEn5ans = super.a3ansActiviteEn5ans();
    } else if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      a3ansActiviteEn5ans = getAttributionPrecedente().a3ansActiviteEn5ans();
    }
    return a3ansActiviteEn5ans;
  }
  
  public BigDecimal getCoefficientTempsPartiel()
  {
    Demande demande = (Demande)getDemande();
    BigDecimal coefficientSaisonnier = BigDecimal.ONE;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      coefficientSaisonnier = super.getCoefficientTempsPartiel();
    } else if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      coefficientSaisonnier = demande.getDonneesTemporaires().getCoefficientTempsPartielSp();
    } else {
      coefficientSaisonnier = getAttributionPrecedente().getCoefficientTempsPartiel();
    }
    return coefficientSaisonnier;
  }
  
  public boolean estSjrBaseSmic()
  {
    Demande demande = (Demande)getDemande();
    boolean sjrBaseSmic = false;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      sjrBaseSmic = super.estSjrBaseSmic();
    } else if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      sjrBaseSmic = getAttributionPrecedente().estSjrBaseSmic();
    }
    return sjrBaseSmic;
  }
  
  public int getCategorieEmploiA2B()
  {
    Demande demande = (Demande)getDemande();
    int categorieA2B = 0;
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      categorieA2B = super.getCategorieEmploiA2B();
    } else if (!demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
      categorieA2B = getAttributionPrecedente().getCategorieEmploiA2B();
    }
    return categorieA2B;
  }
  
  public Quantite getCapitalAServir()
  {
    Quantite capitalAServir = null;
    boolean estCapitalCourantRetenu = getTypeCapitalRetenu() == 1;
    if (estCapitalCourantRetenu) {
      capitalAServir = super.getCapitalAServir();
    } else {
      capitalAServir = getConstitutionProduitResultant().getCapitalDroitPrecedent();
    }
    return capitalAServir;
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    ReglementApplicableSpec reglement = null;
    
    boolean estMontantCourantRetenu = getTypeMontantRetenu() == 1;
    if (estMontantCourantRetenu) {
      reglement = super.getReglementApplicableMontantRetenu();
    } else if (((Demande)getDemande()).estEnContexteDroitAnterieurSecteurPublicValide()) {
      reglement = super.getReglementApplicableMontantRetenu();
    } else {
      reglement = getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return reglement;
  }
}

/* Location:
 * Qualified Name:     Readmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */