package fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.pc.SjcipPC;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoEvenementDebutCREM;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public abstract class SjcipGen
  extends ObjetChronoEvenementDebutCREM
  implements DomGenSpec
{
  private QuantiteEuro m_plafond;
  private QuantiteEuro m_sjcInitial;
  private Collection m_listeSjrActiviteConservee;
  
  public SjcipGen(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public SjcipGen() {}
  
  public SjcipGen(Damj p_dateEffet)
  {
    super(p_dateEffet);
  }
  
  protected DomPCSpec createPC()
  {
    return new SjcipPC();
  }
  
  protected QuantiteEuro rawGetPlafond()
  {
    return ((SjcipPC)getPC()).getPlafond();
  }
  
  public QuantiteEuro getPlafond()
  {
    return ((SjcipPC)getPC()).getPlafond();
  }
  
  public void setPlafond(QuantiteEuro p_plafond)
  {
    if ((m_plafond == null) || (p_plafond == null))
    {
      m_plafond = p_plafond;
      ((SjcipPC)getPC()).setPlafond(p_plafond);
    }
    else if ((m_plafond != null) && (p_plafond != null) && (!p_plafond.equals(m_plafond)))
    {
      m_plafond = p_plafond;
      ((SjcipPC)getPC()).setPlafond(p_plafond);
    }
  }
  
  protected QuantiteEuro rawGetSjcInitial()
  {
    return ((SjcipPC)getPC()).getSjcInitial();
  }
  
  public QuantiteEuro getSjcInitial()
  {
    return ((SjcipPC)getPC()).getSjcInitial();
  }
  
  public void setSjcInitial(QuantiteEuro p_sjcInitial)
  {
    if ((m_sjcInitial == null) || (p_sjcInitial == null))
    {
      m_sjcInitial = p_sjcInitial;
      ((SjcipPC)getPC()).setSjcInitial(p_sjcInitial);
    }
    else if ((m_sjcInitial != null) && (p_sjcInitial != null) && (!p_sjcInitial.equals(m_sjcInitial)))
    {
      m_sjcInitial = p_sjcInitial;
      ((SjcipPC)getPC()).setSjcInitial(p_sjcInitial);
    }
  }
  
  private final Collection getCollectionModifiableSjrActiviteConservee()
  {
    Iterator itCollectionPC;
    if (m_listeSjrActiviteConservee == null)
    {
      m_listeSjrActiviteConservee = new ArrayList();
      for (itCollectionPC = ((SjcipPC)getPC()).getCollectionSjrActiviteConservee().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeSjrActiviteConservee.add(currentOM);
      }
    }
    return m_listeSjrActiviteConservee;
  }
  
  public Collection getCollectionSjrActiviteConservee()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableSjrActiviteConservee());
  }
  
  public List getListSjrActiviteConservee()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableSjrActiviteConservee());
  }
  
  public void remplacerCollectionSjrActiviteConservee(Collection p_collectionACopier)
  {
    clearCollectionSjrActiviteConservee();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      SjrActiviteConservee objet = (SjrActiviteConservee)i.next();
      ajouterSjrActiviteConservee(objet);
    }
  }
  
  public void supprimerSousCollectionSjrActiviteConservee(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      SjrActiviteConservee objet = (SjrActiviteConservee)i.next();
      supprimerSjrActiviteConservee(objet);
    }
  }
  
  public void ajouterSjrActiviteConservee(SjrActiviteConservee p_sjrActiviteConservee)
    throws NullPointerException
  {
    if (p_sjrActiviteConservee == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_sjrActiviteConservee ne devrait pas être nul.", p_sjrActiviteConservee);
    }
    getCollectionModifiableSjrActiviteConservee().add(p_sjrActiviteConservee);
    ((SjcipPC)getPC()).ajouterSjrActiviteConservee(p_sjrActiviteConservee.getPC());
  }
  
  public void supprimerSjrActiviteConservee(SjrActiviteConservee p_sjrActiviteConservee)
    throws NullPointerException
  {
    if (p_sjrActiviteConservee == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_sjrActiviteConservee ne devrait pas être nul.", p_sjrActiviteConservee);
    }
    getCollectionModifiableSjrActiviteConservee().remove(p_sjrActiviteConservee);
    ((SjcipPC)getPC()).supprimerSjrActiviteConservee(p_sjrActiviteConservee.getPC());
  }
  
  public void recopierCollectionSjrActiviteConserveeVers(ObjetMetierSpec p_copie)
  {
    SjcipGen copie = (SjcipGen)p_copie;
    Collection listeACopier = getCollectionSjrActiviteConservee();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterSjrActiviteConservee((SjrActiviteConservee)objet);
    }
  }
  
  public void clearCollectionSjrActiviteConservee()
  {
    getCollectionModifiableSjrActiviteConservee().clear();
    ((SjcipPC)getPC()).getCollectionSjrActiviteConservee().clear();
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    
    super.supprimerEnProfondeur(p_contexteSuppression);
    for (Iterator iter = getCollectionSjrActiviteConservee().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    super.copieElements(p_copie);
  }
}

/* Location:
 * Qualified Name:     SjcipGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */