package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.dom.spec.ConstitutionDelaisSpec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.autresdoms.ga.dom.RegimeRetraite;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ObjetChronoPeriodeSpec;
import java.util.List;

public class AlimenterBaseEchanges
{
  public static void alimenterDonneesProduit(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws CoucheLogiqueException
  {
    if (pDemandeEchange == null) {
      pDemandeEchange = new fr.unedic.cali.dom.echange.Decision();
    }
    pDemandeEchange.setLigne("ASU_CGE01");
    if ((pDossierExamen.getDemande().estNotifieeCourrier()) && ((pDossierExamen instanceof fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision)))
    {
      alimenterDonneesCourrierECAX(pDossierExamen, pDemandeEchange);
      if (!(pDossierExamen instanceof RejetSpec))
      {
        alimenterDonneesCourrier(pDossierExamen, pDemandeEchange);
        alimenterDonneesCourrierEcep(pDossierExamen, pDemandeEchange);
        alimenterDonneesRejetSP(pDossierExamen, pDemandeEchange);
      }
    }
  }
  
  protected static void alimenterDonneesCourrier(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision)pDossierExamen;
    switch (dossierExamen.getNatureDecision())
    {
    case 11: 
      alimenterDonneesCourrierReadAntecedent(dossierExamen, pDemandeEchange);
      break;
    default: 
      alimenterDonneesCourrierNonReadAntecedent(dossierExamen, pDemandeEchange);
    }
    pDemandeEchange.setLibelleEmployeur(dossierExamen.getCompetence().getLibelleEmployeurCompetent());
  }
  
  private static void alimenterDonneesCourrierNonReadAntecedent(fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
  {
    ConstitutionMontantsBruts cepaMontantsBruts = pDossierExamen.getConstitutionMontantsBruts();
    if (cepaMontantsBruts != null)
    {
      if (cepaMontantsBruts.getMontantBrutSansDeduction() != null) {
        pDemandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantBrutSansDeduction().getValeur());
      }
      if (cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte() != null) {
        pDemandeEchange.setMontantPensionInvaliditeAreCourrier(cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
      }
      if (cepaMontantsBruts.getCrc() != null) {
        pDemandeEchange.setMontantCrcCourrier(cepaMontantsBruts.getCrc().getValeur());
      }
      if (cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit() != null) {
        pDemandeEchange.setMontantAllocation(cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit().getValeur());
      }
    }
    ConstitutionDurees cepaDureesReglementaires = pDossierExamen.getConstitutionDurees();
    if ((cepaDureesReglementaires != null) && (cepaDureesReglementaires.getDureeIndemnisation() != null) && (cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique() != null))
    {
      pDemandeEchange.setDureeTheoriqueDroitServiCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique().getValeurEntiere());
      
      pDemandeEchange.setDureeRenouvellementAreCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeEffective().getValeurEntiere());
    }
  }
  
  private static void alimenterDonneesCourrierReadAntecedent(fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
  {
    ConstitutionMontantsBruts cepaMontantsBruts = pDossierExamen.getConstitutionProduitResultant().getConstitutionMontantsBruts();
    if (cepaMontantsBruts != null)
    {
      if (cepaMontantsBruts.getMontantBrutSansDeduction() != null) {
        pDemandeEchange.setMontantAllocationJournalierBrutCourrier(cepaMontantsBruts.getMontantBrutSansDeduction().getValeur());
      }
      if (cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte() != null) {
        pDemandeEchange.setMontantPensionInvaliditeAreCourrier(cepaMontantsBruts.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
      }
      if (cepaMontantsBruts.getCrc() != null) {
        pDemandeEchange.setMontantCrcCourrier(cepaMontantsBruts.getCrc().getValeur());
      }
      if (cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit() != null) {
        pDemandeEchange.setMontantAllocation(cepaMontantsBruts.getMontantJournalierAvantageVieillesseDeduit().getValeur());
      }
    }
    ConstitutionDurees cepaDureesReglementaires = pDossierExamen.getConstitutionProduitResultant().getConstitutionDurees();
    if ((cepaDureesReglementaires != null) && (cepaDureesReglementaires.getDureeIndemnisation() != null))
    {
      pDemandeEchange.setDureeTheoriqueDroitServiCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeTheorique().getValeurEntiere());
      
      pDemandeEchange.setDureeRenouvellementAreCourrier(cepaDureesReglementaires.getDureeIndemnisation().getDureeEffective().getValeurEntiere());
    }
  }
  
  protected static void alimenterDonneesCourrierECAX(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision)pDossierExamen;
    pDemandeEchange.setLibelleEmployeur(dossierExamen.getCompetence().getLibelleEmployeurCompetent());
    
    ConstitutionSjc cepaActiviteConserveeSjc = dossierExamen.getConstitutionSjc();
    ConditionActiviteConservee capaConditionActiviteConservee = dossierExamen.getConditionActiviteConservee();
    if ((cepaActiviteConserveeSjc != null) && (cepaActiviteConserveeSjc.getSjcrp() != null)) {
      pDemandeEchange.setMontantSJC(cepaActiviteConserveeSjc.getSjcrp().getSalaire());
    }
    if (capaConditionActiviteConservee != null) {
      pDemandeEchange.setMontantSJCMax(capaConditionActiviteConservee.getSeuilMontantMensuelActiviteConservee());
    }
  }
  
  protected static void alimenterDonneesCourrierEcep(DossierExamenSpec pDossierExamen, fr.unedic.cali.dom.echange.Decision pDemandeEchange)
    throws CoucheLogiqueException
  {
    int topCaisseInconnue = 0;
    
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision dossierExamen = (fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision)pDossierExamen;
    if (dossierExamen.getConditionFaitGenerateur() != null)
    {
      List listeRegimeRetraite = dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getMetier().getListeRegimeRetraite();
      if (listeRegimeRetraite != null)
      {
        int nbRegimeRetraite = listeRegimeRetraite.size();
        for (int i = 0; i < nbRegimeRetraite; i++)
        {
          RegimeRetraite regimeRetraiteGa = (RegimeRetraite)listeRegimeRetraite.get(i);
          if (regimeRetraiteGa.estCaisseRetraiteAbsente()) {
            topCaisseInconnue = 1;
          }
        }
      }
    }
    pDemandeEchange.setTopCaisseInconnue(topCaisseInconnue);
  }
  
  protected static void alimenterDonneesRejetSP(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision decision = (fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision)dossierExamen;
    
    ConstitutionDelaisSpec cepDelai = decision.getConstitutionDelais();
    if (cepDelai != null) {
      demandeEchange.setDateDebutDernierDelaiAttente(cepDelai.getDateDebutDernierDelaiAttente());
    }
    CompetenceSpec competence = decision.getCompetence();
    if (competence != null)
    {
      if (competence.isEstCoeffTPAppliqueRAC()) {
        demandeEchange.setCoeffTPAppliqueRAC(1);
      } else {
        demandeEchange.setCoeffTPAppliqueRAC(0);
      }
      if (competence.isEstCoeffTPAppliqueSP()) {
        demandeEchange.setCoeffTPAppliqueSP(1);
      } else {
        demandeEchange.setCoeffTPAppliqueSP(0);
      }
      demandeEchange.setDureeActiviteEmployeursRAC(competence.getDureeActiviteSecteurPrive() + competence.getDureeActiviteSecteurPublicAffilie() + competence.getDureeActiviteSecteurPriveCaCae());
      
      demandeEchange.setDureeActiviteEmployeursSP(competence.getDureeActiviteSecteurPublicAutoAssurance() + competence.getDureeActiviteSecteurPublicConventionGestion());
    }
    if (decision.getReglementApplicable() != null) {
      demandeEchange.setReglementApplicableDroit(decision.getReglementApplicable().getReglement().getLibelleCourt());
    }
    demandeEchange.setDateFaitGenerateurDroitPrecedent(decision.getDemandeAssurance().getDateFaitGenerateurOdPrecedente());
    
    ObjetChronoPeriodeSpec periode = OutillagePEC.getPeriodePECIndemnisableContenant(decision.getDemandeAssurance().getDemandeur(), decision.getDateAttribution());
    if (periode != null) {
      demandeEchange.setDateIDE(periode.getDateDebut());
    }
  }
}

/* Location:
 * Qualified Name:     AlimenterBaseEchanges
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */