package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Od;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.CREM;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Hashtable;

public class ConstitutionCREMConstituant
{
  private static final int NB_DECIMALES_ARRONDI_0 = 0;
  private static final int NB_DECIMALES_ARRONDI_2 = 2;
  private static final int NB_DECIMALES_ARRONDI_4 = 4;
  
  public static Hashtable recupererElementsConstituant(DossierExamenSpec p_dossierExamen)
  {
    Hashtable listeConstituant = CREM.getElementsConstitutantVides();
    if ((p_dossierExamen instanceof AttributionSpec))
    {
      DossierExamen dossierExamen = (DossierExamen)p_dossierExamen;
      if ((dossierExamen.getReglementApplicable() != null) && (dossierExamen.getReglementApplicable().getReglement() != null) && (dossierExamen.getReglementApplicable().getReglement().getNomReglement() != null)) {
        listeConstituant.put("Reglement applicable", dossierExamen.getReglementApplicable().getReglement().getNomReglement());
      }
      if ((dossierExamen.getConstitutionSjr() != null) && (dossierExamen.getConstitutionSjr().getSjrip() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getSjrip() != null)) {
        listeConstituant.put("Salaire journalier de ref", Mathematiques.arrondiASup(dossierExamen.getConstitutionSjr().getSjrip().getSjrip(), 2).toString());
      }
      if ((dossierExamen.getConstitutionDurees() != null) && (dossierExamen.getConstitutionDurees().getDureeIndemnisation() != null) && (dossierExamen.getConstitutionDurees().getDureeIndemnisation().getDureeEffective() != null)) {
        listeConstituant.put("Duree Produit Resultant", Mathematiques.arrondiASup(dossierExamen.getConstitutionDurees().getDureeIndemnisation().getDureeEffective().getValeur(), 2).toString());
      }
      if ((dossierExamen.getConstitutionCoefficientTempsPartiel() != null) && (dossierExamen.getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu() != null)) {
        listeConstituant.put("Coefficient temps partiel", Mathematiques.arrondiASup(dossierExamen.getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu(), 4).toString());
      }
      if ((dossierExamen.getDemande() != null) && (dossierExamen.getDemande().estMigree()))
      {
        if (dossierExamen.getDemande().getDateExamen() != null) {
          listeConstituant.put("Date d examen", dossierExamen.getDemande().getDateExamen().toString());
        }
        if (dossierExamen.getDateAttribution() != null) {
          listeConstituant.put("Date d attribution", dossierExamen.getDateAttribution().toString());
        }
        if (dossierExamen.getConstitutionDelais() != null)
        {
          if (dossierExamen.getConstitutionDelais().getDebutPMC() != null) {
            listeConstituant.put("Carence PMC debut", dossierExamen.getConstitutionDelais().getDebutPMC().toString());
          }
          if (dossierExamen.getConstitutionDelais().getTermePMC() != null) {
            listeConstituant.put("Carence PMC fin", dossierExamen.getConstitutionDelais().getTermePMC().toString());
          }
          if (dossierExamen.getConstitutionDelais().getDebutCarenceICCP() != null) {
            listeConstituant.put("Differe ICCP debut", dossierExamen.getConstitutionDelais().getDebutCarenceICCP().toString());
          }
          if (dossierExamen.getConstitutionDelais().getTermeCarenceICCP() != null) {
            listeConstituant.put("Differe ICCP fin", dossierExamen.getConstitutionDelais().getTermeCarenceICCP().toString());
          }
          if (dossierExamen.getConstitutionDelais().getDebutCarenceISLR() != null) {
            listeConstituant.put("Differe ISLR debut", dossierExamen.getConstitutionDelais().getDebutCarenceISLR().toString());
          }
          if (dossierExamen.getConstitutionDelais().getTermeCarenceISLR() != null) {
            listeConstituant.put("Differe ISLR fin", dossierExamen.getConstitutionDelais().getTermeCarenceISLR().toString());
          }
          if (dossierExamen.getConstitutionDelais().getDebutCarenceDiffere() != null) {
            listeConstituant.put("Delai d attente debut", dossierExamen.getConstitutionDelais().getDebutCarenceDiffere().toString());
          }
          if (dossierExamen.getConstitutionDelais().getTermeCarenceDiffere() != null) {
            listeConstituant.put("Delai d attente fin", dossierExamen.getConstitutionDelais().getTermeCarenceDiffere().toString());
          }
        }
      }
      if ((dossierExamen instanceof Od))
      {
        if ((dossierExamen.getConstitutionSjr() != null) && (dossierExamen.getConstitutionSjr().getSjrip() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc().getSrip() != null)) {
          listeConstituant.put("Salaire de reference", Mathematiques.arrondiASup(dossierExamen.getConstitutionSjr().getSjrip().getPrc().getSrip(), 2).toString());
        }
        if ((dossierExamen.getConditionFaitGenerateur() != null) && (dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur() != null)) {
          listeConstituant.put("FGD", dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getPeriode().toString());
        }
        if (((DossierAffectation)dossierExamen.getDossierAffecte() != null) && (((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit() != null) && (((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit().isEstProduitValide()) && (((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit() != null)) {
          listeConstituant.put("FCT retenue", ((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit().getPeriode().toString());
        }
        if ((dossierExamen.getConstitutionQuantiteAffiliation() != null) && (dossierExamen.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise() != null)) {
          listeConstituant.put("Affiliation quantite", Mathematiques.arrondiASup(dossierExamen.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise().getValeur(), 2).toString());
        }
        if ((dossierExamen.getConstitutionQuantiteAffiliation() != null) && (dossierExamen.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise() != null) && (dossierExamen.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise().getUnite() != null) && (dossierExamen.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise().getUnite().getNom() != null)) {
          listeConstituant.put("Affiliation unite", dossierExamen.getConstitutionQuantiteAffiliation().getQuantiteAffiliationAcquise().getUnite().getNom());
        }
        if ((dossierExamen.getDemande() != null) && (dossierExamen.getDemande().estMigree()))
        {
          if ((dossierExamen.getConstitutionCoefficientSaisonnier() != null) && (dossierExamen.getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu() != null)) {
            listeConstituant.put("Coefficient saisonnier", Mathematiques.arrondiASup(dossierExamen.getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu(), 4).toString());
          }
          listeConstituant.put("Coche apprenti", new Boolean(((Od)dossierExamen).isTopContratsRemuneresBaseSmic()).toString());
          if ((dossierExamen.getConstitutionSjr() != null) && (dossierExamen.getConstitutionSjr().getSjrrp() != null) && (dossierExamen.getConstitutionSjr().getSjrrp().getDateDepart() != null)) {
            listeConstituant.put("Date d effet du SJR", dossierExamen.getConstitutionSjr().getSjrrp().getDateDepart().toString());
          }
          if ((dossierExamen.getConstitutionSjc() != null) && (dossierExamen.getConstitutionSjc().getSjcrp() != null) && (dossierExamen.getConstitutionSjc().getSjcrp().getSalaire() != null)) {
            listeConstituant.put("SJC", Mathematiques.arrondiASup(dossierExamen.getConstitutionSjc().getSjcrp().getSalaire(), 2).toString());
          }
          if ((dossierExamen.getConstitutionSjr() != null) && (dossierExamen.getConstitutionSjr().getSjrip() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc().getSrip() != null)) {
            listeConstituant.put("Montant salaire reference", Mathematiques.arrondiASup(dossierExamen.getConstitutionSjr().getSjrip().getPrc().getSrip(), 2).toString());
          }
          if ((dossierExamen.getConstitutionSjr() != null) && (dossierExamen.getConstitutionSjr().getSjrip() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc().getDateFin() != null)) {
            listeConstituant.put("Date d effet du SR", dossierExamen.getConstitutionSjr().getSjrip().getPrc().getDateFin().toString());
          }
          if ((dossierExamen.getConstitutionSjr() != null) && (dossierExamen.getConstitutionSjr().getSjrip() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc() != null) && (dossierExamen.getConstitutionSjr().getSjrip().getPrc().getNombreJourTravailEffectif() != null)) {
            listeConstituant.put("Nombre de jours emploi", Mathematiques.arrondiASup(dossierExamen.getConstitutionSjr().getSjrip().getPrc().getNombreJourTravailEffectif(), 0).toString());
          }
        }
      }
    }
    return listeConstituant;
  }
}

/* Location:
 * Qualified Name:     ConstitutionCREMConstituant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */