package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleDelaiReportSpec;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieFormuleISLRSpec;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.BaseCarence;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.BaseCarenceMontant;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Readmission;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Reprise;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieISLR;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionISLR;
import fr.unedic.cali.asu.outilsfonctionnels.DeterminationCarenceAsu;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.QuantiteJourTravailDansSemaineSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;

public class DeterminationCarence
  implements OutilFonctionnel
{
  private static final int NOMBRE_JOUR_MAXIMUM_PMC = 999;
  
  private static CarenceIccp determinerCarenceIccpOdA4(QuantiteEuro montantCumul, ObjetChronoPeriode periodeOrigine, Sjr salaireJournalierReference)
    throws CoucheLogiqueException
  {
    CarenceIccp nouvelleCarenceIccp = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ICCP pour toutes les périodes d'activité salariée de règlement RG ou A4." });
    
    BaseCarenceMontant baseCarenceMontantTemporaire = null;
    if (((ActiviteSalarie)periodeOrigine).estContratRemunereBaseSmic()) {
      baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, montantCumul, null, null, true);
    } else {
      baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, montantCumul, null, null, false);
    }
    Formule formuleCarenceIccp = new FormuleCarenceIccpMontant();
    QuantiteJour resultatFormuleIccp = (QuantiteJour)formuleCarenceIccp.appliquerFormule(baseCarenceMontantTemporaire);
    if ((resultatFormuleIccp != null) && (resultatFormuleIccp.getNombreJours() > 0))
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ICCP (", Integer.valueOf(resultatFormuleIccp.getNombreJours()), " jours)." });
      nouvelleCarenceIccp = new CarenceIccp(periodeOrigine, resultatFormuleIccp.getNombreJours());
    }
    return nouvelleCarenceIccp;
  }
  
  private static void determinerCarenceIslrOdA4(ActiviteSalarie periodeFg, Sjr salaireJournalierReference, EnsembleCarences ensembleCarencesPeriodeFg, Damj dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ISLR pour la période d'activité salariée qui porte le Fait Générateur." });
    
    determinerMontantIslr(periodeFg, ensembleCarencesPeriodeFg, dateFaitGenerateurOuDernierSinistre);
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFaitGenerateurOuDernierSinistre);
    StrategieSpec strategie = FabriqueStrategieISLR.getInstance().getStrategie(critere);
    FormuleDelaiReportSpec formuleCarenceIslr = ((StrategieFormuleISLRSpec)strategie).getFormuleISLR();
    
    boolean isTransactionEnCours = periodeFg.getContrat().isTransactionEnCours();
    if (isTransactionEnCours)
    {
      BaseCarenceMontant baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference);
      if (periodeFg.getContrat() != null) {
        baseCarenceMontantTemporaire.setMotifRupture(periodeFg.getContrat().getCodeMotifFin());
      }
      CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeFg, formuleCarenceIslr.recupererPlafondISLR(baseCarenceMontantTemporaire));
      
      ensembleCarencesPeriodeFg.setCarenceIslr(nouvelleCarenceIslr);
      ensembleCarencesPeriodeFg.setPresenceTransaction(true);
    }
    else
    {
      QuantiteEuro quantiteEuroIslr = ConstructionBaseCarence.determinerBaseCarence(periodeFg).getQuantiteEuroIslr();
      if ((quantiteEuroIslr != null) && (quantiteEuroIslr.getValeurMontant().compareTo(new BigDecimal("0")) > 0))
      {
        BaseCarenceMontant baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, null, quantiteEuroIslr, periodeFg.getDateFin());
        if (periodeFg.getContrat() != null) {
          baseCarenceMontantTemporaire.setMotifRupture(periodeFg.getContrat().getCodeMotifFin());
        }
        QuantiteJour resultatFormuleIslr = (QuantiteJour)formuleCarenceIslr.appliquerFormule(baseCarenceMontantTemporaire);
        if ((resultatFormuleIslr != null) && (resultatFormuleIslr.getNombreJours() > 0))
        {
          OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ISLR (", Integer.valueOf(resultatFormuleIslr.getNombreJours()), " jours)." });
          
          CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeFg, resultatFormuleIslr.getNombreJours());
          
          ensembleCarencesPeriodeFg.setCarenceIslr(nouvelleCarenceIslr);
        }
      }
    }
  }
  
  private static void determinerMontantIslr(ActiviteSalarie periode, EnsembleCarences ensembleCarences, Damj dateFaitGenerateurOuDernierSinistre)
    throws CoucheLogiqueException
  {
    try
    {
      periode.setQuantiteEuroIslr(ConstitutionISLR.getInstance().calculeISLR(periode.getListeIndemnites(), periode.getCodeMotifFin(), periode.getCategorieEmploiParticulier(), dateFaitGenerateurOuDernierSinistre));
    }
    catch (CoucheLogiqueException clex)
    {
      if (clex.getMessage().equals("ASU_PR_CALI_L_CEPA05_AUTRES_INDEMNITES_LEGALES")) {
        ensembleCarences.setAutresIndemnitesLegales(true);
      } else {
        throw clex;
      }
    }
  }
  
  public static ArrayList determinerCarences(Chronologie chronologie, Demande demande, Chronologie chronologiePMC)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    Sjr salaireJournalierReference = recupererSjrrp(attributionCourante);
    
    return determinerCarences(chronologie, chronologiePMC, demande, salaireJournalierReference);
  }
  
  public static ArrayList determinerCarences(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, Sjr sjrrp)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    Reglement reglementApplicableCourant = null;
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Début de la détermination des Carences." });
    
    ArrayList listeEnsembleCarencesRetournee = new ArrayList();
    
    chronologie.setComparateur(new ComparateurTemporelsSurDateFin());
    
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    ActiviteSalarie periodeFg = null;
    if (attributionCourante.getFaitGenerateur() != null)
    {
      periodeFg = attributionCourante.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    else
    {
      Chronologie passeProfessionnel = new ChronologiePeriodes();
      passeProfessionnel.ajouter(chronologie);
      passeProfessionnel.ajouter(chronologiePMC);
      
      periodeFg = (ActiviteSalarie)RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateExamen(), passeProfessionnel);
    }
    reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
    if ((reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("RG"))) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("OP"))) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A1"))) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A3"))) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A5"))) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A6")))) {
      determinerCarencesOdRg(chronologie, chronologiePMC, demande, periodeFg, sjrrp, listeEnsembleCarencesRetournee);
    } else if ((reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A2a"))) || (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A2b")))) {
      determinerCarencesOdA2(chronologie, chronologiePMC, demande, periodeFg, sjrrp, listeEnsembleCarencesRetournee);
    } else if (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A4"))) {
      determinerCarencesOdA4(chronologie, chronologiePMC, demande, periodeFg, sjrrp, listeEnsembleCarencesRetournee);
    }
    return listeEnsembleCarencesRetournee;
  }
  
  private static EnsembleCarences determinerCarencesPmcOdA4(Demande demande, Chronologie chronologie, Chronologie chronologiePMC, ActiviteSalarie periodeFg, ArrayList listeEnsembleCarencesRetournee)
    throws CoucheLogiqueException
  {
    EnsembleCarences ensembleCarencesPeriodeFg = null;
    boolean ensembleCarencesPeriodeFgTrouve = false;
    
    ActiviteSalarie periodeTraitee = null;
    EnsembleCarences ensembleCarencesPeriodeTraitee = null;
    
    chronologie.iterer();
    while (chronologie.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologie.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      if (!ensembleCarencesPeriodeFgTrouve)
      {
        ensembleCarencesPeriodeFgTrouve = periodeTraitee.getIdentifiant().equals(periodeFg.getIdentifiant());
        if (ensembleCarencesPeriodeFgTrouve) {
          ensembleCarencesPeriodeFg = ensembleCarencesPeriodeTraitee;
        }
      }
    }
    chronologiePMC.iterer();
    while (chronologiePMC.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologiePMC.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      if (!ensembleCarencesPeriodeFgTrouve)
      {
        ensembleCarencesPeriodeFgTrouve = periodeTraitee.getIdentifiant().equals(periodeFg.getIdentifiant());
        if (ensembleCarencesPeriodeFgTrouve) {
          ensembleCarencesPeriodeFg = ensembleCarencesPeriodeTraitee;
        }
      }
    }
    return ensembleCarencesPeriodeFg;
  }
  
  private static void determinerCarencesIccpIslr(ActiviteSalarie periodeActiviteSalarie, Sjr salaireJournalierReference, Damj dateFg, EnsembleCarences ensembleCarences)
    throws CoucheLogiqueException
  {
    CarenceIccp nouvelleCarenceIccp = null;
    Formule formuleCarenceIccp = null;
    QuantiteJour resultatFormuleIccp = null;
    BaseCarenceMontant baseCarenceMontantTemporaire = null;
    
    BaseCarence baseCarenceReglementCourante = ConstructionBaseCarence.determinerBaseCarence(periodeActiviteSalarie);
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ICCP sur la période d'activité salariée: ", periodeActiviteSalarie });
    
    QuantiteJourTravailDansSemaineSpec quantiteJourIccp = baseCarenceReglementCourante.getQuantiteJourIccp();
    if ((quantiteJourIccp != null) && (quantiteJourIccp.getNombreJours() > 0))
    {
      formuleCarenceIccp = new FormuleCarenceIccpTemps();
      resultatFormuleIccp = (QuantiteJour)formuleCarenceIccp.appliquerFormule(ConstructionBaseCarence.determinerBaseCarence(periodeActiviteSalarie));
    }
    else
    {
      QuantiteEuro quantiteEuroIccp = baseCarenceReglementCourante.getQuantiteEuroIccp();
      if ((quantiteEuroIccp != null) && (quantiteEuroIccp.getValeurMontant().compareTo(new BigDecimal("0")) > 0))
      {
        if (periodeActiviteSalarie.estContratRemunereBaseSmic()) {
          baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, quantiteEuroIccp, null, null, true);
        } else {
          baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, quantiteEuroIccp, null, null, false);
        }
        formuleCarenceIccp = new FormuleCarenceIccpMontant();
        resultatFormuleIccp = (QuantiteJour)formuleCarenceIccp.appliquerFormule(baseCarenceMontantTemporaire);
      }
    }
    if ((resultatFormuleIccp != null) && (resultatFormuleIccp.getNombreJours() > 0))
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ICCP (", Integer.valueOf(resultatFormuleIccp.getNombreJours()), " jours)." });
      
      nouvelleCarenceIccp = new CarenceIccp(periodeActiviteSalarie, resultatFormuleIccp.getNombreJours());
      
      ensembleCarences.setCarenceIccp(nouvelleCarenceIccp);
    }
    determinerCarenceIslr(periodeActiviteSalarie, salaireJournalierReference, dateFg, ensembleCarences);
  }
  
  private static void determinerCarenceIslr(ActiviteSalarie periodeActiviteSalarie, Sjr salaireJournalierReference, Damj dateFg, EnsembleCarences ensembleCarences)
    throws CoucheLogiqueException
  {
    BaseCarenceMontant baseCarenceMontantTemporaire = null;
    
    OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Détermination de la Carence ISLR sur la période d'activité salariée: ", periodeActiviteSalarie });
    
    boolean isTransactionEnCours = periodeActiviteSalarie.getContrat().isTransactionEnCours();
    
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFg);
    StrategieSpec strategie = FabriqueStrategieISLR.getInstance().getStrategie(critere);
    FormuleDelaiReportSpec formuleCarenceIslr = ((StrategieFormuleISLRSpec)strategie).getFormuleISLR();
    if (isTransactionEnCours)
    {
      baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference);
      if (periodeActiviteSalarie.getContrat() != null) {
        baseCarenceMontantTemporaire.setMotifRupture(periodeActiviteSalarie.getContrat().getCodeMotifFin());
      }
      CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeActiviteSalarie, formuleCarenceIslr.recupererPlafondISLR(baseCarenceMontantTemporaire));
      
      ensembleCarences.setCarenceIslr(nouvelleCarenceIslr);
      ensembleCarences.setPresenceTransaction(true);
    }
    else
    {
      BaseCarence baseCarenceReglementCourante = ConstructionBaseCarence.determinerBaseCarence(periodeActiviteSalarie);
      
      QuantiteEuro quantiteEuroIslr = baseCarenceReglementCourante.getQuantiteEuroIslr();
      if ((quantiteEuroIslr != null) && (quantiteEuroIslr.getValeurMontant().compareTo(new BigDecimal("0")) > 0))
      {
        baseCarenceMontantTemporaire = new BaseCarenceMontant(salaireJournalierReference, null, quantiteEuroIslr, dateFg);
        if (periodeActiviteSalarie.getContrat() != null) {
          baseCarenceMontantTemporaire.setMotifRupture(periodeActiviteSalarie.getContrat().getCodeMotifFin());
        }
        QuantiteJour resultatFormuleIslr = (QuantiteJour)formuleCarenceIslr.appliquerFormule(baseCarenceMontantTemporaire);
        if ((resultatFormuleIslr != null) && (resultatFormuleIslr.getNombreJours() > 0))
        {
          OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Création de la Carence ISLR (", Integer.valueOf(resultatFormuleIslr.getNombreJours()), " jours)." });
          
          CarenceIslr nouvelleCarenceIslr = new CarenceIslr(periodeActiviteSalarie, resultatFormuleIslr.getNombreJours());
          
          ensembleCarences.setCarenceIslr(nouvelleCarenceIslr);
        }
      }
    }
  }
  
  private static CarenceIccp determinerCarencesIccpForcees(Demande demande, ActiviteSalarie periode)
  {
    CarenceIccp carenceIccp = null;
    if (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire().getValeur().intValue() != 0)
    {
      QuantiteJourTravailDansSemaineSpec qteJourIccp = (QuantiteJourTravailDansSemaineSpec)demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire();
      
      int nombreJoursSemaine = qteJourIccp.getNombreJoursSemaine();
      BigDecimal nominateur1 = demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire().getValeur().setScale(0, 0);
      
      BigDecimal nominateur2 = new BigDecimal("7");
      BigDecimal denominateur = new BigDecimal(String.valueOf(nombreJoursSemaine));
      BigDecimal resultatFormule = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      QuantiteJour quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0).toString());
      carenceIccp = new CarenceIccp(periode, quantiteJourCalculee.getNombreJours());
      
      carenceIccp.setDateFinPeriodeOrigine(demande.getAttribution().getDateAttribution().veille());
    }
    return carenceIccp;
  }
  
  private static void determinerCarencesOdRg(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, ActiviteSalarie periodeFg, Sjr salaireJournalierReference, ArrayList p_listeEnsembleCarencesRetournee)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ActiviteSalarie periodeTraitee = null;
    EnsembleCarences ensembleCarencesPeriodeTraitee = null;
    
    boolean presencePmcForcee = (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null) && (demande.getDonneesTemporaires().getFinPmc() != null);
    
    CarenceIccp carenceIccpForcee = null;
    if (((demande.getDossierExamen() instanceof Reprise)) && (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire() != null))
    {
      carenceIccpForcee = determinerCarencesIccpForcees(demande, periodeFg);
      if (carenceIccpForcee != null)
      {
        ensembleCarencesPeriodeTraitee = new EnsembleCarences();
        ensembleCarencesPeriodeTraitee.setCarenceIccp(carenceIccpForcee);
        p_listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      }
    }
    if (!chronologie.estVide())
    {
      chronologie.iterer();
      while (chronologie.encoreSuivant())
      {
        periodeTraitee = (ActiviteSalarie)chronologie.elementSuivant();
        
        ensembleCarencesPeriodeTraitee = new EnsembleCarences();
        
        determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
        
        determinerMontantIslr(periodeTraitee, ensembleCarencesPeriodeTraitee, demande.getDateFaitGenerateurOuDernierSinistre());
        
        determinerCarencesIccpIslr(periodeTraitee, salaireJournalierReference, periodeFg.getDateFin(), ensembleCarencesPeriodeTraitee);
        
        p_listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      }
      chronologiePMC.iterer();
      while (chronologiePMC.encoreSuivant())
      {
        periodeTraitee = (ActiviteSalarie)chronologiePMC.elementSuivant();
        
        ensembleCarencesPeriodeTraitee = new EnsembleCarences();
        
        determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
        
        p_listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
      }
    }
    EnsembleCarences ensembleCarencesForcee = new EnsembleCarences();
    if (carenceIccpForcee != null) {
      ensembleCarencesForcee.setCarenceIccp(carenceIccpForcee);
    }
    if (presencePmcForcee) {
      ajouterCarencePmcForcee(demande, ensembleCarencesForcee);
    }
    if ((presencePmcForcee) || (carenceIccpForcee != null)) {
      p_listeEnsembleCarencesRetournee.add(ensembleCarencesForcee);
    }
  }
  
  private static void determinerCarencesOdA2(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, ActiviteSalarie periodeFg, Sjr salaireJournalierReference, ArrayList listeEnsembleCarencesRetournee)
    throws PasAssezInformationException, CoucheLogiqueException
  {
    ActiviteSalarie periodeTraitee = null;
    EnsembleCarences ensembleCarencesPeriodeTraitee = null;
    
    chronologie.iterer();
    while (chronologie.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologie.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      determinerMontantIslr(periodeTraitee, ensembleCarencesPeriodeTraitee, demande.getDateFaitGenerateurOuDernierSinistre());
      
      determinerCarencesIccpIslr(periodeTraitee, salaireJournalierReference, periodeFg.getDateFin(), ensembleCarencesPeriodeTraitee);
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
    }
    chronologiePMC.iterer();
    while (chronologiePMC.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)chronologiePMC.elementSuivant();
      
      ensembleCarencesPeriodeTraitee = new EnsembleCarences();
      
      determinerCarencePmc(demande, periodeTraitee, ensembleCarencesPeriodeTraitee);
      
      listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeTraitee);
    }
  }
  
  private static void determinerCarencesOdA4(Chronologie chronologie, Chronologie chronologiePMC, Demande demande, ActiviteSalarie periodeFg, Sjr salaireJournalierReference, ArrayList listeEnsembleCarencesRetournee)
    throws CoucheLogiqueException, PasAssezInformationException, ApplicativeException
  {
    Damj finPeriodePriseEnCompteActiviteReduiteAsuPrecedente = null;
    Damj finPeriodePriseEnCompteActiviteReduiteAssPrecedente = null;
    Chronologie periodesAvecIccpNonPriseEnCompte = null;
    
    Periode periodePriseEnCompteActiviteReduiteAsuPrecedente = DeterminationCarenceAsu.determinerPeriodePriseEnCompteActiviteReduiteAsuPrecedente(demande);
    periodesAvecIccpNonPriseEnCompte = DeterminationCarenceAsu.determinerChronoHorsPeriodePriseEnCompteActiviteReduite(chronologie, periodePriseEnCompteActiviteReduiteAsuPrecedente);
    
    Periode periodePriseEnCompteActiviteReduiteAssPrecedente = DeterminationCarenceAsu.determinerPeriodePriseEnCompteActiviteReduiteAssPrecedente(demande);
    if (periodesAvecIccpNonPriseEnCompte != null) {
      periodesAvecIccpNonPriseEnCompte = DeterminationCarenceAsu.determinerChronoHorsPeriodePriseEnCompteActiviteReduite(periodesAvecIccpNonPriseEnCompte, periodePriseEnCompteActiviteReduiteAssPrecedente);
    }
    if (periodePriseEnCompteActiviteReduiteAsuPrecedente != null) {
      finPeriodePriseEnCompteActiviteReduiteAsuPrecedente = periodePriseEnCompteActiviteReduiteAsuPrecedente.getFin();
    }
    if (periodePriseEnCompteActiviteReduiteAssPrecedente != null) {
      finPeriodePriseEnCompteActiviteReduiteAssPrecedente = periodePriseEnCompteActiviteReduiteAssPrecedente.getFin();
    }
    EnsembleCarences ensembleCarencesPeriodeFg = null;
    
    ensembleCarencesPeriodeFg = determinerCarencesPmcOdA4(demande, chronologie, chronologiePMC, periodeFg, listeEnsembleCarencesRetournee);
    
    CarenceIccp nouvelleCarenceIccp = null;
    ActiviteSalarie periodeTraitee = null;
    BigDecimal cumulMontantsIccpOdA4 = new BigDecimal("0");
    Chronologie chronoPeriodesSalaireCourante = null;
    Salaire periodeSalaireCourante = null;
    Damj dateDebutPeriodeSalaireCourante = null;
    Damj datePeriodeSalaireCourante = null;
    BigDecimal montantIccpSalaireCourant = null;
    
    Periode periodeDelaiRechercheCarences = ((DossierExamen)demande.getDossierExamen()).getConstitutionDelais().getPeriodeReference91jours();
    
    periodesAvecIccpNonPriseEnCompte.iterer();
    while (periodesAvecIccpNonPriseEnCompte.encoreSuivant())
    {
      periodeTraitee = (ActiviteSalarie)periodesAvecIccpNonPriseEnCompte.elementSuivant();
      
      QuantiteEuro quantiteEuroIccpCourante = ConstructionBaseCarence.determinerBaseCarence(periodeTraitee).getQuantiteEuroIccp();
      if ((quantiteEuroIccpCourante != null) && (quantiteEuroIccpCourante.getValeurMontant().compareTo(new BigDecimal("0")) > 0)) {
        cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(quantiteEuroIccpCourante.getValeurMontant());
      }
      chronoPeriodesSalaireCourante = periodeTraitee.getListeSalaires();
      chronoPeriodesSalaireCourante.iterer();
      while (chronoPeriodesSalaireCourante.encoreSuivant())
      {
        periodeSalaireCourante = (Salaire)chronoPeriodesSalaireCourante.elementSuivant();
        dateDebutPeriodeSalaireCourante = periodeSalaireCourante.getDateDebut();
        datePeriodeSalaireCourante = periodeSalaireCourante.getDatePaie() != null ? periodeSalaireCourante.getDatePaie() : periodeSalaireCourante.getDateFin();
        
        boolean iccpAPrendreEnCompteAsu = (finPeriodePriseEnCompteActiviteReduiteAsuPrecedente == null) || (dateDebutPeriodeSalaireCourante.estApres(finPeriodePriseEnCompteActiviteReduiteAsuPrecedente));
        
        boolean iccpAPrendreEnCompteAss = (finPeriodePriseEnCompteActiviteReduiteAssPrecedente == null) || (dateDebutPeriodeSalaireCourante.estApres(finPeriodePriseEnCompteActiviteReduiteAssPrecedente));
        if ((periodeDelaiRechercheCarences.contient(datePeriodeSalaireCourante)) && (iccpAPrendreEnCompteAsu) && (iccpAPrendreEnCompteAss))
        {
          montantIccpSalaireCourant = periodeSalaireCourante.determinerMontantIccp();
          if (montantIccpSalaireCourant != null) {
            cumulMontantsIccpOdA4 = cumulMontantsIccpOdA4.add(montantIccpSalaireCourant);
          }
        }
      }
    }
    ((DossierExamen)demande.getDossierExamen()).getConstitutionDelais().setCumulMontantICCPA4Origine(new QuantiteEuro(cumulMontantsIccpOdA4));
    if (cumulMontantsIccpOdA4.compareTo(new BigDecimal("0")) > 0) {
      nouvelleCarenceIccp = determinerCarenceIccpOdA4(new QuantiteEuro(cumulMontantsIccpOdA4), periodeFg, salaireJournalierReference);
    }
    if (((demande.getDossierExamen() instanceof Reprise)) && (demande.getDonneesTemporaires().getQuantiteJoursDiffereIccpConservatoire() != null))
    {
      CarenceIccp carenceIccpForcee = determinerCarencesIccpForcees(demande, periodeFg);
      if (carenceIccpForcee != null)
      {
        EnsembleCarences ensembleCarencesPeriodeIccpForcee = new EnsembleCarences();
        ensembleCarencesPeriodeIccpForcee.setCarenceIccp(carenceIccpForcee);
        listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeIccpForcee);
      }
    }
    if (ensembleCarencesPeriodeFg == null) {
      ensembleCarencesPeriodeFg = new EnsembleCarences();
    }
    ensembleCarencesPeriodeFg.setCarenceIccp(nouvelleCarenceIccp);
    if (periodeFg != null) {
      determinerCarenceIslrOdA4(periodeFg, salaireJournalierReference, ensembleCarencesPeriodeFg, demande.getDateFaitGenerateurOuDernierSinistre());
    }
    listeEnsembleCarencesRetournee.add(ensembleCarencesPeriodeFg);
  }
  
  private static Sjr recupererSjrrp(DossierExamen dossierExamen)
  {
    Sjr salaireJournalierReference = null;
    if ((dossierExamen instanceof Readmission)) {
      salaireJournalierReference = dossierExamen.getConstitutionProduitResultant().getSjrrpProduitPrecedent();
    } else {
      salaireJournalierReference = dossierExamen.getConstitutionSjr().getSjrrp();
    }
    return salaireJournalierReference;
  }
  
  private static void ajouterCarencePmcForcee(Demande demande, EnsembleCarences ensembleCarences)
  {
    ActiviteSalarie periodeFct = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(demande.getDonneesTemporaires().getIndentifiantFctPMC());
    
    ConstitutionPMC.ajouterPmcForcee(periodeFct, demande.getDonneesTemporaires().isPmcIndemnisable(), demande.getDonneesTemporaires().getFinPmc(), ensembleCarences);
  }
  
  private static void determinerCarencePmc(Demande demande, ActiviteSalarie periodeActiviteSalarie, EnsembleCarences ensembleCarences)
    throws CoucheLogiqueException
  {
    boolean presencePmcForcee = (demande.getDonneesTemporaires().getIndentifiantFctPMC() != null) && (demande.getDonneesTemporaires().getFinPmc() != null);
    
    boolean levagePmc = demande.getDonneesTemporaires().isLeveePmc();
    if (presencePmcForcee)
    {
      if (periodeActiviteSalarie.getIdentifiant().equalsIgnoreCase(demande.getDonneesTemporaires().getIndentifiantFctPMC())) {
        ajouterCarencePmcForcee(demande, ensembleCarences);
      }
    }
    else if (!levagePmc)
    {
      ensembleCarences.setDemande(demande);
      ConstitutionPMC.determinerPMC(periodeActiviteSalarie, ensembleCarences);
    }
    if ((ensembleCarences.getCarencePmc() != null) && (ensembleCarences.getCarencePmc().getQuantiteInitialJour() > 999))
    {
      Damj dateFCTDamj = ensembleCarences.getCarencePmc().getOrigine().getDateFin();
      String dateFCTString = dateFCTDamj.formater();
      
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB17", new String[] { dateFCTString });
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationCarence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */