package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementJustification;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.JustificationAppelGaecReduit;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;

public class DeterminationDateMinPraPrcPrs
  implements OutilFonctionnel
{
  public static final int DUREE_PRS_TROIS = 3;
  private static final int DUREE_PRA = 22;
  private static final String MESSAGE_GAEC_NON_CHARGE = "L'individu GAEC n'a pas été chargé en début de service.";
  
  public static JustificationAppelGaecReduit calculerDateMinimum(DemandeSpec p_demande)
  {
    Damj dateDebutPra = null;
    Damj dateDebutPrc = null;
    Damj dateDebutPrs = null;
    
    Demande demande = (Demande)p_demande;
    Decision decisionAssurance = (Decision)demande.getDossierExamen();
    if ((decisionAssurance instanceof RepriseSpec))
    {
      if (demande.getObjectifDecisionne().getSousType() == 14)
      {
        dateDebutPrs = demande.getElementJustification().getPrsRepriseContextuelle().getDebut();
      }
      else
      {
        Damj dateFaitGenerateurOdPrecedente = getDateFaitGenerateurOdPrecedente(demande);
        if ((decisionAssurance.getConstitutionCaractereSaisonnier() == null) || (decisionAssurance.getConstitutionCaractereSaisonnier().getPeriodeReferenceSaisonnier() == null)) {
          return new JustificationAppelGaecReduit(dateFaitGenerateurOdPrecedente, "Fgd OD précédente", p_demande.getIdentifiant());
        }
        dateDebutPrs = decisionAssurance.getConstitutionCaractereSaisonnier().getPeriodeReferenceSaisonnier().getDebut();
        if (dateDebutPrs.estAvant(dateFaitGenerateurOdPrecedente)) {
          return new JustificationAppelGaecReduit(dateDebutPrs, "Prs", p_demande.getIdentifiant());
        }
        return new JustificationAppelGaecReduit(dateFaitGenerateurOdPrecedente, "Fgd OD précédente", p_demande.getIdentifiant());
      }
    }
    else if ((decisionAssurance instanceof OdSpec))
    {
      if (decisionAssurance.getConstitutionQuantiteAffiliation() != null)
      {
        Periode periodePra = decisionAssurance.getConstitutionQuantiteAffiliation().getPeriodePRA();
        if (periodePra != null) {
          dateDebutPra = periodePra.getDebut();
        }
      }
      if (decisionAssurance.getConstitutionSjr() != null) {
        if (decisionAssurance.getConstitutionSjr().getSjrip().getPrc() != null) {
          dateDebutPrc = decisionAssurance.getConstitutionSjr().getSjrip().getPrc().getDateDebut();
        }
      }
      if (decisionAssurance.getConstitutionCaractereSaisonnier() != null) {
        dateDebutPrs = decisionAssurance.getConstitutionCaractereSaisonnier().getPeriodeReferenceSaisonnier().getDebut();
      }
    }
    else
    {
      Damj dateFgd = null;
      if ((demande.getFaitGenerateur() != null) && (demande.getFaitGenerateur().getDateFaitGenerateur() != null)) {
        dateFgd = demande.getFaitGenerateur().getDateFaitGenerateur();
      }
      Damj dateFinPra = null;
      if (dateFgd != null) {
        dateFinPra = dateFgd;
      } else {
        dateFinPra = demande.getDateExamen();
      }
      dateDebutPra = dateFinPra.deplacerVersArriere(new DureeCalendaire(0, 22, 0));
      
      Damj dateFgdPrecedent = getDateFaitGenerateurOdPrecedente(demande);
      if (dateFgdPrecedent != null) {
        dateDebutPra = Damj.max(dateDebutPra, dateFgdPrecedent);
      }
      if (dateFgd != null)
      {
        Periode prs = CalculDelais.determinerDelai(dateFgd, new DureeCalendaire(3));
        if (prs != null) {
          dateDebutPrs = prs.getDebut();
        } else {
          dateDebutPrs = null;
        }
      }
      else
      {
        dateDebutPrs = null;
      }
    }
    return calculerMinPraPrcPrs(dateDebutPra, dateDebutPrc, dateDebutPrs, p_demande.getIdentifiant());
  }
  
  private static JustificationAppelGaecReduit calculerMinPraPrcPrs(Damj p_datePRA, Damj p_datePRC, Damj p_datePRS, String p_idDemande)
  {
    if ((p_datePRA == null) && (p_datePRS == null)) {
      return new JustificationAppelGaecReduit(p_datePRC, "Prc", p_idDemande);
    }
    if ((p_datePRA == null) && (p_datePRC == null)) {
      return new JustificationAppelGaecReduit(p_datePRS, "Prs", p_idDemande);
    }
    if ((p_datePRC == null) && (p_datePRS == null)) {
      return new JustificationAppelGaecReduit(p_datePRA, "Pra", p_idDemande);
    }
    if (p_datePRA == null)
    {
      if (p_datePRC.estAvant(p_datePRS)) {
        return new JustificationAppelGaecReduit(p_datePRC, "Prc", p_idDemande);
      }
      return new JustificationAppelGaecReduit(p_datePRS, "Prs", p_idDemande);
    }
    if (p_datePRC == null)
    {
      if (p_datePRA.estAvant(p_datePRS)) {
        return new JustificationAppelGaecReduit(p_datePRA, "Pra", p_idDemande);
      }
      return new JustificationAppelGaecReduit(p_datePRS, "Prs", p_idDemande);
    }
    if (p_datePRS == null)
    {
      if (p_datePRA.estAvant(p_datePRC)) {
        return new JustificationAppelGaecReduit(p_datePRA, "Pra", p_idDemande);
      }
      return new JustificationAppelGaecReduit(p_datePRC, "Prc", p_idDemande);
    }
    if ((p_datePRA.estAvant(p_datePRC)) || (p_datePRA.coincideAvec(p_datePRC)))
    {
      if (p_datePRA.estAvant(p_datePRS)) {
        return new JustificationAppelGaecReduit(p_datePRA, "Pra", p_idDemande);
      }
      return new JustificationAppelGaecReduit(p_datePRS, "Prs", p_idDemande);
    }
    if (p_datePRA.estApres(p_datePRC))
    {
      if (p_datePRC.estAvant(p_datePRS)) {
        return new JustificationAppelGaecReduit(p_datePRC, "Prc", p_idDemande);
      }
      return new JustificationAppelGaecReduit(p_datePRS, "Prs", p_idDemande);
    }
    return new JustificationAppelGaecReduit(p_datePRA, "Pra", p_idDemande);
  }
  
  private static Damj getDateFaitGenerateurOdPrecedente(Demande p_demande)
  {
    Damj dateFgdPrecedent = null;
    try
    {
      dateFgdPrecedent = p_demande.getDateFaitGenerateurOdPrecedente();
    }
    catch (UnsupportedOperationException ex)
    {
      if (!"L'individu GAEC n'a pas été chargé en début de service.".equals(ex.getMessage())) {
        throw ex;
      }
    }
    return dateFgdPrecedent;
  }
}

/* Location:
 * Qualified Name:     DeterminationDateMinPraPrcPrs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */