package fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class RechercheQuantiteAppartenance
  implements OutilFonctionnel
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  
  public static ConstitutionQuantiteAffiliation rechercher(Demande p_demande, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    if ((p_demande == null) || (p_demande.getDemandeur() == null)) {
      return null;
    }
    Collection<Pra> listePra = null;
    if ((p_demande.getDossierAffectation() != null) && (((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit() != null) && (((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit().isEstProduitValide()))
    {
      ActiviteSalarie periodeActiviteSalariee = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
      
      boolean contexteRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE");
      
      DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
      donneesEntreeDeterminationListePra.setDemande(p_demande);
      donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_QUANTITE_APPARTENANCE);
      donneesEntreeDeterminationListePra.setActiviteSalarie(periodeActiviteSalariee);
      donneesEntreeDeterminationListePra.setForcerReglementRecharge(contexteRechargement);
      donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(false);
      listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    }
    if ((listePra == null) || (listePra.isEmpty())) {
      return null;
    }
    for (Iterator<Pra> iter = listePra.iterator(); iter.hasNext();)
    {
      Pra pra = (Pra)iter.next();
      ConstitutionQuantiteAffiliation qa = determinerQuantiteAppartenancePRA(p_demande, pra, p_avecPeriodeNonAttestee);
      if (qa != null) {
        return qa;
      }
    }
    return null;
  }
  
  public static ConstitutionQuantiteAffiliation determinerQuantiteAppartenancePRA(Demande p_demande, Pra p_pra, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    Chronologie passeProfessionnel = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    ConstitutionQuantiteAffiliation qteAppartenance = null;
    
    JustificationAffiliation justif = new JustificationAffiliation();
    
    Reglement reglementAppartenance = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheQuantiteAppartenance.getInstance().determinerReglement(p_demande);
    
    QuantitesAppartenance quantitesAppartenance = null;
    
    Quantite quantiteAffiliationForcee = p_demande.getDonneesTemporaires().getQuantiteAffiliation();
    if (quantiteAffiliationForcee != null)
    {
      quantitesAppartenance = new QuantitesAppartenance();
      quantitesAppartenance.putQuantiteAffiliation(quantiteAffiliationForcee);
    }
    else
    {
      ChronologieStandard chronoComplete = new ChronologieStandard();
      Chronologie chronoPeriodesParticipantes = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(null, p_pra, passeProfessionnel, p_avecPeriodeNonAttestee);
      
      chronoComplete.ajouter(chronoPeriodesParticipantes);
      
      Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(p_pra, passeProfessionnel);
      chronoComplete.ajouter(chronoActivitesAssimilables);
      
      quantitesAppartenance = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(p_demande, justif, p_pra, chronoComplete, reglementAppartenance);
    }
    Unite unite = null;
    Quantite qteAffiliation = null;
    Quantite qteAssimilation = null;
    BigDecimal valAcquise = null;
    BigDecimal valRequise = null;
    
    String contexteReglement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE") ? "RECHARGE" : null;
    
    List listeUnite = AccesListeUnitesReglement.get(reglementAppartenance, null).getListeUnites();
    boolean acquisSuperieurRequis = false;
    Iterator iter = listeUnite.iterator();
    while ((iter.hasNext()) && (!acquisSuperieurRequis))
    {
      unite = (Unite)iter.next();
      
      qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      if (qteAffiliation == null) {
        qteAffiliation = new Quantite("0", unite);
      }
      qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      if (qteAssimilation == null) {
        qteAssimilation = new Quantite("0", unite);
      }
      valAcquise = qteAffiliation.getValeur().add(qteAssimilation.getValeur());
      
      valRequise = p_pra.getQuantiteAffiliationRequise(unite).getValeur();
      
      boolean creerJustificationAffiliationForcee = ("RECHARGE".equals(contexteReglement)) && ((p_demande.getDonneesTemporaires().getQuantiteAffiliation() == null) || (p_demande.getDonneesTemporaires().getQuantiteAffiliation().getUnite().equals(unite)));
      if ((valAcquise.compareTo(valRequise) >= 0) || (creerJustificationAffiliationForcee))
      {
        if (quantitesAppartenance.estEnConflit()) {
          p_demande.setLiquideeAvecConflits(true);
        }
        qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
        
        qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
        
        qteAppartenance = new ConstitutionQuantiteAffiliation();
        qteAppartenance.setArticle3(p_pra.getArticle3());
        qteAppartenance.setDureeInitiale(p_pra.getDureeInitiale());
        qteAppartenance.setPeriodePRA(new Periode(p_pra.getDebut(), p_pra.getFin()));
        qteAppartenance.setQuantiteAffiliationAcquise(qteAffiliation);
        qteAppartenance.setQuantiteAssimilationAcquise(qteAssimilation);
        
        justif.setPeriodePraRetenue(p_pra);
        justif.setAppartenanceCalculee(qteAppartenance.getQuantiteAcquise());
        if (((DossierExamen)p_demande.getDossierExamen()).getConstitutionReglementApplicable() != null) {
          justif.setReglementApplicable(((DossierExamen)p_demande.getDossierExamen()).getConstitutionReglementApplicable().getReglement());
        }
        qteAppartenance.setJustificationAffiliation(justif);
        
        acquisSuperieurRequis = true;
      }
    }
    if (qteAppartenance != null)
    {
      iter = listeUnite.iterator();
      boolean ok = false;
      while ((iter.hasNext()) && (!ok))
      {
        unite = (Unite)iter.next();
        if (!unite.equals(qteAffiliation.getUnite()))
        {
          qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
          if (qteAffiliation == null) {
            qteAffiliation = new Quantite("0", unite);
          }
          qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
          if (qteAssimilation == null) {
            qteAssimilation = new Quantite("0", unite);
          }
          qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
          
          qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
          
          qteAppartenance.setQuantiteAffiliationAcquiseSecondaire(qteAffiliation);
          qteAppartenance.setQuantiteAssimilationAcquiseSecondaire(qteAssimilation);
          
          ok = true;
        }
      }
    }
    return qteAppartenance;
  }
  
  public static ConstitutionQuantiteAffiliation determinerQuantiteAppartenancePRAInsuffisante(DossierExamen p_dossierExamen, Pra p_pra, boolean p_avecPeriodeNonAttestee, ActiviteSalarie p_periodeForcee)
    throws ApplicativeException
  {
    Chronologie passeProfessionnel = p_dossierExamen.getDemande().getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    ActiviteSalarie periodeActiviteSalariee = null;
    
    JustificationAffiliation justif = new JustificationAffiliation();
    if (p_periodeForcee != null) {
      periodeActiviteSalariee = p_periodeForcee;
    } else {
      periodeActiviteSalariee = p_dossierExamen.getFaitGenerateur().getPeriodeFaitGenerateur();
    }
    Reglement reglementAppartenance = periodeActiviteSalariee.getReglement();
    
    QuantitesAppartenance quantitesAppartenance = null;
    
    Quantite quantiteAffiliationForcee = ((Demande)p_dossierExamen.getDemande()).getDonneesTemporaires().getQuantiteAffiliation();
    if (quantiteAffiliationForcee != null)
    {
      quantitesAppartenance = new QuantitesAppartenance();
      quantitesAppartenance.putQuantiteAffiliation(quantiteAffiliationForcee);
    }
    else
    {
      Chronologie chronoPeriodesParticipantes = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(null, p_pra, passeProfessionnel, p_avecPeriodeNonAttestee);
      
      quantitesAppartenance = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(p_dossierExamen.getDemande(), justif, p_pra, chronoPeriodesParticipantes, reglementAppartenance);
    }
    String contexteReglement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_dossierExamen.getDemande(), "RECHARGE") ? "RECHARGE" : null;
    
    List listeUnite = AccesListeUnitesReglement.get(reglementAppartenance, contexteReglement).getListeUnites();
    
    Unite unite = (Unite)listeUnite.get(0);
    Unite unite2 = listeUnite.size() > 1 ? (Unite)listeUnite.get(1) : null;
    
    Quantite qteAffiliation = null;
    Quantite qteAffiliation2 = null;
    Quantite qteAssimilation = null;
    Quantite qteAssimilation2 = null;
    
    qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
    if (qteAffiliation == null) {
      qteAffiliation = new Quantite("0", unite);
    }
    qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
    if (qteAssimilation == null) {
      qteAssimilation = new Quantite("0", unite);
    }
    qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
    
    qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
    if (unite2 != null)
    {
      qteAffiliation2 = quantitesAppartenance.getQuantiteAffiliation(unite2);
      if (qteAffiliation2 == null) {
        qteAffiliation2 = new Quantite("0", unite2);
      }
      qteAssimilation2 = quantitesAppartenance.getQuantiteAssimilation(unite2);
      if (qteAssimilation2 == null) {
        qteAssimilation2 = new Quantite("0", unite2);
      }
      qteAffiliation2 = new Quantite(qteAffiliation2.getValeur().setScale(10, 1), qteAffiliation2.getUnite());
      
      qteAssimilation2 = new Quantite(qteAssimilation2.getValeur().setScale(10, 1), qteAssimilation2.getUnite());
    }
    ConstitutionQuantiteAffiliation qteAppartenance = new ConstitutionQuantiteAffiliation();
    
    qteAppartenance.setDureeInitiale(p_pra.getDureeInitiale());
    qteAppartenance.setPeriodePRA(new Periode(p_pra.getDebut(), p_pra.getFin()));
    qteAppartenance.setQuantiteAffiliationAcquise(qteAffiliation);
    qteAppartenance.setQuantiteAssimilationAcquise(qteAssimilation);
    qteAppartenance.setQuantiteAffiliationAcquiseSecondaire(qteAffiliation2);
    qteAppartenance.setQuantiteAssimilationAcquiseSecondaire(qteAssimilation2);
    
    justif.setPeriodePraRetenue(p_pra);
    justif.setAppartenanceCalculee(qteAppartenance.getQuantiteAcquise());
    
    qteAppartenance.setJustificationAffiliation(justif);
    
    return qteAppartenance;
  }
  
  public static Quantite[] determinerAppartenanceInsuffisante(Demande p_demande, ActiviteSalarie p_pas, boolean p_avecPeriodeNonAttestee, ConditionQuantiteAffiliation p_capa07)
    throws ApplicativeException
  {
    if ((p_demande == null) || (p_demande.getDemandeur() == null)) {
      return null;
    }
    boolean estPeriodeFctForcee = p_demande.getDonneesTemporaires().getPeriodeFctARetenir() != null;
    
    Reglement reglementPropose = p_pas.getReglement();
    boolean estEnContexteDeRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE");
    if (estEnContexteDeRechargement)
    {
      EreRechargement ereRechargement = (EreRechargement)p_demande.getEvenementReferenceExamen();
      reglementPropose = ereRechargement.getReglementForcePourRechargement();
    }
    boolean contexteRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE");
    
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setDemande(p_demande);
    donneesEntreeDeterminationListePra.setActiviteSalarie(p_pas);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(contexteRechargement);
    donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(contexteRechargement);
    donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_REGLEMENT_APPLICABLE);
    Collection<Pra> listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    
    Pra praQteRequiseLaPlusPetite = fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.RechercheQuantiteAppartenance.getInstance().recherchePraDontQteRequiseLaPlusPetite(listePra);
    
    JustificationAffiliation justif = new JustificationAffiliation();
    QuantitesAppartenance qteAppartenanceRetenue = null;
    if (estPeriodeFctForcee)
    {
      qteAppartenanceRetenue = premierExamen(p_demande, praQteRequiseLaPlusPetite, reglementPropose, p_avecPeriodeNonAttestee, justif);
      QuantitesAppartenance qteAppartenanceDeuxiemeExamen = null;
      if (RechercheReglementApplicable.determineConditionPram(p_demande, p_pas, reglementPropose, p_avecPeriodeNonAttestee))
      {
        justif = new JustificationAffiliation();
        qteAppartenanceDeuxiemeExamen = deuxiemeExamen(p_demande, praQteRequiseLaPlusPetite, reglementPropose, p_avecPeriodeNonAttestee, justif);
      }
      if (qteAppartenanceDeuxiemeExamen != null) {
        qteAppartenanceRetenue = qteAppartenanceDeuxiemeExamen;
      }
    }
    else
    {
      qteAppartenanceRetenue = deuxiemeExamen(p_demande, praQteRequiseLaPlusPetite, reglementPropose, p_avecPeriodeNonAttestee, justif);
    }
    if (qteAppartenanceRetenue == null)
    {
      Quantite zero = new Quantite("0", UniteAffiliation.JOUR);
      return new Quantite[] { zero, zero };
    }
    justificationAffiliation(p_capa07, qteAppartenanceRetenue, praQteRequiseLaPlusPetite, justif);
    
    return transformeQuantiteAppartenanceEnQuantite(qteAppartenanceRetenue);
  }
  
  private static void justificationAffiliation(ConditionQuantiteAffiliation p_capa07, QuantitesAppartenance p_qteAppartenance, Pra p_pra, JustificationAffiliation p_justif)
  {
    Quantite qteAffiliation2 = null;
    Quantite qteAssimilation2 = null;
    Quantite qteAffiliation = p_qteAppartenance.getQuantiteAffiliation(p_qteAppartenance.getUniteAppartenancePrincipale());
    Quantite qteAssimilation = p_qteAppartenance.getQuantiteAssimilation(p_qteAppartenance.getUniteAppartenancePrincipale());
    if (qteAffiliation != null) {
      qteAffiliation = new Quantite(qteAffiliation.getValeur().setScale(10, 1), qteAffiliation.getUnite());
    }
    if (qteAssimilation != null) {
      qteAssimilation = new Quantite(qteAssimilation.getValeur().setScale(10, 1), qteAssimilation.getUnite());
    }
    if (p_qteAppartenance.getUniteAppartenanceSecondaire() != null)
    {
      qteAffiliation2 = p_qteAppartenance.getQuantiteAffiliation(p_qteAppartenance.getUniteAppartenanceSecondaire());
      qteAssimilation2 = p_qteAppartenance.getQuantiteAssimilation(p_qteAppartenance.getUniteAppartenanceSecondaire());
      if (qteAffiliation2 != null) {
        qteAffiliation2 = new Quantite(qteAffiliation2.getValeur().setScale(10, 1), qteAffiliation2.getUnite());
      }
      if (qteAssimilation2 != null) {
        qteAssimilation2 = new Quantite(qteAssimilation2.getValeur().setScale(10, 1), qteAssimilation2.getUnite());
      }
    }
    ConstitutionQuantiteAffiliation constitutionQuantiteAffiliation = new ConstitutionQuantiteAffiliation();
    
    constitutionQuantiteAffiliation.setDureeInitiale(p_pra.getDureeInitiale());
    
    constitutionQuantiteAffiliation.setPeriodePRA(new Periode(p_pra.getDebut(), p_pra.getFin()));
    constitutionQuantiteAffiliation.setQuantiteAffiliationAcquise(qteAffiliation);
    constitutionQuantiteAffiliation.setQuantiteAssimilationAcquise(qteAssimilation);
    constitutionQuantiteAffiliation.setQuantiteAffiliationAcquiseSecondaire(qteAffiliation2);
    constitutionQuantiteAffiliation.setQuantiteAssimilationAcquiseSecondaire(qteAssimilation2);
    
    p_justif.setPeriodePraRetenue(p_pra);
    if (constitutionQuantiteAffiliation.getQuantiteAssimilationAcquise() != null) {
      p_justif.setAppartenanceCalculee(constitutionQuantiteAffiliation.getQuantiteAcquise());
    } else {
      p_justif.setAppartenanceCalculee(constitutionQuantiteAffiliation.getQuantiteAffiliationAcquise());
    }
    constitutionQuantiteAffiliation.setJustificationAffiliation(p_justif);
    p_capa07.setJustificationAffiliation(constitutionQuantiteAffiliation.getJustificationAffiliation());
  }
  
  private static Quantite[] transformeQuantiteAppartenanceEnQuantite(QuantitesAppartenance p_quantitesAppartenance)
  {
    Quantite[] retourQte = new Quantite[2];
    
    retourQte[0] = new Quantite(Mathematiques.arrondiASup(p_quantitesAppartenance.getQuantiteAppartenance(p_quantitesAppartenance.getUniteAppartenancePrincipale()).getValeur(), 10), p_quantitesAppartenance.getUniteAppartenancePrincipale());
    if (p_quantitesAppartenance.getUniteAppartenanceSecondaire() != null) {
      retourQte[1] = new Quantite(Mathematiques.arrondiASup(p_quantitesAppartenance.getQuantiteAppartenance(p_quantitesAppartenance.getUniteAppartenanceSecondaire()).getValeur(), 10), p_quantitesAppartenance.getUniteAppartenanceSecondaire());
    }
    return retourQte;
  }
  
  private static QuantitesAppartenance premierExamen(Demande p_demande, Pra p_pra, Reglement p_reglement, boolean p_avecPeriodeNonAttestee, JustificationAffiliation p_justif)
    throws ApplicativeException
  {
    Chronologie chronoPAS = RechercheReglementApplicable.determinerActivitesParticipantes(p_demande, p_pra, p_reglement, p_avecPeriodeNonAttestee, true);
    
    QuantitesAppartenance quantitesAppartenance = verifierConditionAffiliation(p_demande, p_pra, chronoPAS, p_reglement, p_justif);
    
    return quantitesAppartenance;
  }
  
  private static QuantitesAppartenance deuxiemeExamen(Demande p_demande, Pra p_pra, Reglement p_reglement, boolean p_avecPeriodeNonAttestee, JustificationAffiliation p_justif)
    throws ApplicativeException
  {
    Chronologie chronoPAS = RechercheReglementApplicable.determinerActivitesParticipantes(p_demande, p_pra, p_avecPeriodeNonAttestee);
    
    QuantitesAppartenance quantitesAppartenance = verifierConditionAffiliation(p_demande, p_pra, chronoPAS, p_reglement, p_justif);
    
    return quantitesAppartenance;
  }
  
  private static QuantitesAppartenance verifierConditionAffiliation(Demande p_demande, Pra p_pra, Chronologie p_chronoPAS, Reglement p_reglementAppartenance, JustificationAffiliation p_justif)
    throws ApplicativeException
  {
    QuantitesAppartenance quantitesAppartenance = null;
    
    Quantite quantiteAffiliationForcee = p_demande.getDonneesTemporaires().getQuantiteAffiliation();
    if (quantiteAffiliationForcee != null)
    {
      quantitesAppartenance = new QuantitesAppartenance();
      quantitesAppartenance.putQuantiteAffiliation(quantiteAffiliationForcee);
    }
    else
    {
      quantitesAppartenance = fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(p_demande, p_justif, p_pra, p_chronoPAS, p_reglementAppartenance);
    }
    String contexteReglement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE") ? "RECHARGE" : null;
    
    List listeUnites = AccesListeUnitesReglement.get(p_reglementAppartenance, contexteReglement).getListeUnites();
    
    Unite unite1 = (Unite)listeUnites.get(0);
    quantitesAppartenance.setUniteAppartenancePrincipale(unite1);
    if (listeUnites.size() > 1)
    {
      Unite unite2 = (Unite)listeUnites.get(1);
      quantitesAppartenance.setUniteAppartenanceSecondaire(unite2);
    }
    return quantitesAppartenance;
  }
}

/* Location:
 * Qualified Name:     RechercheQuantiteAppartenance
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */