package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Reprise;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import java.math.BigDecimal;

public class ConstitutionCoefficientSaisonnierPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  private BigDecimal m_coefficientSaisonnier = new BigDecimal("1");
  private boolean m_coefficientSaisonnierDetermine = false;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution du coefficient saisonnier.");
    }
    if (getAttribution(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution est null pour la constitution du coefficient saisonnier.");
    }
    if (((getAttribution(p_contexte) instanceof Reprise)) && 
      (((Reprise)getAttribution(p_contexte)).getAttributionPrecedente() == null)) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution précédente est null: constitution du coefficient saisonnier impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionDateAttribution.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientSaisonnierPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientSaisonnier.class, "demarrer", "\t\t******** Début Parcours ConstitutionCoefficientSaisonnierPourReprise ********");
    }
    Resultat resultatCEPR12 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    DonneesTemporaires donneestemporaires = demande.getDonneesTemporaires();
    if (donneestemporaires.getCoefficientSaisonnier() != null)
    {
      m_coefficientSaisonnierDetermine = true;
      m_coefficientSaisonnier = donneestemporaires.getCoefficientSaisonnier();
    }
    ConstitutionCoefficientSaisonnier cepr12 = new ConstitutionCoefficientSaisonnier();
    if (m_coefficientSaisonnierDetermine)
    {
      cepr12.setCoefficientSaisonnierRetenu(m_coefficientSaisonnier);
    }
    else
    {
      ElementBaseIndemnisation elementBaseIndemnisation = dossierExamenCourant.getAttributionPrecedente().getElementBaseIndemnisation();
      cepr12.setCoefficientSaisonnierRetenu(elementBaseIndemnisation.getCoefficientSaisonnier());
    }
    dossierExamenCourant.setConstitutionCoefficientSaisonnier(cepr12);
    
    return resultatCEPR12;
  }
  
  private DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
  
  private AttributionSpec getAttribution(Contexte p_contexte)
  {
    return ((Demande)((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec()).getAttribution();
  }
}

/* Location:
 * Qualified Name:     ConstitutionCoefficientSaisonnierPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */