package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p02.calcul.dom.Montant;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeReglementaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Od;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Readmission;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DeterminationCarence;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DeterminationCompetence;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DeterminationDiffere;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Reliquat;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.dom.TraitementReliquat;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilConstructionDonneesEntreesRecuperationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionDecorReglementaire;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.avant.ExecutionAvantImpossibleException;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCge01;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.AppelAvant;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConstitutionProduitResultant
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA15 = new Resultat(0);
    
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant cepa15 = new fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant();
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    dossierExamenCourant.setConstitutionProduitResultant(cepa15);
    if (verifierPreconditions(contexte))
    {
      int contexteExamen = getContexteExamen(contexte);
      if (contexteExamen == 3) {
        constituerProduitResultant(contexte);
      } else if (contexteExamen == 4) {
        constituerProduitResultantSecteurPublic(contexte);
      }
    }
    OutilTrace.tracerFinParcours();
    return resultatCEPA15;
  }
  
  private void constituerProduitResultant(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    Quantite capitalDroitCourant = obtenirCapitalCourant(contexte);
    
    Quantite capitalDroitPrecedent = obtenirCapitalPrecedent(contexte);
    
    MontantAsuSpec montantPrecedent = obtenirMontantDroitPrecedent(contexte);
    MontantAsuSpec montantCourant = obtenirMontantDroitCourant(contexte);
    
    Damj pointDepartUnique = determinerPointDepartUnique(demandeCourante.getAttribution(), montantCourant, montantPrecedent);
    
    Quantite dureeIntermediareDroitCourant = determinerDureeDroitCourant(dossierExamenCourant, pointDepartUnique);
    
    Quantite capitalComparatifDroitCourant = obtenirCapitalPourComparaison(dureeIntermediareDroitCourant, montantCourant);
    
    Quantite dureeIntermediaireDroitPrecedant = determinerDureeDroitPrecedentPourCalculCapital(demandeCourante, pointDepartUnique);
    Quantite capitalComparatifDroitPrecedent = obtenirCapitalPourComparaison(dureeIntermediaireDroitPrecedant, montantPrecedent);
    
    Quantite dureeDroitPrecedent = null;
    if (montantPrecedent.getMontantBrut().getValeur().doubleValue() == 0.0D) {
      dureeDroitPrecedent = new QuantiteJour("0");
    } else {
      dureeDroitPrecedent = new QuantiteJour(Mathematiques.diviseASup(capitalDroitPrecedent.getValeur(), montantPrecedent.getMontantBrut().getValeur(), 0));
    }
    if (capitalComparatifDroitCourant.compareTo(capitalComparatifDroitPrecedent) == -1)
    {
      Readmission readmissionCourante = (Readmission)dossierExamenCourant.changerEtat(11);
      readmissionCourante.setNatureDecision(11);
      DomLiquidationAssurance.getDemande(contexte).getObjectifCourant().setSousType(11);
      demandeCourante.setDemandeOrigine((DemandeAssuranceSpec)dom.getAttributionPrecedente().getDemande());
      dossierExamenCourant.getConstitutionProduitResultant().setCapitalDroitPrecedent(capitalDroitPrecedent);
      dossierExamenCourant.getConstitutionProduitResultant().setMontantDroitPrecedent(montantPrecedent.getMontantBrut());
      dossierExamenCourant.getConstitutionProduitResultant().setDureeDroitPrecedent(dureeDroitPrecedent);
      
      DeterminationCompetence.determinerCompetencesProduitResultant(demandeCourante, capitalDroitCourant.getValeur(), capitalDroitPrecedent.getValeur());
      
      determinationElementsDroits(readmissionCourante);
    }
    else
    {
      dossierExamenCourant.getConstitutionProduitResultant().setCapitalDroitPrecedent(capitalDroitPrecedent);
    }
  }
  
  private void constituerProduitResultantSecteurPublic(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    
    verifieContexteDonneesForceesPresentes(demandeCourante);
    
    MontantAsuSpec montantCourant = obtenirMontantDroitCourant(contexte);
    MontantAsuSpec montantPrecedentSP = obtenirMontantDroitPrecedentSecteurPublic(contexte);
    
    Quantite capitalDroitCourant = obtenirCapitalCourant(contexte);
    
    Quantite capitalDroitPrecedentSP = affecterCapitalDroitPrecedentSP(demandeCourante);
    
    Damj pointDepartUnique = determinerPointDepartUnique(demandeCourante.getAttribution(), montantCourant, montantPrecedentSP);
    
    Quantite dureeDroitCourant = determinerDureeDroitCourant(dossierExamenCourant, pointDepartUnique);
    
    capitalDroitCourant = obtenirCapitalPourComparaison(dureeDroitCourant, montantCourant);
    
    Quantite dureeDroitPrecedentSP = new QuantiteJour("0");
    BigDecimal montantBrut = montantPrecedentSP.getMontantBrut().getValeur();
    if (montantBrut.compareTo(BigDecimal.ZERO) > 0) {
      dureeDroitPrecedentSP = new QuantiteJour(Mathematiques.diviseASup(capitalDroitPrecedentSP.getValeur(), montantPrecedentSP.getMontantBrut().getValeur(), 0));
    }
    dossierExamenCourant.getConstitutionProduitResultant().setMontantDroitPrecedent(montantPrecedentSP.getMontantBrut());
    dossierExamenCourant.getConstitutionProduitResultant().setDureeDroitPrecedent(dureeDroitPrecedentSP);
    dossierExamenCourant.getConstitutionProduitResultant().setCapitalDroitPrecedent(capitalDroitPrecedentSP);
    if (capitalDroitCourant.compareTo(capitalDroitPrecedentSP) == -1)
    {
      Readmission readmissionCourante = (Readmission)dossierExamenCourant.changerEtat(11);
      DomLiquidationAssurance.getDemande(contexte).getObjectifCourant().setSousType(11);
      
      DeterminationCompetence.determinerCompetencesProduitResultant(demandeCourante, capitalDroitCourant.getValeur(), capitalDroitPrecedentSP.getValeur());
      
      determinationElementsDroitsSP(readmissionCourante);
    }
  }
  
  protected boolean verifierPreconditions(Contexte contexte)
  {
    boolean preconditionsValides = true;
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    if ((dossierExamenCourant.getConditionsAttributionAdmission() != null) && (dossierExamenCourant.getConditionsAttributionAdmission().estSatisfait())) {
      preconditionsValides = true;
    } else {
      preconditionsValides = false;
    }
    return preconditionsValides;
  }
  
  private void determinationElementsDroits(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    DossierExamenAssuranceSpec attributionPrecedente = attributionCourante.getAttributionPrecedente();
    
    constitutionDurees(attributionCourante);
    
    reportElementsDroits(attributionCourante, attributionPrecedente);
    constitutionMontant(attributionCourante);
  }
  
  private void determinationElementsDroitsSP(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    constitutionDurees(attributionCourante);
    
    reportElementsDroitsSP(attributionCourante);
    constitutionMontant(attributionCourante);
  }
  
  private Quantite affecterCapitalDroitPrecedentSP(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Quantite capitalProduitPrecedent = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    ((Od)demandeCourante.getAttribution()).getConstitutionProduitResultant().setCapitalDroitPrecedent(capitalProduitPrecedent);
    
    return capitalProduitPrecedent;
  }
  
  private Quantite obtenirCapitalCourant(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demandeCourante = DomLiquidationAssurance.getDemande(contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    return dossierExamenCourant.getConstitutionMontantsBruts().getCapitalInitialBrut();
  }
  
  private Quantite obtenirCapitalPrecedent(Contexte contexte)
    throws CoucheLogiqueException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    DossierExamen dossierExamen = (DossierExamen)dom.getDemande().getListeDossiersExamen().get(0);
    Quantite qteReliquat = dom.getDemande().getTraitementReliquat().getReliquat().getQuantiteReliquat();
    
    AttributionSpec attributionPrecedente = dossierExamen.getAttributionPrecedente();
    
    GammeAsuSpec gamme = (GammeAsuSpec)attributionPrecedente.getGamme();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant(attributionPrecedente);
    donneesEntreesRecuperationMontant.setDateCalculMontant(dossierExamen.getDateAttribution());
    
    Quantite montantProduitPrecedent = DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant).getMontantBrut();
    
    Quantite capitalProduitPrecedent = AppelCalculParLiquidationAsu.calculerCapital(attributionPrecedente, dossierExamen.getDateAttribution(), dossierExamen.getDateAttribution(), qteReliquat);
    
    dossierExamen.getConstitutionProduitResultant().setMontantDroitPrecedent(montantProduitPrecedent);
    dossierExamen.getConstitutionProduitResultant().setDureeDroitPrecedent(qteReliquat);
    dossierExamen.getConstitutionProduitResultant().setCapitalDroitPrecedent(capitalProduitPrecedent);
    
    return capitalProduitPrecedent;
  }
  
  private int getContexteExamen(Contexte contexte)
  {
    return ((DomLiquidationAssurance)contexte.getDonnees()).getContexteExamen();
  }
  
  private void constitutionDurees(Readmission attributionCourante)
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    
    Quantite dureeAServir = ((Demande)attributionCourante.getDemande()).getTraitementReliquat().getReliquat().getQuantiteReliquat();
    cepa15.setConstitutionDurees(new ConstitutionDurees());
    cepa15.getConstitutionDurees().ajouterDuree(new DureeIndemnisation());
    cepa15.getConstitutionDurees().getDureeIndemnisation().setDureeEffective(dureeAServir);
    cepa15.getConstitutionDurees().getDureeIndemnisation().setDureeTheorique(dureeAServir);
  }
  
  private void reportElementsDroitsSP(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    Demande demandeCourante = (Demande)attributionCourante.getDemande();
    
    QuantiteEuro sjrDroitPrecedentSP = new QuantiteEuro(demandeCourante.getDonneesTemporaires().getSjrSP().getValeur());
    Damj dateAttributionDroitAnterieur = demandeCourante.getDonneesTemporaires().getDateAttributionDroitAnterieurSp();
    
    Sjr sjriProduitPrecedent = new Sjr(sjrDroitPrecedentSP.getValeur(), dateAttributionDroitAnterieur, null);
    
    Reglement reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A2b")))
    {
      EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateAttributionDroitAnterieur);
      BigDecimal plafond = evtParam.getPlafond().multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
      
      Sjr sjripProduitPrecedent = new Sjr(sjriProduitPrecedent.getSalaire().min(plafond), sjriProduitPrecedent.getDateDepart(), null);
      cepa15.setSjrrpProduitPrecedent(sjripProduitPrecedent);
    }
    else
    {
      cepa15.setSjrrpProduitPrecedent(RevalorisationSalaire.revaloriserSjr(sjriProduitPrecedent, attributionCourante.getDateAttribution()));
    }
  }
  
  private void reportElementsDroits(Readmission attributionCourante, DossierExamenAssuranceSpec attributionPrecedente)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    
    Sjr sjriProduitPrecedent = new Sjr(attributionPrecedente.getAccesseurDroits().getSjrInitial().getValeur(), attributionPrecedente.getAccesseurDroits().getDateEffetSjr(), null);
    
    Reglement reglementApplicableCourant = attributionCourante.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A2b")))
    {
      EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(attributionCourante.getDateAttribution());
      
      BigDecimal plafond = evtParam.getPlafond().multiply(new BigDecimal("12")).divide(new BigDecimal("365"), 2, 1);
      
      Sjr sjripProduitPrecedent = new Sjr(sjriProduitPrecedent.getSalaire().min(plafond), sjriProduitPrecedent.getDateDepart(), null);
      cepa15.setSjrrpProduitPrecedent(sjripProduitPrecedent);
    }
    else
    {
      cepa15.setSjrrpProduitPrecedent(RevalorisationSalaire.revaloriserSjr(sjriProduitPrecedent, attributionCourante.getDateAttribution()));
    }
  }
  
  private void constitutionMontant(Readmission attributionCourante)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant cepa15 = attributionCourante.getConstitutionProduitResultant();
    
    cepa15.setConstitutionMontantsBruts(new ConstitutionMontantsBruts());
    
    GammeAsuSpec gamme = (GammeAsuSpec)attributionCourante.getGamme();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant(attributionCourante);
    donneesEntreesRecuperationMontant.setDateCalculMontant(attributionCourante.getDateEffet());
    
    Montant montantAAttribution = (Montant)DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
    if (montantAAttribution != null)
    {
      cepa15.getConstitutionMontantsBruts().setMontantJournalierBrut(montantAAttribution.getMontantPrecompteEffectif());
      cepa15.getConstitutionMontantsBruts().setMontantBrutSansDeduction(montantAAttribution.getMontantBrut());
      cepa15.getConstitutionMontantsBruts().setMontantBase(montantAAttribution.getBase());
      cepa15.getConstitutionMontantsBruts().setMontantMini(montantAAttribution.getMini());
      cepa15.getConstitutionMontantsBruts().setMontantPlafond(montantAAttribution.getPlafond());
      cepa15.getConstitutionMontantsBruts().setMontantPlancher(montantAAttribution.getPlancher());
      cepa15.getConstitutionMontantsBruts().setMontantBrutSansPensionInvaliditeADeduire(montantAAttribution.getMontantBrutSansPensionInvaliditeADeduire());
      
      cepa15.getConstitutionMontantsBruts().setPensionInvaliditeADeduirePriseEnCompte(montantAAttribution.getPensionInvaliditeADeduirePriseEnCompte());
      
      cepa15.getConstitutionMontantsBruts().setMontantJournalierAvantageVieillesse(montantAAttribution.getMontantJournalierAvantageVieillesse());
      cepa15.getConstitutionMontantsBruts().setMontantJournalierAvantageVieillesseDeduit(montantAAttribution.getMontantJournalierAvantageVieillesseDeduit());
      
      cepa15.getConstitutionMontantsBruts().setCrc(montantAAttribution.getCrc());
    }
    Quantite nbJourIndemnisesTheorique = attributionCourante.getConstitutionProduitResultant().getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(attributionCourante, attributionCourante.getDateAttribution(), attributionCourante.getDateAttribution(), nbJourIndemnisesTheorique);
    
    cepa15.getConstitutionMontantsBruts().setCapitalInitialBrut(capitalProduitCourant);
  }
  
  private MontantAsuSpec obtenirMontantDroitPrecedent(Contexte contexte)
    throws CoucheLogiqueException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    DossierExamen dossierExamenCourant = (DossierExamen)dom.getDemande().getDossierExamen();
    AttributionSpec attributionPrecedente = dossierExamenCourant.getAttributionPrecedente();
    
    GammeAsuSpec gamme = (GammeAsuSpec)attributionPrecedente.getGamme();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant(attributionPrecedente);
    donneesEntreesRecuperationMontant.setDateCalculMontant(dossierExamenCourant.getDateAttribution());
    
    MontantAsuSpec montantProduitPrecedent = DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
    
    dossierExamenCourant.getConstitutionProduitResultant().setMontantDroitPrecedent(new QuantiteEuro(montantProduitPrecedent.getMontantPrecompteEffectif().getValeur()));
    
    return montantProduitPrecedent;
  }
  
  private MontantAsuSpec obtenirMontantDroitCourant(Contexte contexte)
    throws CoucheLogiqueException
  {
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    DossierExamen dossierExamen = (DossierExamen)dom.getDemande().getDossierExamen();
    AttributionAssuranceSpec attributionCourante = (AttributionAssuranceSpec)dossierExamen;
    
    GammeAsuSpec gamme = (GammeAsuSpec)attributionCourante.getGamme();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = gamme.mapperDonneesEntreesRecuperationMontant(attributionCourante);
    donneesEntreesRecuperationMontant.setDateCalculMontant(dossierExamen.getDateAttribution());
    
    MontantAsuSpec montantProduitCourant = DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
    
    return montantProduitCourant;
  }
  
  private Damj determinerPointDepartUnique(AttributionAssuranceSpec attribution, MontantAsuSpec montantCourant, MontantAsuSpec montantPrecedant)
    throws ApplicativeException
  {
    try
    {
      ArrayList listeCarences = new ArrayList();
      Chronologie chronologieActiviteSalarie = new ChronologiePeriodes();
      Chronologie chronologieActiviteSalariePMC = new ChronologiePeriodes();
      Demande demande = (Demande)attribution.getDemande();
      
      ArrayList listeDelaisReports = DeterminationDiffere.determinerDiffere(demande);
      
      Periode periodeReference = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheCarences(demande);
      
      Periode periodeReferencePMC = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerDelaiRechercheComplementairePMC(demande);
      if (periodeReference != null) {
        chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesParticipantCarences(periodeReference, demande);
      }
      if (periodeReferencePMC != null) {
        chronologieActiviteSalariePMC = ConstructionChronologie.determinerChronoActivitesParticipantPMC(periodeReferencePMC, demande, chronologieActiviteSalarie);
      }
      DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
      
      ConstitutionDelais constitutionDelais = new ConstitutionDelais();
      dossierExamenCourant.setConstitutionDelais(constitutionDelais);
      
      constitutionDelais.setPeriodeReference91jours(periodeReference);
      
      Sjr sjrMontantMax = obtenirSjrDuMontantMax(attribution, montantCourant, montantPrecedant);
      ArrayList listeEnsembleCarences = DeterminationCarence.determinerCarences(chronologieActiviteSalarie, chronologieActiviteSalariePMC, demande, sjrMontantMax);
      
      Iterator it = listeEnsembleCarences.iterator();
      while (it.hasNext())
      {
        EnsembleCarences listeCarencesTemp = (EnsembleCarences)it.next();
        if (listeCarencesTemp != null) {
          listeCarences.addAll(listeCarencesTemp.getListeCarences());
        }
      }
      ResultatAvant resultatAvant = AppelAvant.executerAvant(attribution.getDemande().getDemandeur(), attribution.getDateEffet(), attribution.getProduit(), listeDelaisReports, listeCarences);
      
      return resultatAvant.getPji();
    }
    catch (ExecutionAvantImpossibleException e)
    {
      throw new CoucheLogiqueException("ASU_PR_CALI_L_CESSATION_PENDANT_AVANT", "Cessation pendant l'avant, impossible de determiner le PJI.");
    }
  }
  
  private Sjr obtenirSjrDuMontantMax(AttributionAssuranceSpec attribution, MontantAsuSpec montantCourant, MontantAsuSpec montantPrecedent)
  {
    Sjr sjrMontantMax = null;
    
    int compAdmCourant = attribution.getCompetence().getCompetenceAdministrative();
    int compAdmPrecedent = 0;
    if ((attribution.getAttributionPrecedente() == null) || (((Demande)attribution.getDemande()).getDonneesTemporaires().getSjrSP() != null))
    {
      if (montantCourant.getMontantBrut().compareTo(montantPrecedent.getMontantBrut()) >= 0)
      {
        sjrMontantMax = attribution.getElementBaseIndemnisation().getSjr();
      }
      else
      {
        Sjr sjrDonnesForcees = new Sjr(((Demande)attribution.getDemande()).getDonneesTemporaires().getSjrSP().getValeur(), ((Demande)attribution.getDemande()).getDonneesTemporaires().getTermePrcSp(), null);
        
        sjrMontantMax = sjrDonnesForcees;
      }
    }
    else if ((compAdmCourant == 1) && (compAdmPrecedent == 1))
    {
      if (montantCourant.getMontantPrecompte().compareTo(montantPrecedent.getMontantPrecompte()) >= 0) {
        sjrMontantMax = attribution.getElementBaseIndemnisation().getSjr();
      } else {
        sjrMontantMax = attribution.getAttributionPrecedente().getElementBaseIndemnisation().getSjr();
      }
    }
    else if (montantCourant.getMontantBrut().compareTo(montantPrecedent.getMontantBrut()) >= 0) {
      sjrMontantMax = attribution.getElementBaseIndemnisation().getSjr();
    } else {
      sjrMontantMax = attribution.getAttributionPrecedente().getElementBaseIndemnisation().getSjr();
    }
    return sjrMontantMax;
  }
  
  private Quantite obtenirCapitalPourComparaison(Quantite duree, MontantAsuSpec montant)
    throws ApplicativeException
  {
    Quantite montantRetenu = null;
    if (montant.getAvecPrecompteCRC()) {
      montantRetenu = new QuantiteEuro(montant.getMontantPrecompte());
    } else {
      montantRetenu = montant.getMontantBrut();
    }
    BigDecimal capital = duree.getValeur().multiply(montantRetenu.getValeur());
    return new QuantiteEuro(capital);
  }
  
  private Quantite determinerDureeDroitCourant(DossierExamen dossierExamen, Damj pointDepartUnique)
    throws CoucheLogiqueException
  {
    Quantite dureeEffective = dossierExamen.getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    IndividuSpec individu = dossierExamen.getDemande().getDemandeur();
    
    boolean bornerRetraite = true;
    DonneesTemporaires donneesForcees = ((Demande)dossierExamen.getDemande()).getDonneesTemporaires();
    if (donneesForcees != null) {
      bornerRetraite = !donneesForcees.isLeverBornageDureeEffectiveRetraite();
    }
    int duree = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDepartUnique, dureeEffective, bornerRetraite);
    return new Quantite(duree, DureeReglementaire.UNITE_DEFAUT);
  }
  
  private Quantite determinerDureeDroitPrecedentPourCalculCapital(Demande demandeCourante, Damj pointDepartUnique)
    throws CoucheLogiqueException
  {
    Quantite dureeReliquat = demandeCourante.getReliquat().getQuantiteReliquat();
    IndividuSpec individu = demandeCourante.getDemandeur();
    
    boolean bornerRetraite = true;
    DonneesTemporaires donneesForcees = demandeCourante.getDonneesTemporaires();
    if (donneesForcees != null) {
      bornerRetraite = !donneesForcees.isLeverBornageDureeEffectiveRetraite();
    }
    int duree = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDepartUnique, dureeReliquat, bornerRetraite);
    return new Quantite(duree, DureeReglementaire.UNITE_DEFAUT);
  }
  
  private void verifieContexteDonneesForceesPresentes(Demande demandeCourante)
    throws CoucheLogiqueException
  {
    Quantite capitalDroitPrecedentSP = demandeCourante.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    Quantite sjrDroitPrecedentSP = demandeCourante.getDonneesTemporaires().getSjrSP();
    Damj termePrcDroitPrecedentSP = demandeCourante.getDonneesTemporaires().getTermePrcSp();
    BigDecimal coefSaisonnierDroitprecedentSP = demandeCourante.getDonneesTemporaires().getCoefficientSaisonnierSp();
    BigDecimal coefTPDroitprecedentSP = demandeCourante.getDonneesTemporaires().getCoefficientTempsPartielSp();
    if (capitalDroitPrecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_CAPITAL_RELIQUAT");
    }
    if (sjrDroitPrecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_SJR_SECTEUR_PUBLIC");
    }
    if (termePrcDroitPrecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_TERME_PRC_SP");
    }
    if (coefTPDroitprecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABS_COEFF_SAISONNIER_SP");
    }
    if (coefSaisonnierDroitprecedentSP == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABSENCE_COEFF_TP_SP");
    }
    TravailSpec dernierSinistre = ((DossierAffectation)demandeCourante.getDossierAffectation()).getSinistre();
    if (dernierSinistre != null)
    {
      Damj dateFCT = dernierSinistre.getDateFin();
      if ((dateFCT != null) && (termePrcDroitPrecedentSP.compareTo(dateFCT) > 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_INCOHERENCE_PRC_FCT_FORCEE_SP");
      }
      if ((dernierSinistre instanceof ActiviteSalarie))
      {
        ActiviteSalarie periode = (ActiviteSalarie)dernierSinistre;
        if ((periode.getDernierJourTravaillePaye() != null) && 
          (termePrcDroitPrecedentSP.compareTo(periode.getDernierJourTravaillePaye()) > 0)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_INCOH_PRC_DJTP_FORCEE_SP");
        }
      }
    }
  }
  
  private MontantAsuSpec obtenirMontantDroitPrecedentSecteurPublic(Contexte contexte)
    throws CoucheLogiqueException
  {
    MontantAsuSpec montantProduitPrecedentSP = null;
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = dom.getDemande();
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    Individu individu = (Individu)demande.getDemandeur();
    
    ElementBaseIndemnisation ebi = null;
    Competences conteneurCompetences = null;
    
    ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
    conteneur.setDateRecherche(dossierExamen.getDateAttribution());
    conteneur.setDateFinContrat(dossierExamen.getDateAttribution());
    conteneur.setBesoinCritereQualif(false);
    conteneur.setDemande(demande);
    DecorReglementaire decorReglementaireDateExamen = ConstitutionDecorReglementaire.recupererDecor(conteneur);
    
    ProduitAsuSpec produitPrecedant = (ProduitAsuSpec)decorReglementaireDateExamen.determinerProduitEffectifDeLaLigne(LigneAsuCge01.getInstance());
    
    ebi = new ElementBaseIndemnisation();
    ebi.setSjc(null);
    ebi.setSjr(new Sjr(demande.getDonneesTemporaires().getSjrSP().getValeur(), demande.getDonneesTemporaires().getDateAttributionDroitAnterieurSp(), null));
    
    ebi.setCoefficientSaisonnier(demande.getDonneesTemporaires().getCoefficientSaisonnierSp());
    ebi.setCoefficientTempsPartiel(demande.getDonneesTemporaires().getCoefficientTempsPartielSp());
    
    ebi.setIsConditionCaractereSaisonnierParRythme(false);
    
    ebi.setTypeCaractereSaisonnierRetenu(-1);
    
    ebi.setIsSjrBaseSurPourcentageSMIC(false);
    
    ebi.setReglementApplicableMontantRetenu(dossierExamen.getReglementApplicable());
    
    conteneurCompetences = new Competences();
    conteneurCompetences.setCompetenceAdministrative(2);
    conteneurCompetences.setCompetenceFinanciere(2);
    
    OutilConstructionDonneesEntreesRecuperationMontant outil = new OutilConstructionDonneesEntreesRecuperationMontant();
    DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant = outil.creerDonneesEntreesRecuperationMontant(ebi);
    donneesEntreesRecuperationMontant.setDateCalculMontant(dossierExamen.getDateAttribution());
    donneesEntreesRecuperationMontant.setIndividu(individu);
    donneesEntreesRecuperationMontant.setCompetences(conteneurCompetences);
    donneesEntreesRecuperationMontant.getDonneesCalculMontant().setProduit(produitPrecedant);
    
    montantProduitPrecedentSP = DeterminationMontant.determinerMontant(donneesEntreesRecuperationMontant);
    
    return montantProduitPrecedentSP;
  }
}

/* Location:
 * Qualified Name:     ConstitutionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */