package fr.unedic.cali.asu.cge01.p02.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Sjcip;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.SjrActiviteConservee;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P02;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.Iterator;

public class ConstitutionSjcPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjc impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjc impossible.");
    }
    if (dossierExamenCourant.getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution précédente est nulle : constitution du Sjc impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionSjcPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjcPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjcPourReprise.class, "demarrer", "\t\t******** Début Parcours ConstitutionSjcPourReprise ********");
    }
    Resultat resultat = new Resultat();
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamen = (DossierExamen)demandeCourante.getDossierExamen();
    
    ConstitutionSjc constitutionSjc = new ConstitutionSjc();
    dossierExamen.setConstitutionSjc(constitutionSjc);
    
    Reglement reglementApplicableCourant = dossierExamen.getReglementApplicable().getReglement();
    if (reglementApplicableCourant.equals(ProduitAsuCge01P02.getInstance().getReglement("A4")))
    {
      resultat.setEtat(0);
    }
    else
    {
      ConstitutionSjc constitutionSjcAttributionPrecedente = ((DossierExamen)dossierExamen.getAttributionPrecedente()).getConstitutionSjc();
      Sjcip sjcipAttributionPrecedente = null;
      if (constitutionSjcAttributionPrecedente != null)
      {
        sjcipAttributionPrecedente = constitutionSjcAttributionPrecedente.getSjcip();
        if (sjcipAttributionPrecedente != null)
        {
          Damj dateEffet = sjcipAttributionPrecedente.getDateEvenement();
          QuantiteEuro plafondSjc = sjcipAttributionPrecedente.getPlafond();
          QuantiteEuro sjcInitial = sjcipAttributionPrecedente.getSjcInitial();
          Sjcip sjcipCourant = new Sjcip(dateEffet, plafondSjc, sjcInitial);
          if (sjcipCourant != null)
          {
            Collection listeActivitesConservees = sjcipAttributionPrecedente.getListeSjrActiviteConserve();
            if (listeActivitesConservees != null)
            {
              Iterator itActiviteConservee = listeActivitesConservees.iterator();
              while (itActiviteConservee.hasNext()) {
                sjcipCourant.ajouterSjrActiviteConserve((SjrActiviteConservee)itActiviteConservee.next());
              }
            }
            dossierExamen.getConstitutionSjc().setSjcip(sjcipCourant);
            dossierExamen.getConstitutionSjc().setSjcrp(revaloriserSjc(dossierExamen.getDateAttribution(), dossierExamen.getConstitutionSjc().getSjcip()));
            
            resultat.setEtat(0);
          }
          else
          {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_SJCIP_COURANT_NULL");
          }
        }
        else
        {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_SJCIP_COURANT_NULL");
        }
      }
    }
    if (Log.isTraceActive(ConstitutionSjcPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjcPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjcPourReprise.class, "demarrer", "\t\t******** Résultat Parcours ConstitutionSjcPourReprise ********\n" + resultat);
      
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjcPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionSjcPourReprise.class, "demarrer", "\t\t******** Fin Parcours ConstitutionSjcPourReprise ********\n");
    }
    return resultat;
  }
  
  private Sjc revaloriserSjc(Damj p_dateRevalorisation, Sjcip p_sjcip)
  {
    Sjc sjcCourant = new Sjc(p_sjcip.getSjcInitial().getValeur(), p_sjcip.getDateEffet(), null);
    
    Sjc sjcrpCalcule = RevalorisationSalaire.revaloriserSjc(sjcCourant, p_dateRevalorisation);
    
    return sjcrpCalcule;
  }
}

/* Location:
 * Qualified Name:     ConstitutionSjcPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */