package fr.unedic.cali.asu.cge01.p02.migration.graphes;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Decision;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.Readmission;
import fr.unedic.cali.asu.cge01.p02.migration.recalcul.RecalculerCapitalDroitPrecedent;
import fr.unedic.cali.asu.cge01.p02.migration.recalcul.RecalculerConstituantsProduitResultant;
import fr.unedic.cali.asu.cge01.p02.migration.recalcul.RecalculerMontantBrutDroitPrecedent;
import fr.unedic.cali.asu.cge01.p02.migration.recalcul.RecalculerPji;
import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.autresdoms.cohab.dom.DemandeMigreeEnErreur;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeV1;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;

public class GrapheReadmissionDroitPrecedent
  extends GrapheReadmissionDroitCourant
{
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    
    objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(11, null);
    objectifExamen.setEtat(23);
    
    return objectifExamen;
  }
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = null;
    switch (p_natureDecision)
    {
    case 11: 
      nouvelleDecision = new Readmission();
      nouvelleDecision.setNatureDecision(11);
      break;
    default: 
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_HG_OBJECT_DECIS"));
    }
    return nouvelleDecision;
  }
  
  protected void miseAJourDemandeOrigine(DemandeSpec p_demande)
  {
    AttributionSpec attributionPrecedente = ((DemandeAssuranceSpec)p_demande).rechercherAttributionPrecedenteDuMemeType();
    if (attributionPrecedente != null) {
      ((Demande)p_demande).setDemandeOrigine((DemandeAssuranceSpec)attributionPrecedente.getDemande());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_DEM_ORIG_INCONNU"));
    }
  }
  
  protected void miseAJourMontantBrutJournalierProduitResultant(DemandeMigreeV1 p_demandeV1, DemandeSpec p_demande, DemandeMigreeEnErreur p_demandeMigreeEnErreur)
  {
    AttributionAssuranceSpec attributionPrecedente = ((DemandeAssuranceSpec)p_demande).rechercherAttributionPrecedenteDuMemeType();
    if (attributionPrecedente != null)
    {
      AccesseurDroitsSpec accesseurDroits = attributionPrecedente.getAccesseurDroits();
      if (accesseurDroits != null)
      {
        DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierAffectation().getDossierExamen();
        
        ConstitutionProduitResultant constitutionProduitResultant = dossierExamenCourant.getConstitutionProduitResultant();
        if (constitutionProduitResultant != null)
        {
          ConstitutionMontantsBruts constitutionMontantsBrutsCourant = constitutionProduitResultant.getConstitutionMontantsBruts();
          if (constitutionMontantsBrutsCourant != null) {
            constitutionMontantsBrutsCourant.setMontantJournalierBrut(accesseurDroits.getMontantBrutJournalier());
          }
        }
      }
    }
  }
  
  protected void alimenterProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    super.alimenterProduitResultant(p_decisionTemporaireSource, p_dossierExamen);
    
    alimenterMontantBrutProduitResultant(p_decisionTemporaireSource, p_dossierExamen);
  }
  
  protected void alimenterDureeProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant cepa15 = p_dossierExamen.getConstitutionProduitResultant();
    
    ConstitutionDurees cepaDuree = new ConstitutionDurees();
    
    DureeIndemnisation dureeIndemnisation = new DureeIndemnisation();
    if (p_decisionTemporaireSource.getDureeTheoriqueDroitRetenu() != null) {
      dureeIndemnisation.setDureeTheorique(p_decisionTemporaireSource.getDureeTheoriqueDroitRetenu());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DUREE_T_DR"));
    }
    if (p_decisionTemporaireSource.getDureeEffectiveDroitRetenu() != null) {
      dureeIndemnisation.setDureeEffective(p_decisionTemporaireSource.getDureeEffectiveDroitRetenu());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_DUREE_E_DR"));
    }
    cepaDuree.ajouterDuree(dureeIndemnisation);
    cepa15.setConstitutionDurees(cepaDuree);
  }
  
  protected void alimenterMontantBrutProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant cepa15 = p_dossierExamen.getConstitutionProduitResultant();
    ConstitutionMontantsBruts cepaMontantsBruts = new ConstitutionMontantsBruts();
    if (p_decisionTemporaireSource.getCapitalOdPrecedente() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_CAPITAL_DP"));
    } else {
      cepaMontantsBruts.setCapitalInitialBrut(p_decisionTemporaireSource.getCapitalOdPrecedente());
    }
    if (p_decisionTemporaireSource.getMontantBrutDroitPrecedent() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_MT_BRUT_DP"));
    } else {
      cepaMontantsBruts.setMontantJournalierBrut(p_decisionTemporaireSource.getMontantBrutDroitPrecedent());
    }
    cepa15.setConstitutionMontantsBruts(cepaMontantsBruts);
  }
  
  protected Collection getListRecalcule()
  {
    Collection listeRecalcul = new ArrayList();
    
    listeRecalcul.add(new RecalculerPji());
    listeRecalcul.add(new RecalculerMontantBrutDroitPrecedent());
    listeRecalcul.add(new RecalculerCapitalDroitPrecedent());
    listeRecalcul.add(new RecalculerConstituantsProduitResultant());
    
    return listeRecalcul;
  }
  
  protected void lireConstitutionMontantsBrutDroitRetenu(Decision p_decision, DecisionMigreeAsuV1 p_decisionLue)
  {
    ConstitutionProduitResultant produitResultant = p_decision.getConstitutionProduitResultant();
    if (produitResultant != null)
    {
      if ((produitResultant.getConstitutionMontantsBruts() != null) && (produitResultant.getConstitutionMontantsBruts().getMontantJournalierBrut() != null) && (produitResultant.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur() != null)) {
        p_decisionLue.setMontantBrutRetenu(produitResultant.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeur());
      }
      if ((p_decisionLue.getMontantBrutRetenu() != null) && (p_decisionLue.getMontantBrutRetenu().getValeur() != null) && (p_decisionLue.getDureeEffectiveDroitRetenu() != null) && (p_decisionLue.getDureeEffectiveDroitRetenu().getValeur() != null)) {
        p_decisionLue.setCapitalOdRetenu(p_decisionLue.getMontantBrutRetenu().getValeur().multiply(p_decisionLue.getDureeEffectiveDroitRetenu().getValeur()));
      }
    }
  }
}

/* Location:
 * Qualified Name:     GrapheReadmissionDroitPrecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */