package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.AntecedentGen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.dom.AntecedentSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitDelegueSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;

public class Antecedent
  extends AntecedentGen
  implements AntecedentSpec
{
  private static final long serialVersionUID = 1L;
  
  public Antecedent(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Antecedent() {}
  
  public Antecedent(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public Antecedent(Damj dateEvenement, DossierExamen dossierExamen)
  {
    super(dateEvenement);
    copie(dossierExamen);
  }
  
  protected void copie(Attribution source)
  {
    if (source == null) {
      return;
    }
    super.copie(source);
  }
  
  public void copieElements(ObjetMetierSpec copieObjet)
  {
    Od copie = (Od)copieObjet;
    super.copieElements(copie);
  }
  
  public ObjetMetierSpec copie()
  {
    Antecedent copie = new Antecedent();
    copieElements(copie);
    return copie;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean estExecutable()
  {
    return false;
  }
  
  public SaisieAntecedent getSaisieAntecedent()
  {
    return ((Demande)getDemande()).getSaisieAntecedent();
  }
  
  public boolean estMaintenue()
  {
    if (!getSaisieAntecedent().isEstDroitMaintenu()) {
      return super.estMaintenue();
    }
    return getSaisieAntecedent().isEstDroitMaintenu();
  }
  
  public boolean estPresenceDiffere()
  {
    return getSaisieAntecedent().isDelaiAttente();
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    if ((getConstitutionProduitResultant() == null) || (getConstitutionProduitResultant().getMontantRetenu() != 2))
    {
      setElementBaseIndemnisationPrive(super.getElementBaseIndemnisation());
    }
    else
    {
      Demande demandeOrigineRead = ((Demande)getDemande()).getDemandeOrigine();
      AttributionAssuranceSpec attributionPrecedente = demandeOrigineRead.getAttribution();
      setElementBaseIndemnisationPrive(attributionPrecedente.getElementBaseIndemnisation());
    }
    return (ElementBaseIndemnisation)getElementBaseIndemnisationPrive().copie();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    DemandeSpec demandeRetenu = null;
    if ((getConstitutionProduitResultant() == null) || (getConstitutionProduitResultant().getMontantRetenu() != 2)) {
      demandeRetenu = getDemande();
    } else {
      demandeRetenu = getAttributionPrecedente().getDemandeMontantRetenu();
    }
    return demandeRetenu;
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    FormuleMontantSpec formuleRetour = null;
    if ((getConstitutionProduitResultant() == null) || (getConstitutionProduitResultant().getMontantRetenu() != 2)) {
      formuleRetour = super.getFormuleMontant(code);
    } else {
      formuleRetour = getAttributionPrecedente().getProduitMontantRetenu().getFormuleMontant(code);
    }
    return formuleRetour;
  }
  
  public ProduitDelegueSpec getProduitDelegueMontantRetenu()
  {
    DemandeSpec demandeRetenu = getDemandeMontantRetenu();
    return ((ProduitAbstrait)demandeRetenu.getDossierAffectation().getProduit()).getProduitDelegue();
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    DemandeSpec demandeRetenu = getDemandeMontantRetenu();
    return (ProduitAsuSpec)demandeRetenu.getDossierAffectation().getProduit();
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    return ((Demande)getDemande()).getSaisieAntecedent().getDateAdmission();
  }
}

/* Location:
 * Qualified Name:     Antecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */