package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.CompetenceGen;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.NonConformiteException;
import java.util.Iterator;

public class Competence
  extends CompetenceGen
  implements CompetenceSpec
{
  private static final long serialVersionUID = 1L;
  private transient int mChargeIndemnisationDroitCourant;
  private transient String mIdentifiantEmployeurCompetent;
  private transient ChronologiePeriodes mChronoPeriodesActiviteSecteurPublicRetenues;
  private transient ChronologiePeriodes mChronoPeriodesActiviteSecteurPriveRetenues;
  private transient int mCompetenceAdministrativeDroitCourant = 0;
  private transient int mCompetenceFinanciereDroitCourant = 0;
  private transient ChronologiePeriodes chronoPeriodesParticipantes;
  private transient String mCodeAffectationConventionGestion = null;
  private transient String mBouchonnageAppelCaro = null;
  private transient ConventionGestionSpec mCacheConventionGestion = null;
  private transient Damj mDateDepotDemande = null;
  private transient boolean estCoeffTPAppliqueRAC = false;
  private transient boolean estCoeffTPAppliqueSP = false;
  
  public Competence() {}
  
  public Competence(DomPCSpec pc)
  {
    super(pc);
  }
  
  public int getChargeIndemnisationDroitCourant()
  {
    return mChargeIndemnisationDroitCourant;
  }
  
  public void setChargeIndemnisationDroitCourant(int chargeIndemnisationDroitCourant)
  {
    mChargeIndemnisationDroitCourant = chargeIndemnisationDroitCourant;
  }
  
  public String getIdentifiantEmployeurCompetent()
  {
    return mIdentifiantEmployeurCompetent;
  }
  
  public void setIdentifiantEmployeurCompetent(String identifiantEmployeurCompetent)
  {
    mIdentifiantEmployeurCompetent = identifiantEmployeurCompetent;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void marquerGraphePersistant() {}
  
  public ObjetMetierSpec copie()
  {
    Competence copie = new Competence();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    Competence copie = (Competence)pCopie;
    
    copie.setChargeIndemnisationDroitCourant(getChargeIndemnisationDroitCourant());
    copie.setCompetenceAdministrative(getCompetenceAdministrative());
    copie.setCompetenceFinanciere(getCompetenceFinanciere());
    copie.setDureeActiviteSecteurPrive(getDureeActiviteSecteurPrive());
    copie.setDureeActiviteSecteurPriveCaCae(getDureeActiviteSecteurPriveCaCae());
    copie.setDureeActiviteSecteurPublicAffilie(getDureeActiviteSecteurPublicAffilie());
    copie.setDureeActiviteSecteurPublicAutoAssurance(getDureeActiviteSecteurPublicAutoAssurance());
    copie.setDureeActiviteSecteurPublicConventionGestion(getDureeActiviteSecteurPublicConventionGestion());
    copie.setIdentifiantEmployeurCompetent(getIdentifiantEmployeurCompetent());
    copie.setLibelleEmployeurCompetent(getLibelleEmployeurCompetent());
    copie.setNumeroConventionGestion(getNumeroConventionGestion());
    copie.setCodeAffectationConvention(mCodeAffectationConventionGestion);
    copie.setBouchonnageAppelCaro(getBouchonnageAppelCaro());
    copie.setDateDepotDemande(getDateDepotDemande());
    
    copie.setCompetenceAdministrativeDroitCourant(getCompetenceAdministrativeDroitCourant());
    copie.setCompetenceFinanciereDroitCourant(getCompetenceFinanciereDroitCourant());
    if (getChronoPeriodesActiviteSecteurPublicRetenues() != null)
    {
      Iterator iter = getChronoPeriodesActiviteSecteurPublicRetenues().iterer();
      ActiviteSalarie elementPas = null;
      while (iter.hasNext())
      {
        elementPas = (ActiviteSalarie)iter.next();
        copie.ajouterPeriodeActiviteSecteurPublic((ActiviteSalarie)elementPas.copie());
      }
    }
    if (getChronoPeriodesActiviteSecteurPriveRetenues() != null)
    {
      Iterator iter = getChronoPeriodesActiviteSecteurPriveRetenues().iterer();
      ActiviteSalarie elementPas = null;
      while (iter.hasNext())
      {
        elementPas = (ActiviteSalarie)iter.next();
        copie.ajouterPeriodeActiviteSecteurPrive((ActiviteSalarie)elementPas.copie());
      }
    }
  }
  
  public String donnerLibelleCompetence(int competence)
  {
    String libelleCompetenceRetour = null;
    switch (competence)
    {
    case 1: 
      libelleCompetenceRetour = "Assurance Chômage";
      break;
    case 2: 
      libelleCompetenceRetour = "Secteur public";
      break;
    }
    return libelleCompetenceRetour;
  }
  
  public ChronologiePeriodes getChronoPeriodesActiviteSecteurPublicRetenues()
  {
    if (mChronoPeriodesActiviteSecteurPublicRetenues == null) {
      mChronoPeriodesActiviteSecteurPublicRetenues = new ChronologiePeriodes();
    }
    return mChronoPeriodesActiviteSecteurPublicRetenues;
  }
  
  public void setChronoPeriodesActiviteSecteurPublicRetenues(ChronologiePeriodes chronoPeriodesActiviteSecteurPublicRetenues)
  {
    mChronoPeriodesActiviteSecteurPublicRetenues = chronoPeriodesActiviteSecteurPublicRetenues;
  }
  
  public ChronologiePeriodes getChronoPeriodesActiviteSecteurPriveRetenues()
  {
    if (mChronoPeriodesActiviteSecteurPriveRetenues == null) {
      mChronoPeriodesActiviteSecteurPriveRetenues = new ChronologiePeriodes();
    }
    return mChronoPeriodesActiviteSecteurPriveRetenues;
  }
  
  public void setChronoPeriodesActiviteSecteurPriveRetenues(ChronologiePeriodes chronoPeriodesActiviteSecteurPriveRetenues)
  {
    mChronoPeriodesActiviteSecteurPriveRetenues = chronoPeriodesActiviteSecteurPriveRetenues;
  }
  
  public void ajouterPeriodeActiviteSecteurPublic(ActiviteSalarie periodeActiviteSecteurPublic)
  {
    if (periodeActiviteSecteurPublic != null) {
      try
      {
        getChronoPeriodesActiviteSecteurPublicRetenues().ajouter(periodeActiviteSecteurPublic);
      }
      catch (NonConformiteException ex)
      {
        if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
          Log.ecritTrace(Niveau.DEBUG, Competence.class, "ajouterPeriodeActiviteSecteurPublic", ex);
        }
      }
    }
  }
  
  public void ajouterPeriodeActiviteSecteurPrive(ActiviteSalarie periodeActiviteSecteurPrive)
  {
    if (periodeActiviteSecteurPrive != null) {
      try
      {
        getChronoPeriodesActiviteSecteurPriveRetenues().ajouter(periodeActiviteSecteurPrive);
      }
      catch (NonConformiteException ex)
      {
        if (Log.isTraceActive(Prc.class, Niveau.DEBUG)) {
          Log.ecritTrace(Niveau.DEBUG, Competence.class, "ajouterPeriodeActiviteSecteurPrive", ex);
        }
      }
    }
  }
  
  public boolean estCompetenceFinanciereSecteurPublic()
  {
    boolean competenceFinanciereSecteurPublic = false;
    if (getCompetenceFinanciere() != 0) {
      competenceFinanciereSecteurPublic = getCompetenceFinanciere() == 2;
    } else {
      competenceFinanciereSecteurPublic = getChargeIndemnisationDroitCourant() == 2;
    }
    return competenceFinanciereSecteurPublic;
  }
  
  public boolean estCompetenceAdministrativeSecteurPublic()
  {
    boolean competenceAdministrativeSecteurPublic = false;
    if (getCompetenceAdministrative() != 0) {
      competenceAdministrativeSecteurPublic = getCompetenceAdministrative() == 2;
    } else {
      competenceAdministrativeSecteurPublic = getCompetenceAdministrativeDroitCourant() == 2;
    }
    return competenceAdministrativeSecteurPublic;
  }
  
  public int getCompetenceFinanciereDroitCourant()
  {
    if (mCompetenceFinanciereDroitCourant == 0) {
      return getCompetenceFinanciere();
    }
    return mCompetenceFinanciereDroitCourant;
  }
  
  public int getCompetenceAdministrativeDroitCourant()
  {
    if (mCompetenceAdministrativeDroitCourant == 0) {
      return getCompetenceAdministrative();
    }
    return mCompetenceAdministrativeDroitCourant;
  }
  
  public void setCompetenceAdministrativeDroitCourant(int competenceAdministrative)
  {
    mCompetenceAdministrativeDroitCourant = competenceAdministrative;
  }
  
  public void setCompetenceFinanciereDroitCourant(int competenceFinanciere)
  {
    mCompetenceFinanciereDroitCourant = competenceFinanciere;
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    ConventionGestion conventionGestion = null;
    if (getNumeroConventionGestion() != null) {
      if (mCodeAffectationConventionGestion != null)
      {
        try
        {
          if (mCacheConventionGestion == null) {
            mCacheConventionGestion = ((ConventionGestion)OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(getNumeroConventionGestion(), mCodeAffectationConventionGestion, mDateDepotDemande, getBouchonnageAppelCaro())));
          }
          conventionGestion = (ConventionGestion)mCacheConventionGestion;
        }
        catch (CoucheLogiqueException c)
        {
          throw new RuntimeException(c.getMessage());
        }
      }
      else
      {
        conventionGestion = new ConventionGestion(getNumeroConventionGestion(), null, false, false, false, false, false, "1", false, null, null, null, false);
        
        boolean precompteCrc = true;
        if (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("555", true, conventionGestion)) {
          precompteCrc = false;
        }
        conventionGestion.setEstPrecompteCRC(precompteCrc);
      }
    }
    return conventionGestion;
  }
  
  public void setCodeAffectationConvention(String codeAffectationConvention)
  {
    mCodeAffectationConventionGestion = codeAffectationConvention;
  }
  
  public void setPrecompteCrc(boolean precompteCrc) {}
  
  public void setSignataireConvention(String signataireConvention) {}
  
  public void setLibelleAffectationConventionGestion(String libelleAffectationConventionGestion) {}
  
  public void setDebutValiditeConventionGestion(Damj debutValiditeConventionGestion) {}
  
  public void setFinValiditeConventionGestion(Damj finValiditeConventionGestion) {}
  
  public void setEstAideAdr(boolean estAideAdr) {}
  
  public void setEstAideAllocationDeces(boolean estAideAllocationDeces) {}
  
  public void setEstAideArce(boolean estAideArce) {}
  
  public void setEstAideCongeNonPaye(boolean estAideCongeNonPaye) {}
  
  public void setEstAideFinDroit(boolean estAideFinDroit) {}
  
  public String getIdExterneEmployeurSp()
  {
    return null;
  }
  
  public void setIdExterneEmployeurSp(String id) {}
  
  public boolean estIdExterneObligatoire()
  {
    return false;
  }
  
  public void setIdExterneObligatoire(boolean idObligatoire) {}
  
  public String getBouchonnageAppelCaro()
  {
    return mBouchonnageAppelCaro;
  }
  
  public void setBouchonnageAppelCaro(String bouchonnageAppelCaro)
  {
    mBouchonnageAppelCaro = bouchonnageAppelCaro;
  }
  
  public String getIdFctEmployeurCompetent()
  {
    return null;
  }
  
  public void setIdFctEmployeurCompetent(String id) {}
  
  public Damj getDateDepotDemande()
  {
    return mDateDepotDemande;
  }
  
  public void setDateDepotDemande(Damj dateDepotDemande)
  {
    mDateDepotDemande = dateDepotDemande;
  }
  
  public ChronologiePeriodes getActivitesParticipantes()
  {
    return chronoPeriodesParticipantes;
  }
  
  public void setActivitesParticipantes(ChronologiePeriodes chronologies)
  {
    chronoPeriodesParticipantes = chronologies;
  }
  
  public String getApplicationDesAides()
  {
    return null;
  }
  
  public String getCodeAffectationConvention()
  {
    return mCodeAffectationConventionGestion;
  }
  
  public Damj getDebutValiditeConventionGestion()
  {
    return null;
  }
  
  public Damj getFinValiditeConventionGestion()
  {
    return null;
  }
  
  public String getLibelleAffectationConventionGestion()
  {
    return null;
  }
  
  public String getSignataireConvention()
  {
    return null;
  }
  
  public boolean isEstAideAdr()
  {
    return false;
  }
  
  public boolean isEstAideAllocationDeces()
  {
    return false;
  }
  
  public boolean isEstAideArce()
  {
    return false;
  }
  
  public boolean isEstAideCongeNonPaye()
  {
    return false;
  }
  
  public boolean isEstAideFinDroit()
  {
    return false;
  }
  
  public boolean isPrecompteCrc()
  {
    return false;
  }
  
  public void setApplicationDesAides(String desAides) {}
  
  public void setEstCoeffTPAppliqueRAC(boolean estCoeffTPAppliqueRAC)
  {
    this.estCoeffTPAppliqueRAC = estCoeffTPAppliqueRAC;
  }
  
  public boolean isEstCoeffTPAppliqueRAC()
  {
    return estCoeffTPAppliqueRAC;
  }
  
  public void setEstCoeffTPAppliqueSP(boolean estCoeffTPAppliqueSP)
  {
    this.estCoeffTPAppliqueSP = estCoeffTPAppliqueSP;
  }
  
  public boolean isEstCoeffTPAppliqueSP()
  {
    return estCoeffTPAppliqueSP;
  }
}

/* Location:
 * Qualified Name:     Competence
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */