package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.ConditionsAttributionAdmissionGen;
import fr.unedic.cali.dom.ElementDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConditionsAttributionAdmission
  extends ConditionsAttributionAdmissionGen
  implements ConditionsAttributionSpec
{
  public ConditionsAttributionAdmission() {}
  
  public ConditionsAttributionAdmission(DomPCSpec p_admissionPC)
  {
    super(p_admissionPC);
  }
  
  public List getListeConditionsAttribution()
  {
    List listeConditions = new ArrayList();
    listeConditions.add(getConditionRechercheEmploi());
    listeConditions.add(getConditionFaitGenerateur());
    listeConditions.add(getConditionChomageTotal());
    listeConditions.add(getConditionAge());
    listeConditions.add(getConditionQuantiteAffiliation());
    listeConditions.add(getConditionChomageInvolontaire());
    listeConditions.add(getConditionActiviteConservee());
    listeConditions.add(getConditionCumulPrestationFamiliale());
    listeConditions.add(getConditionMontantNonNul());
    listeConditions.add(getConditionCSRDateAttributionPendantSuspension());
    listeConditions.add(getConditionCSRAccordCP());
    listeConditions.add(getConditionCSR28Jours());
    return listeConditions;
  }
  
  public boolean estSatisfait()
  {
    for (Iterator iter = getListeConditionsAttribution().iterator(); iter.hasNext();)
    {
      ElementDroitSpec droit = (ElementDroitSpec)iter.next();
      if ((droit != null) && 
        (!(droit instanceof ConditionChomageInvolontaire)) && (!droit.estSatisfait())) {
        return false;
      }
    }
    return true;
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getConditionRechercheEmploi());
    DomManager.persisterEnProfondeur(super.getConditionFaitGenerateur());
    DomManager.persisterEnProfondeur(super.getConditionChomageTotal());
    DomManager.persisterEnProfondeur(super.getConditionAge());
    DomManager.persisterEnProfondeur(super.getConditionQuantiteAffiliation());
    DomManager.persisterEnProfondeur(super.getConditionChomageInvolontaire());
    DomManager.persisterEnProfondeur(super.getConditionActiviteConservee());
    DomManager.persisterEnProfondeur(super.getConditionCumulPrestationFamiliale());
    DomManager.persisterEnProfondeur(super.getConditionMontantNonNul());
    DomManager.persisterEnProfondeur(super.getConditionCSRDateAttributionPendantSuspension());
    DomManager.persisterEnProfondeur(super.getConditionCSRAccordCP());
    DomManager.persisterEnProfondeur(super.getConditionCSR28Jours());
    DomManager.persisterEnProfondeur(super.getConditionValiditeReliquat());
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionsAttributionAdmission copie = (ConditionsAttributionAdmission)p_copie;
    
    super.copieElements(copie);
    if (getConditionActiviteConservee() != null)
    {
      ConditionActiviteConservee copieCondition = copie.createConditionActiviteConservee();
      getConditionActiviteConservee().copieElements(copieCondition);
    }
    if (getConditionAge() != null)
    {
      ConditionAge copieCondition = copie.createConditionAge();
      getConditionAge().copieElements(copieCondition);
    }
    if (getConditionChomageInvolontaire() != null)
    {
      ConditionChomageInvolontaire copieCondition = copie.createConditionChomageInvolontaire();
      getConditionChomageInvolontaire().copieElements(copieCondition);
    }
    if (getConditionChomageTotal() != null)
    {
      ConditionChomageTotal copieCondition = copie.createConditionChomageTotal();
      getConditionChomageTotal().copieElements(copieCondition);
    }
    if (getConditionMontantNonNul() != null)
    {
      ConditionMontantNonNul copieCondition = copie.createConditionMontantNonNul();
      getConditionMontantNonNul().copieElements(copieCondition);
    }
    if (getConditionQuantiteAffiliation() != null)
    {
      ConditionQuantiteAffiliation copieCondition = copie.createConditionQuantiteAffiliation();
      getConditionQuantiteAffiliation().copieElements(copieCondition);
    }
    if (getConditionRechercheEmploi() != null)
    {
      ConditionRechercheEmploi copieCondition = copie.createConditionRechercheEmploi();
      getConditionRechercheEmploi().copieElements(copieCondition);
    }
    if (getConditionFaitGenerateur() != null)
    {
      ConditionFaitGenerateur copieCondition = copie.createConditionFaitGenerateur();
      getConditionFaitGenerateur().copieElements(copieCondition);
    }
    if (getConditionCumulPrestationFamiliale() != null)
    {
      ConditionCumulPrestationFamiliale copieCondition = copie.createConditionCumulPrestationFamiliale();
      getConditionCumulPrestationFamiliale().copieElements(copieCondition);
    }
    if (getConditionCSRDateAttributionPendantSuspension() != null)
    {
      ConditionCSRDateAttributionPendantSuspension copieCondition = copie.createConditionCSRDateAttributionPendantSuspension();
      getConditionCSRDateAttributionPendantSuspension().copieElements(copieCondition);
    }
    if (getConditionCSRAccordCP() != null)
    {
      ConditionCSRAccordCP copieCondition = copie.createConditionCSRAccordCP();
      getConditionCSRAccordCP().copieElements(copieCondition);
    }
    if (getConditionCSR28Jours() != null)
    {
      ConditionCSR28Jours copieCondition = copie.createConditionCSR28Jours();
      getConditionCSR28Jours().copieElements(copieCondition);
    }
  }
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
}

/* Location:
 * Qualified Name:     ConditionsAttributionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */