package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.calcul.dom.FormuleMontantRegimeGeneral;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.DureeIndemnisationGen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.pc.ConstitutionElementsRevisionPC;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.spec.ConstitutionElementsAbstraitPC;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;

public class DureeIndemnisation
  extends DureeIndemnisationGen
{
  public static final int FLAG_CONSTITUTION_DUREES = 0;
  public static final int FLAG_CONSTITUTION_PRODUIT_RESULTANT = 1;
  private transient Quantite dureeRestantAImputer = null;
  private transient int m_flagParent = 0;
  
  protected DureeIndemnisation() {}
  
  public DureeIndemnisation(DomPCSpec pc)
  {
    super(pc);
  }
  
  protected DureeIndemnisation(int flagParent) {}
  
  public DureeIndemnisation(DomPCSpec cepAbstraitPC, int flagParent)
  {
    super(cepAbstraitPC);
    m_flagParent = flagParent;
  }
  
  public DureeIndemnisation(int dureeTheorique, int dureeImputation, DomPCSpec cepAbstraitPC, int flagParent)
  {
    super(cepAbstraitPC);
    m_flagParent = flagParent;
    setDureeTheorique(new Quantite(dureeTheorique, UNITE_DEFAUT));
    setDureeImputation(new Quantite(dureeImputation, UNITE_DEFAUT));
  }
  
  public Quantite getDureeImputation()
  {
    if (m_flagParent == 0) {
      return ((ConstitutionElementsAbstraitPC)getPC()).getDureeImputationConstitutionDurees();
    }
    if (m_flagParent == 1) {
      return ((ConstitutionElementsAbstraitPC)getPC()).getDureeImputationConstitutionProduitResultant();
    }
    return null;
  }
  
  public Quantite getDureeTheorique()
  {
    if (m_flagParent == 0) {
      return ((ConstitutionElementsAbstraitPC)getPC()).getDureeTheoriqueConstitutionDurees();
    }
    if (m_flagParent == 1) {
      return ((ConstitutionElementsAbstraitPC)getPC()).getDureeTheoriqueConstitutionProduitResultant();
    }
    return null;
  }
  
  public void setDureeImputation(Quantite dureeImputation)
  {
    if (m_flagParent == 0) {
      ((ConstitutionElementsAbstraitPC)getPC()).setDureeImputationConstitutionDurees(dureeImputation);
    }
    if (m_flagParent == 1) {
      ((ConstitutionElementsAbstraitPC)getPC()).setDureeImputationConstitutionProduitResultant(dureeImputation);
    }
  }
  
  public void setDureeTheorique(Quantite dureeTheorique)
  {
    if (m_flagParent == 0) {
      ((ConstitutionElementsAbstraitPC)getPC()).setDureeTheoriqueConstitutionDurees(dureeTheorique);
    }
    if (m_flagParent == 1) {
      ((ConstitutionElementsAbstraitPC)getPC()).setDureeTheoriqueConstitutionProduitResultant(dureeTheorique);
    }
  }
  
  public String toString()
  {
    StringBuffer chaine = new StringBuffer();
    
    chaine.append("--- Duree Indemnisation ---");
    chaine.append("\n- duree theorique : " + getDureeTheorique());
    chaine.append("\n- duree imputation : " + getDureeImputation());
    chaine.append("\n- duree effective : " + getDureeEffective());
    return chaine.toString();
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    DureeIndemnisation copie = (DureeIndemnisation)p_copie;
    
    copie.setDureeEffective(getDureeEffective());
    copie.setDureeImputation(getDureeImputation());
    copie.setDureeTheorique(getDureeTheorique());
    if (!(getPC() instanceof ConstitutionElementsRevisionPC))
    {
      copie.setQuantiteJourImputationForce(getQuantiteJourImputationForce());
      copie.setQuantiteTotalJourImputation(getQuantiteTotalJourImputation());
    }
    copie.setDureePostPrimeCspConstitutionDurees(getDureePostPrimeCspConstitutionDurees());
    copie.setDureeImputationPostPrime(getDureeImputationPostPrime());
  }
  
  public Quantite getDureePostPrimeCspConstitutionDurees()
  {
    return super.getDureePostPrimeCspConstitutionDurees();
  }
  
  public void marquerGraphePersistant() {}
  
  public QuantiteDroit creerDureeCalcul()
  {
    fr.unedic.cali.asu.cge01.p03.calcul.dom.DureeIndemnisation dureeCalcul = null;
    
    dureeCalcul = new fr.unedic.cali.asu.cge01.p03.calcul.dom.DureeIndemnisation(getDureeEffective().getValeurEntiere());
    dureeCalcul.setCodeFormuleMontant(FormuleMontantRegimeGeneral.getCode());
    
    return dureeCalcul;
  }
  
  public Quantite getDureeEffective()
  {
    if (m_flagParent == 0) {
      return ((ConstitutionElementsAbstraitPC)getPC()).getDureeEffectiveConstitutionDurees();
    }
    if (m_flagParent == 1) {
      return ((ConstitutionElementsAbstraitPC)getPC()).getDureeEffectiveConstitutionProduitResultant();
    }
    return null;
  }
  
  public void setDureeEffective(Quantite dureeEffective)
  {
    if (m_flagParent == 0) {
      ((ConstitutionElementsAbstraitPC)getPC()).setDureeEffectiveConstitutionDurees(dureeEffective);
    }
    if (m_flagParent == 1) {
      ((ConstitutionElementsAbstraitPC)getPC()).setDureeEffectiveConstitutionProduitResultant(dureeEffective);
    }
  }
  
  public Quantite getDureeRestantAImputer()
  {
    return dureeRestantAImputer;
  }
  
  public void setDureeRestantAImputer(Quantite dureeRestantAImputer)
  {
    this.dureeRestantAImputer = dureeRestantAImputer;
  }
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
}

/* Location:
 * Qualified Name:     DureeIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */