package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ElementChomageSansRuptureSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCSR04P01;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.util.Collection;

public class ElementChomageSansRupture
  implements ElementChomageSansRuptureSpec
{
  private transient AttributionSpec m_attributionCourante = null;
  private transient AttributionSpec m_attribution = null;
  private transient Damj m_dateMaxIndemnisation = null;
  private transient Damj m_dateRepriseActivite = null;
  private transient ElementsRuptureContratSuspendu m_elementsRuptureContratSuspendu = null;
  private transient DemandeAssuranceSpec m_demande;
  private transient DemandeAssuranceSpec m_demandeCourante;
  private transient Collection m_listeDelaisReports = null;
  private transient Collection m_periodeDiffere = null;
  
  public ElementChomageSansRupture(Attribution p_attribution)
  {
    m_attributionCourante = p_attribution;
  }
  
  public Damj getDateRepriseActivite()
  {
    if (m_dateRepriseActivite == null)
    {
      Damj dateFinSuspension = OutilsChomageSansRCT.getDateFinSuspension(getDemande());
      if (dateFinSuspension != null) {
        m_dateRepriseActivite = dateFinSuspension.lendemain();
      }
    }
    return m_dateRepriseActivite;
  }
  
  public boolean getDecisionProlongation()
  {
    return getDemande().getDonneesTemporaires().isAccordPoursuite182JoursChomageTotalSansRupture();
  }
  
  public Damj getDateMaxIndeminisation()
  {
    if (m_dateMaxIndemnisation == null) {
      m_dateMaxIndemnisation = getDemande().getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture();
    }
    return m_dateMaxIndemnisation;
  }
  
  public ElementsRuptureContratSuspendu getElementsRuptureContratSuspendu()
    throws CoucheLogiqueException
  {
    if ((m_elementsRuptureContratSuspendu == null) && (OutilsChomageSansRCT.estUnContexteRuptureContratPendantSuspension(getDemandeCourante()))) {
      m_elementsRuptureContratSuspendu = new ElementsRuptureContratSuspendu(getAttributionCourante());
    }
    return m_elementsRuptureContratSuspendu;
  }
  
  public Collection getListeDelaisReports()
  {
    if (m_listeDelaisReports == null)
    {
      ConstitutionDelais constitutionDelais = getAttributionCourante().getConstitutionDelais();
      if (constitutionDelais != null) {
        m_listeDelaisReports = constitutionDelais.getListeDelaisReports();
      }
    }
    return m_listeDelaisReports;
  }
  
  public Collection getPeriodeDiffere()
  {
    if (m_periodeDiffere == null)
    {
      ConstitutionDelais constitutionDelais = getAttributionCourante().getConstitutionDelais();
      if (constitutionDelais != null) {
        m_periodeDiffere = constitutionDelais.getListeCarences();
      }
    }
    return m_periodeDiffere;
  }
  
  public boolean estUneDemandeSuiteARuptureDuContrat()
  {
    ActiviteSalarie activite = OutilsChomageSansRCT.trouverActiviteSalarieRuptureSurContratGAEC(getDemandeCourante());
    if (activite != null)
    {
      Damj dateExamen = getDemandeCourante().getDateExamen();
      return dateExamen.estApres(activite.getDateFin());
    }
    return false;
  }
  
  public boolean estAccordCP()
  {
    return getDemande().getDonneesTemporaires().isAvisFavorableCPChomageTotalSansRupture();
  }
  
  public boolean estSinistreOuCalamite()
  {
    return getDemande().getDonneesTemporaires().isSinistreOuCalamiteNaturelleChomageTotalSansRupture();
  }
  
  private Attribution getAttribution()
  {
    if (m_attribution == null) {
      if ((getAttributionCourante().estType(Reprise.class)) && (getAttributionCourante().getDossierAffecte().getProduit().equals(ProduitAsuCSR04P01.getInstance()))) {
        m_attribution = getAttributionCourante().getAttributionPrecedente();
      } else {
        m_attribution = getAttributionCourante();
      }
    }
    return (Attribution)m_attribution;
  }
  
  private Attribution getAttributionCourante()
  {
    return (Attribution)m_attributionCourante;
  }
  
  private DemandeAssuranceSpec getDemandeCourante()
  {
    if (m_demandeCourante == null) {
      m_demandeCourante = ((DemandeAssuranceSpec)m_attributionCourante.getDemande());
    }
    return m_demandeCourante;
  }
  
  private DemandeAssuranceSpec getDemande()
  {
    if (m_demande == null) {
      m_demande = ((DemandeAssuranceSpec)getAttribution().getDemande());
    }
    return m_demande;
  }
  
  public boolean estDemandeEnContexteDeChomageEnCoursDeSuspension()
  {
    return false;
  }
  
  public boolean estUnContexteDeRupturePendantSuspension()
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     ElementChomageSansRupture
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */