package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.NovationGen;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseActiviteReduite;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.NovationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class Novation
  extends NovationGen
  implements NovationSpec
{
  private static final long serialVersionUID = -3093196909253706931L;
  public static final String CODE_FORMULE_MONTANT = "1";
  public static final String CODE_FORMULE_MONTANT_AREF = "2";
  private boolean comptenceEnrechie = false;
  
  public Novation(DomPCSpec pc)
  {
    super(pc);
  }
  
  public Novation() {}
  
  public Novation(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public String getRsod()
  {
    return getReferenceExterne();
  }
  
  public String getRsrp()
  {
    return "0";
  }
  
  public String getSituationParticuliere()
  {
    String situationParticuliere = "";
    if (getAttributionPrecedente() != null) {
      situationParticuliere = getAttributionPrecedente().getSituationParticuliere();
    }
    return situationParticuliere;
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    if ((DossierExamenAssuranceSpec)((Demande)getDossierAffecte().getDemande()).getDossierAffectationAdmission().getDossierExamen() != null) {
      return ((DossierExamenAssuranceSpec)((Demande)getDossierAffecte().getDemande()).getDossierAffectationAdmission().getDossierExamen()).getJustificationAffiliation();
    }
    return new JustificationAffiliation();
  }
  
  public ElementBaseActiviteReduite getElementBaseActiviteReduite()
  {
    return getAttributionPrecedente().getElementBaseActiviteReduite();
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionOrigine();
    }
    return null;
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() == null) {
      return false;
    }
    return getAttributionPrecedente().isInvestigationFraude();
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return getAttributionPrecedente().getProduitMontantRetenu();
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    Demande demandePrecedente = (Demande)getAttributionPrecedente().getDemande();
    if ((estDemandeEnContexteAreASP((Demande)getDemande())) || ((estDemandeEnContexteAreASP(demandePrecedente)) && (!estDemandeEnContexteAreASP((Demande)getDemande())))) {
      return super.getFormuleMontant(code);
    }
    return getAttributionPrecedente().getFormuleMontant(code);
  }
  
  private boolean estDemandeEnContexteAreASP(Demande demande)
  {
    return (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARECOURCSP"));
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((getMaintienEuropeenPrive() == null) && (getAttributionPrecedente() != null) && (getAttributionPrecedente().getMaintienEuropeen() == null)) {
      setMaintienEuropeenPrive(MaintienEuropeen.getInstanceMaintienEuropeen(this));
    } else if ((getMaintienEuropeenPrive() == null) && (getAttributionPrecedente() != null)) {
      setMaintienEuropeenPrive(getAttributionPrecedente().getMaintienEuropeen());
    }
    return getMaintienEuropeenPrive();
  }
  
  public boolean estMaintenue()
  {
    if (getOuvertureDroit().getNatureDecision() == 38) {
      return ((fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit()).estMaintenue();
    }
    return super.estMaintenue();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    return getAttributionPrecedente().getDemandeMontantRetenu();
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente == null) {
      attributionPrecedente = getDemandeAssurance().rechercherOuvertureDroitPrecedenteDuMemeType();
    }
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return false;
  }
  
  public CompetenceSpec getCompetence()
  {
    Competence competence = (Competence)super.getCompetence();
    if ((competence.getNumeroConventionGestion() != null) && (!comptenceEnrechie))
    {
      comptenceEnrechie = true;
      fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDroit = (fr.unedic.cali.asu.dom.OdAssuranceSpec)getOuvertureDroit();
      if ((ouvertureDroit != null) && ("ASU_23".equals(ouvertureDroit.getDemande().getEvenementReferenceExamen().getTypeExamen())))
      {
        competence.setCodeAffectationConvention(ouvertureDroit.getConventionGestion().getCodeAffectation());
        
        competence.setBouchonnageAppelCaro(ouvertureDroit.getCompetence().getBouchonnageAppelCaro());
        competence.setDateDepotDemande(ouvertureDroit.getCompetence().getDateDepotDemande());
      }
    }
    return competence;
  }
  
  public void setCompetence(CompetenceSpec competence)
  {
    super.setCompetence(competence);
    comptenceEnrechie = false;
  }
  
  public int getTypeMontantRetenu()
  {
    return getAttributionPrecedente().getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    return getAttributionPrecedente().getTypeCapitalRetenu();
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public ObjetMetierSpec copie()
  {
    Novation copie = new Novation();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    Novation novation = (Novation)copie;
    super.copieElements(copie);
    novation.setSituationParticuliere(getSituationParticuliere());
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    return getConstitutionElementsActifs().getConstitutionCaractereSaisonnier();
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsActifs().getConstitutionCoefficientTempsPartiel();
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    return getConstitutionElementsActifs().getConstitutionCoefficientSaisonnier();
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getDateDebutDelaiDecheance();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     Novation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */