package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteBrouillon;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMemeRegime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreMemeDateFin;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class DelaiRecherche
  extends fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche
{
  private static final int DUREE_MOIS_PRC = 12;
  protected static DelaiRecherche s_instanceUnique = null;
  
  public static fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.DelaiRecherche getInstance()
  {
    if (s_instanceUnique == null) {
      s_instanceUnique = new DelaiRecherche();
    }
    return s_instanceUnique;
  }
  
  public Periode deplacerDepartDelai(Damj p_dateOdPrecedente, Periode p_periodeInitiale)
  {
    Damj depart = p_periodeInitiale.getDebut();
    if ((p_dateOdPrecedente != null) && (depart.estAvant(p_dateOdPrecedente)))
    {
      depart = p_dateOdPrecedente.lendemain();
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "départ déplacé : ", depart });
    }
    return new Periode(depart, p_periodeInitiale.getFin());
  }
  
  private Damj determinerDepartPrc(Demande p_demande, Damj p_termePrc, int p_dureePrc)
  {
    Damj borneDebutPrc = null;
    
    borneDebutPrc = p_demande.getDateFaitGenerateurOdPrecedente();
    
    Periode periodeReference = p_termePrc.soustraireNombreMois(p_dureePrc);
    if (borneDebutPrc != null) {
      periodeReference = deplacerDepartDelai(borneDebutPrc, periodeReference);
    }
    boolean coordCee = p_demande.getDonneesTemporaires().isEstCoordCee();
    if (coordCee)
    {
      TravailSpec dernierSinistre = getDernierSinistreE301AvantDate(p_demande, p_termePrc);
      if (dernierSinistre != null)
      {
        Damj lendemainFCTE301 = dernierSinistre.getDateFin();
        borneDebutPrc = Damj.max(periodeReference.getDebut(), lendemainFCTE301);
        if (borneDebutPrc != null) {
          periodeReference = deplacerDepartDelai(borneDebutPrc, periodeReference);
        }
      }
    }
    return periodeReference.getDebut();
  }
  
  private Damj determinerDjtpSimultaneiteFctRa(Demande p_demande, ActiviteSalarie p_periodeActiviteSalarieRa)
  {
    Damj djtpLePlusRecent = null;
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltreMemeDateFin(p_periodeActiviteSalarieRa.getDateFin()));
    DecorReglementaire decor = ((DossierAffectation)p_demande.getDossierAffectation()).getDecorReglementaire();
    filtres.ajouterFiltre(new FiltreMemeRegime(p_periodeActiviteSalarieRa.getReglement().getNomReglement(), decor));
    filtres.ajouterFiltre(new FiltreActiviteBrouillon(false));
    
    Chronologie chronoActivitesRa = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if ((chronoActivitesRa != null) && (!chronoActivitesRa.estVide()))
    {
      chronoActivitesRa.iterer();
      ActiviteSalarie periodeActiviteSalarieCourante = null;
      while (chronoActivitesRa.encoreSuivant())
      {
        periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivitesRa.elementSuivant();
        if ((djtpLePlusRecent == null) || (periodeActiviteSalarieCourante.getDernierJourTravaillePaye().estApres(djtpLePlusRecent))) {
          djtpLePlusRecent = periodeActiviteSalarieCourante.getDernierJourTravaillePaye();
        }
      }
    }
    return djtpLePlusRecent;
  }
  
  private Damj determinerDjtpPourPrc(Demande p_demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeActiviteSalarieRa = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
    Damj djtpCourant = periodeActiviteSalarieRa.getDernierJourTravaillePaye();
    
    Damj djtpLePlusRecent = determinerDjtpSimultaneiteFctRa(p_demande, periodeActiviteSalarieRa);
    if (djtpLePlusRecent != null) {
      djtpCourant = djtpLePlusRecent;
    }
    if ((djtpCourant == null) && (OutilsChomageSansRCT.estUnContexteRuptureDuContrat(p_demande))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CSR_DETERMINATION_DJTP", new Object[] { periodeActiviteSalarieRa.getDateFin() });
    }
    return djtpCourant;
  }
  
  public int determinerDureePrc()
  {
    return 12;
  }
  
  public Periode determinerPrc(Demande p_demande)
    throws CoucheLogiqueException
  {
    int dureePrc = determinerDureePrc();
    
    Damj termePrc = null;
    
    Damj termePrcSaisi = p_demande.getDonneesTemporaires().getTermePrc();
    if (termePrcSaisi == null)
    {
      termePrc = determinerTermePrc(p_demande, dureePrc);
    }
    else
    {
      Damj dateDebut = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit().getDateDebut();
      Damj dateFin = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit().getDateFin();
      if (termePrcSaisi.estContenueDans(new Periode(dateDebut, dateFin))) {
        termePrc = termePrcSaisi;
      } else {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_SC_L_ED_CDR09_INCOHERENCE_TERME_PRC_ACTIVITE");
      }
    }
    Damj debutPrc = determinerDepartPrc(p_demande, termePrc, dureePrc);
    
    return new Periode(debutPrc, termePrc);
  }
  
  private Damj determinerTermePrcRaRg(Demande p_demande, int p_dureePrc)
    throws CoucheLogiqueException
  {
    Damj termePrc = null;
    
    Damj djtpCourant = determinerDjtpPourPrc(p_demande);
    
    termePrc = djtpCourant;
    if (!termePrc.estLaFinDuMois()) {
      termePrc = djtpCourant.getFinMoisPrecedent();
    }
    Periode periodeTemporairePrc = termePrc.soustraireNombreMois(p_dureePrc);
    
    ActiviteSalarie periodeActiviteSalarieRa = ((DossierAffecte)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
    BigDecimal remunerationSalairesActiviteRa = DeterminationRemuneration.determinerRemunerationActiviteSalarie(periodeActiviteSalarieRa, periodeTemporairePrc);
    if (remunerationSalairesActiviteRa.compareTo(new BigDecimal("0")) == 0)
    {
      OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "determinerTermePrc(): cas particulier 1 où dans la PRC, aucune rémunération n'est afférente à l'activité du RA --> terme de la PRC [", termePrc, "] reporté au DJTP [", djtpCourant, "]." });
      
      termePrc = djtpCourant;
    }
    return termePrc;
  }
  
  private Damj determinerTermePrcRaA1(Demande p_demande)
  {
    Damj termePrc = null;
    
    ActiviteSalarie periodeActiviteSalarieRa = ((DossierAffecte)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
    
    Preavis preavisRa = null;
    if (periodeActiviteSalarieRa.getContrat() != null) {
      preavisRa = periodeActiviteSalarieRa.getContrat().getPreavis();
    }
    if ((preavisRa == null) || (preavisRa.estEffectue()) || ((preavisRa.getPeriodeNonEffectueeNonPayee() == null) && (preavisRa.getPeriodeNonEffectueePayee() == null)))
    {
      termePrc = periodeActiviteSalarieRa.getDateFin();
      if (!termePrc.estLaFinDuMois()) {
        termePrc = termePrc.getFinMoisPrecedent();
      }
    }
    else
    {
      termePrc = preavisRa.getDebut();
      if (!termePrc.estLaFinDuMois()) {
        termePrc = termePrc.getFinMoisPrecedent();
      }
    }
    return termePrc;
  }
  
  private Damj determinerTermePrcRaA3(Demande p_demande)
  {
    Damj termePrc = null;
    
    ActiviteSalarie periodeActiviteSalarieRa = ((DossierAffecte)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
    
    termePrc = periodeActiviteSalarieRa.getDateFin();
    if (!termePrc.estLaFinDuMois()) {
      termePrc = periodeActiviteSalarieRa.getDateFin().getFinMoisPrecedent();
    }
    return termePrc;
  }
  
  private Damj determinerTermePrc(Demande p_demande, int p_dureePrc)
    throws CoucheLogiqueException
  {
    Damj termePrc = null;
    
    ProduitSpec produit = ((DossierAffectation)p_demande.getDossierAffectation()).getProduit();
    
    Reglement reglementApplicableCourant = ((DossierExamen)p_demande.getDossierExamen()).getReglementApplicable().getReglement();
    if ((reglementApplicableCourant.equals(produit.getReglement("RG"))) || (reglementApplicableCourant.equals(produit.getReglement("OP"))) || (reglementApplicableCourant.equals(produit.getReglement("A2a"))) || (reglementApplicableCourant.equals(produit.getReglement("A4"))) || (reglementApplicableCourant.equals(produit.getReglement("A5"))) || (reglementApplicableCourant.equals(produit.getReglement("A6"))) || (reglementApplicableCourant.equals(produit.getReglement("A9A"))) || (reglementApplicableCourant.equals(produit.getReglement("A9B")))) {
      termePrc = determinerTermePrcRaRg(p_demande, p_dureePrc);
    } else if (reglementApplicableCourant.equals(produit.getReglement("A1"))) {
      termePrc = determinerTermePrcRaA1(p_demande);
    } else if (reglementApplicableCourant.equals(produit.getReglement("A3"))) {
      termePrc = determinerTermePrcRaA3(p_demande);
    }
    return termePrc;
  }
  
  public Periode determinerPrcSjcipRaA2b(Demande p_demande)
  {
    Damj termePrc = null;
    ActiviteSalarie periodeValidationProduit = ((DossierAffectation)p_demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit();
    if (periodeValidationProduit.getContrat().getDateRuptureContratTravail() != null) {
      termePrc = periodeValidationProduit.getContrat().getDateRuptureContratTravail();
    } else {
      termePrc = periodeValidationProduit.getDateFin();
    }
    if (!termePrc.estLaFinDuMois()) {
      termePrc = termePrc.getFinMoisPrecedent();
    }
    int dureePrc = determinerDureePrc();
    
    Periode periodeReference = termePrc.soustraireNombreMois(dureePrc);
    Damj borneDebutPrc = p_demande.getDateFaitGenerateurOdPrecedente();
    if (borneDebutPrc != null) {
      periodeReference = deplacerDepartDelai(borneDebutPrc, periodeReference);
    }
    Damj debutPrc = periodeReference.getDebut();
    
    return new Periode(debutPrc, termePrc);
  }
  
  private TravailSpec getDernierSinistreE301AvantDate(Demande p_demande, Damj p_dateBorneFin)
  {
    FiltresTemporel desFiltres = new FiltresTemporel();
    TravailSpec dernierSinistre = null;
    
    desFiltres.ajouterFiltre(new FiltrePeriodeActiviteSalarieeE301NonFrontalier());
    desFiltres.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(p_dateBorneFin));
    
    Chronologie chronoPeriodeEeeNonFrontalier = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(desFiltres);
    if ((chronoPeriodeEeeNonFrontalier != null) && (!chronoPeriodeEeeNonFrontalier.estVide()))
    {
      chronoPeriodeEeeNonFrontalier.setComparateur(new ComparateurTemporelsSurDateFin());
      dernierSinistre = (TravailSpec)chronoPeriodeEeeNonFrontalier.premierElement();
    }
    return dernierSinistre;
  }
}

/* Location:
 * Qualified Name:     DelaiRecherche
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */