package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PeriodeHoraireStable;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeIntensite;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.List;
import java.util.SortedSet;

public class DeterminationCoefficientTempsPartiel
  implements OutilFonctionnel
{
  private static final Damj DATE_PIVOT_TEMPS_PLEIN = new Damj(2002, 1, 1);
  private static final int TRENTE_CINQ_HEURES = 35;
  private static final int TRENTE_NEUF_HEURES = 39;
  
  public static Chronologie determinerChronoPeriodesIntensiteADate(Periode p_periodeReference, Chronologie p_chronologiePrs)
  {
    ChronologiePeriodes chroPeriodesIntensite = constituerChronoPeriodeIntensite(p_chronologiePrs);
    SortedSet listeEvenements = OutillageChronologiePeriodes.constituerEvenements(p_periodeReference, chroPeriodesIntensite);
    List listePeriodes = OutillageChronologiePeriodes.constituerListePeriode(listeEvenements);
    Chronologie chronoPeriodeIntensite = deduireChronoPeriodeIntensite(listePeriodes, chroPeriodesIntensite);
    return determinerChronoPeriodesHoraireStable(p_periodeReference, chronoPeriodeIntensite);
  }
  
  public static BigDecimal determinerCoefficientTempsPartiel(Chronologie p_cphs)
  {
    Iterator itCPHS = p_cphs.iterer();
    BigDecimal cumulIntensite = new BigDecimal(0);
    BigDecimal cumulApplicable = new BigDecimal(0);
    
    BigDecimal horaireHebdoEntreprise = null;
    BigDecimal horaireHebdoSalarie = null;
    BigDecimal horaireEntreprise = null;
    BigDecimal horaireSalarie = null;
    if (itCPHS != null) {
      while (itCPHS.hasNext())
      {
        PeriodeHoraireStable pas = (PeriodeHoraireStable)itCPHS.next();
        if (pas.getUniteHoraire() == 1)
        {
          BigDecimal horaireATempsPleinHebdo = new BigDecimal(getNbHeuresTempsPlein(pas.getDateFin()));
          
          horaireHebdoEntreprise = pas.getHorairesEntreprise();
          horaireHebdoSalarie = pas.getHorairesSalarie();
          
          horaireEntreprise = horaireHebdoEntreprise.compareTo(horaireATempsPleinHebdo) < 0 ? horaireHebdoEntreprise : horaireATempsPleinHebdo;
          
          horaireSalarie = horaireHebdoSalarie.compareTo(horaireATempsPleinHebdo) < 0 ? horaireHebdoSalarie : horaireATempsPleinHebdo;
        }
        else
        {
          horaireEntreprise = pas.getHorairesEntreprise();
          horaireSalarie = pas.getHorairesSalarie();
        }
        cumulIntensite = cumulIntensite.add(horaireSalarie.multiply(new BigDecimal(pas.getDuree())));
        cumulApplicable = cumulApplicable.add(horaireEntreprise.multiply(new BigDecimal(pas.getDuree())));
      }
    }
    BigDecimal coefficient;
    BigDecimal coefficient;
    if (cumulApplicable.compareTo(new BigDecimal(0)) != 0)
    {
      BigDecimal ratio = Mathematiques.diviseParDefaut(cumulIntensite, cumulApplicable);
      coefficient = Mathematiques.tronque(ratio, 4);
    }
    else
    {
      coefficient = new BigDecimal(1);
    }
    return coefficient;
  }
  
  private static ChronologiePeriodes constituerChronoPeriodeIntensite(Chronologie p_chronologiePrs)
  {
    ChronologiePeriodes chroPeriodesIntensite = new ChronologiePeriodes();
    Iterator it = p_chronologiePrs.iterer();
    if (it != null) {
      while (it.hasNext())
      {
        ActiviteSalarie pas = (ActiviteSalarie)it.next();
        Chronologie chronoPeriodesIntensites = pas.getListePeriodeIntensite();
        if ((pas.getReglement().estNomReglementIdentique("A4")) && (chronoPeriodesIntensites.getTaille() == 0))
        {
          PeriodeIntensite periodeIntensite = new PeriodeIntensite(pas.getPeriode());
          
          periodeIntensite.setHorairesEntreprise(new BigDecimal(35));
          periodeIntensite.setHorairesSalarie(new BigDecimal(35));
          periodeIntensite.setUniteHoraire(1);
          Chronologie chronoPeriodeIntensite = new ChronologiePeriodes();
          chronoPeriodeIntensite.ajouter(periodeIntensite);
          pas.setListePeriodeIntensite(chronoPeriodeIntensite);
        }
        chroPeriodesIntensite.ajouter(pas.getListePeriodeIntensite());
      }
    }
    return chroPeriodesIntensite;
  }
  
  private static Chronologie determinerChronoPeriodesHoraireStable(Periode p_periodeReference, Chronologie p_periodesIntensite)
  {
    Chronologie chronologieHoraireStable = new ChronologiePeriodes();
    Chronologie chronologieIntersection = trouverIntersectionChronologiePeriodeReference(p_periodeReference, p_periodesIntensite);
    
    Iterator itIntesectionTravail = chronologieIntersection.iterer();
    PeriodeIntensite piPrec = null;
    PeriodeHoraireStable phsCourante = null;
    PeriodeIntensite piCourant = null;
    while (itIntesectionTravail.hasNext())
    {
      piCourant = (PeriodeIntensite)itIntesectionTravail.next();
      if (chronologieHoraireStable.estVide())
      {
        phsCourante = new PeriodeHoraireStable(new Periode(piCourant.getDateDebut(), piCourant.getDateFin()), piCourant.getHorairesEntreprise(), piCourant.getHorairesSalarie());
        
        phsCourante.setUniteHoraire(piCourant.getUniteHoraire());
        chronologieHoraireStable.ajouter(phsCourante);
        piPrec = piCourant;
      }
      else
      {
        if ((piCourant.getDateDebut().estLendemainDe(piPrec.getDateFin())) && (piCourant.getHorairesEntreprise().equals(piPrec.getHorairesEntreprise())) && (piCourant.getHorairesSalarie().equals(piPrec.getHorairesSalarie())))
        {
          phsCourante.setDateFin(piCourant.getDateFin());
        }
        else
        {
          phsCourante = new PeriodeHoraireStable(new Periode(piCourant.getDateDebut(), piCourant.getDateFin()), piCourant.getHorairesEntreprise(), piCourant.getHorairesSalarie());
          
          phsCourante.setUniteHoraire(piCourant.getUniteHoraire());
          chronologieHoraireStable.ajouter(phsCourante);
        }
        piPrec = piCourant;
      }
    }
    return chronologieHoraireStable;
  }
  
  private static Chronologie trouverIntersectionChronologiePeriodeReference(Periode p_periodeReference, Chronologie p_periodeIntensite)
  {
    Chronologie chronologieIntersection = new ChronologiePeriodes();
    Iterator itPeriodeIntensite = p_periodeIntensite.iterer();
    if (itPeriodeIntensite != null) {
      while (itPeriodeIntensite.hasNext())
      {
        PeriodeIntensite pi = (PeriodeIntensite)itPeriodeIntensite.next();
        Periode intersection = pi.periodeIntersection(p_periodeReference);
        if (intersection != null) {
          if (intersection.coincideAvec(new Periode(pi.getDateDebut(), pi.getDateFin())))
          {
            chronologieIntersection.ajouter(pi);
          }
          else
          {
            PeriodeIntensite piDummy = new PeriodeIntensite(intersection);
            piDummy.setHorairesEntreprise(pi.getHorairesEntreprise());
            piDummy.setHorairesSalarie(pi.getHorairesSalarie());
            chronologieIntersection.ajouter(pi);
          }
        }
      }
    }
    return chronologieIntersection;
  }
  
  private static Chronologie deduireChronoPeriodeIntensite(List p_listePeriodes, Chronologie p_chroPeriodesIntensite)
  {
    Chronologie chronoPeriodeIntensite = new ChronologiePeriodes();
    Iterator itPeriodes = p_listePeriodes.iterator();
    Iterator itPeriodesIntensite = null;
    Periode periodeCourante = null;
    PeriodeIntensite periodeIntensiteCourante = null;
    Periode pDummy = null;
    PeriodeIntensite newPeriodeIntensite = null;
    while (itPeriodes.hasNext())
    {
      periodeCourante = (Periode)itPeriodes.next();
      itPeriodesIntensite = p_chroPeriodesIntensite.iterer();
      int nbPeriode = 0;
      BigDecimal horaireEntreprise = new BigDecimal(0);
      BigDecimal horaireSalarie = new BigDecimal(0);
      int uniteHoraire = 0;
      while (itPeriodesIntensite.hasNext())
      {
        periodeIntensiteCourante = (PeriodeIntensite)itPeriodesIntensite.next();
        pDummy = new Periode(periodeIntensiteCourante.getDateDebut(), periodeIntensiteCourante.getDateFin());
        if (periodeCourante.inter(pDummy) > 0)
        {
          horaireEntreprise = horaireEntreprise.add(periodeIntensiteCourante.getHorairesEntreprise());
          horaireSalarie = horaireSalarie.add(periodeIntensiteCourante.getHorairesSalarie());
          uniteHoraire = periodeIntensiteCourante.getUniteHoraire();
          nbPeriode++;
        }
      }
      if (nbPeriode > 1) {
        horaireEntreprise = Mathematiques.diviseParDefaut(horaireEntreprise, new BigDecimal(nbPeriode));
      }
      horaireSalarie = horaireSalarie.min(horaireEntreprise);
      newPeriodeIntensite = new PeriodeIntensite(periodeCourante);
      newPeriodeIntensite.setHorairesEntreprise(horaireEntreprise);
      newPeriodeIntensite.setHorairesSalarie(horaireSalarie);
      newPeriodeIntensite.setUniteHoraire(uniteHoraire);
      chronoPeriodeIntensite.ajouter(newPeriodeIntensite);
    }
    return chronoPeriodeIntensite;
  }
  
  private static int getNbHeuresTempsPlein(Damj p_date)
  {
    int nbheureTempsPlein;
    int nbheureTempsPlein;
    if (p_date.estApresOuCoincideAvec(DATE_PIVOT_TEMPS_PLEIN)) {
      nbheureTempsPlein = 35;
    } else {
      nbheureTempsPlein = 39;
    }
    return nbheureTempsPlein;
  }
}

/* Location:
 * Qualified Name:     DeterminationCoefficientTempsPartiel
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */