package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementCategorieA2B;
import fr.unedic.cali.asu.parametres.ParametresIndemnisationA2B;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Metier;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMemeRegime;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltresTemporel;
import java.math.BigDecimal;

public class DeterminationSjrip
  implements OutilFonctionnel
{
  public static Sjrip determinerSjrip(Prc p_prc, Demande p_demande)
    throws CoucheLogiqueException
  {
    Sjrip sjripRetourne = null;
    if (Log.isTraceActive(DeterminationSjrip.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, DeterminationSjrip.class, "determinerSjrip", "Début de la détermination du SJRIP.");
    }
    Reglement reglementApplicableCourant = ((DossierExamen)p_demande.getDossierExamen()).getReglementApplicable().getReglement();
    p_prc.determinerSrip(p_demande, reglementApplicableCourant, true);
    
    QuantiteEuro quantiteSjri = p_prc.getSjri();
    
    QuantiteEuro quantitePsjr = p_prc.getPlafondSjr();
    
    Damj dateEffetSjrip = p_prc.getDateFin();
    
    sjripRetourne = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionSjr().createSjrip(dateEffetSjrip, quantitePsjr, quantiteSjri);
    
    p_prc.viderChronologies();
    sjripRetourne.setPrc(p_prc);
    
    return sjripRetourne;
  }
  
  public static Sjrip determinerSjripPourA2B(Demande p_demande)
    throws CoucheLogiqueException
  {
    Sjrip sjripRetourne = null;
    if (Log.isTraceActive(DeterminationSjrip.class, Niveau.INFO)) {
      Log.ecritTrace(Niveau.INFO, DeterminationSjrip.class, "determinerSjripPourA2B", "Début de la détermination du SFJ pour A2B.");
    }
    int numeroCategorieA2b = 0;
    if ((p_demande.getSaisieAntecedent() != null) && (p_demande.getSaisieAntecedent().getCodeEmploiA2B() != null))
    {
      numeroCategorieA2b = p_demande.getSaisieAntecedent().getCodeEmploiA2B().intValue();
    }
    else
    {
      DecorReglementaire decor = ((DossierAffectation)p_demande.getDossierAffectation()).getDecorReglementaire();
      FiltresTemporel listeFiltres = new FiltresTemporel();
      listeFiltres.ajouterFiltre(new FiltreActiviteSalarie());
      listeFiltres.ajouterFiltre(new FiltreMemeRegime("A2b", decor));
      listeFiltres.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(p_demande.getDateExamen()));
      Chronologie chronoActivitesSalarieesA2bRetenues = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltres);
      
      chronoActivitesSalarieesA2bRetenues.setComparateur(new ComparateurTemporelsSurDateFin());
      ActiviteSalarie activiteSalarieeA2bRetenue = (ActiviteSalarie)chronoActivitesSalarieesA2bRetenues.premierElement();
      
      numeroCategorieA2b = activiteSalarieeA2bRetenue.getMetier().getCodeEmploi();
    }
    EvenementCategorieA2B evtA2B = ParametresIndemnisationA2B.getParametresIndemnisation().getElementActif(p_demande.getDossierExamen().getDateAttribution());
    
    BigDecimal salaireForfaitaireJournalier = evtA2B.getSalaireA2B(numeroCategorieA2b);
    
    QuantiteEuro quantiteSfj = new QuantiteEuro(salaireForfaitaireJournalier);
    
    sjripRetourne = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionSjr().createSjrip(p_demande.getDateExamen(), quantiteSfj, quantiteSfj);
    
    return sjripRetourne;
  }
  
  public static Sjrip determinerSjripPourReprise(Demande p_demande)
    throws CoucheLogiqueException
  {
    Sjrip sjripRetourne = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    
    Sjr sjrAServir = dossierExamenCourant.getAttributionPrecedente().getElementBaseIndemnisation().getSjr();
    
    sjripRetourne = ((DossierExamen)p_demande.getDossierExamen()).getConstitutionSjr().createSjrip(sjrAServir.getDateDepart(), null, new QuantiteEuro(sjrAServir.getSalaire()));
    
    return sjripRetourne;
  }
  
  public static int determinerCodeEmploiA2b(Demande p_demande)
  {
    int codeEmploi = 0;
    
    DecorReglementaire decor = ((DossierAffectation)p_demande.getDossierAffectation()).getDecorReglementaire();
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(new FiltreActiviteSalarie());
    listeFiltres.ajouterFiltre(new FiltreMemeRegime("A2b", decor));
    listeFiltres.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(p_demande.getDateExamen()));
    Chronologie chronoActivitesSalarieesA2bRetenues = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltres);
    
    chronoActivitesSalarieesA2bRetenues.setComparateur(new ComparateurTemporelsSurDateFin());
    if (!chronoActivitesSalarieesA2bRetenues.estVide())
    {
      ActiviteSalarie activiteSalarieeA2bRetenue = (ActiviteSalarie)chronoActivitesSalarieesA2bRetenues.premierElement();
      if (activiteSalarieeA2bRetenue != null) {
        codeEmploi = activiteSalarieeA2bRetenue.getMetier().getCodeEmploi();
      }
    }
    return codeEmploi;
  }
}

/* Location:
 * Qualified Name:     DeterminationSjrip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */