package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.dom.ConteneurConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.OutilGestionActivitesConservees;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.strategies.spec.StrategieActiviteConserveeConvention2014Spec;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionActiviteConservee;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Decision;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.JustificationSjc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p03.parametres.Parametres;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.Salaire;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P03;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreMemeDateFin;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.Map;

public class RechercheConditionCumulActiviteConservee
  implements OutilFonctionnel
{
  private static final BigDecimal COEFFICIENT_MENSUEL = new BigDecimal("30");
  
  public static void mapperConteneurVersConditionActiviteConservee(ConteneurConditionActiviteConservee p_conteneurConditionActiviteConservee, ConditionActiviteConservee p_conditionActiviteConservee)
  {
    p_conditionActiviteConservee.setCodeMotifEchec(p_conteneurConditionActiviteConservee.getCodeMotifEchec());
    p_conditionActiviteConservee.setEtat(p_conteneurConditionActiviteConservee.getEtat());
    p_conditionActiviteConservee.setMontantMensuelActiviteConservee(p_conteneurConditionActiviteConservee.getMontantMensuelActiviteConservee());
    p_conditionActiviteConservee.setNombreHeuresMensuelActiviteConservee(p_conteneurConditionActiviteConservee.getNombreHeuresMensuelActiviteConservee());
    p_conditionActiviteConservee.setSeuilMontantMensuelActiviteConservee(p_conteneurConditionActiviteConservee.getSeuilMontantMensuelActiviteConservee());
    p_conditionActiviteConservee.setSituationConditionActiviteConservee(p_conteneurConditionActiviteConservee.getSituationConditionActiviteConservee());
  }
  
  public static ConteneurConditionActiviteConservee rechercherConditionCumulActiviteConservee(Demande demande, Chronologie chronoActivitesSalarieesConservees)
    throws CoucheLogiqueException
  {
    ConteneurConditionActiviteConservee conteneurConditionActiviteConservee = new ConteneurConditionActiviteConservee();
    if (!demande.getDonneesTemporaires().isEstLeveeConditionACMemeEmployeur())
    {
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteSalarie());
      filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
      filtres.ajouterFiltre(new FiltrePeriodesQualifiables());
      filtres.ajouterFiltre(new FiltreMemeDateFin(demande.getFaitGenerateur().getDateFaitGenerateur()));
      Chronologie chronoActivitesSalarieesPerduesAuFgd = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      
      ActiviteSalarie activiteSalariePerdueCourante = null;
      ActiviteSalarie activiteSalarieConserveeCourante = null;
      String employeurActivitePerdue = null;
      String employeurActiviteConservee = null;
      do
      {
        chronoActivitesSalarieesPerduesAuFgd.iterer();
        while (!chronoActivitesSalarieesConservees.encoreSuivant())
        {
          if (!chronoActivitesSalarieesPerduesAuFgd.encoreSuivant()) {
            break;
          }
          activiteSalariePerdueCourante = (ActiviteSalarie)chronoActivitesSalarieesPerduesAuFgd.elementSuivant();
          
          employeurActivitePerdue = activiteSalariePerdueCourante.getEntreprise().getIdentifiantBNE();
          
          chronoActivitesSalarieesConservees.iterer();
        }
        activiteSalarieConserveeCourante = (ActiviteSalarie)chronoActivitesSalarieesConservees.elementSuivant();
        
        employeurActiviteConservee = activiteSalarieConserveeCourante.getEntreprise().getIdentifiantBNE();
      } while (employeurActiviteConservee.compareTo(employeurActivitePerdue) != 0);
      conteneurConditionActiviteConservee.setEtatSatisfait(false);
      conteneurConditionActiviteConservee.setCodeMotifEchec(122);
      conteneurConditionActiviteConservee.setSituationConditionActiviteConservee(1);
      return conteneurConditionActiviteConservee;
    }
    StrategieActiviteConserveeConvention2014Spec strategieActiviteConservee = OutilGestionActivitesConservees.getInstance().recupererStrategieActiviteConserveeConvention2014(demande);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    ProduitSpec produit = ((DossierAffectation)demande.getDossierAffectation()).getProduit();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    boolean estReglementApplicableA4 = reglementApplicableCourant.equals(produit.getReglement("A4"));
    if (strategieActiviteConservee.verifierSeuilsConditionActiviteConservee(estReglementApplicableA4)) {
      if (!demande.getDonneesTemporaires().isConditionCumulActiviteConserveeRemplie())
      {
        Periode periodeMoisCivilPrecedantDateExamen = determinerMoisCivilPrecedantDateExamen(demande);
        BigDecimal heuresActiviteConserveeSurMoisCivil = determinerHeuresActiviteConserveeSurMoisCivil(periodeMoisCivilPrecedantDateExamen, chronoActivitesSalarieesConservees);
        
        conteneurConditionActiviteConservee.setNombreHeuresMensuelActiviteConservee(heuresActiviteConserveeSurMoisCivil);
        
        JustificationSjc justificationSjc = new JustificationSjc();
        justificationSjc.setSeuilHoraire(Parametres.PLAFOND_HORAIRE_ACTIVITES_CONSERVEES);
        ((DossierExamen)demande.getDossierExamen()).getConstitutionSjc().setJustificationSjc(justificationSjc);
        if (heuresActiviteConserveeSurMoisCivil.compareTo(Parametres.PLAFOND_HORAIRE_ACTIVITES_CONSERVEES) > 0)
        {
          conteneurConditionActiviteConservee.setEtatSatisfait(false);
          conteneurConditionActiviteConservee.setSituationConditionActiviteConservee(2);
          conteneurConditionActiviteConservee.setCodeMotifEchec(121);
          return conteneurConditionActiviteConservee;
        }
        BigDecimal remunerationBruteConserveeSurMoisCivil = determinerRemunerationBruteConserveeSurMoisCivil(periodeMoisCivilPrecedantDateExamen, chronoActivitesSalarieesConservees);
        
        BigDecimal plafondMensuelRemuneration = determinerPlafondMensuelRemuneration(demande, demande.getDateExamen());
        conteneurConditionActiviteConservee.setMontantMensuelActiviteConservee(remunerationBruteConserveeSurMoisCivil);
        conteneurConditionActiviteConservee.setSeuilMontantMensuelActiviteConservee(plafondMensuelRemuneration);
        if (remunerationBruteConserveeSurMoisCivil.compareTo(plafondMensuelRemuneration) > 0)
        {
          conteneurConditionActiviteConservee.setEtatSatisfait(false);
          conteneurConditionActiviteConservee.setSituationConditionActiviteConservee(3);
          conteneurConditionActiviteConservee.setCodeMotifEchec(121);
          return conteneurConditionActiviteConservee;
        }
      }
      else
      {
        BigDecimal plafondMensuelRemuneration = determinerPlafondMensuelRemuneration(demande, demande.getDateExamen());
        conteneurConditionActiviteConservee.setSeuilMontantMensuelActiviteConservee(plafondMensuelRemuneration);
      }
    }
    conteneurConditionActiviteConservee.setEtatSatisfait(true);
    conteneurConditionActiviteConservee.setSituationConditionActiviteConservee(4);
    
    return conteneurConditionActiviteConservee;
  }
  
  public static BigDecimal determinerPlafondMensuelRemuneration(Demande p_demande, Damj p_dateRevalorisation)
    throws CoucheLogiqueException
  {
    BigDecimal remunerationMensuelleBruteAvantPerteActivite = determinerRemunerationMensuelleBruteAvantPerteActivite(p_demande, p_dateRevalorisation);
    BigDecimal plafondMensuelRemuneration = Parametres.POURCENTAGE_PLAFOND_REMUNERATION_ACTIVITES_CONSERVEES.multiply(remunerationMensuelleBruteAvantPerteActivite);
    plafondMensuelRemuneration = Mathematiques.arrondiASup(plafondMensuelRemuneration, 2);
    
    return plafondMensuelRemuneration;
  }
  
  private static Periode determinerMoisCivilPrecedantDateExamen(Demande p_demande)
  {
    Damj dateDebutMoisCivil = null;
    Damj dateFinMoisCivil = null;
    
    Damj dateExamen = p_demande.getDateExamen();
    if (dateExamen.estLaFinDuMois())
    {
      dateFinMoisCivil = dateExamen;
      dateDebutMoisCivil = dateExamen.getDebutMois();
    }
    else
    {
      dateFinMoisCivil = dateExamen.getFinMoisPrecedent();
      dateDebutMoisCivil = dateFinMoisCivil.getDebutMois();
    }
    return new Periode(dateDebutMoisCivil, dateFinMoisCivil);
  }
  
  private static BigDecimal determinerHeuresActiviteConserveeSurMoisCivil(Periode p_moisCivil, Chronologie p_chronoActivitesSalarieesConservees)
  {
    BigDecimal cumulHeures = new BigDecimal("0");
    Unite uniteHeure = Unite.get("heure de travail");
    
    ActiviteSalarie activiteSalarieConserveeCourante = null;
    Map<Unite, Quantite> tableQuantitesAffiliationProratiseesSurMois = null;
    p_chronoActivitesSalarieesConservees.iterer();
    while (p_chronoActivitesSalarieesConservees.encoreSuivant())
    {
      activiteSalarieConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConservees.elementSuivant();
      if ((!activiteSalarieConserveeCourante.getReglement().equals(ProduitAsuCge01P03.getInstance().getReglement("A1"))) && (activiteSalarieConserveeCourante.getCategorieEmploiParticulier() != 22) && (activiteSalarieConserveeCourante.getCategorieEmploiParticulier() != 23))
      {
        tableQuantitesAffiliationProratiseesSurMois = activiteSalarieConserveeCourante.determinerQuantitesAffiliationArrondie(p_moisCivil);
        cumulHeures = cumulHeures.add(((Quantite)tableQuantitesAffiliationProratiseesSurMois.get(uniteHeure)).getValeur());
      }
    }
    return cumulHeures;
  }
  
  private static BigDecimal determinerRemunerationBruteConserveeSurMoisCivil(Periode p_moisCivil, Chronologie p_chronoActivitesSalarieesConservees)
    throws CoucheLogiqueException
  {
    BigDecimal cumulRemuneration = new BigDecimal("0");
    BigDecimal remunerationCouranteMoisCivil = new BigDecimal("0");
    
    ActiviteSalarie activiteSalarieConserveeCourante = null;
    p_chronoActivitesSalarieesConservees.iterer();
    while (p_chronoActivitesSalarieesConservees.encoreSuivant())
    {
      activiteSalarieConserveeCourante = (ActiviteSalarie)p_chronoActivitesSalarieesConservees.elementSuivant();
      if (activiteSalarieConserveeCourante.getPeriode().chevauche(p_moisCivil))
      {
        boolean isTotalementSuspendu = false;
        FiltresTemporel filtres = new FiltresTemporel();
        filtres.ajouterFiltre(new FiltreIncident());
        Chronologie periodesSuspension = activiteSalarieConserveeCourante.getListePeriodesIncident().copier(filtres);
        int nbJourPeriode = 0;
        
        remunerationCouranteMoisCivil = DeterminationRemuneration.determinerRemunerationActiviteSalarieConserveeSurMoisCivil(activiteSalarieConserveeCourante, p_moisCivil);
        
        remunerationCouranteMoisCivil = Mathematiques.arrondiASup(remunerationCouranteMoisCivil, 2);
        if (remunerationCouranteMoisCivil.compareTo(new BigDecimal("0")) == 0)
        {
          if ((periodesSuspension != null) && (!periodesSuspension.estVide()))
          {
            for (Iterator iterperiodeSuspension = periodesSuspension.iterer(); iterperiodeSuspension.hasNext();)
            {
              IncidentSpec suspension = (IncidentSpec)iterperiodeSuspension.next();
              Periode periodeSuspension = suspension.getPeriode();
              if ((periodeSuspension.chevauche(p_moisCivil)) && (suspension.estTempsPlein())) {
                if (p_moisCivil.estContenueDans(periodeSuspension)) {
                  isTotalementSuspendu = true;
                }
              }
            }
            if (!isTotalementSuspendu)
            {
              Periode tmpPeriode = new Periode();
              if (activiteSalarieConserveeCourante.getDateDebut().estAvantOuCoincideAvec(p_moisCivil.getDebut())) {
                tmpPeriode.setDebut(p_moisCivil.getDebut());
              } else {
                tmpPeriode.setDebut(activiteSalarieConserveeCourante.getDateDebut());
              }
              if (activiteSalarieConserveeCourante.getDateFin().estApresOuCoincideAvec(p_moisCivil.getFin())) {
                tmpPeriode.setFin(p_moisCivil.getFin());
              } else {
                tmpPeriode.setFin(activiteSalarieConserveeCourante.getDateFin());
              }
              if (tmpPeriode.getDuree() == nbJourPeriode) {
                isTotalementSuspendu = true;
              }
            }
          }
          if (!isTotalementSuspendu)
          {
            Periode tmpPeriode = new Periode();
            if (activiteSalarieConserveeCourante.getDateDebut().estAvantOuCoincideAvec(p_moisCivil.getDebut())) {
              tmpPeriode.setDebut(p_moisCivil.getDebut());
            } else {
              tmpPeriode.setDebut(activiteSalarieConserveeCourante.getDateDebut());
            }
            if (activiteSalarieConserveeCourante.getDateFin().estApresOuCoincideAvec(p_moisCivil.getFin())) {
              tmpPeriode.setFin(p_moisCivil.getFin());
            } else {
              tmpPeriode.setFin(activiteSalarieConserveeCourante.getDateFin());
            }
            Chronologie chronoSalaires = activiteSalarieConserveeCourante.getListeSalaires();
            Salaire periodeSalaireCourant = null;
            chronoSalaires.iterer();
            boolean bContinue = true;
            while ((chronoSalaires.encoreSuivant()) && (bContinue))
            {
              periodeSalaireCourant = (Salaire)chronoSalaires.elementSuivant();
              if (periodeSalaireCourant.getPeriode().estContenueDans(p_moisCivil))
              {
                Quantite qteAbscence = periodeSalaireCourant.getQuantiteAbsence();
                if (qteAbscence != null)
                {
                  isTotalementSuspendu = true;
                }
                else
                {
                  isTotalementSuspendu = false;
                  
                  bContinue = false;
                }
              }
            }
          }
          if ((remunerationCouranteMoisCivil.compareTo(BigDecimal.ZERO) == 0) && (!isTotalementSuspendu))
          {
            String[] params = new String[4];
            String moisCivil = "";
            moisCivil = p_moisCivil.getFin().getMois() < 10 ? "0" + String.valueOf(p_moisCivil.getFin().getMois()) : String.valueOf(p_moisCivil.getFin().getMois());
            params[0] = moisCivil;
            params[1] = String.valueOf(p_moisCivil.getFin().getAnnee()).substring(2);
            params[2] = activiteSalarieConserveeCourante.getDateDebut().toString().substring(0, 6).concat(activiteSalarieConserveeCourante.getDateDebut().toString().substring(8));
            params[3] = activiteSalarieConserveeCourante.getDateFin().toString().substring(0, 6).concat(activiteSalarieConserveeCourante.getDateFin().toString().substring(8));
            
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB8", params);
          }
        }
        cumulRemuneration = cumulRemuneration.add(remunerationCouranteMoisCivil);
      }
    }
    return cumulRemuneration;
  }
  
  private static BigDecimal determinerRemunerationMensuelleBruteAvantPerteActivite(Demande p_demande, Damj p_dateRevalo)
    throws CoucheLogiqueException
  {
    BigDecimal remunerationMensuelle = null;
    
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    
    Sjr sjrrp = RevalorisationSalaire.revaloriserSjr(recupererSjrAServir(p_demande), p_dateRevalo);
    
    Sjc sjcrp = DeterminationSjcip.revaloriserSjcip(p_dateRevalo, dossierExamenCourant.getConstitutionSjc().getSjcip());
    
    remunerationMensuelle = COEFFICIENT_MENSUEL.multiply(sjrrp.getSalaire().add(sjcrp.getSalaire()));
    
    return remunerationMensuelle;
  }
  
  private static Sjr recupererSjrAServir(Demande p_demande)
  {
    Decision decision = (Decision)p_demande.getDossierExamen();
    
    AttributionAssuranceSpec attributionPrecedente = decision.getAttributionPrecedente();
    switch (decision.getNatureDecision())
    {
    case 11: 
      if (!p_demande.estEnContexteDroitAnterieurSecteurPublic()) {
        return attributionPrecedente.getElementBaseIndemnisation().getSjr();
      }
      return new Sjr(p_demande.getDonneesTemporaires().getSjrSP().getValeur(), p_demande.getDonneesTemporaires().getTermePrcSp(), null);
    case 26: 
      if (decision.getConstitutionProduitResultant().getMontantRetenu() == 1) {
        return new Sjr(decision.getConstitutionSjr().getSjrip().getSjrip(), decision.getConstitutionSjr().getSjrip().getDateEffet(), decision.getConstitutionSjr().getSjrip().getContexteParticulierSjr());
      }
      if (!p_demande.estEnContexteDroitAnterieurSecteurPublic()) {
        return attributionPrecedente.getElementBaseIndemnisation().getSjr();
      }
      return new Sjr(p_demande.getDonneesTemporaires().getSjrSP().getValeur(), p_demande.getDonneesTemporaires().getTermePrcSp(), null);
    }
    return new Sjr(decision.getConstitutionSjr().getSjrip().getSjrip(), decision.getConstitutionSjr().getSjrip().getDateEffet(), decision.getConstitutionSjr().getSjrip().getContexteParticulierSjr());
  }
}

/* Location:
 * Qualified Name:     RechercheConditionCumulActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */