package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parametres.AccesListeUnitesReglement;
import fr.unedic.cali.asu.parametres.ValeurListeUnitesReglement;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.QuantitesAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.DonneesEntreeDeterminationListePra;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class RechercheReglementApplicable
  implements OutilFonctionnel
{
  private static final int NB_CHIFFRE_APRES_VIRGULE = 10;
  
  public static ValidationProduit rechercher(Demande p_demande, ActiviteSalarie p_pas, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    ValidationProduit validationProduit = null;
    if ((p_demande == null) || (p_demande.getDemandeur() == null)) {
      return null;
    }
    Reglement reglementPropose = p_pas.getReglement();
    boolean estEnContexteDeRechargement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE");
    if (estEnContexteDeRechargement)
    {
      EreRechargement ereRechargement = (EreRechargement)p_demande.getEvenementReferenceExamen();
      reglementPropose = ereRechargement.getReglementForcePourRechargement();
    }
    DonneesEntreeDeterminationListePra donneesEntreeDeterminationListePra = new DonneesEntreeDeterminationListePra();
    donneesEntreeDeterminationListePra.setDemande(p_demande);
    donneesEntreeDeterminationListePra.setActiviteSalarie(p_pas);
    donneesEntreeDeterminationListePra.setForcerReglementRecharge(estEnContexteDeRechargement);
    donneesEntreeDeterminationListePra.setUtiliserParametreAffiRechargement(estEnContexteDeRechargement);
    donneesEntreeDeterminationListePra.setOrdreTriListe(ConstructionPra.ORDRE_REGLEMENT_APPLICABLE);
    Collection<Pra> listePra = ConstructionPra.determinerListePra(donneesEntreeDeterminationListePra);
    if ((listePra == null) || (listePra.isEmpty())) {
      return null;
    }
    validationProduit = premierExamen(p_demande, listePra, reglementPropose, p_avecPeriodeNonAttestee);
    if ((validationProduit == null) && 
      (determineConditionPram(p_demande, p_pas, reglementPropose, p_avecPeriodeNonAttestee))) {
      validationProduit = deuxiemeExamen(p_demande, listePra, reglementPropose, p_avecPeriodeNonAttestee);
    }
    if (validationProduit != null) {
      validationProduit.setPeriodeValidationProduit(p_pas);
    }
    return validationProduit;
  }
  
  private static ValidationProduit premierExamen(Demande p_demande, Collection p_listePra, Reglement p_reglement, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    for (Iterator iter = p_listePra.iterator(); iter.hasNext();)
    {
      Pra pra = (Pra)iter.next();
      ValidationProduit validationProduit = premierExamen(p_demande, pra, p_reglement, p_avecPeriodeNonAttestee);
      if (validationProduit != null)
      {
        validationProduit.setPeriodePra(new Periode(pra.getDebut(), pra.getFin()));
        return validationProduit;
      }
    }
    return null;
  }
  
  private static ValidationProduit premierExamen(Demande p_demande, Pra p_pra, Reglement p_reglement, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    Chronologie chronoPAS = determinerActivitesParticipantes(p_demande, p_pra, p_reglement, p_avecPeriodeNonAttestee, true);
    
    ValidationProduit validationProduit = null;
    QuantitesAppartenance qtesAcquises = null;
    qtesAcquises = verifierConditionAffiliation(p_demande, p_pra, chronoPAS, p_reglement);
    if (qtesAcquises != null)
    {
      validationProduit = new ValidationProduit();
      validationProduit.setReglementApplicable(p_reglement);
      validationProduit.setQuantiteAcquise(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenancePrincipale()).getValeur(), 10), qtesAcquises.getUniteAppartenancePrincipale()));
      if (qtesAcquises.getUniteAppartenanceSecondaire() != null) {
        validationProduit.setQuantiteAcquiseSecondaire(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenanceSecondaire()).getValeur(), 10), qtesAcquises.getUniteAppartenanceSecondaire()));
      }
    }
    return validationProduit;
  }
  
  private static ValidationProduit deuxiemeExamen(Demande p_demande, Collection p_listePra, Reglement p_reglement, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    for (Iterator iter = p_listePra.iterator(); iter.hasNext();)
    {
      Pra pra = (Pra)iter.next();
      ValidationProduit validationProduit = deuxiemeExamen(p_demande, pra, p_reglement, p_avecPeriodeNonAttestee);
      if (validationProduit != null)
      {
        validationProduit.setPeriodePra(new Periode(pra.getDebut(), pra.getFin()));
        return validationProduit;
      }
    }
    return null;
  }
  
  private static ValidationProduit deuxiemeExamen(Demande p_demande, Pra p_pra, Reglement p_reglement, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    Chronologie chronoPAS = determinerActivitesParticipantes(p_demande, p_pra, p_avecPeriodeNonAttestee);
    
    ValidationProduit validationProduit = null;
    QuantitesAppartenance qtesAcquises = null;
    qtesAcquises = verifierConditionAffiliation(p_demande, p_pra, chronoPAS, p_reglement);
    if (qtesAcquises != null)
    {
      validationProduit = new ValidationProduit();
      validationProduit.setReglementApplicable(p_reglement);
      validationProduit.setQuantiteAcquise(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenancePrincipale()).getValeur(), 10), qtesAcquises.getUniteAppartenancePrincipale()));
      if (qtesAcquises.getUniteAppartenanceSecondaire() != null) {
        validationProduit.setQuantiteAcquiseSecondaire(new Quantite(Mathematiques.arrondiASup(qtesAcquises.getQuantiteAppartenance(qtesAcquises.getUniteAppartenanceSecondaire()).getValeur(), 10), qtesAcquises.getUniteAppartenanceSecondaire()));
      }
    }
    return validationProduit;
  }
  
  private static QuantitesAppartenance verifierConditionAffiliation(Demande p_demande, Pra p_pra, Chronologie p_chronoPAS, Reglement p_reglementAppartenance)
    throws ApplicativeException
  {
    Quantite qteAcquise = null;
    QuantitesAppartenance quantitesAppartenance = null;
    
    Quantite quantiteAffiliationForcee = p_demande.getDonneesTemporaires().getQuantiteAffiliation();
    if (quantiteAffiliationForcee != null)
    {
      quantitesAppartenance = new QuantitesAppartenance();
      quantitesAppartenance.putQuantiteAffiliation(quantiteAffiliationForcee);
    }
    else
    {
      quantitesAppartenance = CalculAppartenance.getInstance().calculer(p_demande, null, p_pra, p_chronoPAS, p_reglementAppartenance);
    }
    boolean bAffiliationOk = false;
    Unite unite = null;
    Quantite qteAffiliation = null;
    Quantite qteAssimilation = null;
    BigDecimal valAcquise = null;
    BigDecimal valRequise = null;
    String contexteReglement = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(p_demande, "RECHARGE") ? "RECHARGE" : null;
    
    List listeUnites = AccesListeUnitesReglement.get(p_reglementAppartenance, contexteReglement).getListeUnites();
    Iterator iter = listeUnites.iterator();
    while ((!bAffiliationOk) && (iter.hasNext()))
    {
      unite = (Unite)iter.next();
      
      qteAffiliation = quantitesAppartenance.getQuantiteAffiliation(unite);
      if (qteAffiliation == null) {
        qteAffiliation = new Quantite("0", unite);
      }
      qteAssimilation = quantitesAppartenance.getQuantiteAssimilation(unite);
      if (qteAssimilation == null) {
        qteAssimilation = new Quantite("0", unite);
      }
      valAcquise = qteAffiliation.getValeur().add(qteAssimilation.getValeur());
      if (p_pra.getQuantiteAffiliationRequise(unite) != null)
      {
        valRequise = p_pra.getQuantiteAffiliationRequise(unite).getValeur();
        
        bAffiliationOk = valAcquise.compareTo(valRequise) >= 0;
        if (bAffiliationOk) {
          qteAcquise = new Quantite(valAcquise, unite);
        }
      }
    }
    if (qteAcquise != null)
    {
      quantitesAppartenance.setUniteAppartenancePrincipale(qteAcquise.getUnite());
      
      iter = listeUnites.iterator();
      do
      {
        if (!iter.hasNext()) {
          break;
        }
        unite = (Unite)iter.next();
      } while (unite.equals(qteAcquise.getUnite()));
      quantitesAppartenance.setUniteAppartenanceSecondaire(unite);
    }
    else
    {
      quantitesAppartenance = null;
    }
    return quantitesAppartenance;
  }
  
  protected static Chronologie determinerActivitesParticipantes(Demande p_demande, Periode p_periodeReference, Reglement p_reglement, boolean p_avecPeriodeNonAttestee, boolean p_assimilationIncluse)
  {
    Chronologie passeProfessionnel = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoActivitesSalariees = ConstructionChronologie.determinerChronoPraReglementPropose(p_periodeReference, p_reglement.getNomReglement(), passeProfessionnel, p_demande);
    
    return determinerActivitesParticipantes(chronoActivitesSalariees, passeProfessionnel, p_periodeReference, p_avecPeriodeNonAttestee, p_assimilationIncluse);
  }
  
  protected static Chronologie determinerActivitesParticipantes(Demande p_demande, Periode p_periodeReference, boolean p_avecPeriodeNonAttestee)
  {
    Chronologie passeProfessionnel = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoActivitesSalariees = ConstructionChronologie.determinerChronoPraTousReglement(p_periodeReference, passeProfessionnel);
    
    return determinerActivitesParticipantes(chronoActivitesSalariees, passeProfessionnel, p_periodeReference, p_avecPeriodeNonAttestee, true);
  }
  
  private static Chronologie determinerActivitesParticipantes(Chronologie p_chronoActivitesSalariees, Chronologie p_passeProfessionnel, Periode p_periodeReference, boolean p_avecPeriodeNonAttestee, boolean p_assimilationIncluse)
  {
    ChronologieStandard chronoActivitesSalarieesEtAssimilables = new ChronologieStandard();
    
    Chronologie chronoPeriodesParticipantes = fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(null, p_periodeReference, p_chronoActivitesSalariees, p_avecPeriodeNonAttestee);
    if (p_assimilationIncluse)
    {
      Chronologie chronoActivitesAssimilables = ConstructionChronologie.determinerChronoAssimilablePra(p_periodeReference, p_passeProfessionnel);
      chronoActivitesSalarieesEtAssimilables.ajouter(chronoActivitesAssimilables);
    }
    chronoActivitesSalarieesEtAssimilables.ajouter(chronoPeriodesParticipantes);
    
    return chronoActivitesSalarieesEtAssimilables;
  }
  
  protected static boolean determineConditionPram(Demande p_demande, ActiviteSalarie p_pas, Reglement p_reglement, boolean p_avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    boolean conditionremplie = false;
    
    Pra praMinimale = ConstructionPra.determinerPram(p_pas, p_demande);
    
    Chronologie chronoPAS = determinerActivitesParticipantes(p_demande, praMinimale, p_reglement, p_avecPeriodeNonAttestee, false);
    
    QuantitesAppartenance qtesAcquises = verifierConditionAffiliation(p_demande, praMinimale, chronoPAS, p_reglement);
    if (qtesAcquises != null) {
      conditionremplie = true;
    }
    return conditionremplie;
  }
}

/* Location:
 * Qualified Name:     RechercheReglementApplicable
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */