package fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.Competence;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSecurisationProfessionnelleSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public final class RecuperationElementIndemnisation
  implements OutilFonctionnel
{
  private static final int CINQUANTE = 50;
  
  public static ElementBaseIndemnisation recupererElementBaseIndemnisation(AttributionSpec attribution)
  {
    ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
    alimenterEBIavecAttribution(attribution, ebi);
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), 9))
    {
      ElementBaseIndemnisation sousEbiAspSousJacent = new ElementBaseIndemnisation();
      fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RecuperationElementIndemnisation.alimenterEBIavecAttributionEntreeAspSousJacent(attribution, sousEbiAspSousJacent);
      
      Collection<ElementBaseIndemnisation> listeSousEbiAdmissions = new ArrayList();
      alimenterListeEBIAvecODouNovationOuRevision(attribution, listeSousEbiAdmissions);
      
      Collection<ElementBaseIndemnisation> listeSousEbi = new ArrayList();
      listeSousEbi.add(sousEbiAspSousJacent);
      listeSousEbi.addAll(listeSousEbiAdmissions);
      ebi.setListeSousEBI(listeSousEbi);
    }
    return ebi;
  }
  
  private static void alimenterListeEBIAvecODouNovationOuRevision(AttributionSpec attribution, Collection<ElementBaseIndemnisation> listeSousEbi)
  {
    Attribution attributionCourante = (Attribution)attribution;
    
    Collection<DemandeAssuranceSpec> admissionsDurantDispositifCsp = OutilAsp.getInstance().recupererAdmissionsDurantDispositifCSP(attributionCourante);
    if (!admissionsDurantDispositifCsp.isEmpty())
    {
      Iterator<DemandeAssuranceSpec> iterDemande = admissionsDurantDispositifCsp.iterator();
      while (iterDemande.hasNext())
      {
        DemandeAssuranceSpec demande = (DemandeAssuranceSpec)iterDemande.next();
        ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
        alimenterEBIavecAttribution(demande.getAttribution(), ebi);
        
        ebi.setProduitMontantRetenu(demande.getAttribution().getProduitMontantRetenu());
        
        Competences competenceAttribution = creerConteneurCompetence(demande.getAttribution());
        ebi.setCompetence(competenceAttribution);
        
        ebi.setAvecPrecompteCRC(demande.getAttribution().estAvecPrecompteCRC());
        listeSousEbi.add(ebi);
      }
    }
  }
  
  private static void alimenterEBIavecAttribution(AttributionSpec pAttribution, ElementBaseIndemnisation ebi)
  {
    Attribution attribution = (Attribution)pAttribution;
    
    ebi.setSjr(getSJR(attribution));
    
    ebi.setCoefficientSaisonnier(getCoefficientSaisonnier(attribution));
    
    Quantite dureePostPrime = attribution.getDureePostPrime();
    if ((dureePostPrime != null) && (dureePostPrime.getValeurEntiere() == 0)) {
      ebi.setEstDureePostPrimeEpuisee(true);
    }
    if (attribution.getConstitutionCaractereSaisonnier() != null)
    {
      DureeCalendaire ageALAttribution = new DureeCalendaire(50);
      if (((Demande)attribution.getDemande()).getDonneesTemporaires().isCaractereSaisonnierForce())
      {
        if (((Demande)attribution.getDemande()).getDonneesTemporaires().getTypeCaractereSaisonnierForce() == 1) {
          if (ageALAttribution.compareTo(attribution.getDemandeur().getAgeALaDate(attribution.getDemande().getDateDeclenchementExamen())) > 0) {
            ebi.setIsConditionCaractereSaisonnierParRythme(true);
          } else {
            ebi.setIsConditionCaractereSaisonnierParRythme(attribution.getConstitutionCaractereSaisonnier().isActivite3Sur5());
          }
        }
      }
      else {
        ebi.setIsConditionCaractereSaisonnierParRythme(attribution.getConstitutionCaractereSaisonnier().isActivite3Sur5());
      }
      ebi.setTypeCaractereSaisonnierRetenu(attribution.getConstitutionCaractereSaisonnier().getTypeCaractereSaisonnierRetenu());
    }
    else
    {
      ebi.setIsConditionCaractereSaisonnierParRythme(false);
      ebi.setTypeCaractereSaisonnierRetenu(-1);
    }
    ebi.setCoefficientTempsPartiel(getCoefficientTempsPartiel(attribution));
    
    ebi.setIsSjrBaseSurPourcentageSMIC(attribution.isTopContratsRemuneresBaseSmic());
    if (attribution.getConstitutionSjr() != null) {
      ebi.setCodeEmploiA2B(attribution.getConstitutionSjr().getCodeEmploiA2b());
    }
    ebi.setReglementApplicableMontantRetenu(attribution.getReglementApplicable());
    if (((pAttribution.getDemande() != null) && (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)pAttribution.getDemande(), "ARECOURCSP"))) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)pAttribution.getDemande(), "AREENTRCSP"))) {
      ebi.setProduitAreActif(pAttribution.getProduit());
    } else if ((pAttribution.getProduit() instanceof ProduitSecurisationProfessionnelleSpec)) {
      ebi.setProduitAreActif(((ProduitSecurisationProfessionnelleSpec)pAttribution.getProduit()).recupererProduitAreActif(pAttribution));
    }
  }
  
  public static ElementBaseIndemnisation recupererElementBaseIndemnisation(DonneesTemporaires donneesForcees)
  {
    return recupererElementBaseIndemnisation(donneesForcees, null);
  }
  
  public static ElementBaseIndemnisation recupererElementBaseIndemnisation(DonneesTemporaires donneesForcees, AttributionSpec pattribution)
  {
    ElementBaseIndemnisation ebi = new ElementBaseIndemnisation();
    
    ebi.setSjr(new Sjr(donneesForcees.getSjrSP().getValeur(), donneesForcees.getTermePrcSp(), null));
    
    ebi.setCoefficientSaisonnier(donneesForcees.getCoefficientSaisonnierSp());
    
    ebi.setIsConditionCaractereSaisonnierParRythme(false);
    ebi.setTypeCaractereSaisonnierRetenu(donneesForcees.getTypeCaractereSaisonnierForce());
    
    ebi.setCoefficientTempsPartiel(donneesForcees.getCoefficientTempsPartielSp());
    
    ebi.setIsSjrBaseSurPourcentageSMIC(false);
    
    ebi.setReglementApplicableMontantRetenu(null);
    if (pattribution != null)
    {
      Attribution attribution = (Attribution)pattribution;
      ebi.setReglementApplicableMontantRetenu(attribution.getReglementApplicable());
    }
    return ebi;
  }
  
  private static Sjr getSJR(Attribution attribution)
  {
    Sjr sjrTemporaire = null;
    if ((attribution.getConstitutionSjr() != null) && (attribution.getConstitutionSjr().getSjrip() != null)) {
      sjrTemporaire = new Sjr(attribution.getConstitutionSjr().getSjrip().getSjrInitial().getValeur(), attribution.getConstitutionSjr().getSjrip().getDateEffet(), null);
    }
    return sjrTemporaire;
  }
  
  private static BigDecimal getCoefficientTempsPartiel(Attribution attribution)
  {
    BigDecimal valeurCoefficientTempsPartiel = null;
    if ((attribution.getReglementApplicable() != null) && (attribution.getReglementApplicable().getReglement() != null) && (attribution.getReglementApplicable().getReglement().equals(attribution.getProduit().getReglement("A4")))) {
      valeurCoefficientTempsPartiel = BigDecimal.ONE;
    } else if (attribution.getConstitutionCoefficientTempsPartiel() != null) {
      valeurCoefficientTempsPartiel = attribution.getConstitutionCoefficientTempsPartiel().getCoefficientTempsPartielRetenu();
    }
    if (valeurCoefficientTempsPartiel == null) {
      valeurCoefficientTempsPartiel = BigDecimal.ONE;
    }
    return valeurCoefficientTempsPartiel;
  }
  
  private static BigDecimal getCoefficientSaisonnier(Attribution attribution)
  {
    BigDecimal valeurCoefficientSaisonnier = null;
    if (attribution.getConstitutionCoefficientSaisonnier() != null) {
      valeurCoefficientSaisonnier = attribution.getConstitutionCoefficientSaisonnier().getCoefficientSaisonnierRetenu();
    }
    if (valeurCoefficientSaisonnier == null) {
      valeurCoefficientSaisonnier = BigDecimal.ONE;
    }
    return valeurCoefficientSaisonnier;
  }
  
  private static Competences creerConteneurCompetence(AttributionAssuranceSpec attribution)
  {
    Competences conteneurCompetences = new Competences();
    conteneurCompetences.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
    conteneurCompetences.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
    conteneurCompetences.setConventionGestion(attribution.getConventionGestion());
    if ((attribution.getCompetence() instanceof Competence)) {
      conteneurCompetences.setEstPCRCForce(((Competence)attribution.getCompetence()).isEstPCRCForce());
    }
    return conteneurCompetences;
  }
}

/* Location:
 * Qualified Name:     RecuperationElementIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */