package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionCoefficientTempsPartiel;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Reprise;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ConstitutionCoefficientTempsPartielPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution du coefficient Temps Partiel.");
    }
    if (((DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen()).getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution est null pour la constitution du coefficient Temps Partiel.");
    }
    if (((((DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen()).getAttributionPrecedente() instanceof Reprise)) && 
      (((Reprise)getAttribution(p_contexte)).getAttributionPrecedente() == null)) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution précédente est null: constitution du coefficient Temps Partiel impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionCoefficientTempsPartielPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientTempsPartiel.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientTempsPartielPourReprise.class, "demarrer", "\t\t******** Début Parcours ConstitutionCoefficientTempsPartielPourReprise ********");
    }
    Resultat resultat = new Resultat(0);
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ElementBaseIndemnisation elementBaseIndemnisation = dossierExamenCourant.getAttributionPrecedente().getElementBaseIndemnisation();
    if (elementBaseIndemnisation != null)
    {
      ConstitutionCoefficientTempsPartiel cepr11 = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionCoefficientTempsPartiel();
      
      cepr11.setCoefficientTempsPartielRetenu(elementBaseIndemnisation.getCoefficientTempsPartiel());
    }
    if (Log.isTraceActive(ConstitutionCoefficientTempsPartiel.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientTempsPartiel.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientTempsPartiel.class, "demarrer", "\t\t******** Résultat Parcours ConstitutionCoefficientTempsPartiel ********\n" + resultat);
      
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientTempsPartiel.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionCoefficientTempsPartiel.class, "demarrer", "\t\t******** Fin Parcours ConstitutionCoefficientTempsPartiel ********\n");
    }
    return resultat;
  }
  
  private DemandeSpec getDemande(Contexte p_contexte)
  {
    return ((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec();
  }
  
  private AttributionSpec getAttribution(Contexte p_contexte)
  {
    return ((Demande)((DomLiquidationDemande)p_contexte.getDonnees()).getDemandeSpec()).getAttribution();
  }
}

/* Location:
 * Qualified Name:     ConstitutionCoefficientTempsPartielPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */