package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIccp;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarenceIslr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDelais;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Differe;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.EnsembleCarences;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireIndemnisable;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PreavisMesureConservatoireNonIndemnisable;
import fr.unedic.cali.asu.dom.CarenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilCarence;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.ListIterator;

public class ConstitutionDelaiReportPourRevision
  extends ConstitutionDelaiReportPourReprise
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null pour la constitution des délais reports.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "Le dossier examen courant est null: constitution des délais reports impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDelais constitutionDelais = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDelais();
    
    Collection listeDelaisReports = getDelaiReport(dossierExamenCourant);
    
    Iterator iter = listeDelaisReports.iterator();
    while (iter.hasNext())
    {
      Differe element = (Differe)iter.next();
      if (element != null) {
        dossierExamenCourant.getConstitutionDelais().ajouterDelaisReports((Differe)element.copie());
      }
    }
    ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit((Attribution)dossierExamenCourant, null, false);
    
    alimenterResultatCepaDepuisResultatCalcul(resultatCalcul, constitutionDelais, demande);
    
    OutilTrace.tracerFinParcours();
    return new Resultat();
  }
  
  protected Collection getDelaiReport(DossierExamen p_dossierExamenCourant)
  {
    Collection listeDelaiReport = new ArrayList();
    
    Damj dateAttributionRevision = p_dossierExamenCourant.getDateAttribution();
    Damj pjiAttributionPrecedente = ((Attribution)p_dossierExamenCourant.getAttributionPrecedente()).getConstitutionPointDepartIndemnisation().getPji();
    
    Damj debutProchaineCarence = dateAttributionRevision;
    if (dateAttributionRevision.estAvant(pjiAttributionPrecedente))
    {
      Collection listeEnsembleCarence = ((DossierExamen)p_dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais().getListeEnsembleCarences();
      
      Iterator it = listeEnsembleCarence.iterator();
      while (it.hasNext())
      {
        EnsembleCarences ensembleCarence = (EnsembleCarences)it.next();
        EnsembleCarences nouvelEnsembleCarence = new EnsembleCarences();
        
        debutProchaineCarence = dateAttributionRevision;
        
        nouvelEnsembleCarence.setCarencePmc(definirCarencePMC(ensembleCarence, dateAttributionRevision, debutProchaineCarence));
        debutProchaineCarence = definirProchainDebutCarence(nouvelEnsembleCarence.getCarencePmc(), debutProchaineCarence);
        
        nouvelEnsembleCarence.setCarenceIccp(definirCarenceIccp(ensembleCarence, dateAttributionRevision, debutProchaineCarence));
        debutProchaineCarence = definirProchainDebutCarence(nouvelEnsembleCarence.getCarenceIccp(), debutProchaineCarence);
        
        nouvelEnsembleCarence.setCarenceIslr(definirCarenceIslr(ensembleCarence, dateAttributionRevision, debutProchaineCarence));
        debutProchaineCarence = definirProchainDebutCarence(nouvelEnsembleCarence.getCarenceIslr(), debutProchaineCarence);
        
        p_dossierExamenCourant.getConstitutionDelais().ajouterEnsembleCarences(nouvelEnsembleCarence);
      }
      Collection listeDelaiReportAttributionPrecedente = ((DossierExamen)p_dossierExamenCourant.getAttributionPrecedente()).getConstitutionDelais().getListeDelaisReports();
      
      Differe differe = definirDiffere(listeDelaiReportAttributionPrecedente, debutProchaineCarence);
      if (differe != null) {
        listeDelaiReport.add(differe);
      }
    }
    return listeDelaiReport;
  }
  
  private PreavisMesureConservatoireNonIndemnisable definirCarencePMC(EnsembleCarences p_ensembleCarence, Damj p_dateAttributionRevision, Damj p_debutPochaineCarence)
  {
    PreavisMesureConservatoireNonIndemnisable pmc = null;
    if (p_ensembleCarence.getCarencePmc() != null)
    {
      Periode periodePMCOrigine = p_ensembleCarence.getCarencePmc().getPeriodeApplicationCarence();
      if (p_dateAttributionRevision.estContenueDans(periodePMCOrigine))
      {
        int nbrJours = p_dateAttributionRevision.veille().joursEntre(periodePMCOrigine.getFin());
        Damj dateFinNouvelleCarence = p_debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, nbrJours)).veille();
        Periode periodeCarencePMC = new Periode(p_debutPochaineCarence, dateFinNouvelleCarence);
        pmc = new PreavisMesureConservatoireNonIndemnisable(p_ensembleCarence.getCarencePmc().getOrigine(), periodeCarencePMC);
      }
      else if (p_dateAttributionRevision.estAvant(periodePMCOrigine.getDebut()))
      {
        Periode periodeCarencePMC = new Periode(periodePMCOrigine.getDebut(), periodePMCOrigine.getFin());
        pmc = new PreavisMesureConservatoireNonIndemnisable(p_ensembleCarence.getCarencePmc().getOrigine(), periodeCarencePMC);
      }
    }
    if (pmc != null)
    {
      Damj finProchainePeriode = p_debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, pmc.getQuantiteInitialJour())).veille();
      Periode periodeApplicationCarence = new Periode(p_debutPochaineCarence, finProchainePeriode);
      pmc.setPeriodeApplicationCarence(periodeApplicationCarence);
    }
    return pmc;
  }
  
  private CarenceIslr definirCarenceIslr(EnsembleCarences p_ensembleCarence, Damj p_dateAttributionRevision, Damj p_debutPochaineCarence)
  {
    CarenceIslr carence = null;
    if (p_ensembleCarence.getCarenceIslr() != null)
    {
      Periode periodeISLROrigine = p_ensembleCarence.getCarenceIslr().getPeriodeApplicationCarence();
      if (p_dateAttributionRevision.estContenueDans(periodeISLROrigine))
      {
        int nbrJours = p_dateAttributionRevision.veille().joursEntre(periodeISLROrigine.getFin());
        carence = new CarenceIslr(p_ensembleCarence.getCarenceIslr().getOrigine(), nbrJours);
      }
      else if (p_dateAttributionRevision.estAvant(periodeISLROrigine.getDebut()))
      {
        int nbrJours = periodeISLROrigine.getDuree();
        carence = new CarenceIslr(p_ensembleCarence.getCarenceIslr().getOrigine(), nbrJours);
      }
    }
    if (carence != null)
    {
      Damj finProchainePeriode = p_debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, carence.getQuantiteInitialJour())).veille();
      Periode periodeApplicationCarence = new Periode(p_debutPochaineCarence, finProchainePeriode);
      carence.setPeriodeApplicationCarence(periodeApplicationCarence);
    }
    return carence;
  }
  
  private CarenceIccp definirCarenceIccp(EnsembleCarences p_ensembleCarence, Damj p_dateAttributionRevision, Damj p_debutPochaineCarence)
  {
    CarenceIccp carence = null;
    if (p_ensembleCarence.getCarenceIccp() != null)
    {
      Periode periodeICCPOrigine = p_ensembleCarence.getCarenceIccp().getPeriodeApplicationCarence();
      if (p_dateAttributionRevision.estContenueDans(periodeICCPOrigine))
      {
        int nbrJours = p_dateAttributionRevision.veille().joursEntre(periodeICCPOrigine.getFin());
        carence = new CarenceIccp(p_ensembleCarence.getCarenceIccp().getOrigine(), nbrJours);
      }
      else if (p_dateAttributionRevision.estAvant(periodeICCPOrigine.getDebut()))
      {
        int nbrJours = periodeICCPOrigine.getDuree();
        carence = new CarenceIccp(p_ensembleCarence.getCarenceIccp().getOrigine(), nbrJours);
      }
    }
    if (carence != null)
    {
      Damj finProchainePeriode = p_debutPochaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, carence.getQuantiteInitialJour())).veille();
      Periode periodeApplicationCarence = new Periode(p_debutPochaineCarence, finProchainePeriode);
      carence.setPeriodeApplicationCarence(periodeApplicationCarence);
    }
    return carence;
  }
  
  private Differe definirDiffere(Collection p_listeDelaiReport, Damj p_debutProchaineCarence)
  {
    Iterator itDelaiReport = p_listeDelaiReport.iterator();
    if (itDelaiReport.hasNext())
    {
      Differe differeReference = (Differe)itDelaiReport.next();
      boolean ajouterReport = false;
      Damj dateDebutPeriodeEffet = p_debutProchaineCarence;
      Damj dateFinPeriodeEffet = null;
      int nbrJours = 0;
      if (p_debutProchaineCarence.estContenueDans(differeReference.getPeriodeEffet()))
      {
        nbrJours = p_debutProchaineCarence.veille().joursEntre(differeReference.getPeriodeEffet().getFin());
        dateFinPeriodeEffet = p_debutProchaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, nbrJours));
        ajouterReport = true;
      }
      else if (p_debutProchaineCarence.estAvant(differeReference.getPeriodeEffet().getDebut()))
      {
        nbrJours = differeReference.getQuantiteInitialJour();
        dateFinPeriodeEffet = p_debutProchaineCarence.deplacerVersAvant(new DureeCalendaire(0, 0, nbrJours));
        ajouterReport = true;
      }
      if (ajouterReport)
      {
        Differe differe = new Differe();
        differe.setPeriodeEffet(new Periode(dateDebutPeriodeEffet, dateFinPeriodeEffet));
        differe.setQuantiteInitialJour(nbrJours);
        return differe;
      }
    }
    return null;
  }
  
  private Damj definirProchainDebutCarence(CarencePrefixeAFixer p_carence, Damj p_dateDebutProchaineCarence)
  {
    if (p_carence != null) {
      return p_carence.getPeriodeApplicationCarence().getFin().lendemain();
    }
    return p_dateDebutProchaineCarence;
  }
  
  private static void alimenterResultatCepaDepuisResultatCalcul(ResultatExecutionCalculSpec p_resultat, ConstitutionDelais p_cepa, Demande p_demande)
    throws CoucheLogiqueException
  {
    ListIterator iter;
    if (p_resultat.getListeCarencesEffectives() != null) {
      for (iter = p_resultat.getListeCarencesEffectives().listIterator(); iter.hasNext();)
      {
        CarenceSpec carence = (CarenceSpec)iter.next();
        if ((carence instanceof CarenceIccp))
        {
          CarenceIccp carenceIccp = (CarenceIccp)carence;
          if (carenceIccp.getPeriodeApplicationCarence() != null)
          {
            p_cepa.setDebutCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getDebut());
            p_cepa.setTermeCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getFin());
            p_cepa.setNbJoursCarenceICCP(carenceIccp.getPeriodeApplicationCarence().getDuree());
          }
          if (p_cepa.getDebutPmcIndemnisable() == null)
          {
            PreavisMesureConservatoireIndemnisable pmci = carenceIccp.getEnsembleCarences().getPmcIndemnisable();
            if (pmci != null)
            {
              p_cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
              p_cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
              p_cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
            }
          }
        }
        if ((carence instanceof CarenceIslr))
        {
          CarenceIslr carenceIslr = (CarenceIslr)carence;
          if (carenceIslr.getPeriodeApplicationCarence() != null)
          {
            p_cepa.setDebutCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getDebut());
            p_cepa.setTermeCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getFin());
            p_cepa.setNbJoursCarenceISLR(carenceIslr.getPeriodeApplicationCarence().getDuree());
            if (carenceIslr.getEnsembleCarences().isPresenceTransaction()) {
              leverAlerteA11MNB4SurCarenceIslr(p_demande, (ActiviteSalarie)carenceIslr.getOrigine());
            }
          }
          if (p_cepa.getDebutPmcIndemnisable() == null)
          {
            PreavisMesureConservatoireIndemnisable pmci = carenceIslr.getEnsembleCarences().getPmcIndemnisable();
            if (pmci != null)
            {
              p_cepa.setDebutPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDebut());
              p_cepa.setTermePmcIndemnisable(pmci.getPeriodeApplicationPMC().getFin());
              p_cepa.setNbJoursPmcIndemnisable(pmci.getPeriodeApplicationPMC().getDuree());
            }
          }
        }
        if ((carence instanceof PreavisMesureConservatoireNonIndemnisable))
        {
          PreavisMesureConservatoireNonIndemnisable carencePmc = (PreavisMesureConservatoireNonIndemnisable)carence;
          if (carencePmc.getPeriodeApplicationCarence() != null)
          {
            p_cepa.setDebutCarencePMC(carencePmc.getPeriodeApplicationCarence().getDebut());
            p_cepa.setTermeCarencePMC(carencePmc.getPeriodeApplicationCarence().getFin());
            p_cepa.setNbJoursCarencePMC(carencePmc.getPeriodeApplicationCarence().getDuree());
          }
        }
      }
    }
    Differe differe = (Differe)OutilCarence.trouverCarence(p_resultat.getListeCarencesEffectives(), "Différé");
    if (differe != null)
    {
      p_cepa.setDebutCarenceDiffere(differe.getPeriodeEffet().getDebut());
      p_cepa.setTermeCarenceDiffere(differe.getPeriodeEffet().getFin());
      p_cepa.setNbJoursCarenceDiffere(differe.getQuantiteInitialJour());
    }
  }
  
  private static void leverAlerteA11MNB4SurCarenceIslr(Demande p_demande, ActiviteSalarie p_periodeActiviteSalarieCourante)
  {
    Collection listeActivitesSalariees = null;
    
    String codeAlerteNonBloquante = "A11MNB4";
    if (p_demande.getAlertesNonBloquantes().containsKey(codeAlerteNonBloquante))
    {
      listeActivitesSalariees = (Collection)p_demande.getAlertesNonBloquantes().get(codeAlerteNonBloquante);
      
      ObjetAlertesNonBloquantes objetAlertesNonBloquantes = new ObjetAlertesNonBloquantes(p_periodeActiviteSalarieCourante);
      if (!listeActivitesSalariees.contains(objetAlertesNonBloquantes)) {
        listeActivitesSalariees.add(objetAlertesNonBloquantes);
      }
    }
    else
    {
      listeActivitesSalariees = new ArrayList();
      
      listeActivitesSalariees.add(new ObjetAlertesNonBloquantes(p_periodeActiviteSalarieCourante));
      p_demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listeActivitesSalariees);
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionDelaiReportPourRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */