package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DelaiRecherche;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationSjrip;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class ConstitutionSjr
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final int DUREE_VINGT_SEPT_JOURS = 27;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjr impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen() == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est null: constitution du Sjr impossible.");
    }
    DossierExamenAssuranceSpec dossierExamenCourant = (DossierExamenAssuranceSpec)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Le règlement applicable est null: constitution du Sjr impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    Resultat resultatCEPA07 = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    
    fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr constitutionSjr = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionSjr();
    
    Sjrip sjripCourant = null;
    Periode periodeReferenceCalcul = null;
    
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    
    Quantite sjrSaisi = demandeCourante.getDonneesTemporaires().getSjr();
    if (sjrSaisi != null)
    {
      if (reglementApplicableCourant.equals(produit.getReglement("A2b"))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A16MB2");
      }
      QuantiteEuro quantiteSjr = new QuantiteEuro(sjrSaisi.getValeur());
      
      Damj termePrcSaisi = demandeCourante.getDonneesTemporaires().getTermePrc();
      
      periodeReferenceCalcul = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerPrc(demandeCourante);
      OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Prc : ", periodeReferenceCalcul });
      Prc prcCourante = new PrcSjr(periodeReferenceCalcul);
      
      sjripCourant = dossierExamenCourant.getConstitutionSjr().createSjrip(termePrcSaisi, prcCourante.getPlafondSjr(), quantiteSjr);
      
      sjripCourant.setPrc(prcCourante);
    }
    else
    {
      constitutionSjr.createJustificationSjr();
      sjripCourant = constitutionSjr.createSjrip();
      if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
      {
        sjripCourant = DeterminationSjrip.determinerSjripPourA2B(demandeCourante);
        
        setCodeEmploiA2B(demandeCourante);
      }
      else
      {
        periodeReferenceCalcul = ((DelaiRecherche)DelaiRecherche.getInstance()).determinerPrc(demandeCourante);
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Prc : ", periodeReferenceCalcul });
        try
        {
          Chronologie pnds = demandeCourante.getChronologiePNDS(periodeReferenceCalcul);
          if ((pnds != null) && (!pnds.estVide())) {
            leverAlerteNonBloquanteA11MNB10(demandeCourante, pnds);
          }
        }
        catch (ApplicativeException e)
        {
          throw new CoucheLogiqueException(e.getCode(), e.getLibelle(), e);
        }
        Chronologie chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesPrc(demandeCourante, periodeReferenceCalcul);
        
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des ActiviteSalarie chevauchant la Prc : ", chronologieActiviteSalarie });
        
        Chronologie chronologiePeriodesDeductibles = ConstructionChronologie.determinerChronoPeriodesDeductiblesPrc(demandeCourante, periodeReferenceCalcul);
        
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des Périodes Déductibles chevauchant la Prc : ", chronologiePeriodesDeductibles });
        
        Prc prcCourante = new PrcSjr(periodeReferenceCalcul, chronologieActiviteSalarie, chronologiePeriodesDeductibles);
        
        controleSituationAu28Jour(demandeCourante, periodeReferenceCalcul);
        
        sjripCourant = DeterminationSjrip.determinerSjrip(prcCourante, demandeCourante);
      }
    }
    if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
    {
      Sjr sjrA2b = new Sjr(sjripCourant.getSjrInitial().getValeur(), sjripCourant.getDateEffet(), null);
      dossierExamenCourant.getConstitutionSjr().setSjrrp(sjrA2b);
    }
    else
    {
      dossierExamenCourant.getConstitutionSjr().setSjrrp(RevalorisationSalaire.revaloriserSjr(OutilMappingSjmSjr.creerElementBaseIndeminisationSjrip(dossierExamenCourant.getConstitutionSjr().getSjrip()), (ProduitAsuSpec)dossierExamenCourant.getDossierAffecte().getProduit(), dossierExamenCourant.getDateAttribution()));
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Résultat Parcours ConstitutionSjr ********\n", resultatCEPA07 });
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA07;
  }
  
  private static void leverAlerteNonBloquanteA11MNB10(Demande p_demande, Chronologie p_pnds)
  {
    String codeAlerteNonBloquante = "A11MNB10";
    
    Collection listePnds = new ArrayList();
    for (Iterator iterPnds = p_pnds.iterer(); iterPnds.hasNext();)
    {
      ObjetChronoPeriode pnds = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pnds.getDateDebut(), pnds.getDateFin(), 7);
      
      listePnds.add(objetAlerteNonBloquante);
    }
    p_demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listePnds);
  }
  
  private void setCodeEmploiA2B(Demande p_demande)
  {
    ((DossierExamen)p_demande.getDossierExamen()).getConstitutionSjr().setCodeEmploiA2b(DeterminationSjrip.determinerCodeEmploiA2b(p_demande));
  }
  
  private void controleSituationAu28Jour(Demande p_demande, Periode p_prc)
    throws CoucheLogiqueException
  {
    boolean coordCee = p_demande.getDonneesTemporaires().isEstCoordCee();
    if (coordCee)
    {
      Periode prc12Mois = p_prc.getFin().soustraireNombreMois(((DelaiRecherche)DelaiRecherche.getInstance()).determinerDureePrc());
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltrePeriodeActiviteSalarieeE301NonFrontalier());
      filtres.ajouterFiltre(new FiltreFinDansBornes(prc12Mois));
      Chronologie chronoAvecE301NonFrontalier = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      if (!chronoAvecE301NonFrontalier.estVide())
      {
        chronoAvecE301NonFrontalier.setComparateur(new ComparateurTemporelSurDateFinDecroissante());
        ActiviteSalarie dernierE301NonFrontalier = (ActiviteSalarie)chronoAvecE301NonFrontalier.premierElement();
        Damj dateFaitGenerateurOdPrecedente = p_demande.getDateFaitGenerateurOdPrecedente();
        if ((dateFaitGenerateurOdPrecedente == null) || (dernierE301NonFrontalier.getDateFin().estApres(dateFaitGenerateurOdPrecedente)))
        {
          ChronologiePeriodes chronoActivitesPrc = (ChronologiePeriodes)ConstructionChronologie.determinerChronoActivitesPrc(p_demande, p_prc);
          
          ChronologiePeriodes chronoPostE301Dupliquee = new ChronologiePeriodes();
          
          chronoActivitesPrc.iterer();
          ActiviteSalarie periodeActSalariePostE301 = null;
          while (chronoActivitesPrc.encoreSuivant())
          {
            periodeActSalariePostE301 = (ActiviteSalarie)chronoActivitesPrc.elementSuivant();
            if (periodeActSalariePostE301.getContrat().getPohf() == 0)
            {
              ObjetChronoPeriode periodeAAjouter = null;
              if (periodeActSalariePostE301.getDateDebut().estAvant(p_prc.getDebut())) {
                periodeAAjouter = new ObjetChronoPeriodeConcrete(p_prc.getDebut(), periodeActSalariePostE301.getDateFin());
              } else {
                periodeAAjouter = new ObjetChronoPeriodeConcrete(periodeActSalariePostE301.getDateDebut(), periodeActSalariePostE301.getDateFin());
              }
              chronoPostE301Dupliquee.ajouter(periodeAAjouter);
            }
          }
          boolean resultatCdt = false;
          if (!chronoPostE301Dupliquee.estVide())
          {
            chronoPostE301Dupliquee = chronoPostE301Dupliquee.fusionnerChevauchementPeriodes();
            chronoPostE301Dupliquee = OutillageChronologiePeriodes.fusionnerPeriodesAccolees(chronoPostE301Dupliquee);
            chronoPostE301Dupliquee.iterer();
            ObjetChronoPeriode periodeCourante = null;
            while ((chronoPostE301Dupliquee.encoreSuivant()) && (!resultatCdt))
            {
              periodeCourante = (ObjetChronoPeriode)chronoPostE301Dupliquee.elementSuivant();
              if (periodeCourante.getDuree() > 27) {
                resultatCdt = true;
              }
            }
          }
          if (!resultatCdt) {
            fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB13");
          }
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionSjr
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */