package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Prc;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.PrcSjr;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Revision;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.Sjrip;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationSjrip;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutApresDate;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.Iterator;

public class ConstitutionSjrPourRevision
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final int DUREE_VINGT_SEPT_JOURS = 27;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Sjr impossible.");
    }
    DossierExamen dossierExamenCourant = (DossierExamen)DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen();
    if (dossierExamenCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_OD", "L'attribution courante est null: constitution du Sjr impossible.");
    }
    if (dossierExamenCourant.getAttributionPrecedente() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "L'attribution précédente est nulle : constitution du Sjr impossible.");
    }
    if (((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionSjr().getSjrip() == null) {
      throw new ContexteException("ASU_SC_L_ES_ED_CONTEXTE_ABSENCE_SJRIP", "Le SJRIP de l'attribution precedente est null : constitution du Sjr impossible.");
    }
    if (dossierExamenCourant.getReglementApplicable() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Le règlement applicable est null: constitution du Sjr impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours(Niveau.DEBUG);
    
    Resultat resultat = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    Revision dossierExamenCourant = (Revision)demandeCourante.getDossierExamen();
    Reglement reglementApplicableCourant = dossierExamenCourant.getReglementApplicable().getReglement();
    ProduitSpec produit = ((DossierAffectation)demandeCourante.getDossierAffectation()).getProduit();
    
    ConstitutionSjr constitutionSjr = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionSjr();
    
    Sjrip sjripCourant = null;
    
    Quantite sjrForce = demandeCourante.getDonneesTemporaires().getSjrPerteActConservee();
    if (sjrForce != null)
    {
      QuantiteEuro quantiteSjr = new QuantiteEuro(sjrForce.getValeur());
      
      Damj termePrc = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionSjr().getSjrip().getDateEffet();
      QuantiteEuro plafond = ((DossierExamen)dossierExamenCourant.getAttributionPrecedente()).getConstitutionSjr().getSjrip().getPlafondSjr();
      
      sjripCourant = dossierExamenCourant.getConstitutionSjr().createSjrip(termePrc, plafond, quantiteSjr);
    }
    else
    {
      constitutionSjr.createJustificationSjr();
      sjripCourant = constitutionSjr.createSjrip();
      if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
      {
        sjripCourant = DeterminationSjrip.determinerSjripPourA2B(demandeCourante);
      }
      else
      {
        AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)dossierExamenCourant.getOuvertureDroit();
        
        Periode periodeReferenceCalcul = ((DossierExamen)attributionOrigine).getConstitutionSjr().getSjrip().getPrc().getPeriode();
        
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Prc : ", periodeReferenceCalcul });
        try
        {
          Chronologie pnds = demandeCourante.getChronologiePNDS(periodeReferenceCalcul);
          if ((pnds != null) && (!pnds.estVide())) {
            leverAlerteNonBloquanteA11MNB10(demandeCourante, pnds);
          }
        }
        catch (ApplicativeException e)
        {
          throw new CoucheLogiqueException(e.getCode(), e.getLibelle(), e);
        }
        Chronologie chronologieActiviteSalarie = ConstructionChronologie.determinerChronoActivitesPrcPourRevision(demandeCourante, periodeReferenceCalcul);
        
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des ActiviteSalarie chevauchant la Prc : ", chronologieActiviteSalarie });
        
        Chronologie chronologiePeriodesDeductibles = ConstructionChronologie.determinerChronoPeriodesDeductiblesPrc(demandeCourante, periodeReferenceCalcul);
        
        OutilTrace.ecrireTrace(Niveau.INFO, new Object[] { "Chronologie des Périodes Déductibles chevauchant la Prc : ", chronologiePeriodesDeductibles });
        
        Prc prcCourante = new PrcSjr(periodeReferenceCalcul, chronologieActiviteSalarie, chronologiePeriodesDeductibles);
        
        controleSituationAu28Jour(demandeCourante, periodeReferenceCalcul, chronologieActiviteSalarie);
        
        sjripCourant = DeterminationSjrip.determinerSjrip(prcCourante, demandeCourante);
      }
    }
    if (reglementApplicableCourant.equals(produit.getReglement("A2b")))
    {
      Sjr sjrA2b = new Sjr(sjripCourant.getSjrInitial().getValeur(), sjripCourant.getDateEffet(), null);
      dossierExamenCourant.getConstitutionSjr().setSjrrp(sjrA2b);
    }
    else
    {
      dossierExamenCourant.getConstitutionSjr().setSjrrp(RevalorisationSalaire.revaloriserSjr(OutilMappingSjmSjr.creerElementBaseIndeminisationSjrip(dossierExamenCourant.getConstitutionSjr().getSjrip()), (ProduitAsuSpec)dossierExamenCourant.getDossierAffecte().getProduit(), dossierExamenCourant.getDateAttribution()));
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "\t\t******** Résultat Parcours ConstitutionSjcPourRevision ********\n", resultat });
    OutilTrace.tracerFinParcours(Niveau.DEBUG);
    
    return resultat;
  }
  
  private static void leverAlerteNonBloquanteA11MNB10(Demande p_demande, Chronologie p_pnds)
  {
    String codeAlerteNonBloquante = "A11MNB10";
    
    Collection listePnds = new ArrayList();
    for (Iterator iterPnds = p_pnds.iterer(); iterPnds.hasNext();)
    {
      ObjetChronoPeriode pnds = (ObjetChronoPeriode)iterPnds.next();
      ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pnds.getDateDebut(), pnds.getDateFin(), 7);
      
      listePnds.add(objetAlerteNonBloquante);
    }
    p_demande.getAlertesNonBloquantes().put(codeAlerteNonBloquante, listePnds);
  }
  
  private void controleSituationAu28Jour(Demande p_demande, Periode p_prc, Chronologie p_chronoActivitePrc)
    throws CoucheLogiqueException
  {
    boolean coordCee = p_demande.getDonneesTemporaires().isEstCoordCee();
    if (coordCee)
    {
      Damj dateDebutBorne = p_prc.getDebut();
      boolean bTrouve = false;
      ChronologiePeriodes chronoPeriodeActivite = new ChronologiePeriodes();
      ChronologiePeriodes chronoActivitePrc = (ChronologiePeriodes)p_chronoActivitePrc;
      
      chronoActivitePrc.iterer();
      
      ArrayList desActiviteSalarie = new ArrayList(chronoActivitePrc.mapperVersCollection());
      for (int i = desActiviteSalarie.size() - 1; (i >= 0) && (!bTrouve); i--)
      {
        ObjetChronoPeriode periodeActSalarie = (ObjetChronoPeriode)desActiviteSalarie.get(i);
        if (((ActiviteSalarie)periodeActSalarie).getContrat().getPohf() == 9)
        {
          dateDebutBorne = periodeActSalarie.getDateFin().lendemain();
          bTrouve = true;
        }
      }
      if (bTrouve)
      {
        ChronologiePeriodes chronoPostE301 = (ChronologiePeriodes)chronoActivitePrc.copier(new FiltreDebutApresDate(dateDebutBorne));
        
        chronoPostE301.iterer();
        while (chronoPostE301.encoreSuivant())
        {
          ObjetChronoPeriode periodeCourante = (ObjetChronoPeriode)chronoPostE301.elementSuivant();
          ObjetChronoPeriode periodeAAjouter = new ObjetChronoPeriodeConcrete(periodeCourante.getDateDebut(), periodeCourante.getDateFin());
          chronoPeriodeActivite.ajouter(periodeAAjouter);
        }
        if (!chronoPeriodeActivite.estVide())
        {
          chronoPeriodeActivite = chronoPeriodeActivite.fusionnerChevauchementPeriodes();
          chronoPeriodeActivite = OutillageChronologiePeriodes.fusionnerPeriodesAccolees(chronoPeriodeActivite);
        }
        boolean resultatCdt = false;
        Iterator iterChrono = chronoPeriodeActivite.iterer();
        while (iterChrono.hasNext())
        {
          ObjetChronoPeriode periodeActSalarie = (ObjetChronoPeriode)iterChrono.next();
          if (periodeActSalarie.getDuree() > 27) {
            resultatCdt = true;
          }
        }
        if (!resultatCdt) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB13");
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionSjrPourRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */