package fr.unedic.cali.asu.cge01.p04.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCaractereSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCoefficientSaisonnier;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class DeterminationCoefficientSaisonnier
  implements OutilFonctionnel
{
  private static final int UN_AN = 365;
  public static final Unite JOUR = Unite.get("jour d'affiliation");
  public static final Unite HEURE = Unite.get("heure de travail");
  private BigDecimal m_coefficientSaisonnier = new BigDecimal("1");
  private boolean m_coefficientSaisonnierDetermine = false;
  
  public static DeterminationCoefficientSaisonnier getInstance()
  {
    return new DeterminationCoefficientSaisonnier();
  }
  
  public ConstitutionCoefficientSaisonnier determinerCoefficientSaisonnierPourAdmission(Demande p_demande)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamenCourant = (DossierExamen)p_demande.getDossierExamen();
    Damj dateFCT = dossierExamenCourant.getFaitGenerateur().getDateFaitGenerateur();
    
    DonneesTemporaires donneestemporaires = p_demande.getDonneesTemporaires();
    
    Quantite affiEnJour = null;
    if (!dossierExamenCourant.getConstitutionCaractereSaisonnier().isCaractereSaisonnierRetenu()) {
      m_coefficientSaisonnierDetermine = true;
    }
    if ((!m_coefficientSaisonnierDetermine) && 
      (donneestemporaires.getCoefficientSaisonnier() != null))
    {
      m_coefficientSaisonnierDetermine = true;
      m_coefficientSaisonnier = donneestemporaires.getCoefficientSaisonnier();
    }
    if (!m_coefficientSaisonnierDetermine)
    {
      DureeCalendaire unAn = new DureeCalendaire(0, 0, 365);
      Damj departPrs = dateFCT.deplacerVersArriere(unAn);
      Periode prs = new Periode(departPrs, dateFCT);
      
      Chronologie chronoActivitesPrs = ConstructionChronologie.determinerChronoActivitesPrs(p_demande, prs);
      
      Damj dateFaitGenerateur = p_demande.getDateFaitGenerateurOuDernierSinistre();
      if (dateFaitGenerateur != null) {
        affiEnJour = calculAppartenance(p_demande, prs, chronoActivitesPrs);
      }
      int nbApresVirgule = 4;
      Quantite coefficientSaisonnier = affiEnJour.diviserPar(new Quantite(365, JOUR), 4);
      m_coefficientSaisonnier = coefficientSaisonnier.getValeur();
    }
    if (m_coefficientSaisonnier != null)
    {
      if (m_coefficientSaisonnier.compareTo(new BigDecimal("1")) == 1) {
        m_coefficientSaisonnier = new BigDecimal("1");
      }
      if (((m_coefficientSaisonnier.compareTo(new BigDecimal("0.005")) == 1) || (m_coefficientSaisonnier.compareTo(new BigDecimal("0.005")) == 0)) && (m_coefficientSaisonnier.compareTo(new BigDecimal("0.01")) == -1)) {
        m_coefficientSaisonnier = new BigDecimal("0.01");
      }
      if (((m_coefficientSaisonnier.compareTo(new BigDecimal("0")) == 1) || (m_coefficientSaisonnier.compareTo(new BigDecimal("0")) == 0)) && (m_coefficientSaisonnier.compareTo(new BigDecimal("0.005")) == -1)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB19");
      }
    }
    m_coefficientSaisonnier = m_coefficientSaisonnier.setScale(2, 1);
    
    ConstitutionCoefficientSaisonnier cep12 = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionCoefficientSaisonnier();
    
    cep12.setCoefficientSaisonnierRetenu(m_coefficientSaisonnier);
    cep12.setJourActiviteDouzeDerniersMois(affiEnJour);
    
    return cep12;
  }
  
  private Quantite calculAppartenance(DemandeSpec p_demande, Periode p_periode, Chronologie p_passeProfessionnel)
  {
    return CalculAppartenance.getInstance().calculerAppartenancePRS(p_demande, p_periode, p_passeProfessionnel);
  }
}

/* Location:
 * Qualified Name:     DeterminationCoefficientSaisonnier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */