package fr.unedic.cali.asu.cge01.p04.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstituerSynthesePeriodeChomageSaisonnier;
import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p04.liquidation.outilsfonctionnels.DeterminationCaractereSaisonnier;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.PeriodeChomageSaisonnier;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionQuantiteAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Iterator;

public class ConstitutionCaractereSaisonnier
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final int UN = 1;
  private static final int TROIS = 3;
  private static final int CINQ = 5;
  private static final int QUINZE = 15;
  private static final int QUARANTENEUF = 49;
  private boolean m_caractereSaisonnierDetermine = false;
  private boolean m_caractereSaisonnier = false;
  private boolean m_inactiviteCompatible = false;
  private boolean m_caractereSaisonnierParNature = false;
  private boolean m_caractereSaisonnierParRythme = false;
  public static final Unite JOUR = Unite.get("jour d'affiliation");
  private boolean m_activite3sur5 = false;
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: constitution du Caractère saisonnier impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_contexte).getDossierExamen() == null) {
      throw new ContexteException("ASU_PR_CALI_L_CONTEXTE_ABSENCE_DOSSIER_EXAMEN", "Le dossier examen est null: constitution du Caractère saisonnier impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA18 = new Resultat();
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    IndividuSpec individu = demande.getDemandeur();
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    Damj dateFCT = dossierExamenCourant.getFaitGenerateur().getDateFaitGenerateur();
    
    DonneesTemporaires donneestemporaires = demande.getDonneesTemporaires();
    
    Periode periodePra = dossierExamenCourant.getConstitutionQuantiteAffiliation().getPeriodePRA();
    
    Pra pra = new Pra(periodePra);
    
    Quantite affiTotale = dossierExamenCourant.getConstitutionQuantiteAffiliation().getQuantiteAcquise();
    DureeCalendaire troisAns = new DureeCalendaire(3);
    Periode prs = CalculDelais.determinerDelai(dateFCT, troisAns);
    prs.setDebut(prs.getDebut().lendemain());
    DureeCalendaire cinqAns = new DureeCalendaire(5);
    Periode pras = CalculDelais.determinerDelai(dateFCT, cinqAns);
    pras.setDebut(pras.getDebut().lendemain());
    DureeCalendaire unAn = new DureeCalendaire(1);
    Periode derniereAnneePrs = CalculDelais.determinerDelai(dateFCT, unAn);
    derniereAnneePrs.setDebut(derniereAnneePrs.getDebut().lendemain());
    
    ChronologiePeriodes chronoActivitesPrs = (ChronologiePeriodes)ConstructionChronologie.determinerChronoActivitesPrs(demande, prs);
    
    Collection listePeriodesChomageSaisonnier = ConstituerSynthesePeriodeChomageSaisonnier.constituerListePeriodesChomageSaisonnier(chronoActivitesPrs, prs);
    
    ChronologiePeriodes chronoActivitesPras = (ChronologiePeriodes)ConstructionChronologie.determinerChronoActivitesPrs(demande, pras);
    
    m_activite3sur5 = DeterminationCaractereSaisonnier.getInstance().invaliderCaractereSaisonnierParRythme(chronoActivitesPras, pras);
    if (chronoActivitesPrs.estVide())
    {
      m_caractereSaisonnierDetermine = true;
      m_caractereSaisonnier = false;
    }
    if (donneestemporaires.isCaractereSaisonnierForce())
    {
      if (donneestemporaires.getTypeCaractereSaisonnierForce() == 2)
      {
        m_caractereSaisonnierParNature = true;
        m_caractereSaisonnierDetermine = true;
        m_caractereSaisonnier = true;
      }
      if (donneestemporaires.getTypeCaractereSaisonnierForce() == 1)
      {
        m_caractereSaisonnierParRythme = true;
        if ((individu.getAgeALaDate(dateFCT).getAnnees() > 49) && (m_activite3sur5))
        {
          m_caractereSaisonnierDetermine = true;
          m_caractereSaisonnier = false;
        }
        else
        {
          m_caractereSaisonnier = true;
          m_caractereSaisonnierDetermine = true;
        }
      }
    }
    if (!m_caractereSaisonnierDetermine)
    {
      AttributionSpec derniereAttribution = demande.rechercherAttributionPrecedenteDuMemeType();
      if (derniereAttribution == null)
      {
        m_caractereSaisonnierDetermine = true;
        m_caractereSaisonnier = false;
      }
    }
    if (!m_caractereSaisonnierDetermine)
    {
      ChronologiePeriodes chronoInactivite = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoActivitesPrs, derniereAnneePrs);
      
      ObjetChronoPeriode objetChronoPeriodeCourant = null;
      chronoInactivite.iterer();
      while ((chronoInactivite.encoreSuivant()) && (!m_inactiviteCompatible))
      {
        objetChronoPeriodeCourant = (ObjetChronoPeriode)chronoInactivite.elementSuivant();
        if (objetChronoPeriodeCourant.getDuree() > 15) {
          m_inactiviteCompatible = true;
        }
      }
      if (!m_inactiviteCompatible)
      {
        m_caractereSaisonnierDetermine = true;
        m_caractereSaisonnier = false;
      }
    }
    rechercheActiviteSaisonniereParNature(demande, chronoActivitesPrs, dateFCT, pra, affiTotale);
    
    rechercheActiviteSaisonniereParRythme(demande, chronoActivitesPrs, dateFCT, prs);
    
    fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionCaractereSaisonnier cepa18 = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionCaractereSaisonnier();
    
    cepa18.setActivite3Sur5(m_activite3sur5);
    cepa18.setPeriodeReferenceSaisonnier(prs);
    cepa18.setPeriodeRechercheActiviteSaisonniere(pras);
    if (listePeriodesChomageSaisonnier != null)
    {
      Iterator iter = listePeriodesChomageSaisonnier.iterator();
      ObjetChronoPeriode objetChronoPeriodeChomageSaisonnier = null;
      while (iter.hasNext())
      {
        objetChronoPeriodeChomageSaisonnier = (ObjetChronoPeriode)iter.next();
        cepa18.ajouterPeriodeChomageSaisonnier(new PeriodeChomageSaisonnier(objetChronoPeriodeChomageSaisonnier.getDateDebut(), objetChronoPeriodeChomageSaisonnier.getDateFin()));
      }
    }
    if (m_caractereSaisonnier)
    {
      cepa18.setCaractereSaisonnierRetenu(true);
      if (m_caractereSaisonnierParNature) {
        cepa18.setTypeCaractereSaisonnierRetenu(2);
      }
      if (m_caractereSaisonnierParRythme) {
        cepa18.setTypeCaractereSaisonnierRetenu(1);
      }
    }
    else
    {
      cepa18.setCaractereSaisonnierRetenu(false);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA18;
  }
  
  private void rechercheActiviteSaisonniereParNature(Demande p_demande, ChronologiePeriodes p_chronoActivitesPrs, Damj p_dateFct, Periode p_periodePra, Quantite p_affiTotale)
    throws ApplicativeException
  {
    if ((!m_caractereSaisonnierDetermine) && (!p_demande.getDonneesTemporaires().isFortuiteCaractereSaisonnierParType()))
    {
      boolean caractereSaisonnierParNature = DeterminationCaractereSaisonnier.getInstance().rechercherCaractereSaisonnierParNature(p_dateFct, p_chronoActivitesPrs);
      if (caractereSaisonnierParNature)
      {
        boolean caractereSaisonnierParNatureValide = DeterminationCaractereSaisonnier.getInstance().validerCaractereSaisonnierParNature(p_demande, p_chronoActivitesPrs, p_periodePra, p_affiTotale);
        if (caractereSaisonnierParNatureValide)
        {
          m_caractereSaisonnierDetermine = true;
          m_caractereSaisonnier = true;
          m_caractereSaisonnierParNature = true;
        }
      }
    }
  }
  
  private void rechercheActiviteSaisonniereParRythme(Demande p_demande, ChronologiePeriodes p_chronoActivitesPrs, Damj p_dateFCT, Periode p_prs)
    throws ApplicativeException
  {
    if ((!m_caractereSaisonnierDetermine) && (!p_demande.getDonneesTemporaires().isFortuiteCaractereSaisonnierParRythme()))
    {
      boolean caractereSaisonnierParRythme = DeterminationCaractereSaisonnier.getInstance().rechercherCaractereSaisonnierParRythme(p_dateFCT, p_chronoActivitesPrs);
      if (caractereSaisonnierParRythme)
      {
        boolean caractereSaisonnierParRythmeValide = DeterminationCaractereSaisonnier.getInstance().validerCaractereSaisonnierParRythme(p_chronoActivitesPrs, p_prs);
        if (caractereSaisonnierParRythmeValide)
        {
          if ((p_demande.getDemandeur().getAgeALaDate(p_dateFCT).getAnnees() > 49) && (m_activite3sur5)) {
            caractereSaisonnierParRythmeValide = false;
          }
          if (caractereSaisonnierParRythmeValide)
          {
            m_caractereSaisonnierDetermine = true;
            m_caractereSaisonnier = true;
            m_caractereSaisonnierParRythme = true;
          }
        }
      }
    }
  }
}

/* Location:
 * Qualified Name:     ConstitutionCaractereSaisonnier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */