package fr.unedic.cali.asu.cge01.p07.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.parametres.ParametrageISLR;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class AlimenterBaseEchanges
  extends fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.AlimenterBaseEchanges
{
  private static AlimenterBaseEchanges instance = null;
  
  public static AlimenterBaseEchanges getInstance()
  {
    if (instance == null) {
      instance = new AlimenterBaseEchanges();
    }
    return instance;
  }
  
  protected void alimenterDonneesCourrier(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    super.alimenterDonneesCourrier(dossierExamen, demandeEchange);
    fr.unedic.cali.asu.produits.liquidation.dom.Decision decision = (fr.unedic.cali.asu.produits.liquidation.dom.Decision)dossierExamen;
    alimenterDonneesAllongementAREF(decision, demandeEchange);
    alimenterDonneesCoefficientReducteurSjr(decision, demandeEchange);
    alimenterDonneesDiviseurIslr(decision, demandeEchange);
  }
  
  protected void alimenterDonneesAllongementAREF(fr.unedic.cali.asu.produits.liquidation.dom.Decision decisionAssurance, fr.unedic.cali.dom.echange.Decision decisionEchange)
  {
    int allongementPossibleDemandeEnCours = 0;
    
    ConstitutionDurees constitutionDurees = decisionAssurance.getConstitutionDurees();
    if (constitutionDurees != null)
    {
      DureeIndemnisation dureeIndemnisation = constitutionDurees.getDureeIndemnisation();
      if (dureeIndemnisation != null) {
        allongementPossibleDemandeEnCours = dureeIndemnisation.getDureeAllongementAREF();
      }
    }
    if ((decisionAssurance instanceof Reprise))
    {
      Reprise reprise = (Reprise)decisionAssurance;
      ConstitutionDurees constitutionDureesOd = ((Attribution)reprise.getOuvertureDroit()).getConstitutionDurees();
      if ((constitutionDureesOd != null) && (constitutionDureesOd.getDureeIndemnisation() != null))
      {
        int allongementPossibleOd = constitutionDureesOd.getDureeIndemnisation().getDureeAllongementAREF();
        decisionEchange.setDureeAllongementArefRealisee(allongementPossibleOd - allongementPossibleDemandeEnCours);
      }
    }
    decisionEchange.setDureeAllongementArefPossible(allongementPossibleDemandeEnCours);
  }
  
  protected void alimenterDonneesCoefficientReducteurSjr(fr.unedic.cali.asu.produits.liquidation.dom.Decision decisionAssurance, fr.unedic.cali.dom.echange.Decision decisionEchange)
  {
    ConstitutionSjr constitutionSjr = decisionAssurance.getConstitutionSjr();
    if (constitutionSjr != null)
    {
      decisionEchange.setCoefficientReducteurSJR(constitutionSjr.getCoeffReducteurSjr());
      decisionEchange.setPlancherCoefReducteur(constitutionSjr.getPlancherCoefficientSjr());
    }
  }
  
  protected void alimenterDonneesDiviseurIslr(fr.unedic.cali.asu.produits.liquidation.dom.Decision decisionAssurance, fr.unedic.cali.dom.echange.Decision decisionEchange)
    throws CoucheLogiqueException
  {
    Damj dateParametre = ((Demande)decisionAssurance.getDemande()).getDateFaitGenerateurOuDernierSinistre();
    if (dateParametre == null) {
      dateParametre = decisionAssurance.getDemande().getDateExamen();
    }
    if (dateParametre != null)
    {
      BigDecimal diviseur = ParametrageISLR.getInstance().recuperDiviseur(dateParametre);
      if (diviseur == null) {
        diviseur = ParametrageISLR.getInstance().recuperDiviseur(decisionAssurance.getDemande().getDateExamen());
      }
      if (diviseur != null) {
        decisionEchange.setDiviseurIslr(diviseur);
      }
    }
  }
}

/* Location:
 * Qualified Name:     AlimenterBaseEchanges
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */