package fr.unedic.cali.asu.csa06.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.ConstituerSynthesePeriodeChomageSaisonnier;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.cge01.p02.liquidation.outilsfonctionnels.DeterminationCaractereSaisonnier;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.PeriodeChomageSaisonnier;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.util.Collection;
import java.util.Iterator;

public class ConstitutionCaractereSaisonnier
  extends fr.unedic.cali.asu.cge01.p02.liquidation.parcours.ConstitutionCaractereSaisonnier
{
  private static final int UN = 1;
  private static final int TROIS = 3;
  private static final int CINQ = 5;
  private boolean caractereSaisonnier = false;
  private boolean caractereSaisonnierParNature = false;
  private boolean caractereSaisonnierParRythme = false;
  private boolean activite3sur5 = false;
  private static final int QUARANTENEUF = 49;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCEPA18 = new Resultat();
    
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    Damj dateFCT = dossierExamenCourant.getFaitGenerateur().getDateFaitGenerateur();
    
    IndividuSpec individu = demande.getDemandeur();
    
    DonneesTemporaires donneestemporaires = demande.getDonneesTemporaires();
    
    DureeCalendaire troisAns = new DureeCalendaire(3);
    Periode prs = CalculDelais.determinerDelai(dateFCT, troisAns);
    prs.setDebut(prs.getDebut().lendemain());
    DureeCalendaire cinqAns = new DureeCalendaire(5);
    Periode pras = CalculDelais.determinerDelai(dateFCT, cinqAns);
    pras.setDebut(pras.getDebut().lendemain());
    DureeCalendaire unAn = new DureeCalendaire(1);
    Periode derniereAnneePrs = CalculDelais.determinerDelai(dateFCT, unAn);
    derniereAnneePrs.setDebut(derniereAnneePrs.getDebut().lendemain());
    
    ChronologiePeriodes chronoActivitesPrs = (ChronologiePeriodes)ConstructionChronologie.determinerChronoActivitesPrs(demande, prs);
    
    Collection listePeriodesChomageSaisonnier = ConstituerSynthesePeriodeChomageSaisonnier.constituerListePeriodesChomageSaisonnier(chronoActivitesPrs, prs);
    
    ChronologiePeriodes chronoActivitesPras = (ChronologiePeriodes)ConstructionChronologie.determinerChronoActivitesPrs(demande, pras);
    
    activite3sur5 = DeterminationCaractereSaisonnier.invaliderCaractereSaisonnierParRythme(chronoActivitesPras, pras);
    if (donneestemporaires.isCaractereSaisonnierForce())
    {
      caractereSaisonnier = true;
      if (donneestemporaires.getTypeCaractereSaisonnierForce() == 2) {
        caractereSaisonnierParNature = true;
      }
      if (donneestemporaires.getTypeCaractereSaisonnierForce() == 1) {
        if ((individu.getAgeALaDate(dateFCT).getAnnees() > 49) && (activite3sur5))
        {
          caractereSaisonnierParRythme = false;
          caractereSaisonnier = false;
        }
        else
        {
          caractereSaisonnierParRythme = true;
        }
      }
    }
    else
    {
      caractereSaisonnier = false;
    }
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCaractereSaisonnier cepa18 = new fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionCaractereSaisonnier();
    
    cepa18.setActivite3Sur5(activite3sur5);
    cepa18.setPeriodeReferenceSaisonnier(prs);
    cepa18.setPeriodeRechercheActiviteSaisonniere(pras);
    
    Iterator iter = listePeriodesChomageSaisonnier.iterator();
    ObjetChronoPeriode objetChronoPeriodeChomageSaisonnier = null;
    while (iter.hasNext())
    {
      objetChronoPeriodeChomageSaisonnier = (ObjetChronoPeriode)iter.next();
      cepa18.ajouterPeriodeChomageSaisonnier(new PeriodeChomageSaisonnier(objetChronoPeriodeChomageSaisonnier.getDateDebut(), objetChronoPeriodeChomageSaisonnier.getDateFin()));
    }
    if (caractereSaisonnier)
    {
      cepa18.setCaractereSaisonnierRetenu(true);
      if (caractereSaisonnierParNature) {
        cepa18.setTypeCaractereSaisonnierRetenu(2);
      }
      if (caractereSaisonnierParRythme) {
        cepa18.setTypeCaractereSaisonnierRetenu(1);
      }
    }
    else
    {
      cepa18.setCaractereSaisonnierRetenu(false);
    }
    dossierExamenCourant.setConstitutionCaractereSaisonnier(cepa18);
    
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "******** Résultat Parcours ConstitutionCaractereSaisonnier ********", resultatCEPA18 });
    OutilTrace.tracerFinParcours();
    
    return resultatCEPA18;
  }
}

/* Location:
 * Qualified Name:     ConstitutionCaractereSaisonnier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */