package fr.unedic.cali.asu.csa06.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p02.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.csa06.p01.liquidation.outilsfonctionnels.ConstructionPra;
import fr.unedic.cali.asu.csa06.p01.parametres.Parametres;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.produits.liquidation.dom.Pra;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Periode;

public class ConstitutionQuantiteAffiliation
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    if (Log.isTraceActive(ConstitutionQuantiteAffiliation.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionQuantiteAffiliation.class, "demarrer", "\n\t\t******** Début Parcours ConstitutionQuantiteAffiliation ********\n");
    }
    Resultat resultatCEPA09 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    DossierAffectation dossierAffecte = (DossierAffectation)dossierExamenCourant.getDossierAffecte();
    ActiviteSalarie dernierSinistre = (ActiviteSalarie)dossierAffecte.getSinistre();
    
    Pra pra = ConstructionPra.getPra(dernierSinistre, demande);
    Reglement reglementAppartenance = dernierSinistre.getReglement();
    
    Chronologie passeProfessionnel = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    
    Chronologie chronoPeriodesParticipantes = ConstructionChronologie.determinerPeriodesParticipantesAffiliationRegle13Mois(null, pra, passeProfessionnel, false);
    
    fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionQuantiteAffiliation constitutionQuantiteAppartenance = new fr.unedic.cali.asu.cge01.p02.liquidation.dom.ConstitutionQuantiteAffiliation();
    Quantite quantiteAffiliation = dossierAffecte.getValidationProduit().getQuantiteAcquise();
    Quantite quantiteAffiliationSecondaire = dossierAffecte.getValidationProduit().getQuantiteAcquiseSecondaire();
    
    JustificationAffiliation justificationAffiliation = new JustificationAffiliation();
    
    justificationAffiliation.setAppartenanceCalculee(quantiteAffiliation);
    justificationAffiliation.setPeriodePraRetenue(pra);
    
    fr.unedic.cali.asu.cge01.p02.liquidation.outilsaffiliation.CalculAppartenance.getInstance().calculer(demande, justificationAffiliation, pra, chronoPeriodesParticipantes, reglementAppartenance);
    
    constitutionQuantiteAppartenance.setArticle3("a");
    constitutionQuantiteAppartenance.setQuantiteAffiliationAcquise(quantiteAffiliation);
    constitutionQuantiteAppartenance.setQuantiteAffiliationAcquiseSecondaire(quantiteAffiliationSecondaire);
    constitutionQuantiteAppartenance.setDureeInitiale(Parametres.getDureePraEnMois());
    
    constitutionQuantiteAppartenance.setPeriodePRA(new Periode(pra.getDebut(), pra.getFin()));
    constitutionQuantiteAppartenance.setQuantiteAssimilationAcquise(new Quantite(0, quantiteAffiliation.getUnite()));
    if (quantiteAffiliationSecondaire != null) {
      constitutionQuantiteAppartenance.setQuantiteAssimilationAcquiseSecondaire(new Quantite(0, quantiteAffiliationSecondaire.getUnite()));
    }
    constitutionQuantiteAppartenance.setJustificationAffiliation(justificationAffiliation);
    
    dossierExamenCourant.setConstitutionQuantiteAffiliation(constitutionQuantiteAppartenance);
    if (Log.isTraceActive(ConstitutionQuantiteAffiliation.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionQuantiteAffiliation.class, "demarrer", "\n\t\t******** Fin Parcours ConstitutionQuantiteAffiliation ********\n");
    }
    return resultatCEPA09;
  }
}

/* Location:
 * Qualified Name:     ConstitutionQuantiteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */