package fr.unedic.cali.asu.cva10.calcul;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.FacadeCalculProduitPourLiquidationAsuAbstraite;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.ActiviteReduite;
import fr.unedic.cali.asu.cge01.calcul.outilsfonctionnels.DeterminationReliquat;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.cva10.calcul.dom.FormuleMontantASPDCF;
import fr.unedic.cali.asu.cva10.calcul.dom.FormuleMontantRegimeGeneralASPDC;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilMappingSjmSjr;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePANSConservee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Competences;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontantAsp;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;

public class FacadeCalculLignePourLiquidationCVA10Impl
  extends FacadeCalculProduitPourLiquidationAsuAbstraite
{
  private static final int CINQUANTE_ANS = 50;
  
  public Quantite calculerCapital(AttributionSpec attribution, MontantAsuSpec pmontant, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    IndividuSpec individu = attribution.getDemandeur();
    BigDecimal capital = new BigDecimal("0.00");
    
    Damj pji = pointDeDepart;
    
    int dureeDroit = OutilRetraite.getInstance().bornerDureeALaRetraite(individu, pointDeDepart, nbJoursIndemnisables, false);
    Damj dji = pji.deplacerVersAvant(new DureeCalendaire(0, 0, dureeDroit));
    if (pji.estAvant(dji))
    {
      BigDecimal montant = pmontant.getMontantPrecompteEffectif().getValeur();
      
      capital = montant.multiply(new BigDecimal(dureeDroit));
    }
    return new QuantiteEuro(capital);
  }
  
  public Quantite calculerCapital(AttributionSpec attribution, Damj dateAttribution, Damj pointDeDepart, Quantite nbJoursIndemnisables)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  public Quantite determinerDureeEffectiveReliquat(Quantite quantiteInitiale, Quantite nbHeuresFormation)
    throws IllegalArgumentException
  {
    return DeterminationReliquat.determinerDureeEffectiveReliquat(quantiteInitiale, nbHeuresFormation);
  }
  
  public MontantBaseSpec determinerMontant(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    FormuleMontantSpec fm = null;
    ConstituantsIndemnisation constituantsIndemnisation = initialiserConstituantsIndemnisation(donneesEntreesRecuperationMontant);
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    if (donneesCalculMontant.getFormuleMontant() != null) {
      fm = donneesCalculMontant.getFormuleMontant();
    } else if (donneesCalculMontant.isContexteFormation()) {
      fm = getFormuleMontantEnFormation();
    } else {
      fm = getFormuleMontant();
    }
    return fm.calculer(constituantsIndemnisation, donneesEntreesRecuperationMontant.getDateCalculMontant());
  }
  
  public boolean determinerPrecompteCRC(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attrib = (AttributionAssuranceSpec)attribution;
    
    return (attrib.getCompetenceFinanciere() == 2) && ((attrib.getCompetenceAdministrative() != 1) || ((((AttributionAssuranceSpec)attribution).getConventionGestion() != null) && (!((AttributionAssuranceSpec)attribution).getConventionGestion().estPrecompteCRC())));
  }
  
  public FormuleMontantSpec getFormuleMontant()
  {
    return new FormuleMontantRegimeGeneralASPDC();
  }
  
  public FormuleMontantSpec getFormuleMontantEnFormation()
  {
    return new FormuleMontantASPDCF();
  }
  
  public BigDecimal getSeuilRenumeration(AttributionSpec attribution, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Attribution attrib = (Attribution)attribution;
    ElementBaseIndemnisation ebi = attrib.getElementBaseIndemnisation();
    BigDecimal sjr = null;
    if (ebi.getSjr() != null) {
      sjr = RevalorisationSalaire.revaloriserSjr(ebi.getSjr(), dateCalcul).getSalaire();
    }
    boolean apprenti = ((Attribution)attribution).isTopContratsRemuneresBaseSmic();
    Chronologie chronoPeriodesConserveesLiq = attrib.getListeActiviteConservee();
    boolean estAvecSjc = false;
    BigDecimal sjc = new BigDecimal("0.00");
    boolean presencePansConservee = !chronoPeriodesConserveesLiq.copier(new FiltrePeriodePANSConservee()).estVide();
    return ActiviteReduite.calculerSeuilMensuel(dateCalcul, sjr, sjc, apprenti, estAvecSjc, BigDecimal.ZERO, presencePansConservee);
  }
  
  public Periode determinerPeriodeAvantSansCalendrier(AttributionSpec attribution)
    throws ApplicativeException
  {
    return null;
  }
  
  protected ConstituantsIndemnisation initialiserConstituantsIndemnisation(DonneesEntreesRecuperationMontant donneesEntreesRecuperationMontant)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
    ElementBaseIndemnisation elementBaseIndemnisationCourantDroitAssocie = new ElementBaseIndemnisation();
    
    Damj dateCalcul = donneesEntreesRecuperationMontant.getDateCalculMontant();
    Damj dateAttribution = null;
    IndividuSpec individu = donneesEntreesRecuperationMontant.getIndividu();
    DonneesCalculMontant donneesCalculMontant = donneesEntreesRecuperationMontant.getDonneesCalculMontant();
    DonneesCalculMontantAsp donneesCalculMontantAsp = donneesEntreesRecuperationMontant.getDonneesCalculMontantAsp();
    DonneesCalculMontant donneesCalculMontantDroitAsssocie = null;
    if (donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie() != null) {
      donneesCalculMontantDroitAsssocie = donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontant();
    }
    elementBaseIndemnisationCourant.setProduitAreActif(donneesCalculMontantAsp.getProduitAreSousJacent());
    elementBaseIndemnisationCourantDroitAssocie.setProduitAreActif(donneesCalculMontantAsp.getProduitAreSousJacent());
    
    elementBaseIndemnisationCourant.setElementBaseIndemnisationDroitAssocie(elementBaseIndemnisationCourantDroitAssocie);
    constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
    if (donneesCalculMontant.getCoefficientSaisonnier() != null)
    {
      elementBaseIndemnisationCourant.setCoefficientSaisonnier(donneesCalculMontant.getCoefficientSaisonnier());
      if ((donneesCalculMontant.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50) && 
        (donneesCalculMontant.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontant.isConditionCaractereSaisonnierParRythme())) {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(BigDecimal.ONE);
      }
      if ((donneesCalculMontantDroitAsssocie != null) && (donneesCalculMontantDroitAsssocie.getCoefficientSaisonnier() != null))
      {
        elementBaseIndemnisationCourantDroitAssocie.setCoefficientSaisonnier(donneesCalculMontantDroitAsssocie.getCoefficientSaisonnier());
        if ((donneesCalculMontantDroitAsssocie.getCoefficientSaisonnier().intValue() != 1) && (individu.getAgeALaDate(dateCalcul).getAnnees() >= 50)) {
          if ((donneesCalculMontantDroitAsssocie.getTypeCaractereSaisonnierRetenu() == 1) && (donneesCalculMontantDroitAsssocie.isConditionCaractereSaisonnierParRythme())) {
            elementBaseIndemnisationCourantDroitAssocie.setCoefficientSaisonnier(BigDecimal.ONE);
          }
        }
      }
    }
    if (donneesCalculMontant.getCoefficientTempsPartiel() != null) {
      elementBaseIndemnisationCourant.setCoefficientTempsPartiel(donneesCalculMontant.getCoefficientTempsPartiel());
    }
    if ((donneesCalculMontantDroitAsssocie != null) && 
      (donneesCalculMontantDroitAsssocie.getCoefficientTempsPartiel() != null)) {
      elementBaseIndemnisationCourantDroitAssocie.setCoefficientTempsPartiel(donneesCalculMontantDroitAsssocie.getCoefficientTempsPartiel());
    }
    Sjr sjr = OutilMappingSjmSjr.convertirSjr(donneesCalculMontant.getSalaireJournalier());
    elementBaseIndemnisationCourant.setSjr(sjr);
    if (donneesCalculMontantDroitAsssocie != null)
    {
      Sjr sjrDroitAssocie = OutilMappingSjmSjr.convertirSjr(donneesCalculMontantDroitAsssocie.getSalaireJournalier());
      elementBaseIndemnisationCourantDroitAssocie.setSjr(sjrDroitAssocie);
    }
    Sjr sjrRevalorise = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourant, ProduitAsuCge01P05.getInstance(), dateCalcul);
    elementBaseIndemnisationCourant.setSjr(sjrRevalorise);
    if (donneesCalculMontantDroitAsssocie != null)
    {
      Sjr sjrRevaloriseDroitAssocie = RevalorisationSalaire.revaloriserSjr(elementBaseIndemnisationCourantDroitAssocie, ProduitAsuCge01P05.getInstance(), dateCalcul);
      
      elementBaseIndemnisationCourantDroitAssocie.setSjr(sjrRevaloriseDroitAssocie);
    }
    if (donneesCalculMontant.isPriseEnComptePensionInvalidite())
    {
      elementBaseIndemnisationCourant.setListePensionInvalidite(donneesCalculMontant.getListePensionInvalidite());
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, individu, dateCalcul, dateAttribution));
      if (donneesCalculMontantDroitAsssocie != null)
      {
        elementBaseIndemnisationCourantDroitAssocie.setListePensionInvalidite(donneesCalculMontantDroitAsssocie.getListePensionInvalidite());
        elementBaseIndemnisationCourantDroitAssocie.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourantDroitAssocie, individu, dateCalcul, dateAttribution));
      }
    }
    else
    {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
      if (donneesCalculMontantDroitAsssocie != null) {
        elementBaseIndemnisationCourantDroitAssocie.setMontantPensionInvaliditeADeduire(new BigDecimal("0.00"));
      }
    }
    if (donneesCalculMontant.getAvecPrecompteCRC() != null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(donneesCalculMontant.getAvecPrecompteCRC());
    } else if (donneesEntreesRecuperationMontant.getCompetences() == null) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.TRUE);
    } else if ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
      elementBaseIndemnisationCourant.setAvecPrecompteCRC(Boolean.FALSE);
    }
    if (donneesCalculMontantDroitAsssocie != null) {
      if (donneesCalculMontantDroitAsssocie.getAvecPrecompteCRC() != null) {
        elementBaseIndemnisationCourantDroitAssocie.setAvecPrecompteCRC(donneesCalculMontantDroitAsssocie.getAvecPrecompteCRC());
      } else if (donneesEntreesRecuperationMontant.getCompetences() == null) {
        elementBaseIndemnisationCourantDroitAssocie.setAvecPrecompteCRC(Boolean.TRUE);
      } else if ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceFinanciere() == 2) && ((donneesEntreesRecuperationMontant.getCompetences().getCompetenceAdministrative() != 1) || ((donneesEntreesRecuperationMontant.getCompetences().getConventionGestion() != null) && (!donneesEntreesRecuperationMontant.getCompetences().getConventionGestion().estPrecompteCRC())))) {
        elementBaseIndemnisationCourantDroitAssocie.setAvecPrecompteCRC(Boolean.FALSE);
      }
    }
    elementBaseIndemnisationCourant.setMontantPreavis(donneesCalculMontantAsp.getMontantPreavis());
    if ((((ProduitAsuSpec)donneesCalculMontant.getProduit()).getNom().equalsIgnoreCase("ASU_CVA10_03")) && ((ProduitAsuSpec)donneesCalculMontantAsp.getProduitAreSousJacent() != null)) {
      elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontantAsp.getProduitAreSousJacent());
    } else {
      elementBaseIndemnisationCourant.setProduitMontantRetenu((ProduitAsuSpec)donneesCalculMontant.getProduit());
    }
    if ((donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie() != null) && (donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontantAsp() != null)) {
      elementBaseIndemnisationCourantDroitAssocie.setMontantPreavis(donneesEntreesRecuperationMontant.getDonneesEntreesRecuperationMontantDroitAssocie().getDonneesCalculMontantAsp().getMontantPreavis());
    }
    if (donneesCalculMontant.isContexteFormation())
    {
      ElementBaseIndemnisationAREF ebiAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
      ebiAREF.setProduitAreActif(elementBaseIndemnisationCourant.getProduitAreActif());
      constituantsIndemnisation.setElementBaseIndemnisationCourant(ebiAREF);
    }
    elementBaseIndemnisationCourant.setContextePAPPresent(donneesCalculMontantAsp.isContextePAPPresent());
    
    elementBaseIndemnisationCourant.setContextePapParlementaire(donneesCalculMontantAsp.isContextePapParlementaire());
    
    return constituantsIndemnisation;
  }
  
  public MontantBaseSpec determinerMontant(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE");
    return null;
  }
}

/* Location:
 * Qualified Name:     FacadeCalculLignePourLiquidationCVA10Impl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */