package fr.unedic.cali.asu.cva10.calcul.dom;

import fr.unedic.cali.asu.cva10.calcul.outilsfonctionnels.CotisationRetraiteComplementaire;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleMontantRegimeGeneralASPDC
  implements FormuleMontantASPSpec
{
  private static final BigDecimal COEFFICIENT = new BigDecimal(0.8D);
  protected static final BigDecimal FACTEUR_BASE = new BigDecimal("0.404");
  private static final BigDecimal ZERO = new BigDecimal(0);
  protected static final BigDecimal COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE = new BigDecimal("1");
  protected static final BigDecimal FACTEUR_PLANCHER = new BigDecimal("0.574");
  protected static final BigDecimal MONTANT_PAR_DEFAUT = new BigDecimal(0);
  private FormuleMontantSpec mformuleMontantDroitAssocie = null;
  private int mformuleMontantApplicable = 1;
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation pconstituantsIndemnisation, Damj pdateCalcul)
    throws CoucheLogiqueException
  {
    Montant leMontant = new Montant();
    if (getFormuleMontantApplicable() == 2) {
      leMontant = calculerMontantDroitAssocie(pconstituantsIndemnisation, pdateCalcul);
    } else {
      leMontant = calculerMontantDroitPrincipal(pconstituantsIndemnisation, pdateCalcul);
    }
    return leMontant;
  }
  
  private Montant calculerMontantDroitAssocie(ConstituantsIndemnisation pconstituantsIndemnisation, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    ConstituantsIndemnisation constituantsIndemnisation = new ConstituantsIndemnisation();
    ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)pconstituantsIndemnisation.getElementBaseIndemnisationCourant();
    constituantsIndemnisation.setElementBaseIndemnisationCourant(ebi.getElementBaseIndemnisationDroitAssocie());
    MontantBaseSpec montantDroitAssocie = getFormuleMontantDroitAssocie().calculer(constituantsIndemnisation, dateCalcul);
    Montant leMontant = new Montant(montantDroitAssocie);
    leMontant.setMontantBrut(montantDroitAssocie.getMontantBrutSansAvantageVieillesseDeduit());
    return leMontant;
  }
  
  private Montant calculerMontantDroitPrincipal(ConstituantsIndemnisation constituantsIndemnisation, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Montant montant = new Montant();
    
    EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateCalcul);
    
    ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant();
    if ((ebi != null) && (ebi.getSjr() != null))
    {
      BigDecimal coefficientSurSalaire = COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE;
      if (ebi.getCoefficientSaisonnier() != null) {
        coefficientSurSalaire = ebi.getCoefficientSaisonnier();
      }
      BigDecimal coefficientSurParametre = COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE;
      if (ebi.getCoefficientTempsPartiel() != null) {
        coefficientSurParametre = ebi.getCoefficientTempsPartiel();
      }
      BigDecimal montantPlancher = FACTEUR_PLANCHER.multiply(ebi.getSjr().getSalaire()).multiply(coefficientSurSalaire).max(MONTANT_PAR_DEFAUT);
      
      BigDecimal montant80SJRCs = COEFFICIENT.multiply(ebi.getSjr().getSalaire()).multiply(coefficientSurSalaire);
      BigDecimal montantBase = FACTEUR_BASE.multiply(ebi.getSjr().getSalaire()).multiply(coefficientSurSalaire).add(parametres.getPartieFixe().multiply(coefficientSurParametre)).max(MONTANT_PAR_DEFAUT);
      
      Sjr sjrrp = ebi.getSjr();
      BigDecimal montantBrut = COEFFICIENT.multiply(sjrrp.getSalaire());
      montant.setMontantBrutSansPensionInvaliditeADeduire(new Quantite(Mathematiques.arrondiASup(montantBrut, 2), UniteMonaitaire.EUROS));
      montantBrut = montantBrut.subtract(ebi.getMontantPensionInvaliditeADeduire());
      montantBrut = montantBrut.max(parametres.getSeuilMinimalAREF());
      
      montant.setMontantBrut(new QuantiteEuro(Mathematiques.arrondiASup(montantBrut, 2)));
      if (montant.getMontantBrut().getValeur().compareTo(montantPlancher) == 0) {
        montant.setJustificationCalculMontant("01");
      } else if (montant.getMontantBrut().getValeur().compareTo(parametres.getSeuilMinimalAREF()) == 0) {
        montant.setJustificationCalculMontant("04");
      } else {
        montant.setJustificationCalculMontant("13");
      }
      montant.setPensionInvaliditeADeduirePriseEnCompte(new Quantite(ebi.getMontantPensionInvaliditeADeduire(), UniteMonaitaire.get("Euros")));
      
      montant.setPlafond(new Quantite(Mathematiques.arrondiASup(montant80SJRCs, 2), UniteMonaitaire.get("Euros")));
      montant.setPlancher(new Quantite(Mathematiques.arrondiASup(montantPlancher, 2), UniteMonaitaire.get("Euros")));
      montant.setMini(new Quantite(Mathematiques.arrondiASup(parametres.getSeuilMinimalAREF(), 2), UniteMonaitaire.get("Euros")));
      
      montant.setBase(new Quantite(Mathematiques.arrondiASup(montantBase, 2), UniteMonaitaire.get("Euros")));
      
      boolean estAvecCRC = ebi.getAvecPrecompteCRC() != null ? ebi.getAvecPrecompteCRC().booleanValue() : true;
      Quantite crc = new QuantiteEuro(ZERO);
      if (estAvecCRC) {
        crc = CotisationRetraiteComplementaire.getCotisationEffective(montant, ebi.getSjr().getSalaire(), coefficientSurSalaire, montantBrut, parametres.getAllocationMinimale(), parametres.getCotisationRetraiteComplementaire());
      }
      if (estAvecCRC)
      {
        if (montantBrut.compareTo(ZERO) > 0)
        {
          montant.setAvecPrecompteCRC(estAvecCRC);
          montant.setCrc(crc);
        }
        else
        {
          montant.setCrc(new QuantiteEuro(ZERO));
          montant.setTauxCrc(parametres.getCotisationRetraiteComplementaire());
        }
      }
      else {
        montant.setCrc(new QuantiteEuro(ZERO));
      }
    }
    return montant;
  }
  
  public FormuleMontantSpec getFormuleMontantDroitAssocie()
  {
    return mformuleMontantDroitAssocie;
  }
  
  public int getFormuleMontantApplicable()
  {
    return mformuleMontantApplicable;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec formuleMontantDroitAssocie)
  {
    mformuleMontantDroitAssocie = formuleMontantDroitAssocie;
  }
  
  public void setFormuleMontantApplicable(int formuleMontantApplicable)
  {
    mformuleMontantApplicable = formuleMontantApplicable;
  }
}

/* Location:
 * Qualified Name:     FormuleMontantRegimeGeneralASPDC
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */