package fr.unedic.cali.asu.cva10.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Indemnite;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.util.Collection;
import java.util.Iterator;

public class DeterminationMontantsBruts
  implements OutilFonctionnel
{
  public static DeterminationMontantsBruts getInstance()
  {
    return new DeterminationMontantsBruts();
  }
  
  public void determinerMontantsBruts(Demande p_demande)
    throws CoucheLogiqueException
  {
    Attribution attributionCourante = (Attribution)p_demande.getAttribution();
    
    attributionCourante.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    
    ConstitutionMontantsBruts resultatCep = attributionCourante.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    
    resultatCep.setMontantJournalierPreavis(calculMontantJournalierPreavis(attributionCourante));
    
    DonneesEntreesRecuperationMontant donneesEntrees = ((GammeAsuSpec)attributionCourante.getGamme()).mapperDonneesEntreesRecuperationMontant(attributionCourante);
    
    donneesEntrees.setDateCalculMontant(attributionCourante.getDateEffet());
    
    MontantAsuSpec montantAAttribution = DeterminationMontant.determinerMontant(donneesEntrees);
    
    alimenterResultatCep(montantAAttribution, attributionCourante);
  }
  
  private void alimenterResultatCep(MontantAsuSpec p_montant, Attribution p_attribution)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts resultatCep = p_attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    
    resultatCep.setMontantAAttribution(p_montant);
    
    resultatCep.setMontantJournalierBrut(p_montant.getMontantPrecompteEffectif());
    
    resultatCep.setMontantBrutSansDeduction(p_montant.getMontantBrut());
    if (p_montant != null)
    {
      resultatCep.setMontantBase(p_montant.getBase());
      resultatCep.setMontantMini(p_montant.getMini());
      resultatCep.setMontantPlafond(p_montant.getPlafond());
      resultatCep.setMontantPlancher(p_montant.getPlancher());
      resultatCep.setMontantBrutSansPensionInvaliditeADeduire(p_montant.getMontantBrutSansPensionInvaliditeADeduire());
      resultatCep.setPensionInvaliditeADeduirePriseEnCompte(p_montant.getPensionInvaliditeADeduirePriseEnCompte());
      resultatCep.setMontantJournalierAvantageVieillesse(p_montant.getMontantJournalierAvantageVieillesse());
      resultatCep.setMontantJournalierAvantageVieillesseDeduit(p_montant.getMontantJournalierAvantageVieillesseDeduit());
      resultatCep.setCrc(p_montant.getCrc());
      resultatCep.setQuatreVingtSjr(p_montant.getPlafond().getValeur());
      resultatCep.setQuatreVingtMontantPreavis(p_montant.getMontant80PcentPreavis().getValeur());
      resultatCep.setMiniAREF(p_montant.getMini().getValeur());
    }
    Quantite nbJourIndemnisesTheorique = p_attribution.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(p_attribution, p_montant, p_attribution.getDateAttribution(), nbJourIndemnisesTheorique);
    
    resultatCep.setCapitalInitialBrut(capitalProduitCourant);
  }
  
  private Quantite calculMontantJournalierPreavis(Attribution p_attribution)
  {
    Quantite montantPreavis = null;
    Collection listeIndemnites = p_attribution.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getListeIndemnites();
    
    Iterator it = listeIndemnites.iterator();
    while (it.hasNext())
    {
      Indemnite indemnitePeriode = (Indemnite)it.next();
      int typeIndemnite = indemnitePeriode.getTypeIndemnite();
      switch (typeIndemnite)
      {
      case 125: 
        if (indemnitePeriode.getMontant() != null) {
          montantPreavis = indemnitePeriode.getMontant();
        }
        break;
      }
    }
    return montantPreavis;
  }
}

/* Location:
 * Qualified Name:     DeterminationMontantsBruts
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */