package fr.unedic.cali.asu.cva10.p03.calcul.dom;

import fr.unedic.cali.asu.cva10.calcul.dom.FormuleMontantASPSpec;
import fr.unedic.cali.asu.cva10.calcul.dom.FormuleMontantRegimeGeneralASPDC;
import fr.unedic.cali.asu.cva10.calcul.outilsfonctionnels.CotisationRetraiteComplementaire;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.UniteMonaitaire;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class FormuleMontantRegimeGeneralASPDCP03
  extends FormuleMontantRegimeGeneralASPDC
  implements FormuleMontantASPSpec
{
  protected static final BigDecimal COEF_75_SJR = new BigDecimal("0.75");
  protected static final BigDecimal COEF_SJR_PAP = new BigDecimal("0.70");
  protected static final BigDecimal COEF_SJR_PAP_PARLEMENTAIRE = new BigDecimal("0.75");
  protected static final BigDecimal COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE = BigDecimal.ONE;
  private static final BigDecimal ZERO = BigDecimal.ZERO;
  private FormuleMontantSpec formuleMontantDroitAssocie = null;
  private int formuleMontantApplicable = 1;
  protected static final BigDecimal FACTEUR_PLANCHER = new BigDecimal("0.574");
  protected static final BigDecimal MONTANT_PAR_DEFAUT = BigDecimal.ZERO;
  
  public static String getCode()
  {
    return "1";
  }
  
  public MontantBaseSpec calculer(ConstituantsIndemnisation constituantsInd, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateCalcul);
    Montant leMontant = new Montant();
    
    ElementBaseIndemnisation ebiPrincipal = (ElementBaseIndemnisation)constituantsInd.getElementBaseIndemnisationCourant();
    
    leMontant = calculerMontantEbi(ebiPrincipal, dateCalcul);
    
    leMontant.setMontantAreExecute(leMontant);
    leMontant.setSjrMontantMax(ebiPrincipal.getSjr().getSalaire());
    
    Collection<ElementBaseIndemnisation> listeSousEbi = ebiPrincipal.getListeSousEBI();
    
    leMontant = calculerMontantsSousEBI(leMontant, listeSousEbi, dateCalcul);
    if (leMontant.getMontantPrecompteEffectif().getValeur().compareTo(parametres.getPlafondASP()) > 0)
    {
      Montant montant = new Montant(leMontant);
      Quantite montantBrut = new Quantite(parametres.getPlafondASP().add(leMontant.getCrc().getValeur()), UniteMonaitaire.EUROS);
      
      montant.setMontantBrut(montantBrut);
      montant.setCrc(leMontant.getCrc());
      montant.setAvecPrecompteCRC(!montant.getCrc().getValeur().equals(BigDecimal.valueOf(0L)));
      montant.setMapMontants(leMontant.getMapMontants());
      leMontant = montant;
    }
    leMontant.setPlafondASP(parametres.getPlafondASP());
    
    return leMontant;
  }
  
  private Montant calculerMontantsSousEBI(Montant leMontant, Collection<ElementBaseIndemnisation> listeEbi, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    if (listeEbi != null)
    {
      Iterator<ElementBaseIndemnisation> iteListeEBI = listeEbi.iterator();
      while (iteListeEBI.hasNext())
      {
        Quantite pensionInvaliditeaDeduire = leMontant.getPensionInvaliditeADeduirePriseEnCompte();
        ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)iteListeEBI.next();
        Montant montant;
        if (ebi.getProduitMontantRetenu().getNom().equals("ASU_CVA10_03"))
        {
          Montant montant = calculerMontantASPDC(ebi, dateCalcul);
          if (leMontant.getMontantSJR() != null)
          {
            BigDecimal montantBrutMax = leMontant.getMontantSJR().getMontantBrut().getValeur();
            if (montantBrutMax.compareTo(montant.getMontantBrut().getValeur()) == -1) {
              leMontant.setMontantSJR(montant);
            }
          }
          else
          {
            leMontant.setMontantSJR(montant);
          }
        }
        else
        {
          montant = calculerMontantEbi(ebi, dateCalcul);
          if (leMontant.getMontantAreNonExecute() != null)
          {
            BigDecimal montantBrutMax = leMontant.getMontantAreNonExecute().getMontantBrut().getValeur();
            if (montantBrutMax.compareTo(montant.getMontantBrut().getValeur()) == 0) {
              leMontant.setMontantAreNonExecute(montant);
            }
          }
          else
          {
            leMontant.setMontantAreNonExecute(montant);
          }
        }
        if (montant.getMontantPrecompteEffectif().compareTo(leMontant.getMontantPrecompteEffectif()) > 0)
        {
          montant.setMapMontants(leMontant.getMapMontants());
          leMontant = montant;
          leMontant.setSjrMontantMax(ebi.getSjr().getSalaire());
        }
        leMontant.setPensionInvaliditeADeduirePriseEnCompte(pensionInvaliditeaDeduire);
      }
      if (leMontant.getMontantAreNonExecute() == null) {
        leMontant.setMontantAreNonExecute(leMontant.getMontantAreExecute());
      }
    }
    return leMontant;
  }
  
  private Montant constituerMontant(ElementBaseIndemnisation ebi, Montant montant, EvenementParametre parametres)
  {
    BigDecimal coefficientSurSalaire = COEFFICIENT_PAR_DEFAUT_POUR_PARAMETRE;
    if (ebi.getCoefficientSaisonnier() != null) {
      coefficientSurSalaire = ebi.getCoefficientSaisonnier();
    }
    boolean estAvecCRC = ebi.getAvecPrecompteCRC() != null ? ebi.getAvecPrecompteCRC().booleanValue() : true;
    Quantite crc = new QuantiteEuro(ZERO);
    if (estAvecCRC) {
      crc = CotisationRetraiteComplementaire.getCotisationEffective(montant, ebi.getSjr().getSalaire(), coefficientSurSalaire, montant.getMontantBrut().getValeur(), parametres.getAllocationMinimale(), parametres.getCotisationRetraiteComplementaire());
    }
    if (estAvecCRC)
    {
      if (montant.getMontantBrut().getValeur().compareTo(ZERO) > 0)
      {
        montant.setAvecPrecompteCRC(estAvecCRC);
        montant.setCrc(crc);
      }
      else
      {
        montant.setCrc(new QuantiteEuro(ZERO));
        montant.setTauxCrc(parametres.getCotisationRetraiteComplementaire());
      }
    }
    else {
      montant.setCrc(new QuantiteEuro(ZERO));
    }
    return montant;
  }
  
  protected Montant calculerMontantEbi(ElementBaseIndemnisation ebi, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec produitPourCalculMontant = ebi.getProduitMontantRetenu();
    
    ebi.setProduitMontantRetenu(produitPourCalculMontant);
    ConstituantsIndemnisation constituantBouchon = new ConstituantsIndemnisation();
    constituantBouchon.setElementBaseIndemnisationCourant(ebi);
    FormuleMontantSpec formuleMontantAUtiliser = produitPourCalculMontant.getFormuleMontant("2");
    MontantBaseSpec montantBase = formuleMontantAUtiliser.calculer(constituantBouchon, dateCalcul);
    return new Montant(montantBase);
  }
  
  private Montant calculerMontantASPDC(ElementBaseIndemnisation ebi, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    Montant montant = new Montant();
    if ((ebi != null) && (ebi.getSjr() != null))
    {
      Sjr sjrrp = ebi.getSjr();
      BigDecimal montantBrut = null;
      if (ebi.isContextePapParlementaire()) {
        montantBrut = COEF_SJR_PAP_PARLEMENTAIRE.multiply(sjrrp.getSalaire());
      } else if (ebi.isContextePAPPresent()) {
        montantBrut = COEF_SJR_PAP.multiply(sjrrp.getSalaire());
      } else {
        montantBrut = COEF_75_SJR.multiply(sjrrp.getSalaire());
      }
      montant.setMontantBrutSansPensionInvaliditeADeduire(new Quantite(Mathematiques.arrondiASup(montantBrut, 2), UniteMonaitaire.EUROS));
      montantBrut = montantBrut.subtract(ebi.getMontantPensionInvaliditeADeduire());
      
      montant.setMontantBrut(new QuantiteEuro(Mathematiques.arrondiASup(montantBrut, 2)));
      EvenementParametre parametres = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateCalcul);
      montant = constituerMontant(ebi, montant, parametres);
    }
    return montant;
  }
  
  public FormuleMontantSpec getFormuleMontantDroitAssocie()
  {
    return formuleMontantDroitAssocie;
  }
  
  public int getFormuleMontantApplicable()
  {
    return formuleMontantApplicable;
  }
  
  public void setFormuleMontantDroitAssocie(FormuleMontantSpec formuleMontantDroitAssocie)
  {
    this.formuleMontantDroitAssocie = formuleMontantDroitAssocie;
  }
  
  public void setFormuleMontantApplicable(int formuleMontantApplicable)
  {
    this.formuleMontantApplicable = formuleMontantApplicable;
  }
}

/* Location:
 * Qualified Name:     FormuleMontantRegimeGeneralASPDCP03
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */