package fr.unedic.cali.asu.cve13.p01.calcul.pbjc;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteAsu;
import fr.unedic.cali.asu.calcul.dom.ConstituantsCalculActiviteReduiteGamme;
import fr.unedic.cali.asu.calcul.dom.temps.ObjetChronoPeriodeRejetDVDemandeExpresse;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DossierExamen;
import fr.unedic.cali.asu.parametres.EvenementParametre;
import fr.unedic.cali.asu.parametres.ParametresIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.Reprise;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.ArretProduitAvecRaison;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.EvenementCalculSpec;
import fr.unedic.cali.calcul.dom.EvenementChangementParametre;
import fr.unedic.cali.calcul.dom.EvenementFinCumul;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.Somme;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.dom.periode.ActionFormation;
import fr.unedic.cali.calcul.dom.periode.FinActionFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.dom.periode.PeriodeBlocageIndemnisation;
import fr.unedic.cali.calcul.dom.periode.PeriodeExclusionDefinitiveDDTE;
import fr.unedic.cali.calcul.dom.periode.PeriodeFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodeInterStageFormation;
import fr.unedic.cali.calcul.dom.periode.PeriodePensionInvalidite;
import fr.unedic.cali.calcul.dom.periode.PeriodeSanctionReductionMontant;
import fr.unedic.cali.calcul.dom.periode.PeriodeServiceCivique;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionDDTEAvecImputation;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionDDTESansImputation;
import fr.unedic.cali.calcul.dom.periode.PeriodeSuspensionTitreConservatoire;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire50Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire55Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoAnniversaire60Ans;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeFinPec;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeInterProduits;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeLimiteIndemnisationATP;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRadiation;
import fr.unedic.cali.calcul.dom.temps.ObjetChronoPeriodeRetraite;
import fr.unedic.cali.calcul.pbjc.FacadePBJCProduitSpec;
import fr.unedic.cali.calcul.pbjc.dom.PbjcNcp;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.Prescription;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.Retraite;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class FacadePBJCProduitImpl
  implements FacadePBJCProduitSpec
{
  public static final int REDUCTION_50_POURCENT = 50;
  public static final int REDUCTION_20_POURCENT = 20;
  public static final int REF_BASE_CALCUL_OUVERTURE_DROIT = 1;
  public static final int REF_BASE_CALCUL_READ_SUR_DROIT_ANTECEDENT = 2;
  private static final int AGE_50_ANS = 50;
  private static final int AGE_55_ANS = 55;
  private static final int AGE_60_ANS = 60;
  
  public void ajouterGroupeMontantProduit(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, Somme p_somme, UniteTraitement p_ut)
  {
    if ((p_somme.getMontant() != null) && (p_somme.getMontant().getMontantBrut() != null) && (p_somme.getMontant().getMontantBrut().getValeur().compareTo(new BigDecimal(0)) > 0))
    {
      if ((p_somme.getMontant().getType().equals("FORMATION EFFECTIVE")) || (p_somme.getMontant().getType().equals("FORMATION PREVISIONNELLE"))) {
        ajouterGroupeMontantAREF(p_pbjcNcp, p_attribution.getProduit().getNom(), p_somme, p_ut);
      } else {
        p_pbjcNcp.ajouterGroupeMontants(p_attribution.getProduit().getNom(), 0, new BigDecimal("0"), p_somme.getMontant().getMontantBrut().getValeur(), new BigDecimal("1"), p_somme.getMontant().getMontantBrut().getValeur(), "");
      }
      if (p_pbjcNcp.isTopApplicationCRC()) {
        ajouterGroupeMontantPCRC(p_pbjcNcp, p_somme.getMontant());
      }
      Attribution attribution = (Attribution)p_attribution;
      if ((attribution.getAttributionFinancement() != null) && 
        (p_somme.getMontant().getMontantFinancement() != null)) {
        ajouterGroupeMontantFinancement(p_pbjcNcp, p_attribution, p_somme);
      }
    }
  }
  
  public ChronologiePeriodes creerChronologiePBJCsAvant(AttributionSpec p_attribution, Damj p_dateGeneration, Damj p_dateBlocageActualisation, String p_libelleBlocageActualisation)
    throws ApplicativeException
  {
    return new ChronologiePeriodes();
  }
  
  public void positionnerJustificationFermetureDJI(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    if (p_ut.getArretProduitAvecRaison().isRaisonsContientRaison(4))
    {
      Iterator iterateurPeriodesInterruptives = p_ut.getArretProduitAvecRaison().getPeriodesInterruptivesDefinitives().iterator();
      while (iterateurPeriodesInterruptives.hasNext())
      {
        ObjetChronoPeriode objetChronoPeriode = (ObjetChronoPeriode)iterateurPeriodesInterruptives.next();
        if ((objetChronoPeriode instanceof ObjetChronoPeriodeFinPec))
        {
          if (OutillagePeriodes.estRadiationFaisantSuitePecCA(p_attribution, objetChronoPeriode.getDateDebut())) {
            p_pbjcNcp.ajouterComplementDeJustification("RF");
          }
          String motifRadiation = ((ObjetChronoPeriodeFinPec)objetChronoPeriode).getMotifAnnulationPEC();
          
          p_pbjcNcp.setCodeRadiationLendemainPeriode(motifRadiation);
          
          p_pbjcNcp.ajouterComplementDeJustification("TD");
          if ((motifRadiation != null) && (motifRadiation.equals("73"))) {
            p_pbjcNcp.ajouterComplementDeJustification("OH");
          }
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeRetraite))
        {
          if (((ObjetChronoPeriodeRetraite)objetChronoPeriode).getRetraite().estTypeBase()) {
            p_pbjcNcp.ajouterComplementDeJustification("OD");
          } else {
            p_pbjcNcp.ajouterComplementDeJustification(((ObjetChronoPeriodeRetraite)objetChronoPeriode).getRetraite().getMotif());
          }
        }
        else if ((objetChronoPeriode instanceof PeriodeExclusionDefinitiveDDTE))
        {
          String codeSanction = ((PeriodeExclusionDefinitiveDDTE)objetChronoPeriode).getCodeSanction();
          if (codeSanction.equals("ED")) {
            p_pbjcNcp.ajouterComplementDeJustification("SJ");
          } else if (codeSanction.equals("EX")) {
            p_pbjcNcp.ajouterComplementDeJustification("SI");
          }
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeRejetDVDemandeExpresse))
        {
          p_pbjcNcp.ajouterComplementDeJustification("ST");
        }
        else if ((objetChronoPeriode instanceof PeriodeBlocageIndemnisation))
        {
          p_pbjcNcp.ajouterComplementDeJustification("OM");
        }
        else if ((objetChronoPeriode instanceof ObjetChronoPeriodeLimiteIndemnisationATP))
        {
          p_pbjcNcp.ajouterComplementDeJustification("NF");
        }
      }
    }
  }
  
  public void positionnerComplementJustification(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution)
  {
    fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation elementBaseIndemnisationFinUT = (fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)p_ut.getConstituantsIndemnisationEnFinUT().getElementBaseIndemnisationCourant();
    
    Collection collectionEvtsChangementParametre = null;
    Collection collectionEvenements = null;
    Iterator iterateur = null;
    EvenementChangementParametre evenementChangementParametre = null;
    
    EvenementCalculSpec evtCalcul = null;
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    
    collectionEvtsChangementParametre = getEvtsChangementParametre(p_pbjcNcp.getDateDebut());
    if (collectionEvtsChangementParametre != null)
    {
      iterateur = collectionEvtsChangementParametre.iterator();
      while (iterateur.hasNext())
      {
        evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
        if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
          if ((evenementChangementParametre.getDateEffet().coincideAvec(p_pbjcNcp.getDateDebut())) && (verifierDureePourReval(p_attribution, evenementChangementParametre.getDateEffet()))) {
            p_pbjcNcp.ajouterComplementDeJustification("CD");
          }
        }
        if ((evenementChangementParametre.getNomParametre().equals("NV PARAMETRE")) && 
        
          (evenementChangementParametre.getDateEffet().coincideAvec(p_pbjcNcp.getDateDebut()))) {
          p_pbjcNcp.ajouterComplementDeJustification("DH");
        }
      }
    }
    if (p_ut.isNeutralisee())
    {
      int typeNeutralisation = p_ut.getTypeNeutralisation();
      if ((typeNeutralisation == 0) || (typeNeutralisation == 7)) {
        p_pbjcNcp.ajouterComplementDeJustification("GC");
      } else if ((typeNeutralisation == 1) || (typeNeutralisation == 2)) {
        p_pbjcNcp.ajouterComplementDeJustification("GD");
      } else if (typeNeutralisation == 6) {
        p_pbjcNcp.ajouterComplementDeJustification("GE");
      }
    }
    collectionEvenements = p_ut.getCollectionEvenements();
    if (collectionEvenements != null)
    {
      iterateur = collectionEvenements.iterator();
      while (iterateur.hasNext())
      {
        evtCalcul = (EvenementCalculSpec)iterateur.next();
        if (((evtCalcul instanceof EvenementFinCumul)) && 
          (((EvenementFinCumul)evtCalcul).getDateEvenement().coincideAvec(p_pbjcNcp.getDateDebut()))) {
          p_pbjcNcp.ajouterComplementDeJustification("G7");
        }
      }
    }
    periodes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if (objetChronoPeriode.getDateDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (((objetChronoPeriode instanceof ObjetChronoAnniversaire50Ans)) || ((objetChronoPeriode instanceof ObjetChronoAnniversaire55Ans)) || ((objetChronoPeriode instanceof ObjetChronoAnniversaire60Ans)))
        {
          if ((objetChronoPeriode instanceof ObjetChronoAnniversaire50Ans)) {
            p_pbjcNcp.setCoefAvantageVieillesse(ParametresIndemnisation.getParametresIndemnisation().getTauxAvantageViellesse(new DureeCalendaire(50)));
          } else if ((objetChronoPeriode instanceof ObjetChronoAnniversaire55Ans)) {
            p_pbjcNcp.setCoefAvantageVieillesse(ParametresIndemnisation.getParametresIndemnisation().getTauxAvantageViellesse(new DureeCalendaire(55)));
          } else if ((objetChronoPeriode instanceof ObjetChronoAnniversaire60Ans)) {
            p_pbjcNcp.setCoefAvantageVieillesse(ParametresIndemnisation.getParametresIndemnisation().getTauxAvantageViellesse(new DureeCalendaire(60)));
          }
          if (p_pbjcNcp.getCoefAvantageVieillesse().compareTo(new BigDecimal("0")) == 1) {
            p_pbjcNcp.ajouterComplementDeJustification("DF");
          }
        }
        else if ((objetChronoPeriode instanceof PeriodePensionInvalidite))
        {
          p_pbjcNcp.ajouterComplementDeJustification("FR");
        }
        else if ((objetChronoPeriode instanceof PeriodeAvantageVieillesse))
        {
          p_pbjcNcp.ajouterComplementDeJustification("DG");
          if (objetChronoPeriode.getDateDebut().estApres(PeriodeAvantageVieillesse.DATE_BASCULE_AV)) {
            p_pbjcNcp.ajouterComplementDeJustification("DJ");
          } else {
            p_pbjcNcp.ajouterComplementDeJustification("DI");
          }
        }
        else if (((objetChronoPeriode instanceof PeriodeInterStageFormation)) || ((objetChronoPeriode instanceof FinActionFormation)))
        {
          p_pbjcNcp.ajouterComplementDeJustification("E2");
        }
      }
    }
    Chronologie radiations = OutillagePeriodes.recupererRadiations(p_attribution.getDemandeur());
    radiations.iterer();
    while (radiations.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriodeRadiation)radiations.elementSuivant();
      if (((objetChronoPeriode instanceof ObjetChronoPeriodeRadiation)) && (objetChronoPeriode.getDateDebut().coincideAvec(p_pbjcNcp.getDateFin().lendemain())))
      {
        String motifRadiation = ((ObjetChronoPeriodeRadiation)objetChronoPeriode).getMotifAnnulationPEC();
        
        p_pbjcNcp.setCodeRadiationLendemainPeriode(motifRadiation);
        
        p_pbjcNcp.ajouterComplementDeJustification("TD");
      }
    }
    if (elementBaseIndemnisationFinUT.estMontantReduit()) {
      p_pbjcNcp.ajouterComplementDeJustification("EU");
    }
  }
  
  public void traiterBlocageActuPourLAvant(PbjcNcp p_pbjcNcpAvant, Damj p_dateBlocageActualisation, String p_libelleBlocageActualisation) {}
  
  public Quantite retournerQuantiteIndemnisationInitialeDroit(AttributionSpec p_attribution, UniteTraitement ut)
  {
    Periode periodeIndemnisation = new Periode(p_attribution.getDateAttribution(), ((Attribution)p_attribution).getDateLimiteIndemnisation());
    return new QuantiteJour(new BigDecimal(periodeIndemnisation.getDuree()));
  }
  
  public void traiterPBJCsAPosteriori(ChronologiePeriodes p_chronoPBJCs, AttributionSpec p_attribution, Chronologie chronoUT)
  {
    PbjcNcp pbjcNcp = null;
    PbjcNcp pbjcNcpAvant = null;
    DossierExamen dossierExamen = null;
    Damj dateMaintien = null;
    boolean pbjcTrouvee = false;
    
    ChronologiePeriodes chronologiePeriodesRadiationPEC = OutillagePeriodes.recupererPecsRadiationSuiteEntreeFormation(p_attribution.getDemandeur());
    
    Chronologie demandes = p_attribution.getDemandeur().getChronoDemandeMaintien();
    demandes.iterer();
    while (demandes.encoreSuivant())
    {
      DemandeSpec demandeMaintien = (DemandeSpec)demandes.elementSuivant();
      if (((demandeMaintien instanceof DemandeMaintien)) && (!demandeMaintien.estEnReExamen()) && ((demandeMaintien.getClassementAdministratif() == null) || (((demandeMaintien.getClassementAdministratif() instanceof Prescription)) && (!((Prescription)demandeMaintien.getClassementAdministratif()).isValidite()))))
      {
        dossierExamen = ((DemandeMaintien)demandeMaintien).getDossierExamen();
        if ((dossierExamen != null) && ((dossierExamen instanceof Accord))) {
          dateMaintien = demandeMaintien.getDateEffet();
        }
      }
    }
    p_chronoPBJCs.iterer();
    while (p_chronoPBJCs.encoreSuivant())
    {
      pbjcNcp = (PbjcNcp)p_chronoPBJCs.elementSuivant();
      if ((dateMaintien != null) && (((AttributionAssuranceSpec)p_attribution).estMaintenue()))
      {
        if (pbjcNcp.getDateDebut().estApresOuCoincideAvec(dateMaintien))
        {
          if (pbjcNcp.getDateDebut().coincideAvec(dateMaintien)) {
            pbjcNcp.ajouterComplementDeJustification("B1");
          }
          pbjcTrouvee = true;
        }
        if (pbjcTrouvee) {
          pbjcNcp.setEtatReglementaireOd("5");
        }
      }
      chronologiePeriodesRadiationPEC.iterer();
      while (chronologiePeriodesRadiationPEC.encoreSuivant())
      {
        ObjetChronoPeriodeRadiation periodeRadiation = (ObjetChronoPeriodeRadiation)chronologiePeriodesRadiationPEC.elementSuivant();
        if (periodeRadiation.getDateDebut().veille().coincideAvec(pbjcNcp.getDateFin()))
        {
          pbjcNcp.ajouterComplementDeJustification("TD");
          
          pbjcNcp.setCodeRadiationLendemainPeriode("31");
        }
      }
      if (pbjcNcpAvant != null)
      {
        if (pbjcNcpAvant.getDateFin().coincideAvec(pbjcNcp.getDateDebut().veille()))
        {
          if (pbjcNcp.contientComplementDeJustification("FR")) {
            pbjcNcpAvant.ajouterComplementDeJustification("QF");
          }
          if ((pbjcNcp.getInterrupIndemParPensionInvalidite() != null) && (pbjcNcpAvant.getInterrupIndemParPensionInvalidite() != null))
          {
            if ((pbjcNcp.getInterrupIndemParPensionInvalidite().equals("O")) && 
              (pbjcNcpAvant.getInterrupIndemParPensionInvalidite().equals("N"))) {
              pbjcNcp.ajouterComplementDeJustification("FN");
            }
            if ((pbjcNcp.getInterrupIndemParPensionInvalidite().equals("N")) && 
              (pbjcNcpAvant.getInterrupIndemParPensionInvalidite().equals("O"))) {
              pbjcNcp.ajouterComplementDeJustification("FO");
            }
          }
        }
        if ((pbjcNcpAvant.getMontantCumuleRevaloriseAV() != null) && (pbjcNcpAvant.getMontantCumuleRevaloriseAV().compareTo(new BigDecimal("0")) > 0) && 
          (pbjcNcp.getMontantCumuleRevaloriseAV() != null) && (pbjcNcp.getMontantCumuleRevaloriseAV().compareTo(new BigDecimal("0")) > 0) && 
          (pbjcNcp.getMontantCumuleRevaloriseAV().compareTo(pbjcNcpAvant.getMontantCumuleRevaloriseAV()) != 0) && (!pbjcNcp.contientComplementDeJustification("DG"))) {
          pbjcNcp.ajouterComplementDeJustification("DH");
        }
      }
      if ((pbjcNcp.contientComplementDeJustification("FR")) && (pbjcNcp.getInterrupIndemParPensionInvalidite() != null) && (pbjcNcp.getInterrupIndemParPensionInvalidite().equals("O"))) {
        pbjcNcp.ajouterComplementDeJustification("FN");
      }
      if ((p_attribution.getCalendrierExecutionCalcul() != null) && (p_attribution.getCalendrierExecutionCalcul().getPremierJourIndemnisable().coincideAvec(pbjcNcp.getDateDebut()))) {
        positionnerJustificationOuverturePJI(pbjcNcp, p_attribution);
      }
      if (pbjcNcpAvant != null) {
        pbjcNcp.setNbJoursAREF(pbjcNcpAvant.getNbJoursAREF());
      }
      if ((pbjcNcp.estEnAref()) && (pbjcNcp.getEtatIndemnisation().compareTo("AVANT") != 0)) {
        pbjcNcp.setNbJoursAREF(pbjcNcp.getNbJoursAREF() + pbjcNcp.getNbJoursImputes());
      }
      pbjcNcpAvant = pbjcNcp;
    }
  }
  
  public ChronologiePeriodes traitementPeriodesSuspensives(ChronologiePeriodes p_periodesSuspensives, UniteTraitement p_ut)
  {
    return p_periodesSuspensives;
  }
  
  private void ajouterGroupeMontantAREF(PbjcNcp p_pbjcNcp, String p_nomProduit, Somme p_somme, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    PeriodeFormation periodeFormationCalcul = null;
    
    p_pbjcNcp.ajouterGroupeMontants(p_nomProduit, 1, new BigDecimal("0"), p_somme.getMontant().getMontantBrut().getValeur(), new BigDecimal("1"), p_somme.getMontant().getMontantBrut().getValeur(), "");
    
    periodes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if ((objetChronoPeriode instanceof PeriodeFormation))
      {
        if (objetChronoPeriode.getDateDebut().equals(p_pbjcNcp.getDateDebut())) {
          if (((PeriodeFormation)objetChronoPeriode).getIdentifiantPeriodeFormation() == 1) {
            p_pbjcNcp.ajouterComplementDeJustification("BF");
          } else {
            p_pbjcNcp.ajouterComplementDeJustification("BA");
          }
        }
        if (objetChronoPeriode.getDateFin().equals(p_pbjcNcp.getDateFin()))
        {
          p_pbjcNcp.ajouterComplementDeJustification("TH");
          p_pbjcNcp.ajouterComplementDeJustification("TD");
          
          p_pbjcNcp.setCodeRadiationLendemainPeriode("41");
        }
        if (p_pbjcNcp.chevauche(new Periode(objetChronoPeriode.getDateDebut(), objetChronoPeriode.getDateFin())))
        {
          periodeFormationCalcul = (PeriodeFormation)objetChronoPeriode;
          p_pbjcNcp.setIdStageFormation(periodeFormationCalcul.getIdentifiantPeriodeFormation());
          p_pbjcNcp.setTypeMesurePourLEmploi(periodeFormationCalcul.getTypeMesureEmploi());
        }
      }
      else if (((objetChronoPeriode instanceof PeriodeInterStageFormation)) && 
        (objetChronoPeriode.getDateDebut().veille().equals(p_pbjcNcp.getDateFin())))
      {
        p_pbjcNcp.ajouterComplementDeJustification("TH");
        p_pbjcNcp.ajouterComplementDeJustification("TD");
      }
    }
    periodes = p_ut.getQualificationPeriodes().getPeriodesNonQualifiees();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if (((objetChronoPeriode instanceof ActionFormation)) && 
        (p_pbjcNcp.chevauche(new Periode(objetChronoPeriode.getDateDebut(), objetChronoPeriode.getDateFin()))))
      {
        p_pbjcNcp.setIdPlanFormation(((ActionFormation)objetChronoPeriode).getIdentifiantActionFormation());
        
        p_pbjcNcp.setTypeDePlan(((ActionFormation)objetChronoPeriode).getTypePlan());
      }
    }
  }
  
  private void ajouterGroupeMontantPCRC(PbjcNcp p_pbjcNcp, MontantBaseSpec p_montantBaseSpec)
  {
    MontantAsuSpec montant = (MontantAsuSpec)p_montantBaseSpec;
    
    p_pbjcNcp.ajouterGroupeMontants("PCRC", 0, montant.getSjrNonReduit(), montant.getBaseCalculCrc().setScale(2, 3), Mathematiques.arrondiASup(montant.getTauxCrc().multiply(new BigDecimal("100")), 2), Mathematiques.arrondiASup(montant.getCrc().getValeur(), 2), montant.getPositionExonerationCrc());
    if (montant.getPensionInvaliditeADeduirePriseEnCompte() != null) {
      p_pbjcNcp.setMontantPensionInvalidite(montant.getPensionInvaliditeADeduirePriseEnCompte().getValeur());
    }
  }
  
  private void ajouterGroupeMontantFinancement(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, Somme p_somme)
  {
    Attribution attribution = (Attribution)p_attribution;
    p_pbjcNcp.ajouterGroupeMontants(attribution.getAttributionFinancement().getProduit().getNom(), 0, new BigDecimal("0"), p_somme.getMontant().getMontantFinancement(), new BigDecimal("1"), p_somme.getMontant().getMontantFinancement(), "");
  }
  
  public boolean controlerExecutionPBJCs(AttributionSpec p_attribution)
  {
    return true;
  }
  
  public boolean creerPBJCsurUT(AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    return true;
  }
  
  private Collection getEvtsChangementParametre(Damj p_date)
  {
    List evtsRetour = new ArrayList();
    EvenementParametre evtParam = ParametresIndemnisation.getParametresIndemnisation().getElementActif(p_date);
    EvenementChangementParametre evt = null;
    if (evtParam.isNouveauRevalorisationSjr())
    {
      evt = new EvenementChangementParametre("REVALORISATION", evtParam.getDateEvenement());
      evtsRetour.add(evt);
    }
    if ((evtParam.isNouveauAllocationMinimale()) || (evtParam.isNouveauCotisationRetraiteComplementaire()) || (evtParam.isNouveauPartieFixe()) || (evtParam.isNouveauPlafond()) || (evtParam.isNouveauSeuilMinimalAREF()) || (evtParam.isNouveauSmicHoraire()))
    {
      evt = new EvenementChangementParametre("NV PARAMETRE", evtParam.getDateEvenement());
      evtsRetour.add(evt);
    }
    return evtsRetour;
  }
  
  public Collection getEvtsChangementParametre(Damj p_dateDebut, Damj p_dateFin, AttributionSpec p_attribution)
  {
    List evtsRetour = new ArrayList();
    Chronologie chronoEvtParam = ParametresIndemnisation.getParametresIndemnisation().getParametresActifs(new Periode(p_dateDebut, p_dateFin));
    EvenementChangementParametre evt = null;
    
    Iterator iterateur = chronoEvtParam.iterer();
    while (iterateur.hasNext())
    {
      EvenementParametre evtParam = (EvenementParametre)iterateur.next();
      if (evtParam.isNouveauRevalorisationSjr())
      {
        evt = new EvenementChangementParametre("REVALORISATION", evtParam.getDateEvenement());
        evtsRetour.add(evt);
      }
      else if ((evtParam.isNouveauAllocationMinimale()) || (evtParam.isNouveauCotisationRetraiteComplementaire()) || (evtParam.isNouveauPartieFixe()) || (evtParam.isNouveauPlafond()) || (evtParam.isNouveauSeuilMinimalAREF()) || (evtParam.isNouveauSmicHoraire()))
      {
        evt = new EvenementChangementParametre("NV PARAMETRE", evtParam.getDateEvenement());
        evtsRetour.add(evt);
      }
    }
    return evtsRetour;
  }
  
  public void miseAJourNombreJoursImputes(UniteTraitement p_ut, PbjcNcp p_pbjcNcp) {}
  
  public void positionnerActiviteReduite(PbjcNcp p_pbjcNcp, ConstituantsCalculActiviteReduiteSpec p_constituantsCalculActiviteReduite)
  {
    p_pbjcNcp.setNbMoisActiviteReduite(((ConstituantsCalculActiviteReduiteAsu)p_constituantsCalculActiviteReduite).getCumul());
  }
  
  public void positionnerCategorieAttribution(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    Attribution attribution = (Attribution)p_attribution;
    p_pbjcNcp.setCategorie(attribution.determinerCodeSousProduitPourSigma());
  }
  
  public void positionnerCoefficientTempsPartiel(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution)
  {
    Attribution attribution = (Attribution)p_attribution;
    BigDecimal coeffTP = p_ut.getConstituantsIndemnisationEnDebutUT().getElementBaseIndemnisationCourant().getCoefficientTempsPartiel();
    if ((((fr.unedic.cali.asu.dom.ElementBaseIndemnisation)p_ut.getConstituantsIndemnisationEnDebutUT().getElementBaseIndemnisationCourant()).getElementBaseIndemnisationDroitAssocie() != null) && (attribution.getAttributionFinancement().getPji().estApresOuCoincideAvec(p_pbjcNcp.getDateDebut()))) {
      coeffTP = attribution.getAttributionFinancement().getElementBaseIndemnisation().getCoefficientTempsPartiel();
    }
    p_pbjcNcp.setCoefficientTempsPartiel(coeffTP);
  }
  
  public void positionnerDonneesAvantageVieillesse(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution)
  {
    fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation elementBaseIndemnisationFinUT = null;
    fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation elementBaseIndemnisationDebutUT = null;
    ChronologiePeriodes chronoPeriodesSegmentantes = null;
    PeriodeAvantageVieillesse periodeAvantageVieillesse = null;
    ParametresIndemnisation parametresIndemnisation = ParametresIndemnisation.getParametresIndemnisation();
    BigDecimal montantAVAPositionner = null;
    
    elementBaseIndemnisationDebutUT = (fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)p_ut.getConstituantsIndemnisationEnDebutUT().getElementBaseIndemnisationCourant();
    elementBaseIndemnisationFinUT = (fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)p_ut.getConstituantsIndemnisationEnFinUT().getElementBaseIndemnisationCourant();
    
    chronoPeriodesSegmentantes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    if ((chronoPeriodesSegmentantes != null) && (!chronoPeriodesSegmentantes.estVide()))
    {
      chronoPeriodesSegmentantes.iterer();
      while (chronoPeriodesSegmentantes.encoreSuivant())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)chronoPeriodesSegmentantes.elementSuivant();
        if (((periode instanceof PeriodeAvantageVieillesse)) && (periode.chevauche(new Periode(p_pbjcNcp.getDateDebut(), p_pbjcNcp.getDateFin())))) {
          periodeAvantageVieillesse = (PeriodeAvantageVieillesse)periode;
        }
      }
    }
    p_pbjcNcp.setCoefAvantageVieillesse(parametresIndemnisation.getTauxAvantageViellesse(p_attribution.getDemandeur().getAgeALaDate(p_pbjcNcp.getDateDebut())));
    if (periodeAvantageVieillesse != null)
    {
      BigDecimal sjrDebutUt = elementBaseIndemnisationDebutUT.getSjrATP().getSalaire();
      BigDecimal sjrFinUt = elementBaseIndemnisationFinUT.getSjrATP().getSalaire();
      if ((periodeAvantageVieillesse.getDateDebut().estAvant(p_ut.getDateDebut().getDebutMois())) && (periodeAvantageVieillesse.getDateFin().estAvant(p_ut.getDateFin())))
      {
        if (sjrDebutUt.compareTo(sjrFinUt) != 0) {
          montantAVAPositionner = elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse().multiply(sjrFinUt).divide(sjrDebutUt, 2);
        } else {
          montantAVAPositionner = elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse();
        }
      }
      else if ((periodeAvantageVieillesse.getDateDebut().estApres(p_ut.getDateDebut())) && (periodeAvantageVieillesse.getDateFin().estAvant(p_ut.getDateFin()))) {
        montantAVAPositionner = periodeAvantageVieillesse.getQuantiteEuro().getValeurMontant();
      } else if ((elementBaseIndemnisationFinUT.getMontantAvantageVieillesse() != null) && (elementBaseIndemnisationFinUT.getMontantAvantageVieillesse().compareTo(new BigDecimal("0")) > 0)) {
        montantAVAPositionner = elementBaseIndemnisationFinUT.getMontantAvantageVieillesse();
      } else if ((elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse() != null) && (elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse().compareTo(new BigDecimal("0")) > 0)) {
        montantAVAPositionner = elementBaseIndemnisationDebutUT.getMontantAvantageVieillesse();
      } else {
        montantAVAPositionner = periodeAvantageVieillesse.getQuantiteEuro().getValeurMontant();
      }
      p_pbjcNcp.setMontantCumuleRevaloriseAV(Mathematiques.arrondiASup(montantAVAPositionner, 2));
    }
    else
    {
      p_pbjcNcp.setMontantCumuleRevaloriseAV(new BigDecimal("0"));
    }
  }
  
  public void positionnerEtatsReglementaireEtAdministratif(PbjcNcp p_pbjcNcp)
  {
    p_pbjcNcp.setEtatReglementaireOd("1");
    
    p_pbjcNcp.setEtatAdministratifOd("1");
  }
  
  public void positionnerIndicateurInterruptionIndemnisationParPensionInvalidite(PbjcNcp p_pbjcNcp)
  {
    if (p_pbjcNcp.getMontantPensionInvalidite().compareTo(new BigDecimal("0")) > 0)
    {
      p_pbjcNcp.setInterrupIndemParPensionInvalidite("N");
      if (p_pbjcNcp.getEtatAdministratifOd().equals("1")) {
        if (p_pbjcNcp.getCodeTypeMontant1().equals(p_pbjcNcp.getProduit()))
        {
          if (p_pbjcNcp.getResultatCalcul1().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getCodeTypeMontant2().equals(p_pbjcNcp.getProduit()))
        {
          if (p_pbjcNcp.getResultatCalcul2().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getCodeTypeMontant3().equals(p_pbjcNcp.getProduit()))
        {
          if (p_pbjcNcp.getResultatCalcul3().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getCodeTypeMontant4().equals(p_pbjcNcp.getProduit()))
        {
          if (p_pbjcNcp.getResultatCalcul4().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getCodeTypeMontant5().equals(p_pbjcNcp.getProduit()))
        {
          if (p_pbjcNcp.getResultatCalcul5().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getCodeTypeMontant6().equals(p_pbjcNcp.getProduit()))
        {
          if (p_pbjcNcp.getResultatCalcul6().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
        else if (p_pbjcNcp.getCodeTypeMontant7().equals(p_pbjcNcp.getProduit())) {
          if (p_pbjcNcp.getResultatCalcul7().compareTo(new BigDecimal("0")) == 0) {
            p_pbjcNcp.setInterrupIndemParPensionInvalidite("O");
          }
        }
      }
    }
  }
  
  public void positionnerInformationDecisionSanction(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    
    periodes = p_ut.getQualificationPeriodes().getPeriodesSuspensives();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if ((objetChronoPeriode.chevauche(new Periode(p_pbjcNcp.getDateDebut(), p_pbjcNcp.getDateFin()))) && (((objetChronoPeriode instanceof PeriodeSuspensionDDTEAvecImputation)) || ((objetChronoPeriode instanceof PeriodeSuspensionDDTESansImputation)))) {
        positionnerInformationDecisionSanction(p_pbjcNcp, objetChronoPeriode);
      }
    }
    periodes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if (((objetChronoPeriode instanceof PeriodeSanctionReductionMontant)) && (objetChronoPeriode.chevauche(new Periode(p_pbjcNcp.getDateDebut(), p_pbjcNcp.getDateFin())))) {
        positionnerInformationDecisionSanction(p_pbjcNcp, objetChronoPeriode);
      }
    }
  }
  
  public void positionnerInformationDecisionSanction(PbjcNcp p_pbjcNcp, ObjetChronoPeriode p_periode)
  {
    String codeSanction = null;
    Periode periodeInitiale = null;
    if ((p_periode instanceof PeriodeSuspensionDDTEAvecImputation))
    {
      periodeInitiale = ((PeriodeSuspensionDDTEAvecImputation)p_periode).getPeriodeInitiale();
      codeSanction = ((PeriodeSuspensionDDTEAvecImputation)p_periode).getCodeSanction();
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("EG");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("EI");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("EN");
        }
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("SG");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("SH");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("SN");
        }
      }
    }
    else if ((p_periode instanceof PeriodeSuspensionDDTESansImputation))
    {
      periodeInitiale = ((PeriodeSuspensionDDTESansImputation)p_periode).getPeriodeInitiale();
      codeSanction = ((PeriodeSuspensionDDTESansImputation)p_periode).getCodeSanction();
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("EH");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("EJ");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("EO");
        }
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        if (codeSanction.equals("SD")) {
          p_pbjcNcp.ajouterComplementDeJustification("SG");
        } else if (codeSanction.equals("SE")) {
          p_pbjcNcp.ajouterComplementDeJustification("SH");
        } else if (codeSanction.equals("SF")) {
          p_pbjcNcp.ajouterComplementDeJustification("SO");
        }
      }
    }
    else if ((p_periode instanceof PeriodeSanctionReductionMontant))
    {
      periodeInitiale = ((PeriodeSanctionReductionMontant)p_periode).getPeriodeInitiale();
      codeSanction = ((PeriodeSanctionReductionMontant)p_periode).getCodeSanction();
      if (codeSanction.equals("R1")) {
        p_pbjcNcp.setTxSanction(20);
      } else if (codeSanction.equals("R2")) {
        p_pbjcNcp.setTxSanction(50);
      }
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        if (codeSanction.equals("R1")) {
          p_pbjcNcp.ajouterComplementDeJustification("ES");
        } else if (codeSanction.equals("R2")) {
          p_pbjcNcp.ajouterComplementDeJustification("ET");
        }
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        p_pbjcNcp.ajouterComplementDeJustification("SS");
      }
    }
    else if ((p_periode instanceof PeriodeSuspensionTitreConservatoire))
    {
      periodeInitiale = ((PeriodeSuspensionTitreConservatoire)p_periode).getPeriodeInitiale();
      if (periodeInitiale.getDebut().coincideAvec(p_pbjcNcp.getDateDebut())) {
        p_pbjcNcp.ajouterComplementDeJustification("EC");
      }
      if (periodeInitiale.getFin().coincideAvec(p_pbjcNcp.getDateFin())) {
        p_pbjcNcp.ajouterComplementDeJustification("SG");
      }
    }
  }
  
  public void positionnerInformationSuspension(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodes = null;
    ObjetChronoPeriode objetChronoPeriode = null;
    
    periodes = p_ut.getQualificationPeriodes().getPeriodesSuspensives();
    periodes.iterer();
    while (periodes.encoreSuivant())
    {
      objetChronoPeriode = (ObjetChronoPeriode)periodes.elementSuivant();
      if ((objetChronoPeriode instanceof PeriodeServiceCivique))
      {
        PeriodeServiceCivique periodeServiceCivique = (PeriodeServiceCivique)objetChronoPeriode;
        if (periodeServiceCivique.getPeriodeInitiale().commenceAvec(p_pbjcNcp.getDateDebut())) {
          p_pbjcNcp.ajouterComplementDeJustification("I1");
        }
        if (periodeServiceCivique.getPeriodeInitiale().finitAvec(p_pbjcNcp.getDateFin())) {
          p_pbjcNcp.ajouterComplementDeJustification("U1");
        }
      }
    }
  }
  
  public void positionnerJustificationOuverturePJI(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
  {
    if ((p_attribution instanceof RepriseSpec))
    {
      Reprise reprise = (Reprise)p_attribution;
      
      p_pbjcNcp.ajouterComplementDeJustification("BP");
      if (reprise.getDateAttribution().coincideAvec(reprise.getPji())) {
        p_pbjcNcp.ajouterComplementDeJustification("BO");
      }
      Collection collectionEvtsChangementParametre = null;
      Iterator iterateur = null;
      EvenementChangementParametre evenementChangementParametre = null;
      
      Damj dateDerniereRevalorisationAvantCessation = Damj.NUIT_DES_TEMPS;
      Damj dateDerniereRevalorisationAvantReprise = Damj.NUIT_DES_TEMPS;
      
      CalendrierExecutionCalculSpec calendrier = reprise.getAttributionPrecedente().getCalendrierExecutionCalcul();
      Damj dateFinAttributionPrecedente;
      Damj dateFinAttributionPrecedente;
      if ((calendrier != null) && (calendrier.getEtatAttribution() != 4)) {
        dateFinAttributionPrecedente = calendrier.getDernierJourIndemnisable();
      } else {
        dateFinAttributionPrecedente = reprise.getAttributionPrecedente().getDateAttribution();
      }
      collectionEvtsChangementParametre = getEvtsChangementParametre(dateFinAttributionPrecedente);
      if (collectionEvtsChangementParametre != null)
      {
        iterateur = collectionEvtsChangementParametre.iterator();
        while (iterateur.hasNext())
        {
          evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
          if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
            dateDerniereRevalorisationAvantCessation = evenementChangementParametre.getDateEffet();
          }
        }
      }
      collectionEvtsChangementParametre = getEvtsChangementParametre(dateFinAttributionPrecedente, p_attribution.getCalendrierExecutionCalcul().getPremierJourIndemnisable(), p_attribution);
      if (collectionEvtsChangementParametre != null)
      {
        iterateur = collectionEvtsChangementParametre.iterator();
        while (iterateur.hasNext())
        {
          evenementChangementParametre = (EvenementChangementParametre)iterateur.next();
          if (evenementChangementParametre.getNomParametre().equals("REVALORISATION")) {
            dateDerniereRevalorisationAvantReprise = evenementChangementParametre.getDateEffet();
          }
        }
      }
      Damj dateSjrAttributionPrecedente = reprise.getAttributionPrecedente().getElementBaseIndemnisation().getSjr().getDateDepart();
      if ((dateDerniereRevalorisationAvantCessation.estAvant(dateDerniereRevalorisationAvantReprise)) && (RevalorisationSalaire.verifierDureePourReval(dateSjrAttributionPrecedente, dateDerniereRevalorisationAvantReprise))) {
        p_pbjcNcp.ajouterComplementDeJustification("CD");
      }
    }
    else if ((p_attribution instanceof ReadmissionSpec))
    {
      p_pbjcNcp.ajouterComplementDeJustification("BH");
    }
    else if ((p_attribution instanceof RevisionSpec))
    {
      p_pbjcNcp.ajouterComplementDeJustification("CX");
    }
    else
    {
      p_pbjcNcp.ajouterComplementDeJustification("BD");
    }
  }
  
  public void positionnerMontantSalaireRevalorisePlafonne(PbjcNcp pbjcNcp, AttributionSpec attribution, ConstituantsIndemnisation constituantsIndemnisation, MontantBaseSpec montant)
    throws CoucheLogiqueException
  {
    BigDecimal sjr = ((fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getSjrATP().getSalaire();
    if (((fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getCoefficientSaisonnier() != null) {
      sjr = sjr.multiply(((fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)constituantsIndemnisation.getElementBaseIndemnisationCourant()).getCoefficientSaisonnier());
    }
    pbjcNcp.setMontantSalaireRevalorisePlafonne(sjr.setScale(2, 3));
  }
  
  public void positionnerMontantSjc(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, ConstituantsIndemnisation p_constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    BigDecimal sjc = ((fr.unedic.cali.asu.cve13.p01.calcul.dom.ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant()).getSjc().getSalaire();
    p_pbjcNcp.setMontantSjc(sjc);
  }
  
  public void positionnerNombreMoisEnPaiementProvisoire(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    p_pbjcNcp.setNbMoisPaiementProvis(((ConstituantsCalculActiviteReduiteGamme)p_ut.getConstituantsCalculActiviteReduiteEnFinUT()).getNbMoisEnPPA());
  }
  
  public void positionnerPBJCASupprimer(PbjcNcp p_pbjcNcp, ObjetChronoPeriode p_periode)
  {
    if (((p_periode instanceof ObjetChronoPeriodeInterProduits)) && ("FOR_RFP04_01".equals(((ObjetChronoPeriodeInterProduits)p_periode).getNomProduit()))) {
      p_pbjcNcp.setQualificationPeriode(3);
    }
  }
  
  public void positionnerPriseEnChargeAER(PbjcNcp p_pbjcNcp, Collection p_periodesAER)
  {
    boolean chevauchementAER = false;
    Iterator iterator = p_periodesAER.iterator();
    while ((iterator.hasNext()) && (!chevauchementAER)) {
      chevauchementAER = p_pbjcNcp.chevauche((Periode)iterator.next());
    }
    p_pbjcNcp.setPriseEnChargeAERC(chevauchementAER);
  }
  
  public void positionnerPriseEnChargeAER(PbjcNcp p_pbjcNcp, UniteTraitement p_ut)
  {
    ChronologiePeriodes periodesSegmentantes = null;
    ObjetChronoPeriode periode = null;
    ObjetChronoPeriodeInterProduits periodeInterProduit = null;
    ObjetChronoPeriodeInterProduits periodeRetenue = null;
    
    periodesSegmentantes = p_ut.getQualificationPeriodes().getPeriodesSegmentantes();
    periodesSegmentantes.iterer();
    while (periodesSegmentantes.encoreSuivant())
    {
      periode = (ObjetChronoPeriode)periodesSegmentantes.elementSuivant();
      if (((periode instanceof ObjetChronoPeriodeInterProduits)) && ((((ObjetChronoPeriodeInterProduits)periode).getNomProduit().equals("SOL_AER05_01")) || (((ObjetChronoPeriodeInterProduits)periode).getNomProduit().equals("SOL_AER05_02")) || (((ObjetChronoPeriodeInterProduits)periode).getNomProduit().equals("SOL_AER05_03"))))
      {
        periodeInterProduit = (ObjetChronoPeriodeInterProduits)periode;
        if (p_pbjcNcp.chevauche(periodeInterProduit.getPeriode())) {
          if (periodeRetenue == null) {
            periodeRetenue = periodeInterProduit;
          } else if (periodeInterProduit.getDateDebut().estApresOuCoincideAvec(periodeRetenue.getDateDebut())) {
            periodeRetenue = periodeInterProduit;
          }
        }
      }
    }
    if (periodeRetenue != null) {
      p_pbjcNcp.setPriseEnChargeAERC((periodeRetenue.getTypePeriode() == 2) || (periodeRetenue.getTypePeriode() == 1));
    }
  }
  
  public void positionnerRangProlongation(PbjcNcp p_pbjcNcp, UniteTraitement p_ut, AttributionSpec p_attribution) {}
  
  public void positionnerReferencesOuvertureDroit(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
  {
    p_pbjcNcp.setIdentifiantReprise(new Integer(p_attribution.getRsrp()).intValue());
    
    p_pbjcNcp.setRefOdPjcFaitGenerateurOrigine(new Integer(p_attribution.getRsod()).intValue());
    
    p_pbjcNcp.setRefOdPjcPremierFaitGenerateur(p_pbjcNcp.getRefOdPjcFaitGenerateurOrigine());
  }
  
  public void positionnerRessources(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution) {}
  
  public void positionnerSituationParticuliere(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution, UniteTraitement p_ut)
  {
    p_pbjcNcp.setSituationParticuliere(p_attribution.getSituationParticuliere());
  }
  
  public void qualifierPbjcSuspensive(PbjcNcp p_pbjcNcp, ObjetChronoPeriode p_periode) {}
  
  public int retournerMaxDureeReglementaireCourante(AttributionSpec p_attribution)
  {
    return 0;
  }
  
  public int retournerReferenceBaseCalcul(AttributionSpec p_attribution)
  {
    if (p_attribution.getNatureDecision() == 11) {
      return 2;
    }
    if ((p_attribution instanceof RepriseSpec))
    {
      AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)((AttributionAssuranceSpec)p_attribution).getOuvertureDroit();
      if (attributionOrigine.getNatureDecision() == 11) {
        return 2;
      }
    }
    return 1;
  }
  
  public String retournerReglementApplicable(AttributionSpec p_attribution)
  {
    return ((Attribution)p_attribution).getNomReglementApplicable();
  }
  
  public int retournerReliquatDureeMax(UniteTraitement p_ut, ChronologiePeriodes p_chronoPBJCs, AttributionSpec p_attributionSpec)
  {
    Periode periode = new Periode(p_ut.getDateDebut(), p_ut.getDateFin());
    
    int reliquatARetourner = 0;
    PbjcNcp pbjcNcp = null;
    if (p_chronoPBJCs.estVide())
    {
      Damj dateDebut;
      Damj dateDebut;
      if (p_attributionSpec.getPji().estContenueDans(periode)) {
        dateDebut = p_attributionSpec.getPji();
      } else {
        dateDebut = p_ut.getDateDebut();
      }
      Periode periodeARetenir = new Periode(dateDebut, ((Attribution)p_attributionSpec).getDateLimiteIndemnisation());
      reliquatARetourner = periodeARetenir.getDuree();
    }
    else
    {
      pbjcNcp = (PbjcNcp)p_chronoPBJCs.dernierElement();
      reliquatARetourner = pbjcNcp.getReliquatDureeMax() - pbjcNcp.getNbJoursImputes();
    }
    return reliquatARetourner;
  }
  
  public int retournerReliquatDureeReglementaireCourante(UniteTraitement p_ut)
  {
    return 0;
  }
  
  public boolean retournerTopPeriodeRessourcesSuperieuresPlafond(Somme p_somme)
  {
    return false;
  }
  
  public boolean retournerTopPlafonnementDureeDroitParDate()
  {
    return false;
  }
  
  public ChronologiePeriodes supprimerPBJCsANePasPrendreEnCompte(ChronologiePeriodes p_chronoPBJCs)
  {
    ChronologiePeriodes chronoTemp = null;
    PbjcNcp pbjcNcp = null;
    
    chronoTemp = new ChronologiePeriodes();
    p_chronoPBJCs.iterer();
    while (p_chronoPBJCs.encoreSuivant())
    {
      pbjcNcp = (PbjcNcp)p_chronoPBJCs.elementSuivant();
      if (pbjcNcp.getQualificationPeriode() != 3) {
        chronoTemp.ajouter(pbjcNcp);
      }
    }
    return chronoTemp;
  }
  
  public void positionnerInfoConventionGestion(PbjcNcp p_pbjcNcp, AttributionSpec p_attribution)
  {
    boolean estTopApplicationCRC = true;
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)p_attribution;
    if ((attribution.getCompetenceFinanciere() == 2) && (
      (attribution.getCompetenceAdministrative() != 1) || ((attribution.getConventionGestion() != null) && (!attribution.getConventionGestion().estPrecompteCRC())))) {
      estTopApplicationCRC = false;
    }
    p_pbjcNcp.setTopApplicationCRC(estTopApplicationCRC);
  }
  
  public void mapperPecSurPbjc(PbjcNcp p_pbjc, ObjetChronoPeriodePriseEnCharge p_pec) {}
  
  private static boolean verifierDureePourReval(AttributionSpec p_attribution, Damj p_dateReval)
  {
    Damj dateSjrAttributionPrecedente = null;
    if ((p_attribution instanceof Reprise)) {
      dateSjrAttributionPrecedente = ((Reprise)p_attribution).getAttributionPrecedente().getElementBaseIndemnisation().getSjr().getDateDepart();
    } else {
      dateSjrAttributionPrecedente = ((Attribution)p_attribution).getElementBaseIndemnisation().getSjr().getDateDepart();
    }
    return RevalorisationSalaire.verifierDureePourReval(dateSjrAttributionPrecedente, p_dateReval);
  }
  
  public boolean creerPBJCsurSomme(AttributionSpec p_attribution, Somme p_somme)
  {
    return true;
  }
}

/* Location:
 * Qualified Name:     FacadePBJCProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */