package fr.unedic.cali.asu.cve13.p01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionFaitGenerateur;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class RechercheConditionFaitGenerateur
  implements OutilFonctionnel
{
  public static RechercheConditionFaitGenerateur getInstance()
  {
    return new RechercheConditionFaitGenerateur();
  }
  
  public ConditionFaitGenerateur rechercheConditionFaitGenerateur(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur conditionFaitGenerateur = ((DossierExamen)p_demande.getDossierExamen()).createConditionFaitGenerateur();
    
    TravailSpec dernierSinistre = ((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
    
    rechercherBlocage(dernierSinistre, p_demande);
    if (dernierSinistre == null) {
      lancerAlerte("ASU_PR_CALI_L_ALERTE_A6MB5", new String[] { p_demande.getDateExamen().toString() });
    }
    Damj dateFaitGenerateurAsuPrecedente = p_demande.getDateFaitGenerateurOdPrecedente();
    if ((dateFaitGenerateurAsuPrecedente != null) && 
      (dateFaitGenerateurAsuPrecedente.estApresOuCoincideAvec(dernierSinistre.getDateFin()))) {
      lancerAlerte("ASU_PR_CALI_L_ALERTE_A6MB5", new String[] { p_demande.getDateExamen().toString() });
    }
    if ((dernierSinistre != null) && ((!(dernierSinistre instanceof ActiviteSalarie)) || (Integer.parseInt(((ActiviteSalarie)dernierSinistre).getMotifFin()) != 43))) {
      lancerAlerte("ASU_PR_CALI_L_ALERTE_A11MB27", new String[] { dernierSinistre.getDateFin().toString() });
    }
    if ((dernierSinistre != null) && (!dernierSinistre.getDateFin().coincideAvec(p_demande.getDateExamen().veille()))) {
      lancerAlerte("ASU_PR_CALI_L_ALERTE_A11MB28", new String[] { dernierSinistre.getDateFin().toString() });
    }
    conditionFaitGenerateur.setEtatSatisfait(true);
    conditionFaitGenerateur.setAgeIndividuDateFG(p_demande.getDemandeur().getAgeALaDate(dernierSinistre.getDateFin()));
    conditionFaitGenerateur.setDateFaitGenerateur(dernierSinistre.getDateFin());
    conditionFaitGenerateur.setIdentifiantPeriodeFaitGenerateur(dernierSinistre.getIdentifiant());
    conditionFaitGenerateur.setMotifFinPeriode(((ActiviteSalarie)dernierSinistre).getMotifFin());
    conditionFaitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dernierSinistre);
    conditionFaitGenerateur.setDateEngagementProcedure(((ActiviteSalarie)dernierSinistre).getDateEngagementProcedureLicenciement());
    conditionFaitGenerateur.setCodeBassinCtp(dernierSinistre.getEntreprise().getCodeBassinCTP());
    
    return conditionFaitGenerateur;
  }
  
  private void rechercherBlocage(TravailSpec p_dernierSinistre, Demande p_demande)
    throws CoucheLogiqueException
  {
    if (p_dernierSinistre != null)
    {
      ProduitSpec produit = p_demande.getDossierAffectation().getProduit();
      
      Damj dateEngagementProcedure = ((ActiviteSalarie)p_dernierSinistre).getDateEngagementProcedureLicenciement();
      if (dateEngagementProcedure == null) {
        dateEngagementProcedure = ((ActiviteSalarie)p_dernierSinistre).getDateFin();
      }
      if (dateEngagementProcedure.estApres(produit.getPeriodeValidite().getFin())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB31");
      }
      Reglement reglementApplicable = ((ActiviteSalarie)p_dernierSinistre).getReglement();
      if (reglementApplicable.estNomReglementIdentique("A9B")) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB18");
      }
    }
  }
  
  public ConditionFaitGenerateur rechercheConditionFaitGenerateurBasculeCrpCtp(Demande p_demande)
    throws CoucheLogiqueException
  {
    ConditionFaitGenerateur conditionFaitGenerateur = ((DossierExamen)p_demande.getDossierExamen()).createConditionFaitGenerateur();
    
    TravailSpec dernierSinistre = ((DossierAffectation)p_demande.getDossierAffectation()).getSinistre();
    
    rechercherBlocage(dernierSinistre, p_demande);
    
    conditionFaitGenerateur.setEtatSatisfait(true);
    conditionFaitGenerateur.setAgeIndividuDateFG(p_demande.getDemandeur().getAgeALaDate(dernierSinistre.getDateFin()));
    conditionFaitGenerateur.setDateFaitGenerateur(dernierSinistre.getDateFin());
    conditionFaitGenerateur.setIdentifiantPeriodeFaitGenerateur(dernierSinistre.getIdentifiant());
    conditionFaitGenerateur.setMotifFinPeriode(((ActiviteSalarie)dernierSinistre).getMotifFin());
    conditionFaitGenerateur.setPeriodeFaitGenerateur((ActiviteSalarie)dernierSinistre);
    conditionFaitGenerateur.setDateEngagementProcedure(((ActiviteSalarie)dernierSinistre).getDateEngagementProcedureLicenciement());
    conditionFaitGenerateur.setCodeBassinCtp(dernierSinistre.getEntreprise().getCodeBassinCTP());
    
    return conditionFaitGenerateur;
  }
  
  private void lancerAlerte(String p_codeAlerte, String[] p_libAlerte)
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException(p_codeAlerte, p_libAlerte);
  }
}

/* Location:
 * Qualified Name:     RechercheConditionFaitGenerateur
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */