package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.asu.parcours.ParcoursInstallationAntecedent;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenAntecedentSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionPourTypeProduitExecution;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.temps.Damj;

public class EreAntecedentAssuranceEnCoursDossier
  extends EreGammeAsu
  implements EvenementReferenceExamenAntecedentSpec
{
  private static final long serialVersionUID = 1L;
  
  public ObjetMetierSpec copie()
  {
    EreAntecedentAssuranceEnCoursDossier copie = new EreAntecedentAssuranceEnCoursDossier();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    Damj djc = null;
    Damj dateIde = null;
    if (((Demande)p_demande).getSaisieAntecedent() != null) {
      djc = ((Demande)p_demande).getSaisieAntecedent().getDateDernierJourCalcule();
    }
    if (djc != null)
    {
      setDateDeclenchementExamen(djc);
    }
    else if (p_demande.getDateDepot() != null)
    {
      setDateDeclenchementExamen(p_demande.getDateDepot());
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateDeclenchementExamen(dateIde);
      } else {
        setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    Damj dateIde = null;
    Demande demande = (Demande)p_demande;
    if (getDateEvenement() == null) {
      if ((demande.getSaisieAntecedent() != null) && (demande.getSaisieAntecedent().getDateDernierJourCalcule() != null))
      {
        setDateEvenement(demande.getSaisieAntecedent().getDateDernierJourCalcule());
      }
      else
      {
        ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
        if (periodePEC != null) {
          dateIde = periodePEC.getDateDebut();
        }
        if (dateIde != null) {
          setDateEvenement(dateIde);
        } else {
          setDateEvenement(p_demande.getDateDepot());
        }
      }
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageSansRuptureDeContrat(demande)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_IMPOSSIBLE_CSR");
    }
  }
  
  public String getLibelle()
  {
    return "ANTSO";
  }
  
  public String getLibelleLong()
  {
    return "Antécédent SP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_23";
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public int getPriorite()
  {
    return 21;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreNegation filtre = new FiltreNegation(new FiltreAttributionPourTypeProduitExecution(true, 2));
    return filtre;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    return null;
  }
  
  public boolean verifierPremiereDemandeIndividu(DemandeSpec p_demande)
  {
    return false;
  }
  
  public ParcoursLiquidationAssurance determinerParcoursLiquidationDemandeAssurance(DemandeSpec p_demande)
  {
    return new ParcoursInstallationAntecedent();
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande)
  {
    Demande demande = (Demande)p_demande;
    if ((demande.getSaisieAntecedent() != null) && (demande.getSaisieAntecedent().estAntecedentMayotte()))
    {
      ContexteDemande contexte = new ContexteDemande();
      contexte.setTypeContexteDemande("AREMAYOTTE");
      ((Demande)p_demande).ajouterContexteDemande(contexte);
    }
  }
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreAntecedentAssuranceEnCoursDossier
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */