package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationDateExamenPourFps;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationContexteEre;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuExamenFilEau;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.outilsfonctionnels.GestionnaireErreur;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreApsSuiteRejetAsu
  extends EreGammeAsu
{
  private static final long serialVersionUID = -6001867166883740850L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    try
    {
      if (getDateEvenement() == null) {
        setDateEvenement(determinerDateExamen(demande));
      }
    }
    catch (CoucheLogiqueException ex)
    {
      setDateEvenement(null);
    }
    return getDateEvenement();
  }
  
  private Damj determinerDateExamen(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    return OutilDeterminationDateExamenPourFps.getInstance().getDateIde(demande.getDemandeur(), demande.getFormulaire().getDateDepot());
  }
  
  public String getLibelle()
  {
    return "IDE";
  }
  
  public String getLibelleLong()
  {
    return "Demande APS IDE";
  }
  
  public String getTypeExamen()
  {
    return "ASU_09";
  }
  
  public int getPriorite()
  {
    return 6;
  }
  
  public ObjetMetierSpec copie()
  {
    EreApsSuiteRejetAsu copie = new EreApsSuiteRejetAsu();
    copieElements(copie);
    return copie;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitApsEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateDeclenchementExamen());
    if (determinerDateExamen(demande) == null) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
  }
  
  public void verifierContexteExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitApsEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateExamen());
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionPourLigne("ASU_SSP07");
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeAsuExamenFilEau();
  }
  
  public void determinerContexteDemande(DemandeSpec demande) {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreApsSuiteRejetAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */