package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ResultatConditionRechercheEmploi;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RechercheConditionRechercheEmploi;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class EreAsrSuiteIDE
  extends EreGammeAsu
{
  private static final long serialVersionUID = 6021882448185185010L;
  
  public String getLibelle()
  {
    return "IDE";
  }
  
  public String getLibelleLong()
  {
    return "Adhésion CRP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_16";
  }
  
  public int getPriorite()
  {
    return 16;
  }
  
  public ObjetMetierSpec copie()
  {
    EreAsrSuiteIDE copie = new EreAsrSuiteIDE();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    Damj dateIde = null;
    if ((getDateEvenement() != null) && ((p_demande.estDecisionnee()) || (p_demande.estDemandeLiquidee())) && (!p_demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else
    {
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        setDateDeclenchementExamen(dateIde);
      } else if (p_demande.getDateDepot() != null) {
        setDateDeclenchementExamen(p_demande.getDateDepot());
      } else {
        setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    Damj dernierAu = null;
    Damj dateIde = null;
    Damj dateExamen = null;
    if (getDateEvenement() == null)
    {
      try
      {
        TravailSpec fct = RechercherDernierSinistre.rechercherDernierSinistre(p_demande.getDateDeclenchementExamen().veille(), p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
        if (fct != null) {
          dernierAu = fct.getDateFin();
        }
      }
      catch (CoucheLogiqueException ex)
      {
        dernierAu = null;
      }
      ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(p_demande.getDemandeur(), p_demande.getFormulaire().getIdPec());
      if (periodePEC != null) {
        dateIde = periodePEC.getDateDebut();
      }
      if (dateIde != null) {
        dateExamen = dateIde;
      } else {
        dateExamen = p_demande.getDateDepot();
      }
      if (dernierAu != null) {
        dateExamen = Damj.max(dernierAu.lendemain(), dateExamen);
      }
      setDateEvenement(dateExamen);
    }
    return getDateEvenement();
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Demande demandeAsr = (Demande)p_demande;
    int idPec = p_demande.getFormulaire().getIdPec();
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demandeAsr.getDemandeur(), idPec);
    if (periodePEC == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_PEC_INTROUVABLE", new Object[] { Integer.toString(idPec) }, 1);
    }
    RechercheConditionRechercheEmploi rechercheConditionRechercheEmploi = RechercheConditionRechercheEmploi.getInstance();
    
    ObjetChronoPeriodePriseEnCharge periodePECIndemnisable = OutillagePEC.getPeriodePECIndemnisableContenant(demandeAsr.getDemandeur(), demandeAsr.getDateDeclenchementExamen());
    ResultatConditionRechercheEmploi resultatConditionRechercheEmploi = new ResultatConditionRechercheEmploi();
    ResultatElementDroit resultatElementDroit = new ResultatElementDroit();
    resultatConditionRechercheEmploi.setResultatElementDroit(resultatElementDroit);
    
    boolean estDemandeRechargement = "ASU_29".equals(p_demande.getEvenementReferenceExamen().getTypeExamen());
    resultatConditionRechercheEmploi = rechercheConditionRechercheEmploi.controlerExistancePec(periodePECIndemnisable, resultatConditionRechercheEmploi, estDemandeRechargement);
    if (resultatConditionRechercheEmploi.getResultatElementDroit().getCodeMotifEchec() != 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DEMANDEUR_NON_INSCRIT");
    }
    rechercheConditionRechercheEmploi.controlerCoherencePec(periodePECIndemnisable, demandeAsr, resultatConditionRechercheEmploi);
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreOU filtreAttributionASR = new FiltreOU();
    filtreAttributionASR.ajouterFiltre(new FiltreDecisionARESurDecision());
    filtreAttributionASR.ajouterFiltre(new FiltreDecisionPourProduit(37));
    filtreAttributionASR.ajouterFiltre(new FiltreDecisionPourProduit(36));
    return filtreAttributionASR;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    return new AffectationDemandeAsr();
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {}
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreAsrSuiteIDE
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */