package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationDateExamenPourFps;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationContexteEre;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ConstructionPeriodeExamenFilEau;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ControleFctExamenFilEau;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;

public class EreDemandeAreEfe
  extends EreGammeAsu
{
  private static final long serialVersionUID = 2565888669214053852L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    try
    {
      if (getDateEvenement() == null) {
        setDateEvenement(determinerDateExamen(demande));
      }
    }
    catch (CoucheLogiqueException ex)
    {
      setDateEvenement(null);
    }
    return getDateEvenement();
  }
  
  private Damj determinerDateExamen(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Damj dateExamen;
    try
    {
      Damj dateDepot = demande.getFormulaire().getDateDepot();
      if (dateDepot == null) {
        dateDepot = demande.getFormulaire().getDateCreationDal();
      }
      dateExamen = OutilDeterminationDateExamenPourFps.getInstance().determinerProchaineDateDansPECIndemnisable(demande, dateDepot);
    }
    catch (CoucheLogiqueException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  public String getLibelle()
  {
    return "FDE";
  }
  
  public String getLibelleLong()
  {
    return "Demande Assurance fil de l'eau";
  }
  
  public String getTypeExamen()
  {
    return "ASU_13";
  }
  
  public int getPriorite()
  {
    return 11;
  }
  
  public ObjetMetierSpec copie()
  {
    EreDemandeAreEfe copie = new EreDemandeAreEfe();
    copieElements(copie);
    return copie;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierExistanteAreFdd(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateDeclenchementExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateDeclenchementExamen());
    if (determinerDateExamen(demande) == null)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
    else
    {
      Damj dateDepot = demande.getFormulaire().getDateDepot();
      ConstructionPeriodeExamenFilEau constructionPefe = new ConstructionPeriodeExamenFilEau(demande.getDemandeur());
      ChronologiePeriodes chronoPefe = constructionPefe.getChronologiePeriodeExamenFilEau();
      if (!ControleFctExamenFilEau.getInstance().verifierFctEstDansPEFE(chronoPefe, dateDepot)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_IMPOSSIBLE_ASU_EN_COURS", new Object[] { dateDepot });
      }
    }
  }
  
  public void verifierContexteExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierExistanteAreFdd(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierDroitAreEnCours(demande, demande.getDateExamen());
    OutilVerificationContexteEre.verifierPresenceReliquatAre(demande, demande.getDateExamen());
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieClauseRattrapageSpectacle((Demande)demande);
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreDemandeAreEfe
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */