package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDeterminationDateExamenPourFps;
import fr.unedic.cali.asu.outilsfonctionnels.OutilVerificationContexteEre;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ConstructionPeriodeExamenFilEau;
import fr.unedic.cali.asu.outilsfonctionnels.examenfileau.ControleFctExamenFilEau;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuExamenFilEau;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuFds12;
import fr.unedic.cali.dom.affectation.LigneAsuSsp07;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourLigne;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionEnCoursIndemnisationPourDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;

public class EreDemandeAtAfdEfe
  extends EreGammeAsu
{
  private static final long serialVersionUID = 6965520707174385192L;
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getFormulaire().getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getFormulaire().getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demande)
  {
    try
    {
      if (getDateEvenement() == null) {
        setDateEvenement(determinerDateExamen(demande));
      }
    }
    catch (ApplicativeException ex)
    {
      setDateEvenement(null);
    }
    return getDateEvenement();
  }
  
  private Damj determinerDateExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    Damj dateExamen = null;
    try
    {
      Damj dateDepot = demande.getFormulaire().getDateDepot();
      if (dateDepot == null) {
        dateDepot = demande.getFormulaire().getDateCreationDal();
      }
      TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(dateDepot.veille(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
      if (dernierSinistre != null)
      {
        Damj lendemainDernierSinistre = dernierSinistre.getDateFin().lendemain();
        
        FiltreET filtreAttributionEnCours = new FiltreET();
        filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, true, false, demande));
        filtreAttributionEnCours.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(lendemainDernierSinistre));
        AttributionSpec attributionEnCoursAuLendemainFCT = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), lendemainDernierSinistre.lendemain(), filtreAttributionEnCours);
        if (attributionEnCoursAuLendemainFCT != null)
        {
          Demande demandeAttributionEnCours = (Demande)attributionEnCoursAuLendemainFCT.getDemande();
          if ((demandeAttributionEnCours.estUneDemandeAre()) || (attributionEnCoursAuLendemainFCT.getProduit().getLigne().getNomUnique().equals(LigneAsuSsp07.getInstance().getNomUnique())) || (attributionEnCoursAuLendemainFCT.getProduit().getLigne().getNomUnique().equals(LigneAsuFds12.getInstance().getNomUnique())))
          {
            Damj djiEpuisementAttributionEnCours = OutilDeterminationDateExamenPourFps.getInstance().determinerFinDroitParEpuisementAttribution(demande, attributionEnCoursAuLendemainFCT);
            if (djiEpuisementAttributionEnCours != null)
            {
              FiltreET filtreAttributionEnCours2 = new FiltreET();
              filtreAttributionEnCours2.ajouterFiltre(new FiltreAttributionStandardAssurance(true, true, true, false, demande));
              filtreAttributionEnCours2.ajouterFiltre(new FiltreAttributionEnCoursIndemnisationPourDate(djiEpuisementAttributionEnCours.lendemain()));
              AttributionSpec attributionSansDernierSinistre = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), djiEpuisementAttributionEnCours.lendemain().lendemain(), filtreAttributionEnCours2);
              if ((attributionSansDernierSinistre != null) && (attributionSansDernierSinistre.getProduit().getLigne().getNomUnique().equals(LigneAsuFds12.getInstance().getNomUnique())))
              {
                Damj djiEpuisementAttributionEnCoursSansDernierSinistre = OutilDeterminationDateExamenPourFps.getInstance().determinerFinDroitParEpuisementAttribution(demande, attributionSansDernierSinistre);
                if (djiEpuisementAttributionEnCoursSansDernierSinistre != null) {
                  dateExamen = djiEpuisementAttributionEnCoursSansDernierSinistre.lendemain();
                } else {
                  fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_DERNIER_DROIT_NON_ARRETE_EPUISMT");
                }
              }
              else
              {
                dateExamen = djiEpuisementAttributionEnCours.lendemain();
              }
            }
            else
            {
              fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_DERNIER_DROIT_NON_ARRETE_EPUISMT");
            }
          }
        }
        else
        {
          dateExamen = lendemainDernierSinistre;
        }
      }
      else
      {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CTX_ABS_DERNIER_SINISTRE_AVANT_DATE", new Object[] { dateDepot });
      }
      dateExamen = OutilDeterminationDateExamenPourFps.getInstance().determinerProchaineDateDansPECIndemnisable(demande, dateExamen);
    }
    catch (CoucheLogiqueException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  public String getLibelle()
  {
    return "FDE";
  }
  
  public String getLibelleLong()
  {
    return "Demande AT/AFD fil de l'eau";
  }
  
  public String getTypeExamen()
  {
    return "ASU_15";
  }
  
  public int getPriorite()
  {
    return 5;
  }
  
  public ObjetMetierSpec copie()
  {
    EreDemandeAtAfdEfe copie = new EreDemandeAtAfdEfe();
    copieElements(copie);
    return copie;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public void verifierContexte(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierDroitAtOuAfdEnCours(demande, demande.getDateDeclenchementExamen());
    if (determinerDateExamen(demande) == null)
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
    else
    {
      Damj dateDepot = demande.getFormulaire().getDateDepot();
      ConstructionPeriodeExamenFilEau constructionPefe = new ConstructionPeriodeExamenFilEau(demande.getDemandeur());
      ChronologiePeriodes chronoPefe = constructionPefe.getChronologiePeriodeExamenFilEau();
      if (!ControleFctExamenFilEau.getInstance().verifierFctEstDansPEFE(chronoPefe, dateDepot)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_EFE_IMPOSSIBLE_ASU_EN_COURS", new Object[] { dateDepot });
      }
    }
  }
  
  public void verifierContexteExamen(DemandeSpec demande)
    throws ApplicativeException
  {
    OutilVerificationContexteEre.verifierDroitAtOuAfdEnCours(demande, demande.getDateExamen());
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionPourLigne("ASU_FDS12");
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeAsuExamenFilEau();
  }
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreDemandeAtAfdEfe
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */