package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.LigneAsuCaa14;
import fr.unedic.cali.dom.affectation.LigneAsuCva10;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.ComparateurTemporelSurDateFinCroissante;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFctPrincipale;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreAttributionEnCoursIndemnisationPourDate;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieMayotte;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreMemeDateFin;
import fr.unedic.util.temps.FiltresTemporel;

public class EreDvAuFilEau
  extends EreGammeAsu
{
  private static final long serialVersionUID = -8523332605997423903L;
  private transient ActiviteSalarie dernierDV = null;
  
  public String getLibelle()
  {
    return "DV EAU";
  }
  
  public String getLibelleLong()
  {
    return "DV fil de l’eau";
  }
  
  public String getTypeExamen()
  {
    return "ASU_30";
  }
  
  public ObjetMetierSpec copie()
  {
    EreDvAuFilEau copie = new EreDvAuFilEau();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec demande)
  {
    if ((getDateEvenement() != null) && ((demande.estDecisionnee()) || (demande.estDemandeLiquidee())) && (!demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (demande.getDateDepot() != null) {
      setDateDeclenchementExamen(demande.getDateDepot());
    } else {
      setDateDeclenchementExamen(demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec demandeSpec)
  {
    Damj dateExamen = getDateEvenement();
    if (dateExamen == null) {
      try
      {
        PeriodeGaecSpec derniereAEDv = determinerDerniereAEDv((Demande)demandeSpec);
        if (derniereAEDv != null) {
          dateExamen = derniereAEDv.getDateFin().lendemain();
        }
        setDateEvenement(dateExamen);
      }
      catch (ApplicativeException ex)
      {
        setDateEvenement(null);
      }
    }
    return dateExamen;
  }
  
  public void verifierContexte(DemandeSpec demandeSpec)
    throws ApplicativeException
  {
    int idPec = demandeSpec.getFormulaire().getIdPec();
    ObjetChronoPeriodePriseEnChargeSansFiltre periodePEC = OutillagePEC.getPeriodePEC(demandeSpec.getDemandeur(), idPec);
    if (periodePEC == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_PEC_INTROUVABLE", new Object[] { Integer.toString(idPec) }, 1);
    }
    Demande demande = (Demande)demandeSpec;
    ActiviteSalarie derniereAeDv = determinerDerniereAEDv(demande);
    if ((derniereAeDv == null) || (derniereAeDv.getDateFin().estAvant(GestionnaireDateApplication.getInstance().recupererDateApplication("Prise en compte des DV pour le DV au fil de l'eau."))))
    {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_DV_INTROUVABLE", 1);
    }
    else
    {
      AttributionAssuranceSpec attribution = droitEnCoursADate(demande, derniereAeDv.getDateFin());
      if (attribution == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_DV_ABSENCE_DROIT", 1);
      } else if (estAeDvActiviteConserveeSurAttributionPrecedente(attribution, derniereAeDv)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_DV_EN_AC", 1);
      } else if (existeDecisionLendemainDv(demande, derniereAeDv.getDateFin())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_DV_DECISION_PRESENTE", 1);
      } else if (!estDroitEligible(attribution)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CONTEXTE_DV_DROIT_NON_ELIGIBLE", 1);
      }
    }
  }
  
  public int getPriorite()
  {
    return 6;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec demande)
  {
    return new AffectationDemandeASUClassique();
  }
  
  public void verifierContexteExamen(DemandeSpec demandeSpec)
    throws ApplicativeException
  {}
  
  public void determinerContexteDemande(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    ContexteDemande contexteDemande = new ContexteDemande();
    contexteDemande.setTypeContexteDemande("DVFILEAU");
    ((Demande)demande).ajouterContexteDemande(contexteDemande);
  }
  
  public void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationAssurance donnees = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demande = donnees.getDemande();
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPARE(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteSortieDispositifASPouPAPDC(demande);
    DetectionContexteParticulierLiquidation.getInstance().detectionContextePremiereSortieCsp(demande);
    
    ContexteDemande contexteDemandeEnCoursDispo = (ContexteDemande)OutilGestionContexteDemande.trouverContexteDemandeAssurance(demande, "COURSDISPO");
    if (contexteDemandeEnCoursDispo != null) {
      demande.supprimerContexteDemande(contexteDemandeEnCoursDispo);
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteEnCoursDeDisponibilite(demande);
  }
  
  private ActiviteSalarie determinerDerniereAEDv(Demande demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie premierDV = null;
    if (getDernierDV() == null)
    {
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteSalarieeMotifDvNonLegitime());
      
      FiltreNegation filtreNonMayotte = new FiltreNegation(new FiltreActiviteSalarieMayotte());
      filtres.ajouterFiltre(filtreNonMayotte);
      
      Chronologie chronoActivitesDV = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      if (!chronoActivitesDV.estVide())
      {
        chronoActivitesDV.setComparateur(new ComparateurTemporelSurDateFinCroissante());
        
        DecisionSpec derniereDecisionAre = OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), getDateDeclenchementExamen(demande), new FiltreDecisionARESurDecision());
        Damj borneInferieure;
        try
        {
          borneInferieure = GestionnaireDateApplication.getInstance().recupererDateApplication("Prise en compte des DV pour le DV au fil de l'eau.");
        }
        catch (CoucheLogiqueException ex)
        {
          borneInferieure = Damj.NUIT_DES_TEMPS;
        }
        if ((derniereDecisionAre != null) && (derniereDecisionAre.getDateEffetDecision().estApres(borneInferieure))) {
          borneInferieure = derniereDecisionAre.getDateEffetDecision();
        }
        chronoActivitesDV.iterer();
        ActiviteSalarie aeDVTemporaire = null;
        while ((premierDV == null) && (chronoActivitesDV.encoreSuivant()))
        {
          aeDVTemporaire = (ActiviteSalarie)chronoActivitesDV.elementSuivant();
          if ((aeDVTemporaire.estUneFct()) && (borneInferieure.estAvantOuCoincideAvec(aeDVTemporaire.getDateFin())))
          {
            premierDV = gererPresenceFctPrincipaleSiFctConcomittantes(demande, aeDVTemporaire);
            setDernierDV(premierDV);
          }
        }
      }
    }
    else
    {
      premierDV = getDernierDV();
    }
    return premierDV;
  }
  
  protected ActiviteSalarie gererPresenceFctPrincipaleSiFctConcomittantes(Demande demande, ActiviteSalarie derniereAeDv)
    throws CoucheLogiqueException
  {
    ActiviteSalarie activiteSalarieRetenue = derniereAeDv;
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarieeMotifDvNonLegitime());
    filtres.ajouterFiltre(new FiltreMemeDateFin(derniereAeDv.getDateFin()));
    Chronologie chronoFctMemeDateFin = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if ((chronoFctMemeDateFin != null) && (chronoFctMemeDateFin.getTaille() > 1))
    {
      FiltresTemporel filtre = new FiltresTemporel();
      filtre.ajouterFiltre(new FiltrePeriodeFctPrincipale(derniereAeDv.getDateFin()));
      Chronologie chronoFctPrincipale = chronoFctMemeDateFin.copier(filtre);
      if (chronoFctPrincipale != null) {
        if (chronoFctPrincipale.estVide()) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_CALI_FCT_CONCOMM_DV_FIL_EAU", new Object[] { derniereAeDv.getDateFin() });
        } else {
          activiteSalarieRetenue = (ActiviteSalarie)chronoFctPrincipale.premierElement();
        }
      }
    }
    return activiteSalarieRetenue;
  }
  
  private boolean estAeDvActiviteConserveeSurAttributionPrecedente(AttributionAssuranceSpec attributionAssurance, ActiviteSalarie activiteSalarie)
  {
    Chronologie activitesConservees = attributionAssurance.getListeActiviteConservee();
    
    return (activitesConservees != null) && (activitesConservees.contientElement(activiteSalarie));
  }
  
  private AttributionAssuranceSpec droitEnCoursADate(Demande demande, Damj dateRecherche)
  {
    FiltreET filtres = new FiltreET();
    
    FiltreAttributionEnCoursIndemnisationPourDate enCoursIndemnisation = new FiltreAttributionEnCoursIndemnisationPourDate(dateRecherche);
    FiltreAttributionAssurance filtreAsu = new FiltreAttributionAssurance(true, true, false, false, null);
    
    filtres.ajouterFiltre(filtreAsu);
    filtres.ajouterFiltre(enCoursIndemnisation);
    
    AttributionAssuranceSpec attributionEnCours = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesAssuranceSansCourante(), demande, filtres);
    
    return attributionEnCours;
  }
  
  private boolean existeDecisionLendemainDv(Demande demande, Damj dateRecherche)
  {
    boolean retour = false;
    DecisionSpec decision = OutilRecherche.rechercherDecisionSuivante(demande.getChronologieDemandesAssuranceSansCourante(), dateRecherche, null);
    if ((decision != null) && (decision.getDateEffetDecision().equals(dateRecherche.lendemain()))) {
      retour = true;
    }
    return retour;
  }
  
  private boolean estDroitEligible(AttributionAssuranceSpec attribution)
  {
    boolean estDroitEligible = true;
    String reglementAttribution = attribution.getReglementApplicable().getReglement().getNomReglement();
    LigneSpec ligne = attribution.getProduitExecution().getLigne();
    if (("A10".equals(reglementAttribution)) || ("A8".equals(reglementAttribution))) {
      estDroitEligible = false;
    }
    if ((LigneAsuCva10.getInstance().getNomUnique().equals(ligne.getNomUnique())) || (LigneAsuCaa14.getInstance().getNomUnique().equals(ligne.getNomUnique()))) {
      estDroitEligible = false;
    }
    if (attribution.estMaintenue()) {
      estDroitEligible = false;
    }
    return estDroitEligible;
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public void setDernierDV(ActiviteSalarie dernierDV)
  {
    this.dernierDV = dernierDV;
  }
  
  public ActiviteSalarie getDernierDV()
  {
    return dernierDV;
  }
}

/* Location:
 * Qualified Name:     EreDvAuFilEau
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */