package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.AffectationDemandeASURevision;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursLiquidationAssuranceRevision;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionneeSurDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.Iterator;

public class EreRevisionSuitePerteActiviteConservee
  extends EreGammeAsu
{
  private static final long serialVersionUID = -7853582049154907746L;
  
  public String getLibelle()
  {
    return "REV_ASU";
  }
  
  public String getLibelleLong()
  {
    return "demande de Perte act. cons.";
  }
  
  public String getTypeExamen()
  {
    return "ASU_07";
  }
  
  public int getPriorite()
  {
    return 20;
  }
  
  public ObjetMetierSpec copie()
  {
    EreRevisionSuitePerteActiviteConservee copie = new EreRevisionSuitePerteActiviteConservee();
    copieElements(copie);
    return copie;
  }
  
  public boolean mettreEnBasePivot()
  {
    return false;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    Demande demande = (Demande)p_demande;
    if ((getDateEvenement() != null) && ((p_demande.estDecisionnee()) || (p_demande.estDemandeLiquidee())) && (!p_demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else if (demande.getDemandeur().getDonneesChargementGaec().getAgregatGaec().getCodeService() != 3)
    {
      ActiviteSalarie periode = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeRevision();
      if ((periode != null) && (periode.getDateFin() != null) && (!periode.getDateFin().coincideAvec(Damj.FIN_DES_TEMPS))) {
        setDateDeclenchementExamen(periode.getDateFin().lendemain());
      } else {
        setDateDeclenchementExamen(demande.getDateDepot());
      }
    }
    else
    {
      return demande.getDateDepot();
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    if (getDateEvenement() == null) {
      try
      {
        Demande demande = (Demande)p_demande;
        ActiviteSalarie periode = recupererActiviteConserveePerdue(demande);
        setDateEvenement(periode.getDateFin().lendemain());
      }
      catch (CoucheLogiqueException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  private ActiviteSalarie recupererActiviteConserveePerdue(Demande p_demande)
    throws CoucheLogiqueException
  {
    if ((p_demande.getDonneesTemporaires() == null) || (p_demande.getDonneesTemporaires().getPeriodeRevision() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_CTX_REVISION_ABS_ACT_CONSERVEE", 1);
    }
    return (ActiviteSalarie)p_demande.getDonneesTemporaires().getPeriodeRevision();
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws ApplicativeException
  {
    AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, new FiltreAttributionStandardAssurance(true, true, false, true, p_demande));
    if ((attributionAssurancePrecedente != null) && 
      (!((ProduitAsuSpec)attributionAssurancePrecedente.getProduit()).estUnProduitRevisable())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_SUR_PRODUIT_NON_AUTORISE", new Object[] { attributionAssurancePrecedente.getProduit().getLibelleLong(), attributionAssurancePrecedente.getDateAttribution() });
    }
    ActiviteSalarie fctRevisionCourante = recupererActiviteConserveePerdue((Demande)p_demande);
    
    Damj dateFCT = fctRevisionCourante.getDateFin();
    if (FabriqueConvention2014.DATE_APPLICATION.estAvantOuCoincideAvec(dateFCT)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_ARE14");
    }
    if (attributionAssurancePrecedente != null)
    {
      ProduitSpec produit = attributionAssurancePrecedente.getProduit();
      Reglement reglement = attributionAssurancePrecedente.getReglementApplicable().getReglement();
      if (reglement.equals(produit.getReglement("A4"))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_REVISION_A4_IMPOSSIBLE");
      }
    }
    FiltreET filtre = new FiltreET();
    filtre.ajouterFiltre(new FiltreDemandePourERE("ASU_07"));
    filtre.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    Chronologie listeRevisionPrecedente = OutilRecherche.rechercherDecisionsPrecedentes(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, filtre);
    for (Iterator iter = listeRevisionPrecedente.iterer(); iter.hasNext();)
    {
      DecisionSpec revisionPrecedente = (DecisionSpec)iter.next();
      ActiviteSalarie fctRevisionPrecedente = recupererActiviteConserveePerdue((Demande)revisionPrecedente.getDemande());
      if ((fctRevisionPrecedente != null) && (fctRevisionCourante.getDateFin().coincideAvec(fctRevisionPrecedente.getDateFin()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_REVISIONS_MULTIPLES_MEME_DATE_FCT", new Object[] { fctRevisionCourante.getDateFin() }, 1);
      }
    }
  }
  
  public String getTypeSegment()
  {
    return "";
  }
  
  public boolean verifierBesoinChargementTotalGaec()
  {
    return true;
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    FiltreOU filtre = new FiltreOU();
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(37));
    
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(36));
    
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(50));
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(51));
    
    filtre.ajouterFiltre(new FiltreDecisionPourProduit(39));
    
    filtre.ajouterFiltre(new FiltreDecisionARESurDecision());
    return filtre;
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    return new AffectationDemandeASURevision();
  }
  
  public ParcoursLiquidationAssurance determinerParcoursLiquidationDemandeAssurance(DemandeSpec p_demande)
  {
    return new ParcoursLiquidationAssuranceRevision();
  }
  
  public void verifierPostContexte(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    DecisionSpec revisionCourante = (DecisionSpec)p_demande.getDossierAffectation().getDossierExamen();
    
    FiltreET filtreEt = new FiltreET();
    filtreEt.ajouterFiltre(new FiltreDemandePourERE("ASU_07"));
    filtreEt.ajouterFiltre(new FiltreDecisionneeSurDemande());
    Chronologie listeRevisionPrecedente = OutilRecherche.rechercherDemandesPrecedentes(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, filtreEt);
    for (Iterator iter = listeRevisionPrecedente.iterer(); iter.hasNext();)
    {
      DemandeSpec demandePrecedente = (DemandeSpec)iter.next();
      DecisionSpec revisionPrecedente = (DecisionSpec)demandePrecedente.getDossierAffectation().getDossierExamen();
      if ((revisionPrecedente.getNatureDecision() == 30) && 
        (revisionCourante != null) && (revisionPrecedente.getDateAttribution().estApresOuCoincideAvec(revisionCourante.getDateAttribution()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_REVISION_DATE_REVISION_POSTERIEURE", new Object[] { revisionPrecedente.getDateEffetDecision(), p_demande.getDateExamen(), revisionPrecedente.getDemande().getDateExamen() }, 1);
      }
    }
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionOdprecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, new FiltreOuvertureDroitStandardAssurance(true, true, false, true, p_demande));
    if ((attributionOdprecedente != null) && (ProduitAbstrait.estDuType(2, attributionOdprecedente.getProduit().getCode())))
    {
      ContexteDemande contexteOdPrec = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)attributionOdprecedente.getDemande(), 1);
      ((Demande)p_demande).ajouterContexteDemande((ContexteDemande)contexteOdPrec.copie());
    }
    DetectionContexteParticulierLiquidation.getInstance().detectionContexteParticulierCsr((Demande)p_demande);
  }
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreRevisionSuitePerteActiviteConservee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */