package fr.unedic.cali.asu.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.fabriques.FabriqueStrategieGestionReliquatImputationFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.DetectionContexteParticulierLiquidation;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieGestionReliquatImputationFinDroitSpec;
import fr.unedic.cali.asu.parcours.AffectationDemandeASUClassique;
import fr.unedic.cali.asu.parcours.AffectationDemandeAsuCsr;
import fr.unedic.cali.asu.parcours.ParcoursAffectationDemandeAssurance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.spec.EvenementReferenceExamenFinDroitSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalariePourMotifFin;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.comparateurs.ComparateurDecisionDecroissante;
import fr.unedic.cali.utilitaire.filtres.FiltreCaliSpec;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreFinDroitAssurancePourAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.metiers.FiltreDecisionARESurDecision;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreTemporel;

public class EreSuiteFinDroitAsp
  extends EreGammeAsu
  implements EvenementReferenceExamenFinDroitSpec
{
  private transient boolean m_calculerDateExamenHorsLiquidation = false;
  private static final long serialVersionUID = 6021882448185185010L;
  
  public String getLibelle()
  {
    return "FIN ASP";
  }
  
  public String getLibelleLong()
  {
    return "Fin CSP";
  }
  
  public String getTypeExamen()
  {
    return "ASU_25";
  }
  
  public int getPriorite()
  {
    return 13;
  }
  
  public ObjetMetierSpec copie()
  {
    EreSuiteFinDroitAsp copie = new EreSuiteFinDroitAsp();
    copieElements(copie);
    return copie;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    if ((!p_demande.estDemandeLiquidee()) && (getDateEvenement() != null) && (p_demande.estDecisionnee()) && (!p_demande.estEnReExamen()))
    {
      setDateDeclenchementExamen(getDateEvenement());
    }
    else
    {
      AttributionSpec attributionAspPrecedente = null;
      try
      {
        attributionAspPrecedente = trouverAttributionAspPrecedenteValide(p_demande);
      }
      catch (ApplicativeException ex)
      {
        attributionAspPrecedente = null;
      }
      if (p_demande.getDateDepot() != null)
      {
        if ((attributionAspPrecedente != null) && (attributionAspPrecedente.getDateAttribution() != null)) {
          setDateDeclenchementExamen(Damj.max(p_demande.getDateDepot(), attributionAspPrecedente.getDateAttribution().lendemain()));
        } else {
          setDateDeclenchementExamen(p_demande.getDateDepot());
        }
      }
      else {
        setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
      }
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    Damj dateExamen = null;
    if (isCalculerDateExamenHorsLiquidation()) {
      dateExamen = calculerDateExamenHorsLiquidation(p_demande);
    } else if (p_demande.estDemandeLiquidee()) {
      dateExamen = calculerDateExamen(p_demande);
    } else {
      dateExamen = calculerDateExamenHorsLiquidation(p_demande);
    }
    setDateEvenement(dateExamen);
    
    return dateExamen;
  }
  
  private Damj calculerDateExamen(DemandeSpec p_demande)
  {
    Damj dateExamen = null;
    try
    {
      AttributionSpec attributionAspPrecedente = trouverAttributionAspPrecedenteValide(p_demande);
      if (attributionAspPrecedente != null) {
        dateExamen = attributionAspPrecedente.getDateAttribution();
      }
    }
    catch (ApplicativeException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  public Damj calculerDateExamenHorsLiquidation(DemandeSpec p_demande)
  {
    Demande demande = (Demande)p_demande;
    Damj dateExamen = null;
    Damj djiAsu = null;
    try
    {
      if (OutilFinDroit.estUneDemandeFinDroitSuiteSP(p_demande))
      {
        djiAsu = demande.getDonneesTemporaires().getDjiSpFinDroit();
      }
      else
      {
        AttributionSpec attributionAspPrecedente = rechercherAttributionPrecedente(p_demande);
        
        djiAsu = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionAspPrecedente, null, true).getDernierJourIndemnisable();
      }
      if (djiAsu != null) {
        dateExamen = djiAsu.lendemain();
      }
    }
    catch (ApplicativeException ex)
    {
      dateExamen = null;
    }
    return dateExamen;
  }
  
  public AttributionSpec rechercherAttributionPrecedente(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    AttributionSpec attributionOrigine = trouverAttributionAspPrecedenteValide(demande);
    
    Chronologie chronoDemande = attributionOrigine.getDemandeur().getChronoDemandeAssurance().copier(new FiltreFinDroitAssurancePourAttributionAssurance((OdSpec)attributionOrigine));
    
    chronoDemande.setComparateur(new ComparateurDecisionDecroissante());
    Demande demandeTemp = (Demande)chronoDemande.premierElement();
    return (AttributionSpec)demandeTemp.getDossierExamen();
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_demande;
    if ((OutilFinDroit.estUneDemandeFinDroitSuiteSP(p_demande)) && 
      (demande.getDonneesTemporaires().getDjiSpFinDroit() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ALERTE_BLOQUANTE_DJI_ASP_SP", 1);
    }
    trouverAttributionAspPrecedenteValide(p_demande);
  }
  
  private AttributionSpec trouverAttributionAspPrecedenteValide(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    AttributionSpec attributionAspPrecedente = OutilAsp.getInstance().rechercherAttributionAspLiee(p_demande);
    if (attributionAspPrecedente == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_CTX_NE_PERMET_PLUS_LIQUIDER_DMD_FIN_DROIT_ASR", new Object[] { "ASP", "ASP" });
    }
    return attributionAspPrecedente;
  }
  
  public String getTypeSegment()
  {
    return "LE1D";
  }
  
  public FiltreCaliSpec getFiltreRechercheDecisionDuMemeType()
  {
    return new FiltreDecisionARESurDecision();
  }
  
  public ParcoursAffectationDemandeAssurance determinerParcoursAffectationDemandeAssurance(DemandeSpec p_demande)
  {
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(p_demande)) {
      return new AffectationDemandeAsuCsr();
    }
    return new AffectationDemandeASUClassique();
  }
  
  public boolean isCalculerDateExamenHorsLiquidation()
  {
    return m_calculerDateExamenHorsLiquidation;
  }
  
  public void setCalculerDateExamenHorsLiquidation(boolean p_calculerDateExamenHorsLiquidation)
  {
    m_calculerDateExamenHorsLiquidation = p_calculerDateExamenHorsLiquidation;
  }
  
  public void determinerContexteDemande(DemandeSpec p_demande)
  {
    AttributionAssuranceSpec attributionOrigine = (AttributionAssuranceSpec)OutilFinDroit.rechercherAttributionOrigineCorrespondante(p_demande);
    if (attributionOrigine != null)
    {
      ContexteDemande contexteDemande = new ContexteDemande();
      ((Demande)p_demande).ajouterContexteDemande(contexteDemande);
      Demande demandeOrigine = (Demande)attributionOrigine.getDemande();
      contexteDemande.setAttributionLieeAFinDeDroit(attributionOrigine);
      if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeOrigine.getListContexteDemande(), "IDEASP"))
      {
        contexteDemande.setTypeContexteDemande("FINASP");
      }
      else if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeOrigine.getListContexteDemande(), "ADHVOLARE"))
      {
        contexteDemande.setTypeContexteDemande("FINASPVOL");
        contexteDemande.setAttributionAreAdhesionVolontaire(DetectionContexteParticulierLiquidation.getInstance().trouverOdArePrecedente((Demande)p_demande));
      }
      else if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(demandeOrigine.getListContexteDemande(), "ASPVOLSARE"))
      {
        contexteDemande.setTypeContexteDemande("FINASPVOLC");
        contexteDemande.setAttributionAreAdhesionVolontaire(DetectionContexteParticulierLiquidation.getInstance().trouverOdArePrecedente((Demande)p_demande));
        contexteDemande.setDerniereAeCspVolontaire(trouverAS((Demande)p_demande, new FiltreActiviteSalariePourMotifFin(45)));
      }
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(p_demande.getDateExamen());
      if (critere.getDatePivot() != null) {
        FabriqueStrategieGestionReliquatImputationFinDroit.getInstance().getStrategie(critere).ajouterContexteGestionReliquatImputationSurFinDroit((Demande)p_demande);
      }
    }
  }
  
  private ActiviteSalarie trouverAS(Demande p_demande, FiltreTemporel p_filtre)
  {
    ActiviteSalarie retour = null;
    Chronologie chronologiePeriodePasseProfessionnelLiquidation = p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    if ((chronologiePeriodePasseProfessionnelLiquidation != null) && (!chronologiePeriodePasseProfessionnelLiquidation.estVide()))
    {
      Chronologie periodesCspVolontaire = chronologiePeriodePasseProfessionnelLiquidation.copier(p_filtre);
      if ((periodesCspVolontaire != null) && (!periodesCspVolontaire.estVide()))
      {
        periodesCspVolontaire.setComparateur(new ComparateurTemporelsSurDateFin());
        retour = (ActiviteSalarie)periodesCspVolontaire.dernierElement();
      }
    }
    return retour;
  }
  
  public void determinerContextesLiquidation(Contexte p_contexte)
    throws ApplicativeException
  {}
}

/* Location:
 * Qualified Name:     EreSuiteFinDroitAsp
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */