package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.JustificationAffiliationJoursTravaillesGen;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.temps.Chronologie;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class JustificationAffiliationJoursTravailles
  extends JustificationAffiliationJoursTravaillesGen
  implements ObjetPersistantSpec, JustificationAffiliationSpec
{
  private static final long serialVersionUID = 1L;
  
  public JustificationAffiliationJoursTravailles() {}
  
  public JustificationAffiliationJoursTravailles(DomPCSpec pc)
  {
    super(pc);
  }
  
  public ObjetMetierSpec copie()
  {
    JustificationAffiliationJoursTravailles copie = new JustificationAffiliationJoursTravailles();
    copieElements(copie);
    return copie;
  }
  
  public boolean isPresencePNDS()
  {
    List<SemaineCivile> listeSemCiv = getListSemaineAffiliation();
    boolean presencePNDS = false;
    for (SemaineCivile semaineCourante : listeSemCiv) {
      if (semaineCourante.isEstSanctionne())
      {
        presencePNDS = true;
        break;
      }
    }
    return presencePNDS;
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionPlafonnementAffiliation());
    DomManager.persisterEnProfondeur(super.getCollectionSemaineAffiliation());
    DomManager.persisterEnProfondeur(super.getCollectionPeriodeAssimilation());
    DomManager.persisterEnProfondeur(super.getCollectionPeriodeElementaire());
    DomManager.persisterEnProfondeur(super.getCollectionAffiliationSupplementaire());
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    JustificationAffiliationJoursTravailles jAJTCopie = (JustificationAffiliationJoursTravailles)copie;
    jAJTCopie.setNombreJoursAffiliation(getNombreJoursAffiliation());
    jAJTCopie.setNombreJoursAppartenance(getNombreJoursAppartenance());
    jAJTCopie.setNombreJoursAssimilation(getNombreJoursAssimilation());
    jAJTCopie.setPeriodeRechercheAffiliation(getPeriodeRechercheAffiliation());
    jAJTCopie.setPlafondAssimilation(getPlafondAssimilation());
    jAJTCopie.setAffiliationPlafonnee(isAffiliationPlafonnee());
    copierListes(jAJTCopie);
  }
  
  private void copierListes(JustificationAffiliationJoursTravailles copie)
  {
    Iterator<?> iter = getCollectionPeriodeAssimilation().iterator();
    while (iter.hasNext())
    {
      PeriodeAssimilee element = (PeriodeAssimilee)iter.next();
      if (element != null) {
        copie.ajouterPeriodeAssimilation(element);
      }
    }
    Iterator<?> iter2 = getCollectionSemaineAffiliation().iterator();
    while (iter2.hasNext())
    {
      SemaineCivile semaine = (SemaineCivile)iter2.next();
      if (semaine != null) {
        copie.ajouterSemaineAffiliation(semaine);
      }
    }
    Iterator<?> iter3 = getCollectionPlafonnementAffiliation().iterator();
    while (iter3.hasNext())
    {
      PlafonnementAffiliation plafond = (PlafonnementAffiliation)iter3.next();
      if (plafond != null) {
        copie.ajouterPlafonnementAffiliation(plafond);
      }
    }
    Iterator<?> iter4 = getCollectionPeriodeElementaire().iterator();
    while (iter4.hasNext())
    {
      PeriodeElementaire periode = (PeriodeElementaire)iter4.next();
      if (periode != null) {
        copie.ajouterPeriodeElementaire(periode);
      }
    }
    Iterator<?> iter5 = getCollectionAffiliationSupplementaire().iterator();
    while (iter5.hasNext())
    {
      AffiliationSupplementaire affi = (AffiliationSupplementaire)iter5.next();
      if (affi != null) {
        copie.ajouterAffiliationSupplementaire(affi);
      }
    }
  }
  
  public Collection getListePlafonnementAffiliation()
  {
    return super.getCollectionPlafonnementAffiliation();
  }
  
  public void clearCollectionPlafonnementAffiliation()
  {
    for (Iterator iter = getListePlafonnementAffiliation().iterator(); iter.hasNext();)
    {
      PlafonnementAffiliation element = (PlafonnementAffiliation)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionPlafonnementAffiliation();
  }
  
  public void remplacerCollectionPlafonnementAffiliation(Collection collectionACopier)
  {
    for (Iterator iter = getListePlafonnementAffiliation().iterator(); iter.hasNext();)
    {
      PlafonnementAffiliation element = (PlafonnementAffiliation)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPlafonnementAffiliation(collectionACopier);
  }
  
  public void setListePlafonnementAffiliation(Collection listePlafonnementAffiliation)
  {
    remplacerCollectionPlafonnementAffiliation(listePlafonnementAffiliation);
  }
  
  public Collection getListeSemaineAffiliation()
  {
    return super.getCollectionSemaineAffiliation();
  }
  
  public void clearCollectionSemaineAffiliation()
  {
    for (Iterator iter = getListeSemaineAffiliation().iterator(); iter.hasNext();)
    {
      SemaineCivile element = (SemaineCivile)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionSemaineAffiliation();
  }
  
  public void remplacerCollectionSemaineAffiliation(Collection collectionACopier)
  {
    for (Iterator iter = getListeSemaineAffiliation().iterator(); iter.hasNext();)
    {
      SemaineCivile element = (SemaineCivile)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionSemaineAffiliation(collectionACopier);
  }
  
  public void setListeSemaineAffiliation(Collection listeSemaineAffiliation)
  {
    remplacerCollectionSemaineAffiliation(listeSemaineAffiliation);
  }
  
  public Collection getListePeriodeAssimilation()
  {
    return super.getCollectionPeriodeAssimilation();
  }
  
  public void clearCollectionPeriodeAssimilation()
  {
    for (Iterator iter = getListePeriodeAssimilation().iterator(); iter.hasNext();)
    {
      PeriodeAssimilee element = (PeriodeAssimilee)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionPeriodeAssimilation();
  }
  
  public void remplacerCollectionPeriodeAssimilation(Collection collectionACopier)
  {
    for (Iterator iter = getListePeriodeAssimilation().iterator(); iter.hasNext();)
    {
      PeriodeAssimilee element = (PeriodeAssimilee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPeriodeAssimilation(collectionACopier);
  }
  
  public void setListePeriodeAssimilation(Collection listePeriodeAssimilation)
  {
    remplacerCollectionPeriodeAssimilation(listePeriodeAssimilation);
  }
  
  public void remplacerCollectionPeriodeElementaire(Collection collectionACopier)
  {
    for (Iterator<?> iter = getListPeriodeElementaire().iterator(); iter.hasNext();)
    {
      PeriodeElementaire element = (PeriodeElementaire)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPeriodeElementaire(collectionACopier);
  }
  
  public void clearCollectionPeriodeElementaire()
  {
    for (Iterator<?> iter = getListPeriodeElementaire().iterator(); iter.hasNext();)
    {
      PeriodeElementaire element = (PeriodeElementaire)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionPeriodeElementaire();
  }
  
  public void remplacerCollectionAffiliationSupplementaire(Collection collectionACopier)
  {
    for (Iterator<?> iter = getListAffiliationSupplementaire().iterator(); iter.hasNext();)
    {
      AffiliationSupplementaire element = (AffiliationSupplementaire)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionAffiliationSupplementaire(collectionACopier);
  }
  
  public void clearCollectionAffiliationSupplementaire()
  {
    for (Iterator<?> iter = getListAffiliationSupplementaire().iterator(); iter.hasNext();)
    {
      AffiliationSupplementaire element = (AffiliationSupplementaire)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionAffiliationSupplementaire();
  }
  
  public UniteAffiliation getUniteJustification()
  {
    return null;
  }
  
  public Chronologie getChronoZmes()
  {
    return null;
  }
  
  public String getTypeJustificationAffiliation()
  {
    return "justifJoursTravailles";
  }
}

/* Location:
 * Qualified Name:     JustificationAffiliationJoursTravailles
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */