package fr.unedic.cali.asu.dom;

import fr.unedic.cali.asu.dom.gen.ObjectifExamenGen;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ObjectifExamenSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import java.math.BigDecimal;
import java.util.HashMap;

public abstract class ObjectifExamen
  extends ObjectifExamenGen
  implements ObjetPersistantSpec, Comparable, ObjectifExamenAssuranceSpec
{
  private static final long serialVersionUID = 1L;
  public static final int ETAT_NON_EFFECTUE = 20;
  public static final int ETAT_SATISFAIT = 21;
  public static final int ETAT_NON_SATISFAIT = 22;
  public static final int ETAT_VALIDE = 23;
  private transient ObjectifExamenSpec m_objectifProduitActif;
  
  public ObjectifExamen() {}
  
  public ObjectifExamen(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public static String getLibelleObjectifDecision(BigDecimal p_codeNature)
  {
    return (String)NaturesDecisions.s_libelleObjectifDecision.get(p_codeNature);
  }
  
  public abstract int getType();
  
  public abstract Parcours creerParcoursObjectif();
  
  public int compareTo(Object p_object)
  {
    int numeroThis = getNumeroOrdre();
    int numeroObj = ((ObjectifExamen)p_object).getNumeroOrdre();
    if (numeroThis < numeroObj) {
      return -1;
    }
    if (numeroThis > numeroObj) {
      return 1;
    }
    return 0;
  }
  
  public String toString()
  {
    try
    {
      String type = new String();
      String sousType = new String();
      switch (getSousType())
      {
      case 10: 
      case 32: 
        type = "Admission";
        sousType = "Admission";
        break;
      case 12: 
      case 40: 
        type = "Admission";
        sousType = "Readmission droit courant";
        break;
      case 11: 
        type = "Admission";
        sousType = "Readmission droit précédent";
        break;
      case 26: 
        type = "Admission";
        sousType = "Readmission produit résultant";
        break;
      case 16: 
        type = "Rejet";
        sousType = "Rejet";
        break;
      case 28: 
        type = "Rejet";
        sousType = "Rejet automatique";
        break;
      case 14: 
        type = "Reprise";
        sousType = "Reprise contextuelle";
        break;
      case 13: 
        type = "Reprise";
        sousType = "Reprise droit commun";
        break;
      case 15: 
        type = "Reprise";
        sousType = "Reprise systématique";
        break;
      case 34: 
        type = "Reprise";
        sousType = "Reprise simplifiée";
        break;
      case 27: 
        type = "Reprise";
        sousType = "Reprise automatique";
        break;
      case 17: 
      case 18: 
      case 19: 
      case 20: 
      case 21: 
      case 22: 
      case 23: 
      case 24: 
      case 25: 
      case 29: 
      case 30: 
      case 31: 
      case 33: 
      case 35: 
      case 36: 
      case 37: 
      case 38: 
      case 39: 
      default: 
        type = "inconnu";
        sousType = "inconnu (" + getSousType() + ")";
      }
      String etat = new String();
      switch (getEtat())
      {
      case 20: 
        etat = "Non effectué";
        break;
      case 22: 
        etat = "Non satisfait";
        break;
      case 21: 
        etat = "Satisfait non validé";
        break;
      case 23: 
        etat = "Satisfait validé";
        break;
      default: 
        throw new UnsupportedOperationException("Etat " + getEtat() + "non prévu");
      }
      StringBuffer chaine = new StringBuffer();
      chaine.append("Objectif Examen : \n");
      chaine.append("\t Numero Ordre : " + getNumeroOrdre() + "\n");
      chaine.append("\t Type : " + type + "\n");
      chaine.append("\t Sous-Type : " + sousType + "\n");
      chaine.append("\t Etat : " + etat + "\n");
      return chaine.toString();
    }
    catch (Exception ex)
    {
      String messageErreur = "ObjectifExamen - Erreur lors de la lecture d'un objet persistant : ";
      return messageErreur + ex.getMessage();
    }
  }
  
  public abstract ObjectifExamen getObjectifSauvegarde()
    throws CoucheLogiqueException;
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public void jdoPreStore() {}
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ObjectifExamen copie = (ObjectifExamen)p_copie;
    
    copie.setEtat(getEtat());
    copie.setNumeroOrdre(getNumeroOrdre());
    copie.setSousType(getSousType());
    copie.setObjectifProduitActif(getObjectifProduitActif());
  }
  
  public ObjectifExamenSpec getObjectifProduitActif()
  {
    return m_objectifProduitActif;
  }
  
  public void setObjectifProduitActif(ObjectifExamenSpec objectifProduitActif)
  {
    m_objectifProduitActif = objectifProduitActif;
  }
}

/* Location:
 * Qualified Name:     ObjectifExamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */