package fr.unedic.cali.asu.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.cali.asu.dom.pc.DemandePC;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public abstract class ReliquatGen
  implements DomGenSpec
{
  protected transient DomPCSpec m_demandePC;
  private Quantite m_quantiteReliquat;
  private Quantite m_quantiteFormation;
  private Quantite m_quantiteAide;
  private Quantite m_quantiteReliquatRenouvellement;
  private Quantite m_quantiteJourImputationDonneesForcees;
  private BigDecimal m_montantJournalierReliquat;
  private BigDecimal m_capitalReliquat;
  private Quantite m_dureePostPrime;
  private Damj m_dateFinDispositifCSP;
  
  public ReliquatGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public ReliquatGen() {}
  
  public DomPCSpec getPC()
  {
    return m_demandePC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_demandePC)
  {
    m_demandePC = p_demandePC;
  }
  
  protected Quantite rawGetQuantiteReliquat()
  {
    return ((DemandePC)getPC()).getQuantiteReliquatReliquat();
  }
  
  public Quantite getQuantiteReliquat()
  {
    return ((DemandePC)getPC()).getQuantiteReliquatReliquat();
  }
  
  public void setQuantiteReliquat(Quantite p_quantiteReliquat)
  {
    if ((m_quantiteReliquat == null) || (p_quantiteReliquat == null))
    {
      m_quantiteReliquat = p_quantiteReliquat;
      ((DemandePC)getPC()).setQuantiteReliquatReliquat(p_quantiteReliquat);
    }
    else if ((m_quantiteReliquat != null) && (p_quantiteReliquat != null) && (!p_quantiteReliquat.equals(m_quantiteReliquat)))
    {
      m_quantiteReliquat = p_quantiteReliquat;
      ((DemandePC)getPC()).setQuantiteReliquatReliquat(p_quantiteReliquat);
    }
  }
  
  protected Quantite rawGetQuantiteFormation()
  {
    return ((DemandePC)getPC()).getQuantiteFormationReliquat();
  }
  
  public Quantite getQuantiteFormation()
  {
    return ((DemandePC)getPC()).getQuantiteFormationReliquat();
  }
  
  public void setQuantiteFormation(Quantite p_quantiteFormation)
  {
    if ((m_quantiteFormation == null) || (p_quantiteFormation == null))
    {
      m_quantiteFormation = p_quantiteFormation;
      ((DemandePC)getPC()).setQuantiteFormationReliquat(p_quantiteFormation);
    }
    else if ((m_quantiteFormation != null) && (p_quantiteFormation != null) && (!p_quantiteFormation.equals(m_quantiteFormation)))
    {
      m_quantiteFormation = p_quantiteFormation;
      ((DemandePC)getPC()).setQuantiteFormationReliquat(p_quantiteFormation);
    }
  }
  
  protected Quantite rawGetQuantiteAide()
  {
    return ((DemandePC)getPC()).getQuantiteAideReliquat();
  }
  
  public Quantite getQuantiteAide()
  {
    return ((DemandePC)getPC()).getQuantiteAideReliquat();
  }
  
  public void setQuantiteAide(Quantite p_quantiteAide)
  {
    if ((m_quantiteAide == null) || (p_quantiteAide == null))
    {
      m_quantiteAide = p_quantiteAide;
      ((DemandePC)getPC()).setQuantiteAideReliquat(p_quantiteAide);
    }
    else if ((m_quantiteAide != null) && (p_quantiteAide != null) && (!p_quantiteAide.equals(m_quantiteAide)))
    {
      m_quantiteAide = p_quantiteAide;
      ((DemandePC)getPC()).setQuantiteAideReliquat(p_quantiteAide);
    }
  }
  
  protected boolean rawIsReliquatValide()
  {
    return ((DemandePC)getPC()).isReliquatValideReliquat();
  }
  
  public boolean isReliquatValide()
  {
    return ((DemandePC)getPC()).isReliquatValideReliquat();
  }
  
  public void setReliquatValide(boolean p_reliquatValide)
  {
    ((DemandePC)getPC()).setReliquatValideReliquat(p_reliquatValide);
  }
  
  /**
   * @deprecated
   */
  protected int rawGetCumulMoisActiviteReduite()
  {
    return ((DemandePC)getPC()).getCumulMoisActiviteReduiteReliquat();
  }
  
  /**
   * @deprecated
   */
  public int getCumulMoisActiviteReduite()
  {
    return ((DemandePC)getPC()).getCumulMoisActiviteReduiteReliquat();
  }
  
  /**
   * @deprecated
   */
  public void setCumulMoisActiviteReduite(int p_cumulMoisActiviteReduite)
  {
    ((DemandePC)getPC()).setCumulMoisActiviteReduiteReliquat(p_cumulMoisActiviteReduite);
  }
  
  protected Quantite rawGetQuantiteReliquatRenouvellement()
  {
    return ((DemandePC)getPC()).getQuantiteReliquatRenouvellementReliquat();
  }
  
  public Quantite getQuantiteReliquatRenouvellement()
  {
    return ((DemandePC)getPC()).getQuantiteReliquatRenouvellementReliquat();
  }
  
  public void setQuantiteReliquatRenouvellement(Quantite p_quantiteReliquatRenouvellement)
  {
    if ((m_quantiteReliquatRenouvellement == null) || (p_quantiteReliquatRenouvellement == null))
    {
      m_quantiteReliquatRenouvellement = p_quantiteReliquatRenouvellement;
      ((DemandePC)getPC()).setQuantiteReliquatRenouvellementReliquat(p_quantiteReliquatRenouvellement);
    }
    else if ((m_quantiteReliquatRenouvellement != null) && (p_quantiteReliquatRenouvellement != null) && (!p_quantiteReliquatRenouvellement.equals(m_quantiteReliquatRenouvellement)))
    {
      m_quantiteReliquatRenouvellement = p_quantiteReliquatRenouvellement;
      ((DemandePC)getPC()).setQuantiteReliquatRenouvellementReliquat(p_quantiteReliquatRenouvellement);
    }
  }
  
  protected Quantite rawGetQuantiteJourImputationDonneesForcees()
  {
    return ((DemandePC)getPC()).getQuantiteJourImputationDonneesForceesReliquat();
  }
  
  public Quantite getQuantiteJourImputationDonneesForcees()
  {
    return ((DemandePC)getPC()).getQuantiteJourImputationDonneesForceesReliquat();
  }
  
  public void setQuantiteJourImputationDonneesForcees(Quantite p_quantiteJourImputationDonneesForcees)
  {
    if ((m_quantiteJourImputationDonneesForcees == null) || (p_quantiteJourImputationDonneesForcees == null))
    {
      m_quantiteJourImputationDonneesForcees = p_quantiteJourImputationDonneesForcees;
      ((DemandePC)getPC()).setQuantiteJourImputationDonneesForceesReliquat(p_quantiteJourImputationDonneesForcees);
    }
    else if ((m_quantiteJourImputationDonneesForcees != null) && (p_quantiteJourImputationDonneesForcees != null) && (!p_quantiteJourImputationDonneesForcees.equals(m_quantiteJourImputationDonneesForcees)))
    {
      m_quantiteJourImputationDonneesForcees = p_quantiteJourImputationDonneesForcees;
      ((DemandePC)getPC()).setQuantiteJourImputationDonneesForceesReliquat(p_quantiteJourImputationDonneesForcees);
    }
  }
  
  protected BigDecimal rawGetMontantJournalierReliquat()
  {
    return ((DemandePC)getPC()).getMontantJournalierReliquat();
  }
  
  public BigDecimal getMontantJournalierReliquat()
  {
    return ((DemandePC)getPC()).getMontantJournalierReliquat();
  }
  
  public void setMontantJournalierReliquat(BigDecimal p_montantJournalierReliquat)
  {
    if ((m_montantJournalierReliquat == null) || (p_montantJournalierReliquat == null))
    {
      m_montantJournalierReliquat = p_montantJournalierReliquat;
      ((DemandePC)getPC()).setMontantJournalierReliquat(p_montantJournalierReliquat);
    }
    else if ((m_montantJournalierReliquat != null) && (p_montantJournalierReliquat != null) && (!p_montantJournalierReliquat.equals(m_montantJournalierReliquat)))
    {
      m_montantJournalierReliquat = p_montantJournalierReliquat;
      ((DemandePC)getPC()).setMontantJournalierReliquat(p_montantJournalierReliquat);
    }
  }
  
  protected BigDecimal rawGetCapitalReliquat()
  {
    return ((DemandePC)getPC()).getCapitalReliquat();
  }
  
  public BigDecimal getCapitalReliquat()
  {
    return ((DemandePC)getPC()).getCapitalReliquat();
  }
  
  public void setCapitalReliquat(BigDecimal p_capitalReliquat)
  {
    if ((m_capitalReliquat == null) || (p_capitalReliquat == null))
    {
      m_capitalReliquat = p_capitalReliquat;
      ((DemandePC)getPC()).setCapitalReliquat(p_capitalReliquat);
    }
    else if ((m_capitalReliquat != null) && (p_capitalReliquat != null) && (!p_capitalReliquat.equals(m_capitalReliquat)))
    {
      m_capitalReliquat = p_capitalReliquat;
      ((DemandePC)getPC()).setCapitalReliquat(p_capitalReliquat);
    }
  }
  
  protected Quantite rawGetDureePostPrime()
  {
    return ((DemandePC)getPC()).getDureePostPrime();
  }
  
  public Quantite getDureePostPrime()
  {
    return ((DemandePC)getPC()).getDureePostPrime();
  }
  
  public void setDureePostPrime(Quantite p_dureePostPrime)
  {
    if ((m_dureePostPrime == null) || (p_dureePostPrime == null))
    {
      m_dureePostPrime = p_dureePostPrime;
      ((DemandePC)getPC()).setDureePostPrime(p_dureePostPrime);
    }
    else if ((m_dureePostPrime != null) && (p_dureePostPrime != null) && (!p_dureePostPrime.equals(m_dureePostPrime)))
    {
      m_dureePostPrime = p_dureePostPrime;
      ((DemandePC)getPC()).setDureePostPrime(p_dureePostPrime);
    }
  }
  
  protected Damj rawGetDateFinDispositifCSP()
  {
    return ((DemandePC)getPC()).getDateFinDispositifCSP();
  }
  
  public Damj getDateFinDispositifCSP()
  {
    return ((DemandePC)getPC()).getDateFinDispositifCSP();
  }
  
  public void setDateFinDispositifCSP(Damj p_dateFinDispositifCSP)
  {
    if ((m_dateFinDispositifCSP == null) || (p_dateFinDispositifCSP == null))
    {
      m_dateFinDispositifCSP = p_dateFinDispositifCSP;
      ((DemandePC)getPC()).setDateFinDispositifCSP(p_dateFinDispositifCSP);
    }
    else if ((m_dateFinDispositifCSP != null) && (p_dateFinDispositifCSP != null) && (!p_dateFinDispositifCSP.equals(m_dateFinDispositifCSP)))
    {
      m_dateFinDispositifCSP = p_dateFinDispositifCSP;
      ((DemandePC)getPC()).setDateFinDispositifCSP(p_dateFinDispositifCSP);
    }
  }
  
  protected int rawGetReliquatAllongementArefPossible()
  {
    return ((DemandePC)getPC()).getReliquatAllongementArefPossibleReliquat();
  }
  
  public int getReliquatAllongementArefPossible()
  {
    return ((DemandePC)getPC()).getReliquatAllongementArefPossibleReliquat();
  }
  
  public void setReliquatAllongementArefPossible(int p_reliquatAllongementArefPossible)
  {
    ((DemandePC)getPC()).setReliquatAllongementArefPossibleReliquat(p_reliquatAllongementArefPossible);
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
  }
  
  public void initEnProfondeur()
    throws TechniqueException
  {
    setQuantiteReliquat(null);
    setQuantiteFormation(null);
    setQuantiteAide(null);
    setReliquatValide(false);
    setCumulMoisActiviteReduite(0);
    setQuantiteReliquatRenouvellement(null);
    setQuantiteJourImputationDonneesForcees(null);
    setMontantJournalierReliquat(null);
    setCapitalReliquat(null);
    setDureePostPrime(null);
    setDateFinDispositifCSP(null);
    setReliquatAllongementArefPossible(0);
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     ReliquatGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */