package fr.unedic.cali.asu.exp03.p01.calcul;

import fr.unedic.cali.asu.calcul.outilsfonctionnels.OutilsMaintienEuropeenEessiASU;
import fr.unedic.cali.asu.calcul.outilsfonctionnels.RecuperationPensionInvaliditeAvantDate;
import fr.unedic.cali.asu.cge01.calcul.FacadeCalculLigneSansTrancheImpl;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisationAREF;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.exp03.p01.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.OutillageQuantites;
import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.periode.PeriodeAvantageVieillesse;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationAvantageVieillesseAvantPJI;
import fr.unedic.cali.calcul.outilsfonctionnels.RecuperationSanctionReduction;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.FormuleMontantAREFSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.QuantiteDroit;
import fr.unedic.cali.dom.QuantiteIndemnisationSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class FacadeCalculProduitImpl
  extends FacadeCalculLigneSansTrancheImpl
{
  private static final int DIX = 10;
  
  public void initialiseElementBaseIndemnisationCourante(ConstituantsIndemnisation p_constituantsIndemnisation, AttributionSpec p_attribution, Periode p_periodeUT)
    throws CoucheLogiqueException
  {
    if (p_constituantsIndemnisation.getElementBaseIndemnisationCourant() == null)
    {
      Attribution attribution = (Attribution)p_attribution;
      ElementBaseIndemnisation elementBaseIndemnisationCourant = new ElementBaseIndemnisation();
      ElementBaseIndemnisation ebiAttrib = attribution.getElementBaseIndemnisation();
      
      Reglement reglementApplicable = ebiAttrib.getReglementApplicable();
      if (reglementApplicable != null) {
        elementBaseIndemnisationCourant.setReglementApplicable(reglementApplicable);
      }
      Quantite affiliationRequisePourPRA = ebiAttrib.getAffiliationRequisePourPRA();
      if (affiliationRequisePourPRA != null) {
        elementBaseIndemnisationCourant.setAffiliationRequisePourPRA(affiliationRequisePourPRA);
      }
      SalaireReference salaireReference = ebiAttrib.getSalaireReference();
      if (salaireReference != null) {
        elementBaseIndemnisationCourant.setSalaireReference(salaireReference);
      }
      BigDecimal nombreHeureTravaillesEtendu = ebiAttrib.getNombreHeureTravaillesEtendu();
      if (nombreHeureTravaillesEtendu != null) {
        elementBaseIndemnisationCourant.setNombreHeureTravaillesEtendu(nombreHeureTravaillesEtendu);
      }
      BigDecimal nombreHeuresTravailleesPlafonnees = ebiAttrib.getNombreHeuresTravailleesPlafonnees();
      if (nombreHeuresTravailleesPlafonnees != null) {
        elementBaseIndemnisationCourant.setNombreHeuresTravailleesPlafonnees(nombreHeuresTravailleesPlafonnees);
      }
      Periode prc = ebiAttrib.getPrc();
      if (prc != null) {
        elementBaseIndemnisationCourant.setPrc(prc);
      }
      elementBaseIndemnisationCourant.setNbJoursEmploiSurPrc(ebiAttrib.getNbJoursEmploiSurPrc());
      elementBaseIndemnisationCourant.setCoefficientHoraireJour(ebiAttrib.getCoefficientHoraireJour());
      
      p_constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationCourant);
      if (attribution.getElementBaseIndemnisation().getCoefficientSaisonnier() != null) {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(attribution.getElementBaseIndemnisation().getCoefficientSaisonnier());
      } else {
        elementBaseIndemnisationCourant.setCoefficientSaisonnier(new BigDecimal("1"));
      }
      if (attribution.getElementBaseIndemnisation().getCoefficientTempsPartiel() != null) {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(attribution.getElementBaseIndemnisation().getCoefficientTempsPartiel());
      } else {
        elementBaseIndemnisationCourant.setCoefficientTempsPartiel(new BigDecimal("1"));
      }
      elementBaseIndemnisationCourant.setSjr((Sjr)attribution.getElementBaseIndemnisation().getSjr().copie());
      elementBaseIndemnisationCourant.setSjc((Sjc)attribution.getSJC().copie());
      elementBaseIndemnisationCourant.setCoefficientSanctionReduction(new BigDecimal("1.00"));
      
      elementBaseIndemnisationCourant.setListePensionInvalidite(attribution.getListePensionInvalidite());
      
      boolean gerePensionInvalidite = ((ProduitAsuSpec)attribution.getProduit()).estProduitGerantPensionInvalidite(attribution.getDemande());
      if (gerePensionInvalidite) {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, attribution.getDemandeur(), attribution.getPji().veille(), attribution.getDateAttribution()));
      } else {
        elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(attribution.getDemandeur(), attribution.getPji().veille()));
      }
      PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(attribution.getDemandeur(), attribution.getPji().veille());
      
      BigDecimal montantAV = new BigDecimal(0);
      if (periodeAvCourante != null)
      {
        montantAV = periodeAvCourante.getQuantiteEuro().getValeur();
        
        elementBaseIndemnisationCourant.setDateEffetAV(attribution.getPji().veille());
      }
      elementBaseIndemnisationCourant.setDateMaintienEuropeen(OutilsMaintienEuropeenEessiASU.rechercherDateMaintienEuropeen(p_attribution, p_periodeUT, p_constituantsIndemnisation));
      
      Sjr sjrrp = RevalorisationSalaire.revaloriserSjr(attribution.getElementBaseIndemnisation(), attribution.getProduitMontantRetenu(), attribution.getDateAttribution());
      BigDecimal coeffAV = montantAV.divide(sjrrp.getSalaire(), 10, 4);
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrrp.getSalaire()));
      
      elementBaseIndemnisationCourant.setTypeCaractereSaisonnierRetenu(attribution.getElementBaseIndemnisation().getTypeCaractereSaisonnierRetenu());
      
      elementBaseIndemnisationCourant.setIsConditionCaractereSaisonnierParRythme(attribution.getElementBaseIndemnisation().isConditionCaractereSaisonnierParRythme());
      
      elementBaseIndemnisationCourant.setReglementApplicableMontantRetenu(attribution.getReglementApplicable());
      elementBaseIndemnisationCourant.setReglementMontantRetenu(attribution.getReglementApplicable().getReglement());
      
      elementBaseIndemnisationCourant.setCompetenceAdministrative(attribution.getCompetenceAdministrative());
      elementBaseIndemnisationCourant.setDureeInitialeMaintien(attribution.getDureeTheorique());
      elementBaseIndemnisationCourant.setListeCarences(attribution.getListeCarences());
      elementBaseIndemnisationCourant.setConventionGestion(attribution.getConventionGestion());
      elementBaseIndemnisationCourant.setCapitalRetenuCourant(attribution.isCapitalRetenuCourant());
      elementBaseIndemnisationCourant.setMontantRetenuCourant(attribution.isMontantRetenuCourant());
      if ((attribution.getListeDurees() != null) && (!attribution.getListeDurees().isEmpty()))
      {
        QuantiteDroit durees = null;
        Iterator iterDuree = attribution.getListeDurees().iterator();
        while (iterDuree.hasNext())
        {
          durees = (QuantiteDroit)iterDuree.next();
          elementBaseIndemnisationCourant.getListeDurees().add(durees.copie());
        }
      }
      elementBaseIndemnisationCourant.setDureeProlongationTheorique(attribution.getDureeProlongationTheorique());
      elementBaseIndemnisationCourant.setElementChomageSansRupture(attribution.getElementChomageSansRupture());
      elementBaseIndemnisationCourant.setProduitMontantRetenu(attribution.getProduitMontantRetenu());
      elementBaseIndemnisationCourant.setSeuilMensuelPansConservees(attribution.getSeuilMensuelPansConservees());
      elementBaseIndemnisationCourant.setMaintienEuropeen(attribution.getMaintienEuropeen());
      elementBaseIndemnisationCourant.setSjc(attribution.getSJC());
      elementBaseIndemnisationCourant.setReglementApplicableMontantRetenu(attribution.getReglementApplicable());
      elementBaseIndemnisationCourant.setReglementMontantRetenu(attribution.getReglementApplicable().getReglement());
      elementBaseIndemnisationCourant.setCompetenceFinanciere(attribution.getCompetenceFinanciere());
      elementBaseIndemnisationCourant.setExpatrieApresConvention17(ebiAttrib.isExpatrieApresConvention17());
      
      FormuleMontantSpec formuleMontant = null;
      ElementBaseIndemnisationAREF elementBaseIndemnisationAREF = null;
      
      QuantiteIndemnisationSpec duree = OutillageQuantites.recupererPremiereQuantiteIndemnisationActive(p_constituantsIndemnisation.getCollectionQuantiteDroit());
      if (duree != null) {
        formuleMontant = p_attribution.getFormuleMontant(duree.getCodeFormuleMontant());
      } else {
        formuleMontant = p_attribution.getFormuleMontant(p_constituantsIndemnisation.getCodeFormuleMontant());
      }
      if ((formuleMontant instanceof FormuleMontantAREFSpec))
      {
        elementBaseIndemnisationAREF = new ElementBaseIndemnisationAREF(elementBaseIndemnisationCourant);
        p_constituantsIndemnisation.setElementBaseIndemnisationCourant(elementBaseIndemnisationAREF);
      }
    }
  }
  
  public void miseAJourConstituantsIndemnisationADate(AttributionSpec p_attribution, ConstituantsIndemnisation p_constituantsIndemnisation, Damj p_date, ChronologiePeriodes p_chronologiePeriodesSanctions)
    throws CoucheLogiqueException
  {
    ElementBaseIndemnisation elementBaseIndemnisationCourant = (ElementBaseIndemnisation)p_constituantsIndemnisation.getElementBaseIndemnisationCourant();
    
    elementBaseIndemnisationCourant.setListePensionInvalidite(((AttributionAssuranceSpec)p_attribution).getListePensionInvalidite());
    
    boolean gerePensionInvalidite = ((ProduitAsuSpec)p_attribution.getProduit()).estProduitGerantPensionInvalidite(p_attribution.getDemande());
    if (gerePensionInvalidite) {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPIChainees(elementBaseIndemnisationCourant, p_attribution.getDemandeur(), p_date.veille(), p_attribution.getDateAttribution()));
    } else {
      elementBaseIndemnisationCourant.setMontantPensionInvaliditeADeduire(RecuperationPensionInvaliditeAvantDate.recuperationMontantPI(p_attribution.getDemandeur(), p_date.veille()));
    }
    elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(new BigDecimal(0));
    elementBaseIndemnisationCourant.setMontantAvantageVieillesse(new BigDecimal(0));
    
    PeriodeAvantageVieillesse periodeAvCourante = RecuperationAvantageVieillesseAvantPJI.recupererPeriodeAvADate(((Attribution)p_attribution).getDemandeur(), p_date.veille());
    if (periodeAvCourante != null)
    {
      Damj dateDepart = Damj.max(p_attribution.getDateAttribution(), periodeAvCourante.getDateDebut());
      
      Sjr sjrDepart = RevalorisationSalaire.revaloriserSjr(((AttributionAssuranceSpec)p_attribution).getElementBaseIndemnisation(), ((AttributionAssuranceSpec)p_attribution).getProduitMontantRetenu(), dateDepart);
      
      BigDecimal coeffAV = periodeAvCourante.getQuantiteEuro().getValeur().divide(sjrDepart.getSalaire(), 10, 4);
      
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      
      Sjr sjrCourant = RevalorisationSalaire.revaloriserSjr(((AttributionAssuranceSpec)p_attribution).getElementBaseIndemnisation(), ((AttributionAssuranceSpec)p_attribution).getProduitMontantRetenu(), p_date.veille());
      
      elementBaseIndemnisationCourant.setCoefficientAvantageVieillesse(coeffAV);
      elementBaseIndemnisationCourant.setMontantAvantageVieillesse(coeffAV.multiply(sjrCourant.getSalaire()));
      
      elementBaseIndemnisationCourant.setDateEffetAV(p_date.veille());
    }
    elementBaseIndemnisationCourant.setCoefficientSanctionReduction(RecuperationSanctionReduction.recuperationCoefficientSanctionReductionADate(p_chronologiePeriodesSanctions, p_date));
  }
  
  public QualificationPeriodes qualificationPeriodes(ChronologiePeriodes p_chronologiePeriodes, AttributionSpec p_attribution, ContexteUT p_contexteUT)
    throws CoucheLogiqueException
  {
    return new Qualification().qualificationPeriodes(p_chronologiePeriodes, p_attribution);
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */