package fr.unedic.cali.asu.fds12.p02.calcul.outisfonctionnels;

import fr.unedic.cali.calcul.dom.periode.Pans;
import fr.unedic.cali.calcul.dom.periode.PansNonInstallee;
import fr.unedic.cali.calcul.dom.periode.PeriodeActiviteEmploiCalcul;
import fr.unedic.cali.calcul.dom.periode.PeriodeNonDeclareeSanction;
import fr.unedic.cali.calcul.dom.periode.PeriodePrime;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravail;
import fr.unedic.cali.calcul.dom.periode.PeriodeTravailJustifiee;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodePrimeCalcul;
import fr.unedic.cali.calcul.outilsfonctionnels.filtres.FiltrePeriodeTravailCalcul;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Chronologie;
import java.math.BigDecimal;
import java.util.ListIterator;

public class ActiviteReduite
{
  private static final BigDecimal RAPPORT_SOMME_SUR_UT = new BigDecimal("50");
  public static final int CUMUL_AR_DUREE_INDEMNISATION_MAX = 15;
  public static final int CUMUL_AR_TREIZIEME_MOIS = 13;
  
  public static BigDecimal calculerGainRetenu(Chronologie periodesEmploi)
  {
    BigDecimal gainRetenu = BigDecimal.ZERO;
    
    Chronologie chronoFiltree = periodesEmploi.copier(new FiltrePeriodeTravailCalcul());
    
    PeriodeTravail periodeCourante = null;
    chronoFiltree.iterer();
    while (chronoFiltree.encoreSuivant())
    {
      periodeCourante = (PeriodeTravail)chronoFiltree.elementSuivant();
      if (!(periodeCourante instanceof PansNonInstallee)) {
        gainRetenu = gainRetenu.add(periodeCourante.getGain());
      }
    }
    return gainRetenu;
  }
  
  public static ResultatActiviteReduite genererEvenementActiviteReduite(Chronologie periodeEmploi)
  {
    ResultatActiviteReduite evtRetour = new ResultatActiviteReduite();
    BigDecimal cumulNbHeures = BigDecimal.ZERO;
    BigDecimal cumulGain = BigDecimal.ZERO;
    
    BigDecimal cumulGainPrimes = BigDecimal.ZERO;
    
    BigDecimal cumulGainActiviteNonSalarieeNonInstallee = BigDecimal.ZERO;
    
    BigDecimal cumulGainJustifie = BigDecimal.ZERO;
    BigDecimal cumulNbHeuresJustifiees = BigDecimal.ZERO;
    
    BigDecimal cumulGainPNDS = BigDecimal.ZERO;
    BigDecimal cumulNbJourTravail = BigDecimal.ZERO;
    
    Chronologie periodesEmploiCourantes = periodeEmploi.copier(new FiltrePeriodeTravailCalcul());
    Chronologie periodesPrime = periodeEmploi.copier(new FiltrePeriodePrimeCalcul());
    
    PeriodeTravail periodeCourante = null;
    boolean neutralisation = false;
    
    BigDecimal cumulGainConserve = BigDecimal.ZERO;
    
    periodesPrime.iterer();
    while (periodesPrime.encoreSuivant()) {
      cumulGainPrimes = cumulGainPrimes.add(((PeriodePrime)periodesPrime.elementSuivant()).getMontant().getValeur());
    }
    ListIterator iterateur = periodesEmploiCourantes.iterer();
    while (iterateur.hasNext())
    {
      periodeCourante = (PeriodeTravail)iterateur.next();
      if ((periodeCourante instanceof PeriodeNonDeclareeSanction)) {
        cumulGainPNDS = cumulGainPNDS.add(((PeriodeNonDeclareeSanction)periodeCourante).getGain());
      }
      if ((periodeCourante instanceof PeriodeTravailJustifiee))
      {
        cumulGainJustifie = cumulGainJustifie.add(periodeCourante.getGain());
        cumulNbHeuresJustifiees = cumulNbHeuresJustifiees.add(periodeCourante.getNombreHeures());
      }
      if ((periodeCourante instanceof PansNonInstallee))
      {
        cumulGainActiviteNonSalarieeNonInstallee = cumulGainActiviteNonSalarieeNonInstallee.add(periodeCourante.getGain());
      }
      else
      {
        cumulNbJourTravail = cumulNbJourTravail.add(new BigDecimal(periodeCourante.getDuree()));
        if ((periodeCourante instanceof PeriodeActiviteEmploiCalcul))
        {
          cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          
          cumulGain = cumulGain.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGainHorsIccp());
          if (((PeriodeActiviteEmploiCalcul)periodeCourante).getTypeActivite() == 1) {
            cumulGainConserve = cumulGainConserve.add(((PeriodeActiviteEmploiCalcul)periodeCourante).getGain());
          }
        }
        else
        {
          cumulNbHeures = cumulNbHeures.add(periodeCourante.getNombreHeures());
          
          cumulGain = cumulGain.add(periodeCourante.getGain());
          if (((periodeCourante instanceof Pans)) && (((Pans)periodeCourante).getTypeActivite() == 1)) {
            cumulGainConserve = cumulGainConserve.add(((Pans)periodeCourante).getGain());
          }
        }
      }
    }
    cumulGain = cumulGain.add(cumulGainPrimes);
    if (cumulGainActiviteNonSalarieeNonInstallee.compareTo(BigDecimal.ZERO) > 0)
    {
      BigDecimal nbJoursDecalage = null;
      
      nbJoursDecalage = Mathematiques.diviseEntier(cumulGainActiviteNonSalarieeNonInstallee, RAPPORT_SOMME_SUR_UT);
      
      evtRetour.setDecalageDuree(nbJoursDecalage);
    }
    cumulGain = calculerGainRetenu(periodesEmploiCourantes);
    cumulGain = cumulGain.add(cumulGainPrimes);
    
    BigDecimal nbJoursDecalage = null;
    BigDecimal cumulGainPrDecalage = cumulGain.subtract(cumulGainConserve);
    
    nbJoursDecalage = Mathematiques.diviseEntier(cumulGainPrDecalage, RAPPORT_SOMME_SUR_UT);
    
    evtRetour.setCreditDecalage(nbJoursDecalage);
    
    evtRetour.setNeutralise(neutralisation);
    evtRetour.setNbHeuresPrisesEnCompte(cumulNbHeures);
    evtRetour.setGainPrisEnCompte(cumulGain.add(cumulGainActiviteNonSalarieeNonInstallee));
    
    evtRetour.setCumulGainJustifie(cumulGainJustifie);
    evtRetour.setCumulNbHeuresJustifiees(cumulNbHeuresJustifiees);
    
    evtRetour.setCumulJourDeTravail(cumulNbJourTravail);
    
    evtRetour.setCumulGainPNDS(cumulGainPNDS);
    
    return evtRetour;
  }
}

/* Location:
 * Qualified Name:     ActiviteReduite
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */