package fr.unedic.cali.asu.fds12.p03.avant;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.fds12.p03.avant.outilsfonctionnels.TraitementUtAvant;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.CarencePrefixeAFixer;
import fr.unedic.cali.asu.spe02.p05.calcul.outilsfonctionnels.Qualification;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvantSpec;
import fr.unedic.cali.calcul.dom.ConsommationPeriodes;
import fr.unedic.cali.calcul.dom.DureeConsommableAvant;
import fr.unedic.cali.calcul.dom.EtatAuDernierJourAvant;
import fr.unedic.cali.calcul.dom.QualificationPeriodes;
import fr.unedic.cali.calcul.dom.UniteTraitementAvant;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DureeNonIndemnisable;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreConflitGaec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;

public class FacadeAvantProduitImpl
  extends fr.unedic.cali.asu.spe02.p05.avant.FacadeAvantProduitImpl
{
  private static final int CENT = 100;
  
  public Damj rechercherPremierJourAvant(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return attribution.getDateAttribution();
  }
  
  public boolean estUnProduitGerantLaRefonte()
  {
    return false;
  }
  
  public ResultatAvant executerAvant(AttributionSpec attribution, boolean estAvecPriseEnCompteEvenement, Damj dateEtude, boolean executionPersistante)
    throws CoucheLogiqueException
  {
    Damj pji = null;
    Collection<CarencePrefixeAFixer> carencesEffectives = new ArrayList();
    
    int etat = 0;
    
    CalendrierExecutionAvant calendrierAvant = new CalendrierExecutionAvant();
    calendrierAvant.setPremierJourAvant(attribution.getDateAttribution());
    calendrierAvant.setEtatExecutionAvant(1);
    Damj dateDebutUtAvant = calendrierAvant.getPremierJourAvant().getDebutMois();
    Damj dateFinUtAvant = dateDebutUtAvant.getFinMois();
    ChronologiePeriodes chronologiePeriodes;
    if (estAvecPriseEnCompteEvenement)
    {
      ChronologiePeriodes chronologiePeriodes = recuperationDeToutesLesDesPeriodes(attribution.getDemandeur(), attribution, attribution.getDateAttribution(), null);
      
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePeriodes.recupererPeriodePECContenant(attribution.getDemandeur(), attribution.getDateAttribution());
      if (periodePEC == null)
      {
        if ((!"ASU_22".equals(attribution.getTypeExamen())) && (!"ASU_23".equals(attribution.getTypeExamen()))) {
          throw new CoucheLogiqueException("HG_PR_CALI_L_PAS_DE_PEC_POUR_EXECUTION_AVANT", "Attention lors de l'execution de l'avant, impossible de retrouver une periode de prise en charge.", null);
        }
        ResultatAvant resultatAvant = new ResultatAvant(pji, new ArrayList(carencesEffectives), true);
        resultatAvant.setEtat(1);
        return resultatAvant;
      }
    }
    else
    {
      chronologiePeriodes = (ChronologiePeriodes)recuperationDeToutesLesDesPeriodes(attribution.getDemandeur(), attribution, attribution.getDateAttribution(), attribution.getDateAttribution()).copier(new FiltreChevauchePeriode(new Periode(attribution.getDateAttribution(), attribution.getDateAttribution())));
      
      ChronologiePeriodes chronologiePeriodesSansConflitGAEC = (ChronologiePeriodes)chronologiePeriodes.copier(new FiltreNegation(new FiltreConflitGaec()));
      
      chronologiePeriodes = chronologiePeriodesSansConflitGAEC;
      
      Qualification qualification = new Qualification();
      QualificationPeriodes periodesQualifie = qualification.qualificationPeriodesPourAvant(chronologiePeriodes, attribution);
      chronologiePeriodes = periodesQualifie.getPeriodesSuspensives();
      chronologiePeriodes.ajouter(periodesQualifie.getPeriodesInterruptives());
    }
    etat = executionAvant(attribution, chronologiePeriodes, etat, dateDebutUtAvant, dateFinUtAvant, calendrierAvant);
    if (etat == 0) {
      pji = calendrierAvant.getDernierJourAvant().lendemain();
    }
    return majResultatAvant(attribution, executionPersistante, pji, carencesEffectives, etat, calendrierAvant);
  }
  
  private ResultatAvant majResultatAvant(AttributionSpec attribution, boolean executionPersistante, Damj pji, Collection<CarencePrefixeAFixer> carencesEffectives, int etat, CalendrierExecutionAvant calendrierAvant)
  {
    boolean estPresenceFranchise = (((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getDureeFranchiseCp() > 0) || (((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getDureeFranchiseSalaire() > 0);
    ResultatAvant resultatAvant;
    if ((!((AttributionAssuranceSpec)attribution).getListeCarences().isEmpty()) || (estPresenceFranchise))
    {
      if (executionPersistante) {
        attribution.setCalendrierExecutionAvant(calendrierAvant);
      }
      mettreAJour(calendrierAvant, (Attribution)attribution, carencesEffectives);
      
      ResultatAvant resultatAvant = new ResultatAvant(pji, new ArrayList(carencesEffectives), calendrierAvant.getEtatAuDernierJourAvant().isDelaiAttenteEntame());
      resultatAvant.setEtat(etat);
      resultatAvant.setPremierJourAvant(calendrierAvant.getDateDebut());
      resultatAvant.setDernierJourAvant(calendrierAvant.getDateFin());
      resultatAvant.setCalendrierExecutionAvantCalcul(calendrierAvant);
      resultatAvant.setEstPresenceFranchise(estPresenceFranchise);
    }
    else
    {
      attribution.setCalendrierExecutionAvant(null);
      
      resultatAvant = new ResultatAvant(attribution.getDateAttribution(), new ArrayList(carencesEffectives), false);
      resultatAvant.setEtat(etat);
      resultatAvant.setPremierJourAvant(attribution.getDateAttribution());
      resultatAvant.setDernierJourAvant(attribution.getDateAttribution());
      resultatAvant.setEstPresenceFranchise(false);
    }
    if (etat == 1) {
      resultatAvant.setMessageErreur("Impossible de determiner le PJI : Un événement interruptif est survenu avant la fin du différé.");
    }
    return resultatAvant;
  }
  
  private int executionAvant(AttributionSpec attribution, ChronologiePeriodes chronologiePeriodes, int etat, Damj dateDebutUtAvant, Damj dateFinUtAvant, CalendrierExecutionAvant calendrierAvant)
    throws CoucheLogiqueException
  {
    int etatResultat = etat;
    Damj dateDebutUtAvantTmp = dateDebutUtAvant;
    Damj dateFinUtAvantTmp = dateFinUtAvant;
    
    IndividuSpec individu = attribution.getDemandeur();
    while ((calendrierAvant.getEtatExecutionAvant() != 3) && ((!((AttributionAssuranceSpec)attribution).getListeCarences().isEmpty()) || (((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getDureeFranchiseSalaire() > 0) || (((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation().getDureeFranchiseCp() > 0)))
    {
      Periode periodeUtAvant = new Periode(dateDebutUtAvantTmp, dateFinUtAvantTmp);
      if ((individu != null) && (individu.getDateNaissance() != null) && (periodeUtAvant.getDebut().estApres(individu.getDateNaissance().deplacerVersAvant(new DureeCalendaire(100))))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_EXECUTION_ATTRIBUTION_DEMARRE_JAMAIS", new Object[] { attribution.getDateAttribution() });
      } else if (periodeUtAvant.getDebut().estApres(new Damj("2200, 01, 01"))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_EXECUTION_ATTRIBUTION_DEMARRE_JAMAIS", new Object[] { attribution.getDateAttribution() });
      } else if (periodeUtAvant.getDebut().estApres(Damj.FIN_DES_TEMPS)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_EXECUTION_ATTRIBUTION_DEMARRE_JAMAIS", new Object[] { attribution.getDateAttribution() });
      }
      dateDebutUtAvantTmp = dateFinUtAvantTmp.getDebutMoisSuivant();
      dateFinUtAvantTmp = dateDebutUtAvantTmp.getFinMois();
      
      etatResultat = TraitementUtAvant.executerUtAvant(attribution, calendrierAvant, periodeUtAvant, chronologiePeriodes);
    }
    return etatResultat;
  }
  
  public QualificationPeriodes qualificationPeriodesPourAvant(ChronologiePeriodes chronologiePeriodes, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    Qualification qualification = new Qualification();
    return qualification.qualificationPeriodesPourAvant(chronologiePeriodes, attribution);
  }
  
  public void mettreAJourCarencesSurResultatAvant(CalendrierExecutionAvant calendrierExecutionAvant, AttributionSpec attribution, Collection listeCarences) {}
  
  public void creerDureeIndemnisation(AttributionSpec attribution, CalendrierExecutionAvant calendrierAvant, UniteTraitementAvant utAvant)
  {
    DureeConsommableAvant dureeFranchiseCP = new DureeConsommableAvant(5, new QuantiteJour("0"));
    DureeConsommableAvant dureeFranchiseSalaire = new DureeConsommableAvant(6, new QuantiteJour("0"));
    
    DureeNonIndemnisable dniFranchiseCP = getFranchiseCP((Attribution)attribution);
    if (dniFranchiseCP != null)
    {
      dureeFranchiseCP.setQuantiteInitial(dniFranchiseCP.getQuantiteInitial());
      dureeFranchiseCP.setTypeDureeConsommable(5);
    }
    DureeNonIndemnisable dniFranchiseSalaire = getFranchiseSalaire((Attribution)attribution);
    if (dniFranchiseSalaire != null)
    {
      dureeFranchiseSalaire.setQuantiteInitial(dniFranchiseSalaire.getQuantiteInitial());
      dureeFranchiseSalaire.setTypeDureeConsommable(6);
    }
    dureeFranchiseCP.activer();
    if (dureeFranchiseCP.getQuantiteInitial().getValeurEntiere() > 0)
    {
      Periode p = new Periode(calendrierAvant.getPremierJourAvant());
      utAvant.getConsommationPeriodes().setPeriodePmc(p);
    }
    utAvant.setDureeFranchiseCPEnDebutUT(dureeFranchiseCP);
    utAvant.setDureeFranchiseSalaireEnDebutUT(dureeFranchiseSalaire);
  }
  
  public static DureeNonIndemnisable getFranchiseCP(AttributionSpec attribution)
  {
    ElementBaseIndemnisation ebiAttributionSpectacle = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation();
    DureeNonIndemnisable dureeFCP = null;
    if (ebiAttributionSpectacle.getDureeFranchiseCp() > 0)
    {
      dureeFCP = new DureeNonIndemnisable(ebiAttributionSpectacle.getDureeFranchiseCp());
      dureeFCP.setType("FCP");
    }
    return dureeFCP;
  }
  
  public static DureeNonIndemnisable getFranchiseSalaire(AttributionSpec attribution)
  {
    ElementBaseIndemnisation ebiAttributionSpectacle = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation();
    DureeNonIndemnisable dureeFCP = null;
    if (ebiAttributionSpectacle.getDureeFranchiseSalaire() > 0)
    {
      dureeFCP = new DureeNonIndemnisable(ebiAttributionSpectacle.getDureeFranchiseSalaire());
      dureeFCP.setType("FS");
    }
    return dureeFCP;
  }
  
  public boolean estUnCarenceGereeParLeProduit(DureeConsommableAvant dureeAvant)
  {
    return (dureeAvant.getTypeDureeConsommable() == 5) || (dureeAvant.getTypeDureeConsommable() == 6);
  }
  
  public boolean estCarenceTerminantProduit(DureeConsommableAvant dureeAvant)
  {
    return dureeAvant.getTypeDureeConsommable() == 6;
  }
  
  public ResultatAvant postTraitementResultatDeterminationEtatAvant(AttributionSpec attribution)
  {
    ResultatAvant resultat = super.postTraitementResultatDeterminationEtatAvant(attribution);
    
    CalendrierExecutionAvantSpec calendrierAvant = attribution.getCalendrierExecutionAvant();
    EtatAuDernierJourAvant etatAuDernierJourAvant = calendrierAvant.getEtatAuDernierJourAvant();
    if (etatAuDernierJourAvant.getReliquatCP() != null)
    {
      resultat.setReliquatFranchiseCP(new QuantiteJour(Integer.toString(etatAuDernierJourAvant.getReliquatCP().intValue())));
      resultat.setPeriodeApplicationFranchiseCP(etatAuDernierJourAvant.getPeriodeApplicationCP());
    }
    if (etatAuDernierJourAvant.getReliquatSalaire() != null)
    {
      resultat.setReliquatFranchiseSalaire(new QuantiteJour(Integer.toString(etatAuDernierJourAvant.getReliquatSalaire().intValue())));
      resultat.setPeriodeApplicationFranchiseSalaire(etatAuDernierJourAvant.getPeriodeApplicationSalaire());
    }
    return resultat;
  }
}

/* Location:
 * Qualified Name:     FacadeAvantProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */