package fr.unedic.cali.asu.fps.liquidation.parcours.convention17;

import fr.pe.cali.reglementaire.dom.impl.CriteresFabriqueReglementaire;
import fr.pe.cali.reglementaire.regles.assurance.cap.beneficeautreproduit.dom.DonneesEntreeBeneficeAutreProduitConvention2017;
import fr.pe.cali.reglementaire.regles.assurance.cap.beneficeautreproduit.dom.DonneesSortieBeneficeAutreProduitConvention2017;
import fr.pe.cali.reglementaire.regles.assurance.cap.beneficeautreproduit.fabrique.FabriqueCorpsRegleConditionBeneficeAutreProduit;
import fr.pe.cali.reglementaire.regles.assurance.cap.beneficeautreproduit.outils.spec.IOutilConditionBeneficeAutreProduit;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionBeneficeAutreProduit;
import fr.unedic.cali.asu.ssp07.p05.liquidation.outilsfonctionnels.OutilFonctionnelBeneficeAutreProduitAPS2017;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.LigneSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourGamme;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;

public abstract class ParcoursConditionBeneficeAutreProduitAbstrait
  extends ParcoursCali
  implements ParcoursAssurance
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = (Demande)((DomLiquidationAssurance)contexte.getDonnees()).getDemandeSpec();
    Demande demandePrecedente = recupererDemandePrecedente(demandeCourante);
    
    return determinationConditionBeneficeAutreProduit(demandeCourante, demandePrecedente);
  }
  
  protected abstract Resultat determinationConditionBeneficeAutreProduit(Demande paramDemande1, Demande paramDemande2)
    throws ApplicativeException;
  
  protected IOutilConditionBeneficeAutreProduit recupererOutilReglementaire(Demande demandeCourante, Demande demandePrecedente)
  {
    CriteresFabriqueReglementaire criteres = recupererCriteresFabriqueReglementaire(demandeCourante, demandePrecedente);
    return FabriqueCorpsRegleConditionBeneficeAutreProduit.getInstance().recupererOutilCorpsRegle(criteres);
  }
  
  protected abstract CriteresFabriqueReglementaire recupererCriteresFabriqueReglementaire(Demande paramDemande1, Demande paramDemande2);
  
  protected boolean estUneDemandeAre(Demande demande)
  {
    LigneSpec ligne = demande.getDossierAffectation().getProduit().getLigne();
    return OutilDemande.estUneDemandeAre(ligne);
  }
  
  protected DonneesEntreeBeneficeAutreProduitConvention2017 creerConteneurDonneesEntree(Demande demandeCourante, Demande demandePrecedente)
  {
    DonneesEntreeBeneficeAutreProduitConvention2017 donneesEntree = new DonneesEntreeBeneficeAutreProduitConvention2017();
    donneesEntree.setLeveeConditionBeneficeAutreProduitForcee(demandeCourante.getDonneesTemporaires().isLeverConditionBeneficeAutreProduit());
    
    OutilFonctionnelBeneficeAutreProduitAPS2017 outilFonctionnel = new OutilFonctionnelBeneficeAutreProduitAPS2017(demandePrecedente);
    donneesEntree.setOutilFonctionnel(outilFonctionnel);
    
    return donneesEntree;
  }
  
  protected void mettreAJourConteneurDonneesSortie(Resultat resultat, ConditionBeneficeAutreProduit condition, DonneesSortieBeneficeAutreProduitConvention2017 donneesSortie)
  {
    if (donneesSortie.isSatisfait())
    {
      resultat.setEtat(0);
      condition.setEtat(0);
    }
    else
    {
      resultat.setEtat(1);
      condition.setEtat(1);
      condition.setCodeMotifEchec(141);
    }
  }
  
  protected Demande recupererDemandePrecedente(Demande demandeCourante)
  {
    Chronologie chronologieDemandesAsuSansCourante = demandeCourante.getChronologieDemandesAssuranceSansCourante();
    return (Demande)OutilRecherche.rechercherDemandePrecedente(chronologieDemandesAsuSansCourante, demandeCourante, new FiltreDecisionPourGamme(GammeAsu.getInstance().getNomUnique()));
  }
}

/* Location:
 * Qualified Name:     ParcoursConditionBeneficeAutreProduitAbstrait
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */