package fr.unedic.cali.asu.liquidation.antecedent;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;

public class VerificationDonneesSaisieAntecedentFinDroitSP
  implements VerificationDonneesSaisieAntecedentSpec
{
  private static final Integer ZERO = Integer.valueOf(0);
  private static final BigDecimal BD_ZERO = new BigDecimal("0");
  private static final BigDecimal BD_UN = new BigDecimal("1");
  private static final Damj DATE_ATTRIB_CG = new Damj(2003, 1, 1);
  private static final Damj DATE_MIN_FGD = new Damj(2003, 1, 1);
  
  public static VerificationDonneesSaisieAntecedentFinDroitSP getInstance()
  {
    return new VerificationDonneesSaisieAntecedentFinDroitSP();
  }
  
  public void verifierDonneesForcees(Demande demande, Damj dateTraitement)
    throws CoucheLogiqueException
  {
    SaisieAntecedent saisieAntecedent = demande.getSaisieAntecedent();
    if ((saisieAntecedent == null) || (saisieAntecedent.getCodeProduit() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_ANTECEDENT_CODE_PRODUIT");
    }
    verifierDonneesContexte(saisieAntecedent);
    
    verifierDonneesConstituants(saisieAntecedent, demande);
    
    verifierDonneesReliquat(saisieAntecedent, dateTraitement);
    
    verifierDonneesConventionGestion(saisieAntecedent, demande);
  }
  
  private static void verifierDonneesContexte(SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getCodeProduit() == null) || (saisieAntecedent.getCodeProduit().compareTo(ZERO) == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_PRODUIT");
    }
    if ((saisieAntecedent.getContexteDemande() == null) || (saisieAntecedent.getContexteDemande().compareTo(ZERO) == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_CONTEXTE");
    }
    if ((saisieAntecedent.getContexteDemande() != null) && (saisieAntecedent.getCodeProduit() != null) && (saisieAntecedent.getContexteDemande().compareTo(Integer.valueOf(3)) == 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(1)) != 0) && (saisieAntecedent.getCodeProduit().compareTo(Integer.valueOf(5)) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_SP");
    }
  }
  
  private static void verifierDonneesConstituants(SaisieAntecedent saisieAntecedent, Demande demande)
    throws CoucheLogiqueException
  {
    ActiviteSalarie fctRetenue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFCTRetenue());
    
    TravailSpec faitGenerateur = (TravailSpec)demande.getDemandeur().rechercherPeriodePasseProfessionnel(saisieAntecedent.getIdentifiantFaitGenerateur());
    if (fctRetenue == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FCT_INCONNUE");
    }
    if (faitGenerateur == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ANTECEDENT_FGD_INCONNUE");
    }
    if ((saisieAntecedent.getDateAttribution() == null) || (saisieAntecedent.getDateAttribution().coincideAvec(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_DTE_ATTRIB");
    }
    if ((fctRetenue.getDateFin() != null) && (faitGenerateur.getDateFin() != null) && (fctRetenue.getDateFin().estApres(faitGenerateur.getDateFin()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FCT");
    }
    if ((saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateAttribution().estAvant(fctRetenue.getDateFin()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB");
    }
    if ((fctRetenue.getCollectionOrigineInformationPAS().contains(Integer.valueOf(10))) && (saisieAntecedent.getTypeCoordinationEuropeenne() == 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHERENCE_COORDINATION");
    }
    if ((fctRetenue.getCategorieEmploiParticulier() != 38) && (saisieAntecedent.getSalaireJournalierReferencePlafonne() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_SJRP");
    }
    if ((fctRetenue.getCategorieEmploiParticulier() != 38) && ((saisieAntecedent.getTermePRC() == null) || (saisieAntecedent.getTermePRC().coincideAvec(Damj.FIN_DES_TEMPS)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_FIN_PRC");
    }
    if ((fctRetenue.getCategorieEmploiParticulier() != 38) && ((saisieAntecedent.getDateDebutPRC() == null) || (saisieAntecedent.getDateDebutPRC().coincideAvec(Damj.FIN_DES_TEMPS)))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_DEBUT_PRC");
    }
    if ((saisieAntecedent.getDateDebutPRC() != null) && (saisieAntecedent.getTermePRC() != null) && (saisieAntecedent.getTermePRC().estAvant(saisieAntecedent.getDateDebutPRC()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_CORH_PRC");
    }
    if ((saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateAttribution().estAvant(DATE_ATTRIB_CG))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DTE_ATTRIB_CG");
    }
    if ((saisieAntecedent.getCoefficientTempsPartiel() != null) && ((saisieAntecedent.getCoefficientTempsPartiel().compareTo(BD_UN) > 0) || (saisieAntecedent.getCoefficientTempsPartiel().compareTo(BD_ZERO) <= 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_COEF_TP");
    }
    if ((saisieAntecedent.getCoefficientSaisonnier() != null) && ((saisieAntecedent.getCoefficientSaisonnier().compareTo(BD_UN) > 0) || (saisieAntecedent.getCoefficientSaisonnier().compareTo(BD_ZERO) <= 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_COEF_SAISONNIER");
    }
    if ((saisieAntecedent.getCoefficientSaisonnier() != null) && ((saisieAntecedent.getTypeCaractereSaisonnier() == null) || (saisieAntecedent.getTypeCaractereSaisonnier().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_TYPE_SAISONNIER");
    }
    if ((saisieAntecedent.getCoefficientSaisonnier() == null) && (saisieAntecedent.getTypeCaractereSaisonnier() != null) && (saisieAntecedent.getTypeCaractereSaisonnier().compareTo(ZERO) != 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_TYPE_SAISONNIER");
    }
    if ((saisieAntecedent.isA3ansActiviteEn5ans()) && ((saisieAntecedent.getTypeCaractereSaisonnier() == null) || (saisieAntecedent.getTypeCaractereSaisonnier().compareTo(Integer.valueOf(1)) != 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_ACTIVITE_3_ANS");
    }
    if ((saisieAntecedent.getTermePRC() != null) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getTermePRC().estApresOuCoincideAvec(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FIN_PRC_DATE_ATTRIB");
    }
    if ((saisieAntecedent.getCodeEmploiA2B() != null) && (saisieAntecedent.getCodeEmploiA2B().compareTo(ZERO) != 0) && (fctRetenue.getCategorieEmploiParticulier() != 38)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_REGLEMENT_A2B_2");
    } else if (((saisieAntecedent.getCodeEmploiA2B() == null) || (saisieAntecedent.getCodeEmploiA2B().compareTo(ZERO) == 0)) && (fctRetenue.getCategorieEmploiParticulier() == 38)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_REGLEMENT_A2B");
    }
    if (((saisieAntecedent.getSalaireJournalierReferencePlafonne() != null) || ((saisieAntecedent.getTermePRC() != null) && (!saisieAntecedent.getTermePRC().coincideAvec(Damj.FIN_DES_TEMPS)))) && (fctRetenue.getCategorieEmploiParticulier() == 38)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_REGLEMENT_A2B_3");
    }
    if ((faitGenerateur.getDateFin() != null) && (faitGenerateur.getDateFin().estAvant(DATE_MIN_FGD))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FGD");
    }
  }
  
  private static void verifierDonneesReliquat(SaisieAntecedent saisieAntecedent, Damj dateTraitement)
    throws CoucheLogiqueException
  {
    if ((saisieAntecedent.getDateDernierJourCalcule() == null) || (saisieAntecedent.getDateDernierJourCalcule().equals(Damj.FIN_DES_TEMPS))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_OBLG_DJC");
    }
    if ((saisieAntecedent.getDateDernierJourCalcule() != null) && (dateTraitement != null) && (saisieAntecedent.getDateDernierJourCalcule().estApres(dateTraitement))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_SP_FIN_DROIT");
    }
    if ((saisieAntecedent.getDateDernierJourCalcule() != null) && (saisieAntecedent.getDateAttribution() != null) && (saisieAntecedent.getDateDernierJourCalcule().estAvant(saisieAntecedent.getDateAttribution()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_N_CALI_ANTECEDENT_COHR_DJC");
    }
    if ((saisieAntecedent.getNombreJourIndemniseARE() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreJourIndemniseARE().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_ARE");
    }
    if ((saisieAntecedent.getNombreJourIndemniseAREF() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getDureeInitialeDroit().getValeur().compareTo(new BigDecimal(saisieAntecedent.getNombreJourIndemniseAREF().intValue())) < 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_JOURS_AREF");
    }
    if ((saisieAntecedent.getReliquatDuree() != null) && (saisieAntecedent.getDureeInitialeDroit() != null) && (saisieAntecedent.getReliquatDuree().compareTo(saisieAntecedent.getDureeInitialeDroit()) > 0)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_RELIQUAT_DUREE");
    }
    if ((saisieAntecedent.isEstEnFormationAuDJC()) && ((saisieAntecedent.getNombreJourIndemniseAREF() == null) || (saisieAntecedent.getNombreJourIndemniseAREF().compareTo(ZERO) == 0))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_FORMATION_DJC");
    }
    if ((saisieAntecedent.getReliquatJoursDelaiAttente() != null) && (!saisieAntecedent.isDelaiAttente())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_DELAI_ATTENTE_2");
    }
  }
  
  public void verifierDonneesForceesPostLiquidation(Demande demande)
    throws CoucheLogiqueException
  {}
  
  private void verifierDonneesConventionGestion(SaisieAntecedent saisieAntecedent, Demande demande)
    throws CoucheLogiqueException
  {
    if (((saisieAntecedent.getEtablissementFinanceur() != null) && (saisieAntecedent.getEtablissementFinanceur().length() > 0)) || ((saisieAntecedent.getCodeAffectation() != null) && (saisieAntecedent.getCodeAffectation().length() > 0)))
    {
      ConventionGestionSpec convention = OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(saisieAntecedent.getEtablissementFinanceur(), saisieAntecedent.getCodeAffectation(), demande.getDateDepot(), demande.getCommentaire()));
      if (convention == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_CONVENTION_GESTION");
      } else if ((convention.estIdExterneObligatoire()) && ((saisieAntecedent.getIdExterneEmployeurSp() == null) || (saisieAntecedent.getIdExterneEmployeurSp().equals("")))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_OBLG_ID_EXTERNE");
      }
    }
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesSaisieAntecedentFinDroitSP
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */