package fr.unedic.cali.asu.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.cge01.AttributionAssuranceCgeSpec;
import fr.unedic.cali.dom.AttributionAssuranceSpec;
import fr.unedic.cali.dom.ComparateurDecisionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.ElementComparaisonReexamen;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

public class ComparateurDecision
  implements ComparateurDecisionSpec, OutilFonctionnel
{
  protected static ArrayList listeNaturesDecisionsReprise = new ArrayList();
  private static boolean listeRepriseInitialise = false;
  protected static ArrayList listeNaturesDecisionsRejet = new ArrayList();
  private static boolean listeRejetInitialise = false;
  
  protected static boolean decisionEgal(DecisionSpec decisionAvant, DecisionSpec decisionApres)
  {
    boolean decisionEgales = false;
    
    decisionEgales = ignorerChangerNatureDecisionReprise(decisionAvant, decisionApres);
    if (!decisionEgales) {
      decisionEgales = ignorerChangerNatureDecisionRejet(decisionAvant, decisionApres);
    }
    if (!decisionEgales) {
      decisionEgales = decisionAvant.getNatureDecision() == decisionApres.getNatureDecision();
    }
    if ((decisionEgales) && (!estDecisionsEgalesRejetDV(decisionAvant, decisionApres))) {
      decisionEgales = false;
    }
    return decisionEgales;
  }
  
  protected static boolean estDecisionsEgalesRejetDV(DecisionSpec decisionAvant, DecisionSpec decisionApres)
  {
    DossierExamenAssuranceSpec dossierExamenAvant = (DossierExamenAssuranceSpec)decisionAvant;
    DossierExamenAssuranceSpec dossierExamenApres = (DossierExamenAssuranceSpec)decisionApres;
    boolean decisionsEgalesRejetDV = false;
    if (dossierExamenAvant.estRejetDV() == dossierExamenApres.estRejetDV()) {
      decisionsEgalesRejetDV = true;
    }
    return decisionsEgalesRejetDV;
  }
  
  protected static synchronized void initialiserListeNaturesDecisionsReprise()
  {
    if (!listeRepriseInitialise)
    {
      listeRepriseInitialise = true;
      listeNaturesDecisionsReprise = new ArrayList();
      listeNaturesDecisionsReprise.add(Integer.valueOf(27));
      listeNaturesDecisionsReprise.add(Integer.valueOf(13));
      listeNaturesDecisionsReprise.add(Integer.valueOf(15));
      listeNaturesDecisionsReprise.add(Integer.valueOf(34));
    }
  }
  
  protected static boolean ignorerChangerNatureDecisionReprise(DecisionSpec decisionAvant, DecisionSpec decisionApres)
  {
    initialiserListeNaturesDecisionsReprise();
    return (listeNaturesDecisionsReprise.contains(Integer.valueOf(decisionAvant.getNatureDecision()))) && (listeNaturesDecisionsReprise.contains(Integer.valueOf(decisionApres.getNatureDecision())));
  }
  
  protected static synchronized void initialiserListeNaturesDecisionsRejet()
  {
    if (!listeRejetInitialise)
    {
      listeRejetInitialise = true;
      listeNaturesDecisionsRejet = new ArrayList();
      listeNaturesDecisionsRejet.add(Integer.valueOf(28));
      listeNaturesDecisionsRejet.add(Integer.valueOf(16));
      listeNaturesDecisionsRejet.add(Integer.valueOf(33));
    }
  }
  
  protected static boolean ignorerChangerNatureDecisionRejet(DecisionSpec decision1, DecisionSpec decision2)
  {
    initialiserListeNaturesDecisionsRejet();
    return (listeNaturesDecisionsRejet.contains(Integer.valueOf(decision1.getNatureDecision()))) && (listeNaturesDecisionsRejet.contains(Integer.valueOf(decision2.getNatureDecision())));
  }
  
  protected static boolean dureePostPrimeEgale(DecisionAssuranceSpec decisionAvant, DecisionAssuranceSpec decisionApres)
  {
    boolean resultatComparaison = true;
    if (((decisionAvant instanceof AttributionAssuranceCgeSpec)) && ((decisionApres instanceof AttributionAssuranceCgeSpec)))
    {
      Quantite dureePostPrimeAvant = ((AttributionAssuranceCgeSpec)decisionAvant).getDureePostPrime();
      Quantite dureePostPrimeApres = ((AttributionAssuranceCgeSpec)decisionApres).getDureePostPrime();
      
      boolean dureesPostPrimeNulles = (dureePostPrimeAvant == null) && (dureePostPrimeApres == null);
      boolean dureesPostPrimesEgales = (dureePostPrimeAvant != null) && (dureePostPrimeApres != null) && (dureePostPrimeApres.compareTo(dureePostPrimeAvant) == 0);
      
      resultatComparaison = (dureesPostPrimeNulles) || (dureesPostPrimesEgales);
    }
    return resultatComparaison;
  }
  
  protected static void alimenterDureePostPrime(DecisionAssuranceSpec decisionAvant, DecisionAssuranceSpec decisionApres, List listeComparaison)
  {
    Quantite dureePostPrimeAvant = ((AttributionAssuranceCgeSpec)decisionAvant).getDureePostPrime();
    Quantite dureePostPrimeApres = ((AttributionAssuranceCgeSpec)decisionApres).getDureePostPrime();
    alimenterDifferences(formaterDureePostPrime(dureePostPrimeAvant), formaterDureePostPrime(dureePostPrimeApres), "Durée restant en CSP DC", listeComparaison);
  }
  
  private static String formaterDureePostPrime(Quantite dureePostPrime)
  {
    String dureePostPrimeString = "";
    if ((dureePostPrime != null) && (dureePostPrime.getValeur() != null)) {
      dureePostPrimeString = String.valueOf(dureePostPrime.getValeur().intValue());
    }
    return dureePostPrimeString;
  }
  
  protected static boolean dateLimiteIndemnisationEgale(DecisionSpec decisionAvant, DecisionSpec decisionApres)
  {
    boolean resultatComparaison = true;
    if (((decisionAvant instanceof AttributionAssuranceSpec)) && ((decisionApres instanceof AttributionAssuranceSpec))) {
      try
      {
        Damj dateLimiteAvant = ((AttributionAssuranceSpec)decisionAvant).getDateLimiteIndemnisation();
        Damj dateLimiteApres = ((AttributionAssuranceSpec)decisionApres).getDateLimiteIndemnisation();
        
        boolean datesLimiteNulles = (dateLimiteAvant == null) && (dateLimiteApres == null);
        boolean datesLimiteEgales = (dateLimiteAvant != null) && (dateLimiteApres != null) && (dateLimiteAvant.coincideAvec(dateLimiteApres));
        
        resultatComparaison = (datesLimiteNulles) || (datesLimiteEgales);
      }
      catch (CoucheLogiqueException ex)
      {
        resultatComparaison = false;
      }
    }
    return resultatComparaison;
  }
  
  protected static void alimenterDateLimiteIndemnisation(DecisionSpec decisionAvant, DecisionSpec decisionApres, List listeDifferences)
  {
    alimenterDifferences(formaterDateLimiteIndemnisation(decisionAvant), formaterDateLimiteIndemnisation(decisionApres), "Date fin du dispositif", listeDifferences);
  }
  
  private static String formaterDateLimiteIndemnisation(DecisionSpec decision)
  {
    String dateLimiteString = "";
    try
    {
      Damj dateLimite = ((AttributionAssuranceSpec)decision).getDateLimiteIndemnisation();
      if (dateLimite != null) {
        dateLimiteString = dateLimite.toString();
      }
    }
    catch (CoucheLogiqueException ex)
    {
      dateLimiteString = "";
    }
    return dateLimiteString;
  }
  
  protected static void alimenterDifferences(Object valeurAvant, Object valeurApres, String libelleElement, List liste)
  {
    ElementComparaisonReexamen elementDecision = new ElementComparaisonReexamen(libelleElement, valeurAvant, valeurApres);
    liste.add(elementDecision);
  }
}

/* Location:
 * Qualified Name:     ComparateurDecision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */