package fr.unedic.cali.asu.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.GestionDemandeDv122eJour;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.BulletinSalaire;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.DeclareSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.DetectionTypeChomage;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenContenueDansPeriode;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreODValidee;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;

public class RechercheConditionChomageInvolontaire
  implements OutilFonctionnel
{
  public static RechercheConditionChomageInvolontaire getInstance()
  {
    return new RechercheConditionChomageInvolontaire();
  }
  
  public void leverAlerteA11MB26(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    DemandeSpec rejetDv = GestionDemandeDv122eJour.retrouverDemandePortantDv(p_demande);
    
    Periode periodeRecherche = new Periode(rejetDv.getDateExamen(), p_demande.getDateDeclenchementExamen());
    
    FiltresTemporel rechercheOd = new FiltresTemporel();
    rechercheOd.ajouterFiltre(new FiltreODValidee());
    rechercheOd.ajouterFiltre(new FiltreDateDeclenchementExamenContenueDansPeriode(periodeRecherche));
    
    Chronologie listeOd = p_demande.getDemandeur().getChronoDemandeAssurance().copier(rechercheOd);
    listeOd.iterer();
    while (listeOd.encoreSuivant())
    {
      Demande demandeCourante = (Demande)listeOd.elementSuivant();
      if ((demandeCourante.getEvenementReferenceExamen().getTypeExamen() != "ASU_04") && (demandeCourante.compareTo(rejetDv) > 0)) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB26", new String[] { demandeCourante.getDossierAffectation().getDossierExamen().getDateAttribution().toString() });
      }
    }
  }
  
  public boolean determinerChomageNonLegitime(TravailSpec p_dernierePeriode)
  {
    return ((p_dernierePeriode instanceof ActiviteSalarie)) && (!DetectionTypeChomage.estChomageLegitime(((ActiviteSalarie)p_dernierePeriode).getCodeMotifFin(), ((ActiviteSalarie)p_dernierePeriode).getContrat().getContexteDemission()));
  }
  
  public void verifierConditionChomageInvolontaireVerifiable(TravailSpec p_dernierePeriode)
    throws CoucheLogiqueException
  {
    if (((p_dernierePeriode instanceof CertifieSpec)) && (!((CertifieSpec)p_dernierePeriode).estAtteste()))
    {
      if ((p_dernierePeriode instanceof BulletinSalaire)) {
        lancerA11MB4Bs(p_dernierePeriode);
      } else {
        lancerA11MB4Fct(p_dernierePeriode);
      }
    }
    else if (((p_dernierePeriode instanceof DeclareSpec)) && (!((DeclareSpec)p_dernierePeriode).estJustifie())) {
      lancerA11MB4Dnj(p_dernierePeriode);
    } else if (p_dernierePeriode.estEnConflit()) {
      lancerA11MB3();
    }
  }
  
  private void lancerA11MB3()
    throws CoucheLogiqueException
  {
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB3");
  }
  
  private void lancerA11MB4Fct(TravailSpec p_dernierePeriode)
    throws CoucheLogiqueException
  {
    Damj dateFCTDamj = p_dernierePeriode.getDateFin();
    String dateFCTString = new String();
    if (dateFCTDamj.equals(Damj.FIN_DES_TEMPS)) {
      dateFCTString = "ouverte";
    } else {
      dateFCTString = "du " + dateFCTDamj.formater();
    }
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB4", new String[] { dateFCTString });
  }
  
  private void lancerA11MB4Bs(TravailSpec p_dernierePeriode)
    throws CoucheLogiqueException
  {
    Damj dateFCTDamj = p_dernierePeriode.getDateFin();
    String dateFCTString = new String();
    dateFCTString = dateFCTDamj.formater();
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB4_BS", new String[] { dateFCTString });
  }
  
  private void lancerA11MB4Dnj(TravailSpec p_dernierePeriode)
    throws CoucheLogiqueException
  {
    Damj dateFCTDamj = p_dernierePeriode.getDateFin();
    String dateFCTString = new String();
    dateFCTString = dateFCTDamj.formater();
    fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB4_DNJ", new String[] { dateFCTString });
  }
}

/* Location:
 * Qualified Name:     RechercheConditionChomageInvolontaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */