package fr.unedic.cali.asu.liquidation.pnds.outilsfonctionnels;

import fr.unedic.cali.asu.liquidation.pnds.StrategiePNDSSpec;
import fr.unedic.cali.asu.liquidation.pnds.dom.CriteresStrategiePNDS;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public class FabriqueStrategiePNDS
{
  public static final Damj DATE_MEP_08SI1 = new Damj(2008, 2, 22);
  public static final Damj DATE_MEP_09SI2 = new Damj(2009, 6, 22);
  private static final StrategiePNDSSpec STRATEGIE_SPECTACLE = new StrategiePNDSSpe();
  private static final StrategiePNDSSpec STRATEGIE_CAS_GENERAL_AVANT_MEP_08SI1 = new StrategiePNDSCgeAvantMEP08SI1();
  private static final StrategiePNDSSpec STRATEGIE_CAS_GENERAL_APRES_MEP_08SI1 = new StrategiePNDSCgeApresMEP08SI1();
  private static final StrategiePNDSSpec STRATEGIE_CAS_GENERAL_APRES_MEP_09SI2 = new StrategiePNDSCgeApresMEP09SI2();
  private static final StrategiePNDSSpec STRATEGIE_CAS_GENERAL_DESACTIVE = new StrategiePNDSCgeDesactives();
  private static final StrategiePNDSSpec STRATEGIE_PNDS_SUITE_REACTIVATION = new StrategiePNDSCgeApresMEP09SI2();
  
  public static StrategiePNDSSpec determinerStrategiePNDS(CriteresStrategiePNDS criteres)
    throws CoucheLogiqueException
  {
    StrategiePNDSSpec strategieAMettreEnOeuvre = null;
    if (criteres.getPopulationDE() == 1) {
      strategieAMettreEnOeuvre = retournerStrategiePourPopulationSpectacle(criteres);
    } else if (criteres.getPopulationDE() == 0) {
      strategieAMettreEnOeuvre = retournerStrategiePourPopulationCasGeneral(criteres);
    }
    return strategieAMettreEnOeuvre;
  }
  
  private static StrategiePNDSSpec retournerStrategiePourPopulationSpectacle(CriteresStrategiePNDS criteres)
    throws CoucheLogiqueException
  {
    Damj dateReactivationPNDS = GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS");
    StrategiePNDSSpec strategieAMettreEnOeuvre;
    StrategiePNDSSpec strategieAMettreEnOeuvre;
    if ((criteres.getDateExamen() != null) && (criteres.getDateExamen().estApresOuCoincideAvec(dateReactivationPNDS)))
    {
      strategieAMettreEnOeuvre = STRATEGIE_PNDS_SUITE_REACTIVATION;
    }
    else
    {
      StrategiePNDSSpec strategieAMettreEnOeuvre;
      if ((criteres.getDateExamen() != null) && (criteres.getDateExamen().estApres(GestionnaireDateApplication.DATE_FIN_SANCTION_PNDS))) {
        strategieAMettreEnOeuvre = STRATEGIE_CAS_GENERAL_DESACTIVE;
      } else {
        strategieAMettreEnOeuvre = STRATEGIE_SPECTACLE;
      }
    }
    return strategieAMettreEnOeuvre;
  }
  
  private static StrategiePNDSSpec retournerStrategiePourPopulationCasGeneral(CriteresStrategiePNDS criteres)
    throws CoucheLogiqueException
  {
    Damj dateReactivationPNDS = GestionnaireDateApplication.getInstance().recupererDateApplication("Réactivation de la détermination des PNDS");
    
    Damj datePivot = criteres.getDatePivot();
    if (datePivot == null) {
      throw new UnsupportedOperationException("FabriqueStrategiePNDS : la date pivot PNDS est null.");
    }
    StrategiePNDSSpec strategieAMettreEnOeuvre;
    StrategiePNDSSpec strategieAMettreEnOeuvre;
    if ((criteres.getDateExamen() != null) && (criteres.getDateExamen().estApresOuCoincideAvec(dateReactivationPNDS)))
    {
      strategieAMettreEnOeuvre = STRATEGIE_PNDS_SUITE_REACTIVATION;
    }
    else
    {
      StrategiePNDSSpec strategieAMettreEnOeuvre;
      if ((criteres.getDateExamen() != null) && (criteres.getDateExamen().estApres(GestionnaireDateApplication.DATE_FIN_SANCTION_PNDS)))
      {
        strategieAMettreEnOeuvre = STRATEGIE_CAS_GENERAL_DESACTIVE;
      }
      else
      {
        StrategiePNDSSpec strategieAMettreEnOeuvre;
        if (datePivot.estApres(DATE_MEP_09SI2))
        {
          strategieAMettreEnOeuvre = STRATEGIE_CAS_GENERAL_APRES_MEP_09SI2;
        }
        else
        {
          StrategiePNDSSpec strategieAMettreEnOeuvre;
          if (datePivot.estApres(DATE_MEP_08SI1)) {
            strategieAMettreEnOeuvre = STRATEGIE_CAS_GENERAL_APRES_MEP_08SI1;
          } else {
            strategieAMettreEnOeuvre = STRATEGIE_CAS_GENERAL_AVANT_MEP_08SI1;
          }
        }
      }
    }
    return strategieAMettreEnOeuvre;
  }
}

/* Location:
 * Qualified Name:     FabriqueStrategiePNDS
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */