package fr.unedic.cali.asu.may17.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.asu.cge01.outilsfonctionnels.RevalorisationSalaireMayotte;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantPremiereTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantSecondeTranche;
import fr.unedic.cali.asu.may17.p02.calcul.dom.FormuleMontantTroisiemeTranche;
import fr.unedic.cali.asu.may17.p02.liquidation.dom.Admission;
import fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels.DeterminationConstituantsSupplementaires;
import fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels.OutilCalculDonneesNonPersistantes;
import fr.unedic.cali.dom.ConventionGestion;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;

public abstract class ConstitutionConstituantsSupplementaires
  extends ParcoursCali
{
  private static final int TAILLE_MAX = 50;
  
  protected void constituerAgeAuFaitGenerateur(Demande demande, Admission admission)
    throws ApplicativeException
  {
    String ageFaitGenerateur = DeterminationConstituantsSupplementaires.determinerAgeAuFaitGenerateur(demande);
    ElementDroit elementDroitAgeAuFaitGenerateur = OutilElementDroit.creerElementDroit("AGE_AU_FAIT_GENERATEUR", false, null, null, null, ageFaitGenerateur);
    
    elementDroitAgeAuFaitGenerateur.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitAgeAuFaitGenerateur);
  }
  
  protected void constituerConstituantsMontants(Demande demande, Admission admission)
    throws ApplicativeException
  {
    Damj pji = DeterminationConstituantsSupplementaires.determinerPJI(demande);
    ElementDroit elementDroitPji = OutilElementDroit.creerElementDroit("PJI", false, pji, null, null, null);
    
    elementDroitPji.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitPji);
    
    Sjr sjrRP = RevalorisationSalaireMayotte.revaloriserSjrMayotte(new Sjr(admission.getSJRInitial(), admission.getTermePRC(), "AREMAYOTTE"), admission.getDateAttribution());
    ElementDroit elementDroitSjrRP = OutilElementDroit.creerElementDroit("SJR_RP", false, null, null, new QuantiteEuro(sjrRP.getSalaire()), null);
    
    elementDroitSjrRP.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitSjrRP);
    
    MontantBaseSpec montant1 = determinerMontantTranche(demande, FormuleMontantPremiereTranche.getCode());
    
    Quantite piDeduite = montant1.getPensionInvaliditeADeduirePriseEnCompte() != null ? montant1.getPensionInvaliditeADeduirePriseEnCompte() : new QuantiteEuro("0");
    ElementDroit elementDroitPIDeduite = OutilElementDroit.creerElementDroit("PI_DEDUITE", false, null, null, piDeduite, null);
    
    elementDroitPIDeduite.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitPIDeduite);
    
    Quantite avDeduit = montant1.getMontantJournalierAvantageVieillesseDeduit() != null ? montant1.getMontantJournalierAvantageVieillesseDeduit() : new QuantiteEuro("0");
    ElementDroit elementDroitAVDeduit = OutilElementDroit.creerElementDroit("AVANTAGE_VIEILLESSE_DEDUIT", false, null, null, avDeduit, null);
    
    elementDroitAVDeduit.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitAVDeduit);
  }
  
  protected void constituerConstituantsTranche1(Demande demande, Admission admission)
    throws ApplicativeException
  {
    MontantBaseSpec montant1 = determinerMontantTranche(demande, FormuleMontantPremiereTranche.getCode());
    Quantite montantTranche1 = montant1.getMontantBrut();
    ElementDroit elementDroitMontantTranche1 = OutilElementDroit.creerElementDroit("MONTANT_TRANCHE1", false, null, null, montantTranche1, null);
    
    elementDroitMontantTranche1.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitMontantTranche1);
    
    Quantite montantCrcTranche1 = montant1.getCrc() != null ? montant1.getCrc() : new QuantiteEuro("0");
    ElementDroit elementDroitMontantCrcTranche1 = OutilElementDroit.creerElementDroit("MONTANT_CRC_TRANCHE1", false, null, null, montantCrcTranche1, null);
    
    elementDroitMontantCrcTranche1.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitMontantCrcTranche1);
    
    QuantiteEuro capitalTranche1 = DeterminationConstituantsSupplementaires.determinerCapitalTranche(demande, montantTranche1, "DUREE_TRANCHE1");
    
    ElementDroit elementDroitCapitalTranche1 = OutilElementDroit.creerElementDroit("CAPITAL_TRANCHE1", false, null, null, capitalTranche1, null);
    
    elementDroitCapitalTranche1.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitCapitalTranche1);
  }
  
  protected MontantBaseSpec determinerMontantTranche(Demande demande, String codeFormule)
    throws CoucheLogiqueException
  {
    return DeterminationConstituantsSupplementaires.determinerMontantTranche(demande, codeFormule);
  }
  
  protected void constituerConstituantsTranche2(Demande demande, Admission admission)
    throws ApplicativeException
  {
    MontantBaseSpec montant2 = determinerMontantTranche(demande, FormuleMontantSecondeTranche.getCode());
    Quantite montantTranche2 = montant2.getMontantBrut();
    ElementDroit elementDroitMontantTranche2 = OutilElementDroit.creerElementDroit("MONTANT_TRANCHE2", false, null, null, montantTranche2, null);
    
    elementDroitMontantTranche2.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitMontantTranche2);
    
    Quantite montantCrcTranche2 = montant2.getCrc() != null ? montant2.getCrc() : new QuantiteEuro("0");
    ElementDroit elementDroitMontantCrcTranche2 = OutilElementDroit.creerElementDroit("MONTANT_CRC_TRANCHE2", false, null, null, montantCrcTranche2, null);
    
    elementDroitMontantCrcTranche2.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitMontantCrcTranche2);
    
    QuantiteEuro capitalTranche2 = DeterminationConstituantsSupplementaires.determinerCapitalTranche(demande, montantTranche2, "DUREE_TRANCHE2");
    
    ElementDroit elementDroitCapitalTranche2 = OutilElementDroit.creerElementDroit("CAPITAL_TRANCHE2", false, null, null, capitalTranche2, null);
    
    elementDroitCapitalTranche2.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitCapitalTranche2);
  }
  
  protected void constituerConstituantsTranche3(Demande demande, Admission admission)
    throws ApplicativeException
  {
    MontantBaseSpec montant3 = determinerMontantTranche(demande, FormuleMontantTroisiemeTranche.getCode());
    Quantite montantTranche3 = montant3.getMontantBrut();
    ElementDroit elementDroitMontantTranche3 = OutilElementDroit.creerElementDroit("MONTANT_TRANCHE3", false, null, null, montantTranche3, null);
    
    elementDroitMontantTranche3.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitMontantTranche3);
    
    Quantite montantCrcTranche3 = montant3.getCrc() != null ? montant3.getCrc() : new QuantiteEuro("0");
    ElementDroit elementDroitMontantCrcTranche3 = OutilElementDroit.creerElementDroit("MONTANT_CRC_TRANCHE3", false, null, null, montantCrcTranche3, null);
    
    elementDroitMontantCrcTranche3.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitMontantCrcTranche3);
    
    QuantiteEuro capitalTranche3 = DeterminationConstituantsSupplementaires.determinerCapitalTranche(demande, montantTranche3, "DUREE_TRANCHE3");
    
    ElementDroit elementDroitCapitalTranche3 = OutilElementDroit.creerElementDroit("CAPITAL_TRANCHE3", false, null, null, capitalTranche3, null);
    
    elementDroitCapitalTranche3.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitCapitalTranche3);
  }
  
  protected void constituerConstituantsCompetenceAdministrative(Admission admission)
    throws ApplicativeException
  {
    String competenceAdministrative = DeterminationConstituantsSupplementaires.determinerCompetenceAdministrative();
    ElementDroit elementDroitCompetenceAdministrative = OutilElementDroit.creerElementDroit("COMPETENCE_ADMINISTRATIVE", false, null, null, null, competenceAdministrative);
    
    elementDroitCompetenceAdministrative.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitCompetenceAdministrative);
  }
  
  protected void constituerConstituantsCompetenceFinanciere(Demande demande, Admission admission)
    throws ApplicativeException
  {
    String competenceFinanciere = DeterminationConstituantsSupplementaires.determinerCompetenceFinanciere(demande);
    ElementDroit elementDroitCompetenceFinanciere = OutilElementDroit.creerElementDroit("COMPETENCE_FINANCIERE", false, null, null, null, competenceFinanciere);
    
    elementDroitCompetenceFinanciere.setTypeElement("3");
    admission.ajouterElementsDroits(elementDroitCompetenceFinanciere);
  }
  
  protected void constituerConstituantsConventionGestion(Demande demande, Admission admission)
    throws ApplicativeException
  {
    ConventionGestionSpec conventionGestion = DeterminationConstituantsSupplementaires.determinerConventionGestion(demande);
    if (conventionGestion != null)
    {
      if (conventionGestion.getApplicationAides() != null)
      {
        ElementDroit elementDroitApplicationAides = OutilElementDroit.creerElementDroit("APPLICATION_DES_AIDES", false, null, null, null, conventionGestion.getApplicationAides());
        
        elementDroitApplicationAides.setTypeElement("3");
        admission.ajouterElementsDroits(elementDroitApplicationAides);
      }
      ElementDroit elementDroitEstAideAdr = OutilElementDroit.creerElementDroit("EST_AIDE_ADR", conventionGestion.isEstAideAdr(), null, null, null, null);
      
      elementDroitEstAideAdr.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitEstAideAdr);
      
      ElementDroit elementDroitEstAideAllocationDeces = OutilElementDroit.creerElementDroit("EST_AIDE_ALLOCATION_DECES", conventionGestion.isEstAideAllocationDeces(), null, null, null, null);
      
      elementDroitEstAideAllocationDeces.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitEstAideAllocationDeces);
      
      ElementDroit elementDroitEstAideArce = OutilElementDroit.creerElementDroit("EST_AIDE_ARCE", conventionGestion.isEstAideArce(), null, null, null, null);
      
      elementDroitEstAideArce.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitEstAideArce);
      
      ElementDroit elementDroitEstAideCongeNonPaye = OutilElementDroit.creerElementDroit("EST_AIDE_CONGE_NON_PAYE", conventionGestion.isEstAideCongeNonPaye(), null, null, null, null);
      
      elementDroitEstAideCongeNonPaye.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitEstAideCongeNonPaye);
      
      ElementDroit elementDroitEstAideFinDroit = OutilElementDroit.creerElementDroit("EST_AIDE_FIN_DROIT", conventionGestion.isEstAideFinDroit(), null, null, null, null);
      
      elementDroitEstAideFinDroit.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitEstAideFinDroit);
      
      ElementDroit elementDroitPrecompteCrc = OutilElementDroit.creerElementDroit("PRECOMPTE_CRC", conventionGestion.estPrecompteCRC(), null, null, null, null);
      
      elementDroitPrecompteCrc.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitPrecompteCrc);
      if (conventionGestion.getSignataire() != null)
      {
        ElementDroit elementDroitSignataireConvention = OutilElementDroit.creerElementDroit("SIGNATAIRE_CONVENTION", false, null, null, null, conventionGestion.getSignataire());
        
        elementDroitSignataireConvention.setTypeElement("3");
        admission.ajouterElementsDroits(elementDroitSignataireConvention);
      }
      ElementDroit elementDroitDebutValiditeConvention = OutilElementDroit.creerElementDroit("DEBUT_VALIDITE_CG", false, conventionGestion.getDebutValidite(), null, null, null);
      
      elementDroitDebutValiditeConvention.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitDebutValiditeConvention);
      if (conventionGestion.getFinValidite() != null)
      {
        ElementDroit elementDroitFinValiditeConvention = OutilElementDroit.creerElementDroit("FIN_VALIDITE_CG", false, conventionGestion.getFinValidite(), null, null, null);
        
        elementDroitFinValiditeConvention.setTypeElement("3");
        admission.ajouterElementsDroits(elementDroitFinValiditeConvention);
      }
      ElementDroit elementDroitIdExterneObligatoire = OutilElementDroit.creerElementDroit("EST_ID_EXTERNE_OBLIGATOIRE", conventionGestion.estIdExterneObligatoire(), null, null, null, null);
      
      elementDroitIdExterneObligatoire.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitIdExterneObligatoire);
      if (conventionGestion.getLibelleAffectation() != null)
      {
        String libelleConvention = conventionGestion.getLibelleAffectation();
        int taille = libelleConvention.length();
        if (taille > 50) {
          taille = 50;
        }
        String libelleConventionTronque = libelleConvention.substring(0, taille);
        ElementDroit elementDroitLibelleAffectation = OutilElementDroit.creerElementDroit("LIBELLE_AFFECTATION", false, null, null, null, libelleConventionTronque);
        
        elementDroitLibelleAffectation.setTypeElement("3");
        admission.ajouterElementsDroits(elementDroitLibelleAffectation);
      }
    }
  }
  
  protected void constituerConstituantsConventionUnedic(Demande demande, Admission admission)
    throws ApplicativeException
  {
    String numeroConventionUnedic = OutilCalculDonneesNonPersistantes.trouverNumeroConventionUnedic(demande);
    if ((numeroConventionUnedic != null) && (!"".equals(numeroConventionUnedic)))
    {
      ConventionGestionSpec conventionGestion = new ConventionGestion(numeroConventionUnedic, null, false, false, false, false, false, "1", false, null, null, null, false);
      
      boolean precompteCrc = true;
      if (OutilConventionGestion.estTypeConventionGestionEtSignataireUnedic("555", true, conventionGestion)) {
        precompteCrc = false;
      }
      ElementDroit elementDroitPrecompteCrc = OutilElementDroit.creerElementDroit("PRECOMPTE_CRC", precompteCrc, null, null, null, null);
      
      elementDroitPrecompteCrc.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitPrecompteCrc);
      
      ElementDroit elementDroitSignataireConvention = OutilElementDroit.creerElementDroit("SIGNATAIRE_CONVENTION", false, null, null, null, "1");
      
      elementDroitSignataireConvention.setTypeElement("3");
      admission.ajouterElementsDroits(elementDroitSignataireConvention);
    }
  }
  
  protected Demande getDemande(Contexte contexte)
  {
    return (Demande)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
  }
}

/* Location:
 * Qualified Name:     ConstitutionConstituantsSupplementaires
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */