package fr.unedic.cali.asu.may17.p02.liquidation.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.produits.liquidation.dom.ElementChomageSansRupture;
import fr.unedic.cali.asu.produits.liquidation.dom.Od;
import fr.unedic.cali.asu.produits.liquidation.dom.pc.ConstitutionElementsAdmissionPC;
import fr.unedic.cali.calcul.dom.CalendrierExecutionAvant;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.QuantiteDroitSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAriSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.ApplicativeRuntimeException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class AttributionAssuranceMayotte
  extends Od
{
  private static final long serialVersionUID = 5506223664106331550L;
  protected transient Admission m_admissionMayotte = null;
  
  public AttributionAssuranceMayotte(Admission p_admissionMayotte)
  {
    m_admissionMayotte = p_admissionMayotte;
  }
  
  public Admission getAdmission()
  {
    return m_admissionMayotte;
  }
  
  public Collection getListeCarences()
  {
    try
    {
      return m_admissionMayotte.getListeCarences();
    }
    catch (Exception e) {}
    return new ArrayList();
  }
  
  public String getNomReglementApplicable()
  {
    return "RG";
  }
  
  public boolean isTopContratsRemuneresBaseSmic()
  {
    try
    {
      return m_admissionMayotte.isTopContratsRemuneresBaseSmic();
    }
    catch (Exception e) {}
    return false;
  }
  
  public Chronologie getListeActiviteConservee()
  {
    return new ChronologiePeriodes();
  }
  
  public Damj getDateFaitGenerateur()
  {
    try
    {
      return m_admissionMayotte.getDateFaitGenerateur();
    }
    catch (Exception e) {}
    return null;
  }
  
  public BigDecimal getSeuilMensuelPansConservees()
  {
    try
    {
      return m_admissionMayotte.getRevenuMensuelANSConservee();
    }
    catch (Exception e) {}
    return null;
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    try
    {
      return m_admissionMayotte.getElementBaseIndemnisation();
    }
    catch (Exception e) {}
    return null;
  }
  
  public ElementChomageSansRupture getElementChomageSansRupture()
  {
    return null;
  }
  
  public Damj getDateAttribution()
  {
    return m_admissionMayotte.getDateAttribution();
  }
  
  public IndividuSpec getDemandeur()
  {
    return m_admissionMayotte.getDemandeur();
  }
  
  public ReglementApplicableSpec getReglementApplicable()
  {
    ConstitutionReglementApplicable constitutionReglementApplicable = new ConstitutionReglementApplicable(new ConstitutionElementsAdmissionPC());
    constitutionReglementApplicable.setReglement(Reglement.getInstance(getNomReglementApplicable(), m_admissionMayotte.getProduit()));
    return constitutionReglementApplicable;
  }
  
  public ProduitSpec getProduit()
  {
    return m_admissionMayotte.getProduit();
  }
  
  public ProduitSpec getProduitExecution()
  {
    return getProduit();
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    return ProduitAsuCge01P05.getInstance();
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    Quantite dureeTotale = new QuantiteJour("0");
    try
    {
      List listeDurees = m_admissionMayotte.getListeDurees();
      
      QuantiteDroitSpec duree = null;
      if (listeDurees != null)
      {
        Iterator iterator = listeDurees.iterator();
        while (iterator.hasNext())
        {
          duree = (QuantiteDroitSpec)iterator.next();
          dureeTotale = dureeTotale.ajouter(duree.getQuantiteInitial());
        }
      }
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
    return dureeTotale;
  }
  
  public Quantite getDureeTheorique()
  {
    return getDureeIndemnisationInitiale();
  }
  
  public Quantite getDureeInitiale()
  {
    return getDureeIndemnisationInitiale();
  }
  
  public List getListeDurees()
  {
    try
    {
      return m_admissionMayotte.getListeDurees();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public Quantite getDureeProlongationTheorique()
  {
    return null;
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    Quantite dureeTotale = new QuantiteJour("0");
    try
    {
      List listeDurees = m_admissionMayotte.getListeDurees();
      
      QuantiteDroitSpec duree = null;
      if (listeDurees != null)
      {
        Iterator iterator = listeDurees.iterator();
        while (iterator.hasNext())
        {
          duree = (QuantiteDroitSpec)iterator.next();
          dureeTotale = dureeTotale.ajouter(duree.getQuantiteInitial());
        }
      }
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
    return dureeTotale;
  }
  
  public boolean estEnReexamen()
  {
    return m_admissionMayotte.estEnReexamen();
  }
  
  public DemandeSpec getDemande()
  {
    return m_admissionMayotte.getDemande();
  }
  
  public void setCalendrierExecutionAvant(CalendrierExecutionAvant p_calendrierExecutionAvant)
  {
    m_admissionMayotte.setCalendrierExecutionAvant(p_calendrierExecutionAvant);
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    try
    {
      return m_admissionMayotte.getDateFaitGenerateur();
    }
    catch (CoucheLogiqueException ex) {}
    return null;
  }
  
  public String getRsod()
  {
    return m_admissionMayotte.getRsod();
  }
  
  public Damj getPji()
  {
    if (m_admissionMayotte.getPjiEffectif() != null) {
      return m_admissionMayotte.getPjiEffectif();
    }
    return m_admissionMayotte.getPji();
  }
  
  public String getSituationParticuliere()
  {
    return "";
  }
  
  public FormuleMontantSpec getFormuleMontant(String p_code)
  {
    return ((ProduitAriSpec)getProduit()).getFormuleMontant(p_code);
  }
  
  public boolean estDemandeSuiteFinDeDroit()
  {
    return false;
  }
  
  public Sjc getSJC()
  {
    try
    {
      return m_admissionMayotte.getElementBaseIndemnisation().getSjc();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public BigDecimal getSJCInitial()
  {
    try
    {
      return m_admissionMayotte.getSJCInitial();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public BigDecimal getRevenuMensuelANSConservee()
  {
    try
    {
      return m_admissionMayotte.getRevenuMensuelANSConservee();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public Damj getTermePrcActiviteConservee()
  {
    try
    {
      return m_admissionMayotte.getTermePRC();
    }
    catch (CoucheLogiqueException ex) {}
    return null;
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    try
    {
      return m_admissionMayotte.getConventionGestion();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public int getCompetenceAdministrative()
  {
    try
    {
      return m_admissionMayotte.getCompetenceAdministrative();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public int getCompetenceFinanciere()
  {
    try
    {
      return m_admissionMayotte.getCompetenceFinanciere();
    }
    catch (CoucheLogiqueException ex)
    {
      throw new ApplicativeRuntimeException(ex.getCode());
    }
  }
  
  public CalendrierExecutionCalculSpec getCalendrierExecutionCalcul()
  {
    return m_admissionMayotte.getCalendrierExecutionCalcul();
  }
  
  public AttributionAssuranceSpec getAttributionPrecedente()
  {
    return null;
  }
  
  public GammeSpec getGamme()
  {
    return GammeAsu.getInstance();
  }
}

/* Location:
 * Qualified Name:     AttributionAssuranceMayotte
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */