package fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.DonneesForcees;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Hashtable;

public class CREM
{
  public static Hashtable recupererDonneesImposees(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Hashtable listeDonneesImposees = getElementsDonneesImposeesVides();
    
    Demande demandeAri = (Demande)demande;
    DonneesForcees donneesForcees = demandeAri.getDonneesForcees();
    String[] nomEltRecherche = null;
    if (donneesForcees != null)
    {
      Collection listeEltDroit = donneesForcees.getCopieCollectionElementsDroitType("6");
      if ((listeEltDroit != null) && (!listeEltDroit.isEmpty()))
      {
        alimenterListeDonneesImposeesDates(listeDonneesImposees, listeEltDroit);
        
        alimenterListeDonneesImposeesMontant(listeDonneesImposees, listeEltDroit);
        
        nomEltRecherche = new String[] { "COEFFICIENT_TEMPS_PARTIEL" };
        ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
        {
          String coefTP = Mathematiques.arrondiASup(eltDroit.getQuantiteGenerique().getValeur(), 2).toString();
          listeDonneesImposees.put("Coefficient temps partiel", coefTP);
        }
        alimenterListeDonneesImposeesTranches(listeDonneesImposees, listeEltDroit);
        
        alimenterListeDonneesImposeesDiffere(listeDonneesImposees, listeEltDroit);
        
        nomEltRecherche = new String[] { "TOP_SR_POURCENTAGE_SMIG" };
        eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
        if (eltDroit != null)
        {
          String topSr = String.valueOf(eltDroit.isBooleenGenerique());
          listeDonneesImposees.put("SR calcule sur base SMIC", topSr);
        }
        alimenterListeDonneesImposeesConvention(listeDonneesImposees, listeEltDroit);
        
        alimenterListeDonneesImposeesAREM2016(listeDonneesImposees, listeEltDroit);
      }
    }
    return listeDonneesImposees;
  }
  
  private static void alimenterListeDonneesImposeesDates(Hashtable listeDonneesImposees, Collection listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = null;
    
    nomEltRecherche = new String[] { "DATE_FAIT_GENERATEUR" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getDate1Generique() != null)) {
      listeDonneesImposees.put("FGD", eltDroit.getDate1Generique().toString());
    }
    nomEltRecherche = new String[] { "TERME_PRC" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getDate1Generique() != null)) {
      listeDonneesImposees.put("Terme de la PRC", eltDroit.getDate1Generique().toString());
    }
    nomEltRecherche = new String[] { "DATE_FIN_PMC" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getDate1Generique() != null)) {
      listeDonneesImposees.put("Fin PMC", eltDroit.getDate1Generique().toString());
    }
  }
  
  private static void alimenterListeDonneesImposeesConvention(Hashtable listeDonneesImposees, Collection listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = null;
    
    nomEltRecherche = new String[] { "NUMERO_CONVENTION_GESTION_PE" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroit != null) {
      listeDonneesImposees.put("Etablissement financeur", eltDroit.getStringGenerique());
    }
    nomEltRecherche = new String[] { "CODE_AFFECTATION" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroit != null) {
      listeDonneesImposees.put("Code affectation", eltDroit.getStringGenerique());
    }
    nomEltRecherche = new String[] { "NUMERO_CONVENTION_UNEDIC" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroit != null) {
      listeDonneesImposees.put("Convention de gestion Unedic", eltDroit.getStringGenerique());
    }
  }
  
  private static void alimenterListeDonneesImposeesMontant(Hashtable listeDonneesImposees, Collection listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = null;
    
    nomEltRecherche = new String[] { "SJR_INITIAL" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String sjr = Mathematiques.arrondiASup(eltDroit.getQuantiteGenerique().getValeur(), 2).toString();
      listeDonneesImposees.put("SJR", sjr);
    }
    nomEltRecherche = new String[] { "SJC_INITIAL" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String sjc = Mathematiques.arrondiASup(eltDroit.getQuantiteGenerique().getValeur(), 2).toString();
      listeDonneesImposees.put("SJC", sjc);
    }
    nomEltRecherche = new String[] { "REVENU_MENSUEL_ANS_CONSERVEE" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String revenu = Mathematiques.arrondiASup(eltDroit.getQuantiteGenerique().getValeur(), 2).toString();
      listeDonneesImposees.put("Revenu ANS conservee", revenu);
    }
  }
  
  private static void alimenterListeDonneesImposeesAREM2016(Hashtable listeDonneesImposees, Collection listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = null;
    
    nomEltRecherche = new String[] { "CONVENTION_AREM" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroit != null) {
      listeDonneesImposees.put("Convention Mayotte", eltDroit.getStringGenerique());
    }
    nomEltRecherche = new String[] { "PRESENCE_AC" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroit != null)
    {
      String topPresenceAc = String.valueOf(eltDroit.isBooleenGenerique());
      listeDonneesImposees.put("Presence activite conservee", topPresenceAc);
    }
    nomEltRecherche = new String[] { "MOTIF_REJET" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroit != null) {
      listeDonneesImposees.put("Motif Rejet", eltDroit.getStringGenerique());
    }
  }
  
  private static void alimenterListeDonneesImposeesDiffere(Hashtable listeDonneesImposees, Collection listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = null;
    
    nomEltRecherche = new String[] { "NB_JOURS_ICCP" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String iccp = eltDroit.getQuantiteGenerique().getValeur().toString();
      listeDonneesImposees.put("Differe ISLR", iccp);
    }
    nomEltRecherche = new String[] { "NB_JOURS_ISLR" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String islr = eltDroit.getQuantiteGenerique().getValeur().toString();
      listeDonneesImposees.put("Differe ISLR", islr);
    }
    nomEltRecherche = new String[] { "NB_JOURS_DELAI_ATTENTE" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String delai = eltDroit.getQuantiteGenerique().getValeur().toString();
      listeDonneesImposees.put("Delai attente", delai);
    }
    nomEltRecherche = new String[] { "POINT_DEPART_DELAIS_REPORT" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getDate1Generique() != null)) {
      listeDonneesImposees.put("Point depart delais reports", eltDroit.getDate1Generique().toString());
    }
  }
  
  private static void alimenterListeDonneesImposeesTranches(Hashtable listeDonneesImposees, Collection listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = null;
    
    nomEltRecherche = new String[] { "DUREE_TRANCHE1" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String duree = eltDroit.getQuantiteGenerique().getValeur().toString();
      listeDonneesImposees.put("Duree 1ere tranche", duree);
    }
    nomEltRecherche = new String[] { "DUREE_TRANCHE2" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String duree = eltDroit.getQuantiteGenerique().getValeur().toString();
      listeDonneesImposees.put("Duree 2eme tranche", duree);
    }
    nomEltRecherche = new String[] { "DUREE_TRANCHE3" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null))
    {
      String duree = eltDroit.getQuantiteGenerique().getValeur().toString();
      listeDonneesImposees.put("Duree 3eme tranche", duree);
    }
  }
  
  public static Hashtable getElementsDonneesImposeesVides()
  {
    Hashtable listeDonneesImposees = new Hashtable();
    
    listeDonneesImposees.put("Type demande", "");
    listeDonneesImposees.put("Premier jour indemnisable", "");
    listeDonneesImposees.put("Montant journalier", "");
    listeDonneesImposees.put("Dernier jour indemnisable", "");
    listeDonneesImposees.put("Debut prestation possible", "");
    listeDonneesImposees.put("Nombre de jours de reliquat", "");
    listeDonneesImposees.put("Nb jour indem. semaine", "");
    listeDonneesImposees.put("Nb jour indem. mois", "");
    listeDonneesImposees.put("Date chang. taux conversion", "");
    listeDonneesImposees.put("Salaire journalier de ref", "");
    listeDonneesImposees.put("FGD", "");
    listeDonneesImposees.put("SJR", "");
    listeDonneesImposees.put("SJC", "");
    listeDonneesImposees.put("Coefficient temps partiel", "");
    listeDonneesImposees.put("Terme de la PRC", "");
    listeDonneesImposees.put("Revenu ANS conservee", "");
    listeDonneesImposees.put("Duree 1ere tranche", "");
    listeDonneesImposees.put("Duree 2eme tranche", "");
    listeDonneesImposees.put("Duree 3eme tranche", "");
    listeDonneesImposees.put("Point depart delais reports", "");
    listeDonneesImposees.put("Fin PMC", "");
    listeDonneesImposees.put("Differe ISLR", "");
    listeDonneesImposees.put("Differe ISLR", "");
    listeDonneesImposees.put("Delai attente", "");
    listeDonneesImposees.put("SR calcule sur base SMIC", "");
    listeDonneesImposees.put("Etablissement financeur", "");
    listeDonneesImposees.put("Code affectation", "");
    listeDonneesImposees.put("Convention de gestion Unedic", "");
    listeDonneesImposees.put("Libelle aide", "");
    listeDonneesImposees.put("Montant aide", "");
    listeDonneesImposees.put("Famille aide", "");
    listeDonneesImposees.put("Date d attribution", "");
    listeDonneesImposees.put("Type aide", "");
    listeDonneesImposees.put("Date d attribution", "");
    listeDonneesImposees.put("Presence activite conservee", "");
    listeDonneesImposees.put("Convention Mayotte", "");
    listeDonneesImposees.put("Motif Rejet", "");
    
    return listeDonneesImposees;
  }
}

/* Location:
 * Qualified Name:     CREM
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */