package fr.unedic.cali.asu.may17.p02.liquidation.outilsfonctionnels;

import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.DonneesForcees;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilElementDroit;
import fr.unedic.cali.dom.ConteneurConventionGestion;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuMay17P02;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilConventionGestion;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;

public final class VerificationDonneesForcees
  implements OutilFonctionnel
{
  private static final BigDecimal DUREE_TRANCHE1 = BigDecimal.valueOf(91L);
  private static final BigDecimal DUREE_TRANCHE2_MOINS50 = BigDecimal.valueOf(274L);
  private static final BigDecimal DUREE_TRANCHE2_50 = BigDecimal.valueOf(639L);
  private static final BigDecimal DUREE_ISLR_2012 = BigDecimal.valueOf(75L);
  private static final BigDecimal DUREE_ISLR_2016 = BigDecimal.valueOf(180L);
  private static final BigDecimal DUREE_DELAI_ATTENTE = BigDecimal.valueOf(7L);
  private static final DureeCalendaire AGE_SEUIL = new DureeCalendaire(50);
  private static final String CHAINE_VIDE = "";
  
  public static void verifierDonneesForcees(DemandeSpec pDemande)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)pDemande;
    DonneesForcees donneesForcees = demande.getDonneesForcees();
    if (donneesForcees != null)
    {
      Collection<ElementDroit> listeEltDroit = donneesForcees.getCopieCollectionElementsDroitType("6");
      if ((listeEltDroit != null) && (!listeEltDroit.isEmpty()))
      {
        controleChampsObligatoires(listeEltDroit);
        
        controleDateExamen(listeEltDroit, pDemande);
        
        controleFaitGenerateur(listeEltDroit);
        
        controleDateFgdAREM2016(listeEltDroit);
        
        controleTermePRC(listeEltDroit);
        
        controleCoefficientTP(listeEltDroit);
        
        controleDureeTranches(listeEltDroit, pDemande);
        
        controleDelaisReports(listeEltDroit);
        
        controleConventionGestion(listeEltDroit, pDemande);
        
        controleMotifRejetAREM2016(listeEltDroit);
      }
    }
  }
  
  private static void controleDateFgdAREM2016(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    if (estMayotte2016(listeEltDroit))
    {
      String[] nomEltFGD = { "DATE_FAIT_GENERATEUR" };
      ElementDroit eltDroitFGD = OutilElementDroit.rechercherElement(listeEltDroit, nomEltFGD);
      Damj dateArem2016 = GestionnaireDateApplication.getInstance().recupererDateApplication("Application des règles métropole pour Mayotte");
      if ((!estDateNulle(eltDroitFGD)) && (eltDroitFGD.getDate1Generique().estAvant(dateArem2016))) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ARI_PR_CALI_L_ERR_COHERENCE_FGD_AREM2016");
      }
    }
  }
  
  private static void controleMotifRejetAREM2016(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    if (estMayotte2016(listeEltDroit))
    {
      String[] nomEltMotifRejet = { "MOTIF_REJET" };
      ElementDroit eltDroitMotifRejet = OutilElementDroit.rechercherElement(listeEltDroit, nomEltMotifRejet);
      if ((eltDroitMotifRejet != null) && (eltDroitMotifRejet.getStringGenerique() != null)) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_CALI_L_ERR_REJET_MAYOTTE_SO", 1);
      }
    }
  }
  
  private static boolean estMayotte2016(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    
    String[] nomEltRecherche = { "CONVENTION_AREM" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit != null) && (eltDroit.getStringGenerique() != null))
    {
      String typeConvention = eltDroit.getStringGenerique();
      if ("1".equals(typeConvention)) {
        retour = true;
      }
    }
    return retour;
  }
  
  private static void controleChampsObligatoires(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "TYPE_DEMANDE" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getStringGenerique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_TYPE_DEMANDE", 1);
    }
    controlerDatesObligatoires(listeEltDroit);
    
    nomEltRecherche = new String[] { "SJR_INITIAL" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getQuantiteGenerique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_SJR_INITIAL", 1);
    }
    nomEltRecherche = new String[] { "TERME_PRC" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getDate1Generique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AATC_TERME_PRC_NON_RENSEIGNE", 1);
    }
    nomEltRecherche = new String[] { "COEFFICIENT_TEMPS_PARTIEL" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getQuantiteGenerique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_COEFF_TP", 1);
    }
  }
  
  private static void controlerDatesObligatoires(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_EXAMEN" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getDate1Generique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_DATE_EXAMEN", 1);
    }
    nomEltRecherche = new String[] { "DATE_FAIT_GENERATEUR" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((eltDroit == null) || (eltDroit.getDate1Generique() == null)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DATE_FAIT_GENERATEUR", 1);
    }
  }
  
  private static void controleDateExamen(Collection<ElementDroit> listeEltDroit, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_EXAMEN" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    Damj dateExamen = eltDroit.getDate1Generique();
    if (!OutillagePEC.estContenueDansUnePecIndemnisable(demande.getDemandeur(), dateExamen)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_ARI_DATE_EXAMEN_HORS_PEC", 1);
    }
    if ((dateExamen != null) && (dateExamen.estAvant(ProduitAsuMay17P02.getInstance().getPeriodeValidite().getDebut()))) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DATE_EXAMEN_APRES_311212", 1);
    }
  }
  
  private static void controleFaitGenerateur(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_FAIT_GENERATEUR" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    Damj dateFGD = eltDroit.getDate1Generique();
    
    nomEltRecherche = new String[] { "DATE_EXAMEN" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    Damj dateExamen = eltDroit.getDate1Generique();
    if ((dateFGD != null) && (dateExamen != null) && (!dateFGD.estAvant(dateExamen))) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DATE_FGD_AVANT_DATE_EXAMEN", 1);
    }
  }
  
  private static void controleTermePRC(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "TERME_PRC" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    Damj termePRC = eltDroit.getDate1Generique();
    
    nomEltRecherche = new String[] { "DATE_FAIT_GENERATEUR" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    Damj dateFGD = eltDroit.getDate1Generique();
    if ((termePRC != null) && (dateFGD != null) && (termePRC.estApres(dateFGD))) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_TERME_PRC_AVANT_FGD", 1);
    }
  }
  
  private static void controleCoefficientTP(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "COEFFICIENT_TEMPS_PARTIEL" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    BigDecimal coeffTP = eltDroit.getQuantiteGenerique().getValeur();
    if ((coeffTP.compareTo(BigDecimal.ZERO) < 0) || (coeffTP.compareTo(BigDecimal.ZERO) == 0) || (coeffTP.compareTo(BigDecimal.ONE) > 0)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_COEFF_TP_ENTRE_0_ET_1", 1);
    }
  }
  
  private static void controleDureeTranches(Collection<ElementDroit> listeEltDroit, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DUREE_TRANCHE1" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    BigDecimal dureeTranche1 = BigDecimal.ZERO;
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      dureeTranche1 = eltDroit.getQuantiteGenerique().getValeur();
    }
    if ((dureeTranche1 != null) && (dureeTranche1.compareTo(DUREE_TRANCHE1) > 0)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DUREE_TRANCHE1", 1);
    }
    nomEltRecherche = new String[] { "DUREE_TRANCHE2" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    BigDecimal dureeTranche2 = BigDecimal.ZERO;
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      dureeTranche2 = eltDroit.getQuantiteGenerique().getValeur();
    }
    nomEltRecherche = new String[] { "DUREE_TRANCHE3" };
    eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    BigDecimal dureeTranche3 = BigDecimal.ZERO;
    if ((eltDroit != null) && (eltDroit.getQuantiteGenerique() != null)) {
      dureeTranche3 = eltDroit.getQuantiteGenerique().getValeur();
    }
    controlerSommeTranche(dureeTranche1, dureeTranche2, dureeTranche3);
    if (estMayotte2016(listeEltDroit)) {
      controlerTranche2Arem2016(listeEltDroit, demande, dureeTranche2);
    }
  }
  
  private static void controlerTranche2Arem2016(Collection<ElementDroit> listeEltDroit, DemandeSpec demande, BigDecimal dureeTranche2)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "DATE_FAIT_GENERATEUR" };
    ElementDroit eltDroit = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    Damj dateFGD = eltDroit.getDate1Generique();
    
    DureeCalendaire age = demande.getDemandeur().getAgeALaDate(dateFGD);
    if (age.compareTo(AGE_SEUIL) < 0)
    {
      if (dureeTranche2.compareTo(DUREE_TRANCHE2_MOINS50) > 0) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ARI_PR_CALI_L_ERR_TRANCHE2_MAYOTTE");
      }
    }
    else if (dureeTranche2.compareTo(DUREE_TRANCHE2_50) > 0) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ARI_PR_CALI_L_ERR_TRANCHE2_MAYOTTE");
    }
  }
  
  private static void controlerSommeTranche(BigDecimal dureeTranche1, BigDecimal dureeTranche2, BigDecimal dureeTranche3)
    throws CoucheLogiqueException
  {
    BigDecimal sommeTranches = BigDecimal.ZERO;
    if (dureeTranche1 != null) {
      sommeTranches = sommeTranches.add(dureeTranche1);
    }
    if (dureeTranche2 != null) {
      sommeTranches = sommeTranches.add(dureeTranche2);
    }
    if (dureeTranche3 != null) {
      sommeTranches = sommeTranches.add(dureeTranche3);
    }
    if (sommeTranches.compareTo(BigDecimal.ZERO) == 0) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_SOMME_DUREE_TRANCHES", 1);
    }
  }
  
  private static void controleDelaisReports(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "NB_JOURS_ISLR" };
    ElementDroit eltDroitIslr = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "NB_JOURS_DELAI_ATTENTE" };
    ElementDroit eltDroitDelaiAttente = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    controlerDatesDelaisReports(listeEltDroit);
    if (estMayotte2016(listeEltDroit))
    {
      if ((!estQuantiteNulle(eltDroitIslr)) && (eltDroitIslr.getQuantiteGenerique().getValeur().compareTo(DUREE_ISLR_2016) == 1)) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DUREE_DIFFERE_ISLR_2016", 1);
      }
    }
    else if ((!estQuantiteNulle(eltDroitIslr)) && (eltDroitIslr.getQuantiteGenerique().getValeur().compareTo(DUREE_ISLR_2012) == 1)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DUREE_DIFFERE_ISLR_2012", 1);
    }
    if ((!estQuantiteNulle(eltDroitDelaiAttente)) && (eltDroitDelaiAttente.getQuantiteGenerique().getValeur().compareTo(DUREE_DELAI_ATTENTE) == 1)) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DUREE_DIFFERE_DELAI_ATTENTE", 1);
    }
  }
  
  private static void controlerDatesDelaisReports(Collection<ElementDroit> listeEltDroit)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "POINT_DEPART_DELAIS_REPORT" };
    ElementDroit eltDroitPointDepart = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    boolean estMayotte2016 = estMayotte2016(listeEltDroit);
    
    nomEltRecherche = new String[] { "DATE_FAIT_GENERATEUR" };
    ElementDroit eltDroitFGD = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "DATE_FIN_PMC" };
    ElementDroit eltDroitFinPMC = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "NB_JOURS_ICCP" };
    ElementDroit eltDroitIccp = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "NB_JOURS_ISLR" };
    ElementDroit eltDroitIslr = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "NB_JOURS_DELAI_ATTENTE" };
    ElementDroit eltDroitDelaiAttente = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if (eltDroitPointDepart != null)
    {
      Damj pointDepart = eltDroitPointDepart.getDate1Generique();
      if (pointDepart != null)
      {
        controlerCoherencesDatesDelaisReports(eltDroitFGD, eltDroitFinPMC, pointDepart, estMayotte2016);
        if ((estQuantiteNulle(eltDroitIccp)) && (estQuantiteNulle(eltDroitIslr)) && (estQuantiteNulle(eltDroitDelaiAttente))) {
          fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DELAIS_REPORTS_NON_RENSEIGNE", 1);
        }
      }
    }
    else if ((eltDroitFinPMC != null) || (eltDroitIccp != null) || (eltDroitIslr != null) || (eltDroitDelaiAttente != null))
    {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DEPART_DL_REPORTS_NON_RENS", 1);
    }
  }
  
  private static void controlerCoherencesDatesDelaisReports(ElementDroit eltDroitFGD, ElementDroit eltDroitFinPMC, Damj pointDepart, boolean estMayotte2016)
    throws CoucheLogiqueException
  {
    if (!estDateNulle(eltDroitFGD)) {
      if (estMayotte2016)
      {
        if (pointDepart.estAvantOuCoincideAvec(eltDroitFGD.getDate1Generique())) {
          fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DEPART_DL_REPORTS_AVANT_FGD", 1);
        }
      }
      else if (pointDepart.estAvant(eltDroitFGD.getDate1Generique())) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_DEPART_DL_REPORTS_AVANT_FGD", 1);
      }
    }
    if ((!estDateNulle(eltDroitFinPMC)) && (eltDroitFinPMC.getDate1Generique().estAvantOuCoincideAvec(pointDepart))) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_FIN_PMC_AVANT_POINT_DEPART", 1);
    }
  }
  
  private static void controleConventionGestion(Collection<ElementDroit> listeEltDroit, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    String[] nomEltRecherche = { "NUMERO_CONVENTION_GESTION_PE" };
    ElementDroit numConventionGestionPe = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "NUMERO_CONVENTION_UNEDIC" };
    ElementDroit numConventionGestionUnedic = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    
    nomEltRecherche = new String[] { "CODE_AFFECTATION" };
    ElementDroit codeAffectation = OutilElementDroit.rechercherElement(listeEltDroit, nomEltRecherche);
    if ((numConventionGestionPe != null) && (numConventionGestionUnedic != null) && (!"".equals(numConventionGestionPe.getStringGenerique())) && (!"".equals(numConventionGestionUnedic.getStringGenerique()))) {
      fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ARI_PR_N_CALI_ERR_AAS_CG_PE_ET_UNEDIC_RENSEIGNES", 1);
    }
    if ((numConventionGestionPe != null) && (codeAffectation != null) && (!"".equals(numConventionGestionPe.getStringGenerique())) && (!"".equals(codeAffectation.getStringGenerique())))
    {
      ConventionGestionSpec convention = OutilConventionGestion.getInstance().trouverConventionGestion(new ConteneurConventionGestion(numConventionGestionPe.getStringGenerique(), codeAffectation.getStringGenerique(), demande.getDateDepot(), demande.getCommentaire()));
      if (convention == null) {
        fr.unedic.cali.ari.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_COHR_CONVENTION_GESTION");
      }
    }
  }
  
  private static boolean estQuantiteNulle(ElementDroit element)
  {
    return (element == null) || (element.getQuantiteGenerique() == null);
  }
  
  private static boolean estDateNulle(ElementDroit element)
  {
    return (element == null) || (element.getDate1Generique() == null);
  }
}

/* Location:
 * Qualified Name:     VerificationDonneesForcees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */