package fr.unedic.cali.asu.may17.p03.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.ari.dom.Demande;
import fr.unedic.cali.ari.dom.ElementDroit;
import fr.unedic.cali.ari.outilsfonctionnels.OutilPiSurElementDroit;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.OutilConstructionDonneesEntreesRecuperationMontant;
import fr.unedic.cali.asu.may17.p02.liquidation.dom.Admission;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.affectation.ProduitAriSpec;
import fr.unedic.cali.dom.conteneurs.DonneesCalculMontant;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.ListIterator;

public class ConstitutionConstituantsSupplementaires
  extends fr.unedic.cali.asu.may17.liquidation.outilsfonctionnels.ConstitutionConstituantsSupplementaires
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = getDemande(contexte);
    Admission admission = (Admission)demande.getDossierExamen();
    
    constituerListePensionInvalidite(demande, admission);
    
    constituerAgeAuFaitGenerateur(demande, admission);
    
    constituerConstituantsTranche1(demande, admission);
    
    constituerConstituantsTranche2(demande, admission);
    
    constituerConstituantsMontants(demande, admission);
    
    constituerConstituantsCompetenceAdministrative(admission);
    
    constituerConstituantsCompetenceFinanciere(demande, admission);
    
    constituerConstituantsConventionGestion(demande, admission);
    
    constituerConstituantsConventionUnedic(demande, admission);
    
    return new Resultat(0);
  }
  
  private void constituerListePensionInvalidite(Demande demande, Admission admission)
    throws CoucheLogiqueException
  {
    supprimerListePI(admission);
    Chronologie listePI = demande.getDemandeur().getChronoPensionsInvaliditeChainees();
    ChronologiePeriodes chronoPensions = new ChronologiePeriodes();
    Collection<PeriodePensionInvaliditeChaineeSpec> listePiDemande = OutilPiSurElementDroit.mapperDonneesForceesVersListePi(demande.getDonneesForcees());
    
    ListIterator it = listePI.iterer();
    while (it.hasNext())
    {
      PeriodePensionInvaliditeChaineeSpec pension = (PeriodePensionInvaliditeChaineeSpec)it.next();
      if (pension.getDateDebut().estAvant(admission.getDateAttribution()))
      {
        PeriodePensionInvaliditeChaineeSpec pensionForcee = OutilPiSurElementDroit.rechercherPensionInvaliditeSurDemande(listePiDemande, pension);
        chronoPensions.ajouter(pension);
        if (pensionForcee != null) {
          pension.setStatut(pensionForcee.getStatut());
        } else {
          pension.setStatut(1);
        }
      }
    }
    ElementDroit listePi = OutilPiSurElementDroit.mapperListePiVersElementDroit(chronoPensions.mapperVersCollection());
    admission.ajouterElementsDroits(listePi);
  }
  
  private void supprimerListePI(Admission admission)
    throws CoucheLogiqueException
  {
    Collection<ElementDroit> elements = admission.getCollectionElementsDroits();
    ElementDroit listePi = OutilPiSurElementDroit.rechercherElement(elements, "LISTE_PI");
    if (listePi != null) {
      admission.supprimerElementsDroits(listePi);
    }
  }
  
  protected MontantBaseSpec determinerMontantTranche(Demande demande, String codeFormule)
    throws CoucheLogiqueException
  {
    Admission admission = (Admission)demande.getDossierExamen();
    ProduitAriSpec produit = (ProduitAriSpec)demande.getDossierAffectation().getProduit();
    MontantBaseSpec montant = null;
    
    OutilConstructionDonneesEntreesRecuperationMontant outil = new OutilConstructionDonneesEntreesRecuperationMontant();
    DonneesEntreesRecuperationMontant donneesEntrees = outil.creerDonneesEntreesRecuperationMontant((ElementBaseIndemnisation)admission.getElementBaseIndemnisation().copie());
    
    donneesEntrees.setDateCalculMontant(admission.getDateAttribution());
    donneesEntrees.getDonneesCalculMontant().setProduit(produit);
    donneesEntrees.setIndividu(demande.getDemandeur());
    donneesEntrees.getDonneesCalculMontant().setFormuleMontant(produit.getFormuleMontant(codeFormule));
    
    donneesEntrees.getDonneesCalculMontant().setListePensionInvalidite(admission.getListePensionsInvalidite());
    donneesEntrees.getDonneesCalculMontant().setEstProduitGerantPensionInvalidite(Boolean.valueOf(true));
    
    montant = DeterminationMontant.determinerMontant(donneesEntrees);
    return montant;
  }
}

/* Location:
 * Qualified Name:     ConstitutionConstituantsSupplementaires
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */