package fr.unedic.cali.asu.migration.graphes;

import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.migration.recalcul.RecalculerCapitalDroitCourant;
import fr.unedic.cali.asu.migration.recalcul.RecalculerCapitalDroitPrecedent;
import fr.unedic.cali.asu.migration.recalcul.RecalculerConstituantsProduitResultant;
import fr.unedic.cali.asu.migration.recalcul.RecalculerMontantBrutDroitCourant;
import fr.unedic.cali.asu.migration.recalcul.RecalculerMontantBrutDroitPrecedent;
import fr.unedic.cali.asu.migration.recalcul.RecalculerPji;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionProduitResultant;
import fr.unedic.cali.asu.produits.liquidation.dom.Decision;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Readmission;
import fr.unedic.cali.autresdoms.cohab.dom.CodesErreursMigration;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cohabitation.sigma.migration.dom.DecisionMigreeAsuV1;
import fr.unedic.cohabitation.sigma.migration.dom.DemandeMigreeAsuV1;
import fr.unedic.util.Quantite;
import java.util.ArrayList;
import java.util.Collection;

public class GrapheReadmissionProduitResultant
  extends GrapheReadmissionDroitPrecedent
{
  protected ObjectifExamen creerObjectifDecision(DemandeMigreeAsuV1 p_demandeTemporaireSource)
  {
    ObjectifExamen objectifExamen = null;
    
    ProduitAsuSpec produitAsu = (ProduitAsuSpec)Parametres.getProduit(p_demandeTemporaireSource.getCodeProduit());
    
    objectifExamen = (ObjectifExamen)produitAsu.creerObjectifExamen(26, null);
    objectifExamen.setEtat(23);
    
    return objectifExamen;
  }
  
  protected Decision creerDecision(int p_natureDecision)
  {
    Decision nouvelleDecision = null;
    
    nouvelleDecision = new Readmission();
    nouvelleDecision.setNatureDecision(26);
    
    return nouvelleDecision;
  }
  
  protected void alimenterDureeProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant cepa15 = p_dossierExamen.getConstitutionProduitResultant();
    if (p_decisionTemporaireSource.getDureeTheoriqueDroitRetenu() != null) {
      cepa15.setDureeTheorique(p_decisionTemporaireSource.getDureeTheoriqueDroitRetenu());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(2, "LIQ_ASU_DUREE_T_DR"));
    }
    if (p_decisionTemporaireSource.getDureeEffectiveDroitRetenu() != null) {
      cepa15.setDureeEffective(p_decisionTemporaireSource.getDureeEffectiveDroitRetenu());
    } else {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_DUREE_E_DR"));
    }
  }
  
  protected void alimenterMontantBrutProduitResultant(DecisionMigreeAsuV1 p_decisionTemporaireSource, DossierExamen p_dossierExamen)
  {
    ConstitutionProduitResultant cepa15 = p_dossierExamen.getConstitutionProduitResultant();
    
    Quantite montantRetenu = null;
    if (p_decisionTemporaireSource.isMontantRetenuEstLePrecedent())
    {
      if (p_decisionTemporaireSource.getMontantBrutDroitPrecedent() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MT_BRUT_DP"));
      } else {
        montantRetenu = p_decisionTemporaireSource.getMontantBrutDroitPrecedent();
      }
    }
    else if (p_decisionTemporaireSource.getMontantBrut() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_MONTANT_BRUT"));
    } else {
      montantRetenu = p_decisionTemporaireSource.getMontantBrut();
    }
    Quantite capitalRetenu = null;
    if (p_decisionTemporaireSource.isCapitalRetenuEstLePrecendent())
    {
      if (p_decisionTemporaireSource.getCapitalOdPrecedente() == null) {
        getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_CAPITAL_DP"));
      } else {
        capitalRetenu = p_decisionTemporaireSource.getCapitalOdPrecedente();
      }
    }
    else if (p_decisionTemporaireSource.getCapitalOdCourante() == null) {
      getListeErreurs().add(CodesErreursMigration.getErreur(3, "LIQ_ASU_CAPITAL_DC"));
    } else {
      capitalRetenu = p_decisionTemporaireSource.getCapitalOdCourante();
    }
    cepa15.setMontantJournalierBrut(montantRetenu);
  }
  
  protected Collection getListRecalcule()
  {
    Collection listeRecalcul = new ArrayList();
    
    listeRecalcul.add(new RecalculerPji());
    listeRecalcul.add(new RecalculerMontantBrutDroitCourant());
    listeRecalcul.add(new RecalculerCapitalDroitCourant());
    listeRecalcul.add(new RecalculerMontantBrutDroitPrecedent());
    listeRecalcul.add(new RecalculerCapitalDroitPrecedent());
    listeRecalcul.add(new RecalculerConstituantsProduitResultant());
    
    return listeRecalcul;
  }
}

/* Location:
 * Qualified Name:     GrapheReadmissionProduitResultant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */