package fr.unedic.cali.asu.mnt.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.mnt.dom.gen.EreDemandeMaintienGen;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;

public class EreDemandeMaintien
  extends EreDemandeMaintienGen
{
  private static final long serialVersionUID = -3166677153453127547L;
  private static final int CHOIX_AGE = 1;
  private static final int CHOIX_100_TRIMESTRES = 2;
  private static final int CHOIX_365_JOURS = 3;
  private int m_choixDateExamen;
  
  public EreDemandeMaintien() {}
  
  public EreDemandeMaintien(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public String getLibelle()
  {
    return "Maintien manuel";
  }
  
  public String getLibelleLong()
  {
    return "demande de maintien";
  }
  
  public String getTypeExamen()
  {
    return "ASU_06";
  }
  
  public int getPriorite()
  {
    return 10;
  }
  
  public Damj getDateDeclenchementExamen(DemandeSpec p_demande)
  {
    if ((getDateEvenement() != null) && ((p_demande.estDecisionnee()) || (p_demande.estDemandeLiquidee())) && (!p_demande.estEnReExamen())) {
      setDateDeclenchementExamen(getDateEvenement());
    } else if (p_demande.getDateDepot() != null) {
      setDateDeclenchementExamen(p_demande.getDateDepot());
    } else {
      setDateDeclenchementExamen(p_demande.getFormulaire().getDateCreationDal());
    }
    return getDateDeclenchementExamen();
  }
  
  public Damj getDateExamen(DemandeSpec p_demande)
  {
    if (getDateEvenement() == null) {
      try
      {
        setDateEvenement(calculerDateExamen((DemandeMaintien)p_demande));
      }
      catch (CoucheLogiqueException ex)
      {
        setDateEvenement(null);
      }
    }
    return getDateEvenement();
  }
  
  private Damj calculerDateExamen(DemandeMaintien p_demandeMaintien)
    throws CoucheLogiqueException
  {
    Damj dateExamen = null;
    if (p_demandeMaintien.getDemandeMaintenue() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_MNT_CTX_DROIT_MAINTENU_INEXISTANT");
    }
    ProduitAsuSpec produitMaintenu = p_demandeMaintien.getProduitMaintenu();
    if (produitMaintenu == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_CONTEXTE_PRODUIT_MAINTENU", new Object[] { p_demandeMaintien.getDateDeclenchementExamen() });
    }
    Damj date60ans = recupererDate60Ans(produitMaintenu, p_demandeMaintien);
    Damj date100Trimestres = recupererDate100Trimestres(produitMaintenu, p_demandeMaintien);
    Damj dateNombreJoursIndemnisesNecessaireMaintien = recupererDateNombreJoursIndemnisesNecessaireMaintien(produitMaintenu, p_demandeMaintien).lendemain();
    
    dateExamen = date60ans;
    if (date100Trimestres != null) {
      dateExamen = Damj.max(dateExamen, date100Trimestres);
    }
    dateExamen = Damj.max(dateExamen, dateNombreJoursIndemnisesNecessaireMaintien);
    if (dateExamen.equals(date60ans)) {
      m_choixDateExamen = 1;
    }
    if ((date100Trimestres != null) && (dateExamen.equals(date100Trimestres))) {
      m_choixDateExamen = 2;
    }
    if (dateExamen.equals(dateNombreJoursIndemnisesNecessaireMaintien)) {
      m_choixDateExamen = 3;
    }
    return dateExamen;
  }
  
  public String getLibelleDateExamenChoisie(DemandeSpec p_demande)
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)((DemandeMaintien)p_demande).getAttributionAssurance().getProduit();
    DureeCalendaire ageMiniPourMaintien = produit.getAgeMinimumObtentionMaintien(p_demande);
    String libelle;
    switch (m_choixDateExamen)
    {
    case 1: 
      StringBuffer sb = new StringBuffer("date des ");
      sb.append(ageMiniPourMaintien.getAnnees());
      sb.append(" ans");
      if (ageMiniPourMaintien.getMois() > 0)
      {
        sb.append(" et ");
        sb.append(ageMiniPourMaintien.getMois());
        sb.append(" mois");
      }
      if (ageMiniPourMaintien.getJours() > 0)
      {
        sb.append(" et ");
        sb.append(ageMiniPourMaintien.getJours());
        sb.append(" jours");
      }
      libelle = sb.toString();
      break;
    case 2: 
      libelle = "date des 100 trimestres";
      break;
    case 3: 
      libelle = "date du 365ème jour indemnisé en ARE";
      break;
    default: 
      libelle = "";
    }
    return libelle;
  }
  
  private Damj recupererDate60Ans(ProduitAsuSpec p_produitMaintenu, DemandeMaintien p_demandeMaintien)
  {
    return p_produitMaintenu.getDateObtentionAgePourMaintien(p_demandeMaintien);
  }
  
  private Damj recupererDate100Trimestres(ProduitAsuSpec p_produitMaintenu, DemandeMaintien p_demandeMaintien)
  {
    return p_produitMaintenu.getDateObtentionDesTrimestres(p_demandeMaintien);
  }
  
  private Damj recupererDateNombreJoursIndemnisesNecessaireMaintien(ProduitAsuSpec p_produitMaintenu, DemandeMaintien p_demandeMaintien)
    throws CoucheLogiqueException
  {
    try
    {
      return p_produitMaintenu.getDateObtentionIndemnisation(p_demandeMaintien);
    }
    catch (ApplicativeException ex)
    {
      throw new CoucheLogiqueException(ex.getCode(), ex.getLibelle());
    }
  }
  
  public void verifierContexte(DemandeSpec p_demande)
    throws ApplicativeException
  {
    calculerDateExamen((DemandeMaintien)p_demande);
  }
  
  public ObjetMetierSpec copie()
  {
    EreDemandeMaintien copie = new EreDemandeMaintien();
    copieElements(copie);
    return copie;
  }
  
  public String getTypeSegment()
  {
    return "LK1B";
  }
  
  public boolean mettreEnBasePivot()
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     EreDemandeMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */