package fr.unedic.cali.asu.mnt.outilsfonctionnels;

import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DonneesForcees;
import fr.unedic.cali.dom.ClassementAdministratifSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Hashtable;

public final class CREM
{
  private static final int NB_DECIMALES_ARRONDI_2 = 2;
  
  public static Hashtable<String, String> getElementsConstitutantVides()
  {
    Hashtable<String, String> listeConstituant = new Hashtable();
    
    return listeConstituant;
  }
  
  public static Hashtable<String, String> recupererDonneesImposees(DemandeSpec demande)
  {
    Hashtable<String, String> listeDonneesImposees = getElementsDonneesImposeesVides();
    
    DemandeMaintien demandeMaintien = (DemandeMaintien)demande;
    DonneesForcees donneesForcees = demandeMaintien.getDonneesForcees();
    if (donneesForcees != null)
    {
      Quantite appartenance = donneesForcees.getQuantiteAppartenance();
      if (appartenance != null)
      {
        listeDonneesImposees.put("Quantite d appartenance", Mathematiques.arrondiASup(appartenance.getValeur(), 2).toString());
        
        listeDonneesImposees.put("Quantite d appartenance unite", appartenance.getUnite().toString());
      }
      Quantite qteActivite3ans = donneesForcees.getQuantiteActiviteTroisAns();
      if (qteActivite3ans != null)
      {
        listeDonneesImposees.put("Condition d activite 3 ans", Mathematiques.arrondiASup(qteActivite3ans.getValeur(), 2).toString());
        
        listeDonneesImposees.put("Condition d activite 3 ans", qteActivite3ans.getUnite().toString());
      }
      Quantite qteActivite5ans = donneesForcees.getQuantiteActiviteCinqAns();
      if (qteActivite5ans != null)
      {
        listeDonneesImposees.put("Condition d activite 5 ans", Mathematiques.arrondiASup(qteActivite5ans.getValeur(), 2).toString());
        
        listeDonneesImposees.put("Condition d activite 5 ans", qteActivite5ans.getUnite().toString());
      }
      int continuDiscontinu = donneesForcees.getActiviteContinue();
      if (continuDiscontinu != 0) {
        listeDonneesImposees.put("Continu/Discontinu", Integer.toString(continuDiscontinu));
      }
      int decisionCP = donneesForcees.getDecisionCPFavorable();
      if (decisionCP != 0) {
        listeDonneesImposees.put("Decision CP", Integer.toString(decisionCP));
      }
      int motifDecisionCp = donneesForcees.getMotifDecisionCP();
      if (motifDecisionCp != 0) {
        listeDonneesImposees.put("Decision CP motif", Integer.toString(motifDecisionCp));
      }
    }
    return listeDonneesImposees;
  }
  
  public static Hashtable<String, String> getElementsDonneesImposeesVides()
  {
    Hashtable<String, String> listeDonneesImposees = new Hashtable();
    
    listeDonneesImposees.put("Quantite d appartenance", "");
    listeDonneesImposees.put("Quantite d appartenance unite", "");
    
    listeDonneesImposees.put("Condition d activite 3 ans", "");
    listeDonneesImposees.put("Condition d activite 3 ans", "");
    
    listeDonneesImposees.put("Condition d activite 5 ans", "");
    listeDonneesImposees.put("Condition d activite 5 ans", "");
    
    listeDonneesImposees.put("Continu/Discontinu", "");
    
    listeDonneesImposees.put("Decision CP", "");
    
    listeDonneesImposees.put("Decision CP motif", "");
    
    return listeDonneesImposees;
  }
  
  public static Hashtable<String, String> recupererElementsDecision(DemandeMaintien demande)
    throws CoucheLogiqueException
  {
    Hashtable<String, String> elementDecision = getElementsDecisionVides();
    if (demande != null)
    {
      ClassementAdministratifSpec classement = demande.getClassementAdministratif();
      if (classement != null)
      {
        elementDecision.put("Nature Decision", "Classement " + classement.getTypeClassement());
      }
      else
      {
        DossierExamenSpec dossierExamen = demande.getDossierExamen();
        if ((dossierExamen instanceof DecisionSpec))
        {
          int codeDecisionCourante = ((DecisionSpec)dossierExamen).getNatureDecision();
          String libelleNatureDecision = (String)NaturesDecisions.s_libelleObjectifDecision.get(new BigDecimal(codeDecisionCourante));
          elementDecision.put("Nature Decision", libelleNatureDecision);
        }
      }
    }
    return elementDecision;
  }
  
  public static Hashtable<String, String> getElementsDecisionVides()
  {
    Hashtable<String, String> listeDecision = new Hashtable();
    
    listeDecision.put("Nature Decision", "");
    
    return listeDecision;
  }
}

/* Location:
 * Qualified Name:     CREM
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */