package fr.unedic.cali.asu.outilsaffiliation;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeEvenementPersonnel;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeFormationAssimilable;
import fr.unedic.cali.autresdoms.ga.dom.spec.CertifieSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreCategorieEmploiParticulier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMaladieGrave;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreMaladieLongueDuree;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNatureEvementPersonnel;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesCertifiees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.Iterator;

public class CalculAffiliationSimplifie
{
  private static final DureeCalendaire DUREE_PRA = new DureeCalendaire(0, 0, 365);
  private static final BigDecimal QUANTITE_AFFILIATION_REQUISE = new BigDecimal(507);
  private static final BigDecimal NOMBRE_HEURE_AFFILIATION_TRAVAIL_JOUR = new BigDecimal(12);
  private static final BigDecimal NOMBRE_HEURE_AFFILIATION_PEP_JOUR = new BigDecimal(5);
  private static final BigDecimal NOMBRE_HEURE_AFFILIATION_NON_EXECUTION = new BigDecimal(5);
  private static final BigDecimal ZERO = new BigDecimal(0);
  
  public static boolean estAffiliationMinimaleValidee(IndividuSpec individu, Damj dateEtude)
    throws CoucheLogiqueException
  {
    Periode pra = determinerPRA(individu, dateEtude);
    
    Chronologie chronologiePeriodesParticipantes = determinerPeriodesParticipantes(individu, pra);
    
    BigDecimal quantiteAffiSimplifieeAcquise = calculerAffiliationSimplifiee(chronologiePeriodesParticipantes);
    
    BigDecimal quantiteAffiSimplifieeRequise = determinerQuantiteRequise();
    
    return quantiteAffiSimplifieeAcquise.max(quantiteAffiSimplifieeRequise).equals(quantiteAffiSimplifieeAcquise);
  }
  
  private static Periode determinerPRA(IndividuSpec individu, Damj dateEtude)
    throws CoucheLogiqueException
  {
    Damj termePRA = dateEtude;
    
    Damj debutPRA = CalculDelais.determinerDelaiCalendaire(termePRA, DUREE_PRA).getDebut();
    
    AttributionSpec od = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), dateEtude, new FiltreOuvertureDroitStandardAssurance(true, true, false, false, null));
    if (od != null)
    {
      Damj dateFgdAttributionPrecedente = ((Demande)od.getDemande()).getDateFaitGenerateurOuFinDernierContratTravailRompu();
      
      debutPRA = Damj.min(debutPRA, dateFgdAttributionPrecedente.lendemain());
    }
    return new Periode(debutPRA, termePRA);
  }
  
  private static Chronologie determinerPeriodesParticipantes(IndividuSpec individu, Periode pra)
  {
    FiltresTemporel filtrePeriodeParticipantes = new FiltresTemporel();
    FiltrePeriodesSurFiltresExclusifs filtreOU = new FiltrePeriodesSurFiltresExclusifs();
    
    filtreOU.ajouterFiltre(new FiltrePeriodesCertifiees());
    
    filtreOU.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    
    FiltreCategorieEmploiParticulier filtreCategorieEmploiParticulier = new FiltreCategorieEmploiParticulier();
    filtreCategorieEmploiParticulier.ajouterCategorieEmploi(31);
    filtreOU.ajouterFiltre(filtreCategorieEmploiParticulier);
    
    filtreOU.ajouterFiltre(new FiltreMaladieLongueDuree());
    
    filtreOU.ajouterFiltre(new FiltreMaladieGrave());
    
    FiltreNatureEvementPersonnel filtreNatureEvenementPersonnel = new FiltreNatureEvementPersonnel();
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(25);
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(26);
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(23);
    filtreOU.ajouterFiltre(filtreNatureEvenementPersonnel);
    
    filtrePeriodeParticipantes.ajouterFiltre(new FiltreChevauchePeriode(pra));
    filtrePeriodeParticipantes.ajouterFiltre(filtreOU);
    
    return individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtrePeriodeParticipantes);
  }
  
  private static BigDecimal calculerAffiliationSimplifiee(Chronologie chronologieActivitesParticipantes)
    throws CoucheLogiqueException
  {
    BigDecimal resultat = ZERO;
    if (chronologieActivitesParticipantes != null)
    {
      Iterator itChronologieActivitesParticipantes = chronologieActivitesParticipantes.iterer();
      while (itChronologieActivitesParticipantes.hasNext())
      {
        Temporel element = (Temporel)itChronologieActivitesParticipantes.next();
        
        BigDecimal quantiteAffiliationSimplifieParJour = determinerQuantiteParJourPourElement(element);
        
        int dureeActivite = new Periode(element.getDateDebut(), element.getDateFin()).getDuree();
        
        BigDecimal qttAffiTotal = quantiteAffiliationSimplifieParJour.multiply(new BigDecimal(dureeActivite));
        
        resultat = resultat.add(qttAffiTotal);
        if ((element instanceof ActiviteSalarie)) {
          resultat = resultat.add(determinerQuantiteNonExecution((ActiviteSalarie)element));
        }
      }
    }
    return resultat;
  }
  
  private static BigDecimal determinerQuantiteParJourPourElement(Temporel element)
    throws CoucheLogiqueException
  {
    if ((element instanceof PeriodeEvenementPersonnel)) {
      return NOMBRE_HEURE_AFFILIATION_PEP_JOUR;
    }
    if (((element instanceof CertifieSpec)) || ((element instanceof PeriodeFormationAssimilable))) {
      return NOMBRE_HEURE_AFFILIATION_TRAVAIL_JOUR;
    }
    throw new CoucheLogiqueException("Ce type de période n’est pas géré dans le calcul d’affiliation simplifié : " + element);
  }
  
  private static BigDecimal determinerQuantiteNonExecution(ActiviteSalarie activite)
  {
    Periode periodeNonExecution = OutilActiviteSalarie.getInstance().determinerPeriodeNonExecution(activite);
    if (periodeNonExecution != null) {
      return NOMBRE_HEURE_AFFILIATION_NON_EXECUTION.multiply(new BigDecimal(periodeNonExecution.getDuree()));
    }
    return ZERO;
  }
  
  private static BigDecimal determinerQuantiteRequise()
  {
    return QUANTITE_AFFILIATION_REQUISE;
  }
}

/* Location:
 * Qualified Name:     CalculAffiliationSimplifie
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */