package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Hashtable;

public final class CREM
{
  private static final int NB_DECIMALES_ARRONDI_0 = 0;
  private static final int NB_DECIMALES_ARRONDI_2 = 2;
  private static final int NB_DECIMALES_ARRONDI_4 = 4;
  
  public static Hashtable<String, String> getElementsConstitutantVides()
  {
    Hashtable<String, String> listeConstituant = new Hashtable();
    
    listeConstituant.put("Reglement applicable", "");
    listeConstituant.put("Salaire de reference", "");
    listeConstituant.put("Salaire journalier de ref", "");
    listeConstituant.put("Salaire journalier moyen", "");
    listeConstituant.put("Affiliation quantite", "");
    listeConstituant.put("Affiliation unite", "");
    listeConstituant.put("Duree Produit Resultant", "");
    listeConstituant.put("Coefficient temps partiel", "");
    listeConstituant.put("FGD", "");
    listeConstituant.put("FCT retenue", "");
    listeConstituant.put("Montant aide pour imputation", "");
    listeConstituant.put("Heures trav. PRA (NHTp)", "");
    listeConstituant.put("Heures trav. PRA (NHTe)", "");
    listeConstituant.put("Date d examen", "");
    listeConstituant.put("Date d attribution", "");
    listeConstituant.put("Coche apprenti", "");
    listeConstituant.put("Date d effet du SJR", "");
    listeConstituant.put("SJC", "");
    listeConstituant.put("Coefficient saisonnier", "");
    listeConstituant.put("Carence PMC debut", "");
    listeConstituant.put("Carence PMC fin", "");
    listeConstituant.put("Differe ICCP debut", "");
    listeConstituant.put("Differe ICCP fin", "");
    listeConstituant.put("Differe ISLR debut", "");
    listeConstituant.put("Differe ISLR fin", "");
    listeConstituant.put("Delai d attente debut", "");
    listeConstituant.put("Delai d attente fin", "");
    listeConstituant.put("Differe standard debut", "");
    listeConstituant.put("Differe standard fin", "");
    listeConstituant.put("Montant salaire reference", "");
    listeConstituant.put("Date d effet du SR", "");
    listeConstituant.put("Nombre de jours emploi", "");
    listeConstituant.put("Derogation CSP", "");
    listeConstituant.put("Montant tranche 1", "");
    listeConstituant.put("Montant tranche 2", "");
    listeConstituant.put("Montant tranche 3", "");
    
    return listeConstituant;
  }
  
  public static Hashtable<String, String> recupererDonneesImposees(DemandeSpec demande)
  {
    Hashtable<String, String> listeDonneesImposees = getElementsDonneesImposeesVides();
    
    Demande demandeAsu = (Demande)demande;
    DonneesTemporaires donneesTemporaires = demandeAsu.getDonneesTemporaires();
    if (donneesTemporaires != null)
    {
      Quantite sjr = donneesTemporaires.getSjr();
      if (sjr != null) {
        listeDonneesImposees.put("SJR", Mathematiques.arrondiASup(sjr.getValeur(), 2).toString());
      }
      Quantite qteAffi = donneesTemporaires.getQuantiteAffiliation();
      if (qteAffi != null)
      {
        listeDonneesImposees.put("Affiliation quantite", Mathematiques.arrondiASup(qteAffi.getValeur(), 2).toString());
        listeDonneesImposees.put("Affiliation unite", qteAffi.getUnite().toString());
      }
      Damj dateFinPrc = donneesTemporaires.getTermePrc();
      if (dateFinPrc != null) {
        listeDonneesImposees.put("Date fin PRC", dateFinPrc.toString());
      }
      TravailSpec fctARetenir = donneesTemporaires.getPeriodeFctARetenir();
      if (fctARetenir != null) {
        listeDonneesImposees.put("FCT a retenir", fctARetenir.getPeriode().toString());
      }
      BigDecimal coefTpsPartiel = donneesTemporaires.getCoefficientTempsPartiel();
      if (coefTpsPartiel != null) {
        listeDonneesImposees.put("Coefficient temps partiel", Mathematiques.arrondiASup(coefTpsPartiel, 4).toString());
      }
      Quantite carencesConservatoires = donneesTemporaires.getQuantiteJoursDiffereIccpConservatoire();
      if (carencesConservatoires != null)
      {
        listeDonneesImposees.put("Differe ICCP conserv. reprise", Mathematiques.arrondiASup(carencesConservatoires.getValeur(), 2).toString());
        
        listeDonneesImposees.put("Differe ICCP conserv. reprise", carencesConservatoires.getUnite().toString());
      }
      Quantite differeIccp = donneesTemporaires.getQuantiteJourICCP();
      if (differeIccp != null)
      {
        listeDonneesImposees.put("Differe ICCP qte", Mathematiques.arrondiASup(differeIccp.getValeur(), 2).toString());
        
        listeDonneesImposees.put("Differe ICCP unite", differeIccp.getUnite().toString());
      }
      BigDecimal coefSaisonnier = donneesTemporaires.getCoefficientSaisonnier();
      if (coefSaisonnier != null) {
        listeDonneesImposees.put("Coefficient saisonnier", Mathematiques.arrondiASup(coefSaisonnier, 2).toString());
      }
      short avisCPpourDV = donneesTemporaires.getAvisCommissionParitaire();
      if (avisCPpourDV != 0) {
        listeDonneesImposees.put("Avis IPR pour DV", String.valueOf(new BigDecimal(avisCPpourDV).intValue()));
      }
      String pmcFCTConcernee = donneesTemporaires.getIndentifiantFctPMC();
      if (pmcFCTConcernee != null) {
        listeDonneesImposees.put("PMC FCT concernee", pmcFCTConcernee);
      }
      Damj termePMC = donneesTemporaires.getFinPmc();
      if (termePMC != null) {
        listeDonneesImposees.put("PMC terme", termePMC.toString());
      }
      Boolean naturePMC = Boolean.valueOf(donneesTemporaires.isPmcIndemnisable());
      listeDonneesImposees.put("PMC nature", naturePMC.toString());
      
      BigDecimal nbJoursAImputer = donneesTemporaires.getNbJourImputer();
      if (nbJoursAImputer != null) {
        listeDonneesImposees.put("Nb jours a imputer", Mathematiques.arrondiASup(nbJoursAImputer, 0).toString());
      }
      BigDecimal nbJoursImputationDroitPrecedent = donneesTemporaires.getNbJourImputationDroitPrecedent();
      if (nbJoursImputationDroitPrecedent != null) {
        listeDonneesImposees.put("Nb jours imput droit prec", Mathematiques.arrondiASup(nbJoursImputationDroitPrecedent, 0).toString());
      }
      BigDecimal montantAide = donneesTemporaires.getMontantAide();
      if (montantAide != null) {
        listeDonneesImposees.put("Montant aide pour imputation", Mathematiques.arrondiASup(montantAide, 2).toString());
      }
      String reglementApplicable = donneesTemporaires.getReglementApplicableSpectacle();
      if (reglementApplicable != null) {
        listeDonneesImposees.put("Reglement applicable", reglementApplicable);
      }
      if (donneesTemporaires.getRangAllongementPraSpectacle() != null)
      {
        int rangAllongementPRASpectacle = donneesTemporaires.getRangAllongementPraSpectacle().intValue();
        listeDonneesImposees.put("Rang allongement PRA", String.valueOf(rangAllongementPRASpectacle));
      }
      QuantiteEuro sripSpectacle = donneesTemporaires.getSripSpectacle();
      if (sripSpectacle != null) {
        listeDonneesImposees.put("SRip", Mathematiques.arrondiASup(sripSpectacle.getValeurMontant(), 2).toString());
      }
      QuantiteEuro totalRemunerationDansPRC = donneesTemporaires.getTotalRemunerationDansPRC();
      if (totalRemunerationDansPRC != null) {
        listeDonneesImposees.put("Total remuneration NP PRC", Mathematiques.arrondiASup(totalRemunerationDansPRC.getValeurMontant(), 2).toString());
      }
      Quantite nhtpSpectacle = donneesTemporaires.getNbHeuresTravailPlafonneSpectacle();
      if ((nhtpSpectacle != null) && (nhtpSpectacle.getValeur() != null)) {
        listeDonneesImposees.put("Heures trav. PRA (NHTp)", String.valueOf(nhtpSpectacle.getValeur().intValue()));
      }
      Quantite nhteSpectacle = donneesTemporaires.getNbHeuresTravailEtenduSpectacle();
      if ((nhteSpectacle != null) && (nhteSpectacle.getValeur() != null)) {
        listeDonneesImposees.put("Heures trav. PRA (NHTe)", String.valueOf(nhteSpectacle.getValeur().intValue()));
      }
      Quantite nbJoursContratSurPraSpectacle = donneesTemporaires.getNbJourContratSurPraSpectacle();
      if (nbJoursContratSurPraSpectacle != null) {
        listeDonneesImposees.put("Nb jours contrat PRA", Mathematiques.arrondiASup(nbJoursContratSurPraSpectacle.getValeur(), 0).toString());
      }
      Boolean beneficeAT12Mois = Boolean.valueOf(donneesTemporaires.isABeneficeDroitAt12Mois());
      listeDonneesImposees.put("Benefice droit AT ss 12 mois", beneficeAT12Mois.toString());
      
      Integer dureeAnciennete = donneesTemporaires.getDureeAncienneteIntermittantSpectacle();
      if (dureeAnciennete != null) {
        listeDonneesImposees.put("Duree ancien interm spectacle", dureeAnciennete.toString());
      }
      Boolean fctDansLesDeuxMoisAvantFddAre = Boolean.valueOf(donneesTemporaires.isFctDansLesDeuxMoisAvantFddAre());
      listeDonneesImposees.put("FCT 2 mois avant FDD ARE", fctDansLesDeuxMoisAvantFddAre.toString());
      
      Quantite capitalSP = donneesTemporaires.getCapitalReliquatSecteurPublic();
      if (capitalSP != null) {
        listeDonneesImposees.put("Capital SP", Mathematiques.arrondiASup(capitalSP.getValeur(), 2).toString());
      }
      Quantite sjrSP = donneesTemporaires.getSjrSP();
      if (sjrSP != null) {
        listeDonneesImposees.put("SJR SP", Mathematiques.arrondiASup(sjrSP.getValeur(), 2).toString());
      }
      Damj termePRCSP = donneesTemporaires.getTermePrcSp();
      if (termePRCSP != null) {
        listeDonneesImposees.put("Terme de la PRC SP", termePRCSP.toString());
      }
      BigDecimal coefTempsPartielSP = donneesTemporaires.getCoefficientTempsPartielSp();
      if (coefTempsPartielSP != null) {
        listeDonneesImposees.put("Coefficient temps partiel SP", Mathematiques.arrondiASup(coefTempsPartielSP, 2).toString());
      }
      BigDecimal coefSaisonnierSP = donneesTemporaires.getCoefficientSaisonnierSp();
      if (coefSaisonnierSP != null) {
        listeDonneesImposees.put("Coefficient saisonnier SP", Mathematiques.arrondiASup(coefSaisonnierSP, 2).toString());
      }
      Damj fgdSP = donneesTemporaires.getDateFgDroitAnterieurSp();
      if (fgdSP != null) {
        listeDonneesImposees.put("Fait generateur de droit SP", fgdSP.toString());
      }
      Damj dateAttributionSP = donneesTemporaires.getDateAttributionDroitAnterieurSp();
      if (dateAttributionSP != null) {
        listeDonneesImposees.put("Date d attribution SP", dateAttributionSP.toString());
      }
      Integer dureeInitialeDroitSP = Integer.valueOf(donneesTemporaires.getDureeInitialeDroitAnterieurSp());
      if (dureeInitialeDroitSP != null) {
        listeDonneesImposees.put("Duree initiale du droit SP", dureeInitialeDroitSP.toString());
      }
      Boolean derogationCSP = Boolean.valueOf(donneesTemporaires.isEstDerogationCsp());
      listeDonneesImposees.put("Derogation CSP", derogationCSP.toString());
      
      String etablissementFinanceur = donneesTemporaires.getNumeroConventionPE();
      if (etablissementFinanceur != null) {
        listeDonneesImposees.put("Etablissement financeur", etablissementFinanceur);
      }
      String codeAffectation = donneesTemporaires.getCodeAffectationConvention();
      if (codeAffectation != null) {
        listeDonneesImposees.put("Code affectation", codeAffectation);
      }
      String idExterne = donneesTemporaires.getIdExterneEmployeurSp();
      if (idExterne != null) {
        listeDonneesImposees.put("Identifiant ext. employeur SP", idExterne);
      }
      Boolean estLeveeControlePANSSuiteARCE = Boolean.valueOf(donneesTemporaires.isEstLeveeControlePANSSuiteARCE());
      if (estLeveeControlePANSSuiteARCE != null) {
        listeDonneesImposees.put("Levee controle ANS suite ARCE", estLeveeControlePANSSuiteARCE.toString());
      }
      Boolean estLeveeConditionACMemeEmployeur = Boolean.valueOf(donneesTemporaires.isEstLeveeConditionACMemeEmployeur());
      if (estLeveeConditionACMemeEmployeur != null) {
        listeDonneesImposees.put("Levee cond. AC meme employeur", estLeveeConditionACMemeEmployeur.toString());
      }
      Boolean estPCRCForceDroitCourant = Boolean.valueOf(donneesTemporaires.isEstPCRCForceDroitCourant());
      if (estPCRCForceDroitCourant != null) {
        listeDonneesImposees.put("PCRC force sur droit courant", estPCRCForceDroitCourant.toString());
      }
      Boolean estPCRCForceDroitPrecedent = Boolean.valueOf(donneesTemporaires.isEstPCRCForceDroitPrecedent());
      if (estPCRCForceDroitPrecedent != null) {
        listeDonneesImposees.put("PCRC force sur droit precedent", estPCRCForceDroitPrecedent.toString());
      }
      BigDecimal dureeImputation = donneesTemporaires.getDureeImputation();
      if (dureeImputation != null) {
        listeDonneesImposees.put("Imputation durée post prime", Mathematiques.arrondiASup(dureeImputation, 2).toString());
      }
      Damj finCsp = donneesTemporaires.getDateLimiteIndemnisationDonneeForcee();
      if (finCsp != null) {
        listeDonneesImposees.put("Date fin Csp", finCsp.toString());
      }
      Boolean estLeveeConditionCLCA = Boolean.valueOf(donneesTemporaires.isLeveeConditionCLCA());
      if (estLeveeConditionCLCA != null) {
        listeDonneesImposees.put("Levee cond. CLCA", estLeveeConditionCLCA.toString());
      }
      Boolean estConditionAffiliationSatisfaite = donneesTemporaires.isConditionAffiliationSatisfaiteForcee();
      if (estConditionAffiliationSatisfaite != null) {
        listeDonneesImposees.put("Condition affiliation", estConditionAffiliationSatisfaite.toString());
      }
      Boolean estConditionAncienneteSatisfaite = donneesTemporaires.isConditionAncienneteSatisfaiteForcee();
      if (estConditionAncienneteSatisfaite != null) {
        listeDonneesImposees.put("Condition anciennete", estConditionAncienneteSatisfaite.toString());
      }
      Damj dateFinPeriodeAnciennete = donneesTemporaires.getDateFinPeriodeAncienneteForcee();
      if (dateFinPeriodeAnciennete != null) {
        listeDonneesImposees.put("Date fin periode anciennete", dateFinPeriodeAnciennete.toString());
      }
      BigDecimal nbHeureTotalA8A10 = donneesTemporaires.getNombreJourTotalA8A10Force();
      if (nbHeureTotalA8A10 != null) {
        listeDonneesImposees.put("Nombre total heure A8 et A10", nbHeureTotalA8A10.toString());
      }
      BigDecimal dureeAllongementAref = donneesTemporaires.getDureeAllongementAREFForcee();
      if (dureeAllongementAref != null) {
        listeDonneesImposees.put("Durée algt possible AREF", String.valueOf(dureeAllongementAref.intValue()));
      }
      Boolean droitInterimaire = Boolean.valueOf(donneesTemporaires.isDroitInterimaireForce());
      if (droitInterimaire != null) {
        listeDonneesImposees.put("Interimaire", String.valueOf(droitInterimaire));
      }
      BigDecimal diviseurSJR = donneesTemporaires.getDiviseurSjrForce();
      if (diviseurSJR != null) {
        listeDonneesImposees.put("Diviseur SJR", diviseurSJR.toString());
      }
    }
    SaisieAntecedent saisieAntecedent = demandeAsu.getSaisieAntecedent();
    if (saisieAntecedent != null)
    {
      Damj dateAttribution = saisieAntecedent.getDateAttribution();
      if (dateAttribution != null) {
        listeDonneesImposees.put("Date d attribution", dateAttribution.toString());
      }
      TravailSpec fgd = saisieAntecedent.getPeriodeFGD();
      if (fgd != null) {
        listeDonneesImposees.put("Fait generateur de droit", fgd.getPeriode().toString());
      }
      TravailSpec competence = saisieAntecedent.getPeriodeFctCompetence();
      if (competence != null) {
        listeDonneesImposees.put("FCT competence financiere", competence.getPeriode().toString());
      }
      Quantite dureeInitiale = saisieAntecedent.getDureeInitialeDroit();
      if ((dureeInitiale != null) && (dureeInitiale.getValeur() != null)) {
        listeDonneesImposees.put("Duree initiale du droit", String.valueOf(dureeInitiale.getValeur().intValue()));
      }
      Damj pji = saisieAntecedent.getPremierJourIndemnisable();
      if (pji != null) {
        listeDonneesImposees.put("Premier jour indemnise", pji.toString());
      }
      Quantite sjcp = saisieAntecedent.getSalaireJournalierConservePlafonne();
      if ((sjcp != null) && (sjcp.getValeur() != null)) {
        listeDonneesImposees.put("SJC Plafonne", String.valueOf(sjcp.getValeur().intValue()));
      }
      Integer catA2b = saisieAntecedent.getCodeEmploiA2B();
      if (catA2b != null) {
        listeDonneesImposees.put("Categorie A2B", String.valueOf(catA2b.intValue()));
      }
      Damj djc = saisieAntecedent.getDateDernierJourCalcule();
      if (djc != null) {
        listeDonneesImposees.put("Dernier jour calcule", djc.toString());
      }
      Quantite reliquatDuree = saisieAntecedent.getReliquatDuree();
      if ((reliquatDuree != null) && (reliquatDuree.getValeur() != null)) {
        listeDonneesImposees.put("Reliquat de duree", String.valueOf(reliquatDuree.getValeur().intValue()));
      }
      Integer joursAREF = saisieAntecedent.getNombreJourIndemniseAREF();
      if (joursAREF != null) {
        listeDonneesImposees.put("Jours indemnises AREF", String.valueOf(joursAREF.intValue()));
      }
      Integer moisASU = saisieAntecedent.getNombreMoisIndemnisationAssurance();
      if (moisASU != null) {
        listeDonneesImposees.put("Mois indemnises ASU", String.valueOf(moisASU.intValue()));
      }
      Integer cumulAR = saisieAntecedent.getCumulMoisActiviteReduite();
      if (cumulAR != null) {
        listeDonneesImposees.put("Cumul Activite Reduite", String.valueOf(cumulAR.intValue()));
      }
      Quantite reliquatDureeRenouvellement = saisieAntecedent.getReliquatDureeRenouvellement();
      if ((reliquatDureeRenouvellement != null) && (reliquatDureeRenouvellement.getValeur() != null)) {
        listeDonneesImposees.put("Reliquat duree renouvellement", String.valueOf(reliquatDureeRenouvellement.getValeur().intValue()));
      }
      Boolean droitMaintenu = Boolean.valueOf(saisieAntecedent.isEstDroitMaintenu());
      listeDonneesImposees.put("Droit Maintenu", droitMaintenu.toString());
      
      Boolean formation = Boolean.valueOf(saisieAntecedent.isEstEnFormationAuDJC());
      listeDonneesImposees.put("DE en formation au DJC", formation.toString());
      
      Boolean delaiAttente = Boolean.valueOf(saisieAntecedent.isDelaiAttente());
      listeDonneesImposees.put("Presence de delai d attente", delaiAttente.toString());
      
      Boolean situationParticuliereARE01 = Boolean.valueOf(saisieAntecedent.isEstSituationParticuliereAre2001());
      listeDonneesImposees.put("Situation particuliere ARE01", situationParticuliereARE01.toString());
      
      listeDonneesImposees.put("Readmission composite A8A10", saisieAntecedent.getMontantReadmissionRetenu());
      
      String etablissementFinanceur = saisieAntecedent.getEtablissementFinanceur();
      if (etablissementFinanceur != null) {
        listeDonneesImposees.put("Etablissement financeur", etablissementFinanceur);
      }
      String codeAffectation = saisieAntecedent.getCodeAffectation();
      if (codeAffectation != null) {
        listeDonneesImposees.put("Code affectation", codeAffectation);
      }
      String idExterne = saisieAntecedent.getIdExterneEmployeurSp();
      if (idExterne != null) {
        listeDonneesImposees.put("Identifiant ext. employeur SP", idExterne);
      }
    }
    return listeDonneesImposees;
  }
  
  public static Hashtable<String, String> getElementsDonneesImposeesVides()
  {
    Hashtable<String, String> listeDonneesImposees = new Hashtable();
    
    listeDonneesImposees.put("SJR", "");
    listeDonneesImposees.put("Affiliation quantite", "");
    listeDonneesImposees.put("Affiliation unite", "");
    listeDonneesImposees.put("Date fin PRC", "");
    listeDonneesImposees.put("FCT a retenir", "");
    listeDonneesImposees.put("Coefficient temps partiel", "");
    listeDonneesImposees.put("Differe ICCP conserv. reprise", "");
    listeDonneesImposees.put("Differe ICCP conserv. reprise", "");
    listeDonneesImposees.put("Differe ICCP qte", "");
    listeDonneesImposees.put("Differe ICCP unite", "");
    listeDonneesImposees.put("Coefficient saisonnier", "");
    listeDonneesImposees.put("Avis IPR pour DV", "");
    listeDonneesImposees.put("PMC nature", "");
    listeDonneesImposees.put("PMC terme", "");
    listeDonneesImposees.put("PMC FCT concernee", "");
    listeDonneesImposees.put("Montant aide pour imputation", "");
    listeDonneesImposees.put("Reglement applicable", "");
    listeDonneesImposees.put("Total remuneration NP PRC", "");
    listeDonneesImposees.put("SRip", "");
    listeDonneesImposees.put("Total remuneration NP PRC", "");
    listeDonneesImposees.put("Heures trav. PRA (NHTp)", "");
    listeDonneesImposees.put("Heures trav. PRA (NHTe)", "");
    listeDonneesImposees.put("Nb jours contrat PRA", "");
    listeDonneesImposees.put("Rang allongement PRA", "");
    listeDonneesImposees.put("Nb jours a imputer", "");
    listeDonneesImposees.put("Nb jours imput droit prec", "");
    listeDonneesImposees.put("Benefice droit AT ss 12 mois", "");
    listeDonneesImposees.put("Duree ancien interm spectacle", "");
    listeDonneesImposees.put("FCT 2 mois avant FDD ARE", "");
    listeDonneesImposees.put("Capital SP", "");
    listeDonneesImposees.put("SJR SP", "");
    listeDonneesImposees.put("Terme de la PRC SP", "");
    listeDonneesImposees.put("Coefficient temps partiel SP", "");
    listeDonneesImposees.put("Coefficient saisonnier SP", "");
    listeDonneesImposees.put("Fait generateur de droit SP", "");
    listeDonneesImposees.put("Date d attribution SP", "");
    listeDonneesImposees.put("Duree initiale du droit SP", "");
    listeDonneesImposees.put("Date d attribution", "");
    listeDonneesImposees.put("Fait generateur de droit", "");
    listeDonneesImposees.put("FCT competence financiere", "");
    listeDonneesImposees.put("Duree initiale du droit", "");
    listeDonneesImposees.put("Premier jour indemnise", "");
    listeDonneesImposees.put("SJC Plafonne", "");
    listeDonneesImposees.put("Categorie A2B", "");
    listeDonneesImposees.put("Dernier jour calcule", "");
    listeDonneesImposees.put("Reliquat de duree", "");
    listeDonneesImposees.put("Jours indemnises AREF", "");
    listeDonneesImposees.put("Mois indemnises ASU", "");
    listeDonneesImposees.put("Cumul Activite Reduite", "");
    listeDonneesImposees.put("Reliquat duree renouvellement", "");
    listeDonneesImposees.put("Droit Maintenu", "");
    listeDonneesImposees.put("DE en formation au DJC", "");
    listeDonneesImposees.put("Presence de delai d attente", "");
    listeDonneesImposees.put("Situation particuliere ARE01", "");
    listeDonneesImposees.put("Readmission composite A8A10", "");
    listeDonneesImposees.put("Identifiant ext. employeur SP", "");
    listeDonneesImposees.put("Code affectation", "");
    listeDonneesImposees.put("Etablissement financeur", "");
    listeDonneesImposees.put("Levee controle ANS suite ARCE", "");
    listeDonneesImposees.put("Levee cond. AC meme employeur", "");
    listeDonneesImposees.put("PCRC force sur droit courant", "");
    listeDonneesImposees.put("PCRC force sur droit precedent", "");
    listeDonneesImposees.put("Imputation durée post prime", "");
    listeDonneesImposees.put("Date fin Csp", "");
    listeDonneesImposees.put("Levee cond. CLCA", "");
    listeDonneesImposees.put("Condition affiliation", "");
    listeDonneesImposees.put("Condition anciennete", "");
    listeDonneesImposees.put("Date fin periode anciennete", "");
    listeDonneesImposees.put("Nombre total heure A8 et A10", "");
    listeDonneesImposees.put("Durée algt possible AREF", "");
    listeDonneesImposees.put("Interimaire", "");
    listeDonneesImposees.put("Diviseur SJR", "");
    return listeDonneesImposees;
  }
}

/* Location:
 * Qualified Name:     CREM
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */