package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeAvecMontantIccpRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeHorsAttributionODA4;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionSolidariteAss;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;

public class DeterminationCarenceAsu
  implements OutilFonctionnel
{
  public static Chronologie determinerChronoPendantPeriodePriseEnCompteActiviteReduite(Chronologie p_chronologie, Periode p_periodePeriodePriseEnCompteActiviteReduite)
    throws CoucheLogiqueException, ApplicativeException
  {
    if (p_periodePeriodePriseEnCompteActiviteReduite != null)
    {
      FiltresTemporel filtres = new FiltresTemporel();
      FiltreTemporel filtrePeriodeHorsAttributionODA4 = new FiltreNegation(new FiltrePeriodeHorsAttributionODA4(p_periodePeriodePriseEnCompteActiviteReduite));
      filtres.ajouterFiltre(filtrePeriodeHorsAttributionODA4);
      FiltreTemporel filtreMontantIccpRupture = new FiltrePeriodeAvecMontantIccpRupture();
      filtres.ajouterFiltre(filtreMontantIccpRupture);
      return p_chronologie.copier(filtres);
    }
    return new ChronologiePeriodes();
  }
  
  public static Chronologie determinerChronoHorsPeriodePriseEnCompteActiviteReduite(Chronologie p_chronologie, Periode p_periodePeriodePriseEnCompteActiviteReduite)
    throws CoucheLogiqueException, ApplicativeException
  {
    if (p_periodePeriodePriseEnCompteActiviteReduite != null)
    {
      FiltrePeriodeHorsAttributionODA4 filtre = new FiltrePeriodeHorsAttributionODA4(p_periodePeriodePriseEnCompteActiviteReduite);
      return p_chronologie.copier(filtre);
    }
    return p_chronologie;
  }
  
  public static Periode determinerPeriodePriseEnCompteActiviteReduiteAsuPrecedente(DemandeSpec p_demande)
    throws ApplicativeException
  {
    AttributionSpec attributionPrecedente = ((DemandeAssuranceSpec)p_demande).rechercherAttributionPrecedenteDuMemeType();
    
    return determinerPeriodePriseEnCompteActiviteReduite(attributionPrecedente);
  }
  
  public static Periode determinerPeriodePriseEnCompteActiviteReduiteAssPrecedente(DemandeSpec p_demande)
    throws ApplicativeException
  {
    AttributionSpec attributionSolidaritePrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getDemandeur().getChronoDemandesNonTriees(), p_demande, new FiltreAttributionSolidariteAss(true));
    
    return determinerPeriodePriseEnCompteActiviteReduite(attributionSolidaritePrecedente);
  }
  
  private static Periode determinerPeriodePriseEnCompteActiviteReduite(AttributionSpec p_attribution)
    throws ApplicativeException
  {
    Periode periodePriseEnCompteCopie = null;
    if (p_attribution != null) {
      try
      {
        ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(p_attribution, null, true);
        
        Periode periodePriseEnCompte = resultatCalcul.determinerPeriodePriseEnCompteActiviteReduite();
        if (periodePriseEnCompte != null) {
          periodePriseEnCompteCopie = (Periode)periodePriseEnCompte.copie();
        }
      }
      catch (Exception e) {}
    }
    return periodePriseEnCompteCopie;
  }
  
  public static ChronologiePeriodes determinerPeriodesPriseEnCompteActiviteReduiteSurPeriodeReference(Chronologie p_chronologieAttributions, Periode p_periodeReference)
    throws ApplicativeException
  {
    ChronologiePeriodes chronoPeriodesIndemnisationAttributionsRetour = new ChronologiePeriodes();
    if ((p_chronologieAttributions != null) && (p_chronologieAttributions.getTaille() > 0))
    {
      AttributionSpec attributionCourante = null;
      Periode periodeIndemnisationAttributionCourante = null;
      Periode periodeIntersectionCourante = null;
      p_chronologieAttributions.iterer();
      while (p_chronologieAttributions.encoreSuivant())
      {
        attributionCourante = (AttributionSpec)p_chronologieAttributions.elementSuivant();
        
        periodeIndemnisationAttributionCourante = determinerPeriodePriseEnCompteActiviteReduite(attributionCourante);
        if (periodeIndemnisationAttributionCourante != null) {
          if (p_periodeReference != null)
          {
            periodeIntersectionCourante = p_periodeReference.periodeIntersection(periodeIndemnisationAttributionCourante);
            if (periodeIntersectionCourante != null) {
              chronoPeriodesIndemnisationAttributionsRetour.ajouter(new ObjetChronoPeriodeConcrete(periodeIntersectionCourante));
            }
          }
          else
          {
            chronoPeriodesIndemnisationAttributionsRetour.ajouter(new ObjetChronoPeriodeConcrete(periodeIndemnisationAttributionCourante));
          }
        }
      }
    }
    return chronoPeriodesIndemnisationAttributionsRetour;
  }
}

/* Location:
 * Qualified Name:     DeterminationCarenceAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */