package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class OutilCopieDonneesForcees
{
  public static void copieDonneesForcees(DemandeAssuranceSpec p_demandeCible)
    throws CoucheLogiqueException
  {
    if ((p_demandeCible.estUneDemandeFinDroit()) && (!p_demandeCible.estUneDemandeFinDroitAtp()))
    {
      miseAJourDonneesForceesFdd(p_demandeCible);
    }
    else
    {
      ContexteDemande contexteDemandeEnCrsSusp = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)p_demandeCible, 4);
      if (contexteDemandeEnCrsSusp != null)
      {
        String idDemande = contexteDemandeEnCrsSusp.getIdPremiereDemandeCsrDansSuspension();
        DemandeAssuranceSpec demandeOrigine = (DemandeAssuranceSpec)recupererIndividu(p_demandeCible).rechercherDemande(idDemande);
        if (!demandeOrigine.getIdentifiant().equals(p_demandeCible.getIdentifiant())) {
          OutilsChomageSansRCT.copieDonneesForceesCsr(demandeOrigine, p_demandeCible);
        }
      }
    }
  }
  
  private static void miseAJourDonneesForceesFdd(DemandeAssuranceSpec p_demandeCible)
  {
    Demande demandePrecedente = (Demande)OutilFinDroit.rechercherDemandeODPrecedenteCorrespondante(p_demandeCible);
    if ((demandePrecedente.getSaisieAntecedent() == null) || (!demandePrecedente.getSaisieAntecedent().estAntecedentAsp()))
    {
      DonneesTemporaires donneesForceesDemandeCible = p_demandeCible.getDonneesTemporaires();
      BigDecimal dureeSecteurPublicFinDroit = donneesForceesDemandeCible.getDureeImputationSP();
      Damj djiSpFinDroit = donneesForceesDemandeCible.getDjiSpFinDroit();
      boolean saisieDfSurFinAsp = ((dureeSecteurPublicFinDroit != null) && (new BigDecimal(0.0D).compareTo(dureeSecteurPublicFinDroit) != 0)) || (djiSpFinDroit != null);
      boolean saisieDfSurFinAspCasGeneral = (saisieDfSurFinAsp) && (donneesForceesDemandeCible.isSaisieCasGeneralDonneesTemporaire());
      boolean saisieDfSurFinAspExpat = (saisieDfSurFinAsp) && (donneesForceesDemandeCible.isSaisieCasExpatriesDonneesTemporaire());
      if (demandePrecedente != null) {
        OutilDemande.copieDonneesForcees(demandePrecedente, p_demandeCible);
      }
      donneesForceesDemandeCible.setDureeImputationSP(dureeSecteurPublicFinDroit);
      donneesForceesDemandeCible.setDjiSpFinDroit(djiSpFinDroit);
      if (FabriqueConvention2014.DATE_APPLICATION.estAvantOuCoincideAvec(p_demandeCible.getDateDeclenchementExamen())) {
        donneesForceesDemandeCible.setSjc(null);
      }
      if (saisieDfSurFinAspCasGeneral) {
        donneesForceesDemandeCible.setSaisieCasGeneralDonneesTemporaire(true);
      } else if (saisieDfSurFinAspExpat) {
        donneesForceesDemandeCible.setSaisieCasExpatriesDonneesTemporaire(true);
      }
    }
  }
  
  public static void nettoyerDonneesForcees(DemandeAssuranceSpec p_demandeCible)
  {
    ContexteDemande contexteDemandeEnCrsSusp = (ContexteDemande)OutilGestionContexteDemande.trouverUnContexteDemandeAssurancePresent((Demande)p_demandeCible, 4);
    if (contexteDemandeEnCrsSusp != null)
    {
      String idDemande = contexteDemandeEnCrsSusp.getIdPremiereDemandeCsrDansSuspension();
      DemandeAssuranceSpec demandeOrigine = (DemandeAssuranceSpec)recupererIndividu(p_demandeCible).rechercherDemande(idDemande);
      if (!demandeOrigine.getIdentifiant().equals(p_demandeCible.getIdentifiant())) {
        OutilsChomageSansRCT.copieDonneesForceesCsr(new Demande(), p_demandeCible);
      }
    }
  }
  
  private static void miseAJourDonneesForceesIpr(DemandeAssuranceSpec p_demandeCible)
    throws CoucheLogiqueException
  {
    Demande demandeRevision = GestionDemandeDv122eJour.retrouverDemandePortantDv(p_demandeCible);
    
    DonneesTemporaires donneesForceesDV = demandeRevision.getDonneesTemporaires();
    DonneesTemporaires donneesForcees = p_demandeCible.getDonneesTemporaires();
    if (donneesForceesDV != null)
    {
      donneesForcees.setQuantiteAffiliation(donneesForceesDV.getQuantiteAffiliation());
      donneesForcees.setCoefficientTempsPartielActConservee(donneesForceesDV.getCoefficientTempsPartielActConservee());
      donneesForcees.setSjcPerteActConservee(donneesForceesDV.getSjrPerteActConservee());
      donneesForcees.setDureeTheoriqueForcee(donneesForceesDV.getDureeTheoriqueForcee());
      donneesForcees.setTermePrc(donneesForceesDV.getTermePrc());
      
      donneesForcees.setPmcIndemnisable(donneesForceesDV.isPmcIndemnisable());
      donneesForcees.setFinPmc(donneesForceesDV.getFinPmc());
      donneesForcees.setIndentifiantFctPMC(donneesForceesDV.getIndentifiantFctPMC());
      donneesForcees.setLeveePmc(donneesForceesDV.isLeveePmc());
      donneesForcees.setQuantiteJourICCP(donneesForceesDV.getQuantiteJourICCP());
      donneesForcees.setQuantiteJourISLR(donneesForceesDV.getQuantiteJourISLR());
      donneesForcees.setDelaiAttenteForce(donneesForceesDV.isDelaiAttenteForce());
    }
  }
  
  private static IndividuSpec recupererIndividu(DemandeAssuranceSpec p_demandeCible)
  {
    return p_demandeCible.getDemandeur();
  }
}

/* Location:
 * Qualified Name:     OutilCopieDonneesForcees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */