package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAyantMemePays;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.Collection;

public final class OutilGestionEESSI
{
  private static final int DUREE_MOIS_PERIODE_RECHERCHE = 24;
  private static final int NB_JOURS_ACTIVITE_LONGUE_DUREE = 365;
  private static final int NB_MOIS_A_REMBOURSER_PAR_DEFAUT = 3;
  private static final int NB_MOIS_A_REMBOURSER_LONGUE_DUREE = 5;
  private static OutilGestionEESSI instance = new OutilGestionEESSI();
  
  public static OutilGestionEESSI getInstance()
  {
    return instance;
  }
  
  public int determinerNombreMoisARembourser(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    int nbreMoisRembourses = 3;
    
    Periode periodeRecherche = determinerPeriodeRecherche(demande);
    if ((periodeRecherche != null) && (demande.getFaitGenerateur() != null))
    {
      ActiviteSalarie activiteFgd = demande.getFaitGenerateur().getPeriodeFaitGenerateur();
      int paysFgd = activiteFgd.getContrat().getPays();
      
      FiltresTemporel listeFiltres = new FiltresTemporel();
      listeFiltres.ajouterFiltre(new FiltreActiviteSalarieAyantMemePays(paysFgd));
      listeFiltres.ajouterFiltre(new FiltreChevauchePeriode(periodeRecherche));
      listeFiltres.ajouterFiltre(new FiltreFinDansBornes(periodeRecherche));
      ChronologiePeriodes chronoActiviteSalarieParticipantes = (ChronologiePeriodes)demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(listeFiltres);
      
      int nbrejoursActiviteDansPeriodeRecherche = periodeRecherche.inter(chronoActiviteSalarieParticipantes);
      if (nbrejoursActiviteDansPeriodeRecherche >= 365) {
        nbreMoisRembourses = 5;
      }
    }
    return nbreMoisRembourses;
  }
  
  private Periode determinerPeriodeRecherche(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    Periode periodeRecherche = null;
    
    Damj dateDepartPeriode = null;
    Damj termePeriode = null;
    if (demande.getFaitGenerateur() != null) {
      termePeriode = demande.getFaitGenerateur().getDateFaitGenerateur();
    }
    if (termePeriode != null)
    {
      DureeCalendaire dureeMoisPeriode = new DureeCalendaire(0, 24);
      periodeRecherche = CalculDelais.determinerDelai(termePeriode, dureeMoisPeriode);
      dateDepartPeriode = periodeRecherche.getDebut().lendemain();
      periodeRecherche.setDebut(dateDepartPeriode);
    }
    Damj borneDepartPeriode = demande.getDateFaitGenerateurOdPrecedente();
    if ((borneDepartPeriode != null) && (dateDepartPeriode != null) && (dateDepartPeriode.estAvantOuCoincideAvec(borneDepartPeriode)))
    {
      dateDepartPeriode = borneDepartPeriode.lendemain();
      periodeRecherche.setDebut(dateDepartPeriode);
    }
    return periodeRecherche;
  }
  
  public boolean estTemporelActiviteSalarieeOrigineE301(Temporel temporel)
  {
    return (temporel.estType(ActiviteSalarie.class)) && (((ActiviteSalarie)temporel).getCollectionOrigineInformationPAS().contains(Integer.valueOf(10)));
  }
  
  public boolean estAttributionAssuranceFrontaliere(AttributionAssuranceSpec attributionAssurance)
  {
    boolean retour = false;
    if ((attributionAssurance != null) && (!attributionAssurance.getDemande().estEnReExamen()))
    {
      FaitGenerateurSpec faitGenerateur = attributionAssurance.getFaitGenerateur();
      if (faitGenerateur != null)
      {
        ActiviteSalarie activiteSalarie = faitGenerateur.getPeriodeFaitGenerateur();
        if ((activiteSalarie != null) && (activiteSalarie.getCollectionOrigineInformationPAS().contains(Integer.valueOf(10)))) {
          retour = true;
        }
      }
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     OutilGestionEESSI
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */