package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.RevisionAdmission;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.PeriodeGaecSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeInr;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourNatureDecision;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionsSuivantesSurDecisions;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.List;
import java.util.Map;

public class OutilVerificationPresenceRevision
{
  public void controlerPresenceDemandeRevision(DemandeSpec demandePrestationsCourante, fr.unedic.cali.dom.AttributionAssuranceSpec attributionAssurancePrecedente)
    throws CoucheLogiqueException
  {
    Chronologie activitesConserveesPerdues = ((fr.unedic.cali.asu.dom.AttributionAssuranceSpec)attributionAssurancePrecedente).getListeActiviteConserveePerdues();
    List<TravailSpec> activitesConserveesPerduesRevisees = ((DecisionAssuranceSpec)attributionAssurancePrecedente).getListeActiviteConserveePerduesRevisees();
    
    fr.unedic.cali.asu.dom.AttributionAssuranceSpec attributionPrecedente = (fr.unedic.cali.asu.dom.AttributionAssuranceSpec)attributionAssurancePrecedente;
    DemandeSpec cacheDemandeSuivante = null;
    if (attributionPrecedente.getDemandeSuivantePourTraitementReliquat() != null) {
      cacheDemandeSuivante = attributionPrecedente.getDemandeSuivantePourTraitementReliquat();
    }
    if (activitesConserveesPerdues == null) {
      return;
    }
    Map<TravailSpec, DemandeSpec> mapFcts = OutilsRevisions.getMapFctsAssociees(demandePrestationsCourante.getDemandeur());
    activitesConserveesPerdues.iterer();
    while (activitesConserveesPerdues.encoreSuivant())
    {
      TravailSpec activiteCourante = (TravailSpec)activitesConserveesPerdues.elementSuivant();
      if (((activiteCourante instanceof ActiviteSalarie)) && (estActiviteAVerifier(demandePrestationsCourante, activiteCourante)) && (!listeActivitesConserveesPerduesReviseesContient(activitesConserveesPerduesRevisees, activiteCourante)))
      {
        DemandeSpec demandeFcts = (DemandeSpec)mapFcts.get(activiteCourante);
        verifierActiviteCourante(demandePrestationsCourante, attributionPrecedente, activiteCourante, demandeFcts);
      }
    }
    attributionPrecedente.setDemandeSuivantePourTraitementReliquat(cacheDemandeSuivante);
  }
  
  private boolean estActiviteAVerifier(DemandeSpec demandePrestationsCourante, TravailSpec activiteCourante)
  {
    Damj dateExamen = demandePrestationsCourante.getDateExamen();
    return (activiteCourante.getDateFin().estApresOuCoincideAvec(FabriqueConvention2014.DATE_APPLICATION)) && ((activiteCourante.getDateFin().estAvant(dateExamen.veille())) || ((activiteCourante.getDateFin().coincideAvec(dateExamen.veille())) && (!OutilDemande.estUneDemandeRevisionAdmission(demandePrestationsCourante))));
  }
  
  private void verifierActiviteCourante(DemandeSpec demandePrestationsCourante, fr.unedic.cali.asu.dom.AttributionAssuranceSpec attributionPrecedente, TravailSpec activiteCourante, DemandeSpec demandeFcts)
    throws CoucheLogiqueException
  {
    if (demandeFcts == null) {
      try
      {
        attributionPrecedente.setDemandeSuivantePourTraitementReliquat(demandePrestationsCourante);
        
        ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attributionPrecedente, activiteCourante.getDateFin(), true, true);
        if (resultatCalcul.getEtatAttribution() == 3) {
          verifierActiviteNonRevisee();
        }
      }
      catch (ApplicativeException ex)
      {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException(ex.getCode());
      }
    } else if (!demandeFcts.estDecisionnee()) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_REVISION_NON_DECISIONNEE");
    } else {
      verifierActiviteRevisee(demandeFcts);
    }
  }
  
  protected void verifierActiviteRevisee(DemandeSpec demandeFcts)
    throws CoucheLogiqueException
  {}
  
  protected void verifierActiviteNonRevisee()
    throws CoucheLogiqueException
  {
    GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_L_AC_NON_REVISEE");
  }
  
  public Periode recupererPansAttributionArcePrecedente(DemandeSpec demandePrestationsCourante, fr.unedic.cali.dom.AttributionAssuranceSpec attributionAssurancePrecedente)
  {
    Periode retour = null;
    
    fr.unedic.cali.dom.AttributionAssuranceSpec attribAsuPrecedente = attributionAssurancePrecedente;
    if ((attribAsuPrecedente instanceof RevisionAdmission))
    {
      FiltreET filtre = new FiltreET();
      filtre.ajouterFiltre(new FiltreAttributionAssurance(false, false, false, false, null));
      filtre.ajouterFiltre(new FiltreNegation(new FiltreDecisionPourNatureDecision(45)));
      DecisionSpec attrib = OutilRecherche.rechercherDecisionPrecedente(demandePrestationsCourante.getDemandeur().getChronoDemandesNonTriees(), attribAsuPrecedente, filtre);
      if (attrib != null) {
        attribAsuPrecedente = (fr.unedic.cali.dom.AttributionAssuranceSpec)attrib;
      }
    }
    FiltreET filtre = new FiltreET();
    filtre.ajouterFiltre(new FiltreAttributionSurDecisions(true));
    filtre.ajouterFiltre(new FiltreDecisionPourProduit("INR_RCE04_01"));
    filtre.ajouterFiltre(new FiltreDecisionsSuivantesSurDecisions(attribAsuPrecedente));
    DecisionSpec decisionPrecedente = OutilRecherche.rechercherDecisionPrecedente(demandePrestationsCourante.getDemandeur().getChronoDemandesNonTriees(), demandePrestationsCourante, filtre);
    if ((decisionPrecedente instanceof AttributionSpec))
    {
      String idPeriode = GammeInr.getInstance().getIdActiviteLiee(decisionPrecedente.getDemande());
      PeriodeGaecSpec pansArce = demandePrestationsCourante.getDemandeur().rechercherPeriodePasseProfessionnel(idPeriode);
      if (pansArce != null) {
        retour = new Periode(pansArce.getDateDebut(), pansArce.getDateFin());
      }
    }
    return retour;
  }
  
  private boolean listeActivitesConserveesPerduesReviseesContient(List<TravailSpec> listeActivitesConserveesPerduesRevisees, TravailSpec activiteCourante)
  {
    return listeActivitesConserveesPerduesRevisees.contains(activiteCourante);
  }
}

/* Location:
 * Qualified Name:     OutilVerificationPresenceRevision
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */