package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreRevisionConvention2014;
import fr.unedic.cali.asu.dom.EreRevisionSuitePerteActiviteConservee;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.fabriques.FabriqueConvention2014;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDemandesGammeAsu;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteNonSalariee;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreRevision;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreOuvertureDroitStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFinAvantDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Temporel;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public final class OutilsActiviteConserve
{
  public static Chronologie getListeActiviteConservees(IndividuSpec individu, DemandeSpec demande)
  {
    Chronologie listeActiviteConserveOrig = null;
    if (OutilDemande.estUneDemandeRevisionAdmission(demande)) {
      listeActiviteConserveOrig = getListeActiviteConserveesPerduesRevisionAdmission(demande);
    } else {
      listeActiviteConserveOrig = getListeActiviteConserveesPerduesHorsDv(demande);
    }
    if (listeActiviteConserveOrig != null)
    {
      Demande demandeAsu = (Demande)demande;
      List<String> listeIdentifiantActiviteConservee = getListeIdentifiantActiviteConserveePerdueRevisee(individu);
      
      Map<TravailSpec, DemandeSpec> map = OutilsRevisions.getMapFctsAssociees(individu);
      
      listeActiviteConserveOrig.iterer();
      while (listeActiviteConserveOrig.encoreSuivant())
      {
        TravailSpec activite = (TravailSpec)listeActiviteConserveOrig.elementSuivant();
        if ((!activite.getIdentifiant().equals(demandeAsu.getDonneesTemporaires().getIdentifiantPeriodeActiviteConserveePerdue())) && (listeIdentifiantActiviteConservee.contains(activite.getIdentifiant())))
        {
          listeActiviteConserveOrig.supprimer();
        }
        else
        {
          DemandeSpec demandeAssociee = (DemandeSpec)map.get(activite);
          if ((demandeAssociee != null) && (!demandeAssociee.equals(demande))) {
            listeActiviteConserveOrig.supprimer();
          }
        }
      }
    }
    return listeActiviteConserveOrig;
  }
  
  public static Chronologie getListeActiviteConserveesPerduesHorsDv(DemandeSpec demande)
  {
    Chronologie listeActiviteConserveOrig = null;
    AttributionAssuranceSpec odOrigine = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesSansCourante(), demande, new FiltreOuvertureDroitStandardAssurance(false, true, false, false, null));
    if (odOrigine != null) {
      listeActiviteConserveOrig = filtreListeActiviteConserve(odOrigine.getListeActiviteConserveePerdues());
    }
    return listeActiviteConserveOrig;
  }
  
  public static Chronologie getListeActiviteConserveesPerdues(DemandeSpec demande)
  {
    Chronologie listeActiviteConserve = null;
    if (demande.getDossierAffectation().getDossierExamen() != null)
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)demande.getDossierAffectation().getDossierExamen();
      listeActiviteConserve = filtreListeActiviteConserve(attribution.getListeActiviteConserveePerdues());
    }
    return listeActiviteConserve;
  }
  
  public static Chronologie getListeActiviteConserveesPerduesRevisionAdmission(DemandeSpec demande)
  {
    Chronologie listeActiviteConserveOrig = null;
    if ((((Demande)demande).getObjectifCourant() != null) && (NaturesDecisions.estdeTypeReprise(((Demande)demande).getObjectifCourant().getSousType())) && (fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsp(demande)))
    {
      AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesSansCourante(), demande, new FiltreOuvertureDroitStandardAssurance(false, true, false, true, demande));
      
      listeActiviteConserveOrig = attributionPrecedente.getListeActiviteConserveePerdues();
      if ((listeActiviteConserveOrig != null) && (listeActiviteConserveOrig.getTaille() != 0) && (NaturesDecisions.estdeTypeReprise(((Demande)demande).getObjectifCourant().getSousType()))) {
        listeActiviteConserveOrig = filtrerActiviteesConservees(listeActiviteConserveOrig, (Demande)demande);
      }
    }
    else if (fr.unedic.cali.outilsfonctionnels.OutilDemande.estUneDemandeFinDroitAsp(demande))
    {
      AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesSansCourante(), demande, new FiltreOuvertureDroitStandardAssurance(false, true, false, false, null));
      
      listeActiviteConserveOrig = attributionPrecedente.getListeActiviteConserveePerdues();
    }
    else
    {
      AttributionAssuranceSpec attributionPrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getChronologieDemandesSansCourante(), demande, new FiltreAttributionStandardAssurance(false, true, false, false, null));
      if (attributionPrecedente != null) {
        listeActiviteConserveOrig = attributionPrecedente.getListeActiviteConserveePerdues();
      }
    }
    if (listeActiviteConserveOrig != null) {
      listeActiviteConserveOrig = filtreListeActiviteConserveAvecDv(listeActiviteConserveOrig);
    }
    return listeActiviteConserveOrig;
  }
  
  private static Chronologie filtrerActiviteesConservees(Chronologie listeActiviteConserveOrig, Demande demande)
  {
    Chronologie chronoActiviteConservee = new ChronologiePeriodes();
    AttributionSpec attAsp = OutilAsp.getInstance().rechercherAttributionAspLiee(demande);
    listeActiviteConserveOrig.iterer();
    while (listeActiviteConserveOrig.encoreSuivant())
    {
      Temporel temp = listeActiviteConserveOrig.elementSuivant();
      if (attAsp.getDateAttribution().estAvant(temp.getDateFin())) {
        chronoActiviteConservee.ajouter(temp);
      }
    }
    return chronoActiviteConservee;
  }
  
  public static Chronologie filtreListeActiviteConserve(Chronologie listeActiviteConserve)
  {
    FiltresTemporel desFiltres = new FiltresTemporel();
    Chronologie listeActiviteConserveRetour = null;
    if (listeActiviteConserve != null)
    {
      desFiltres.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
      desFiltres.ajouterFiltre(new FiltrePeriodesAttestees());
      desFiltres.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteNonSalariee()));
      desFiltres.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieeMotifDvNonLegitime()));
      listeActiviteConserveRetour = listeActiviteConserve.copier(desFiltres);
    }
    return listeActiviteConserveRetour;
  }
  
  public static Chronologie filtreListeActiviteConserveAvecDv(Chronologie listeActiviteConserve)
  {
    FiltresTemporel desFiltres = new FiltresTemporel();
    Chronologie listeActiviteConserveRetour = null;
    if (listeActiviteConserve != null)
    {
      desFiltres.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
      desFiltres.ajouterFiltre(new FiltrePeriodesAttestees());
      desFiltres.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteNonSalariee()));
      listeActiviteConserveRetour = listeActiviteConserve.copier(desFiltres);
    }
    return listeActiviteConserveRetour;
  }
  
  public static boolean estUneDemandeDeRevision(DemandeSpec demande)
  {
    boolean retour = false;
    if ((demande.getEvenementReferenceExamen() instanceof EreRevisionSuitePerteActiviteConservee)) {
      retour = true;
    }
    return retour;
  }
  
  public static boolean estUneDemandeDeRevisionAdmission(DemandeSpec demande)
  {
    boolean retour = false;
    if ((demande.getEvenementReferenceExamen() instanceof EreRevisionConvention2014)) {
      retour = true;
    }
    return retour;
  }
  
  public static TravailSpec estDerniereActiviteConserveePerdueNonRevisee(DemandeSpec demande)
  {
    AttributionAssuranceSpec attribPrec = ((DemandeAssuranceSpec)demande).rechercherAttributionPrecedenteDuMemeType();
    if (attribPrec != null)
    {
      Chronologie listeACP = attribPrec.getListeActiviteConserveePerdues();
      if ((listeACP != null) && (listeACP.getTaille() > 0))
      {
        FiltresTemporel desFiltres = new FiltresTemporel();
        desFiltres.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieeMotifDvNonLegitime()));
        desFiltres.ajouterFiltre(new FiltreActiviteSalarieFinAvantDate(FabriqueConvention2014.DATE_APPLICATION));
        listeACP = listeACP.copier(desFiltres);
        if ((listeACP != null) && (listeACP.getTaille() > 0))
        {
          listeACP.setComparateur(new ComparateurTemporelsSurDateFin());
          listeACP.iterer();
          TravailSpec derniereActivite = (TravailSpec)listeACP.dernierElement();
          List<String> listeIdentifiantACPR = getListeIdentifiantActiviteConserveePerdueSurDemandeRevision(demande);
          if ((!listeIdentifiantACPR.contains(derniereActivite.getIdentifiant())) && (!derniereActivite.getDateFin().estApres(demande.getDateExamen()))) {
            return derniereActivite;
          }
        }
      }
    }
    return null;
  }
  
  private static List<String> getListeIdentifiantActiviteConserveePerdueRevisee(IndividuSpec individu)
  {
    FiltresTemporel listeFiltres = new FiltresTemporel();
    listeFiltres.ajouterFiltre(new FiltreDemandesGammeAsu());
    listeFiltres.ajouterFiltre(new FiltreRevision());
    Chronologie listeRevisions = individu.getChronoDemandes().copier(listeFiltres);
    
    Demande demande = null;
    List<String> listeIdentifiantActiviteConserveePerdueRevisee = new ArrayList();
    listeRevisions.iterer();
    while (listeRevisions.encoreSuivant())
    {
      demande = (Demande)listeRevisions.elementSuivant();
      listeIdentifiantActiviteConserveePerdueRevisee.add(demande.getDonneesTemporaires().getIdentifiantPeriodeActiviteConserveePerdue());
    }
    return listeIdentifiantActiviteConserveePerdueRevisee;
  }
  
  private static List<String> getListeIdentifiantActiviteConserveePerdueSurDemandeRevision(DemandeSpec demande)
  {
    Chronologie listeRevisionPrecedente = OutilRecherche.rechercherDemandesPrecedentes(demande.getDemandeur().getChronoDemandesNonTriees(), demande, new FiltreDemandePourERE("ASU_07"));
    
    List<String> listeIdentifiantActiviteConserveePerdueRevisee = new ArrayList();
    listeRevisionPrecedente.iterer();
    while (listeRevisionPrecedente.encoreSuivant())
    {
      DemandeAssuranceSpec demandeRevision = (DemandeAssuranceSpec)listeRevisionPrecedente.elementSuivant();
      listeIdentifiantActiviteConserveePerdueRevisee.add(demandeRevision.getDonneesTemporaires().getIdentifiantPeriodeActiviteConserveePerdue());
    }
    return listeIdentifiantActiviteConserveePerdueRevisee;
  }
  
  public static void alimenterDonneesPerteActiviteConserveSurRevision(DossierExamenAssuranceSpec dossierExamen)
  {
    DemandeAssuranceSpec demande = (DemandeAssuranceSpec)dossierExamen.getDemande();
    
    String identifiantPeriodeActiviteConserveePerdue = demande.getDonneesTemporaires().getIdentifiantPeriodeActiviteConserveePerdue();
    if (identifiantPeriodeActiviteConserveePerdue != null)
    {
      ActiviteSalarie periodeActiviteConserveePerdue = (ActiviteSalarie)demande.getDemandeur().rechercherPeriodePasseProfessionnel(identifiantPeriodeActiviteConserveePerdue);
      if (periodeActiviteConserveePerdue != null)
      {
        dossierExamen.setDateFinPerteActiviteConservee(periodeActiviteConserveePerdue.getDateFin());
        dossierExamen.setMotifFinPerteActiviteConservee(periodeActiviteConserveePerdue.getMotifFin());
      }
    }
  }
}

/* Location:
 * Qualified Name:     OutilsActiviteConserve
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */