package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.ConditionChomageInvolontaireSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeAsu;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuCva10P02;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreRevisionAre14;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDecisionPourProduit;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreOuvertureDroitSurDecision;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class OutilsRevisions
{
  public static Map<TravailSpec, DemandeSpec> getMapFctsAssociees(IndividuSpec p_demandeur)
  {
    HashMap<TravailSpec, DemandeSpec> mapRetour = new HashMap();
    
    FiltreOU filtre = new FiltreOU();
    FiltreDemandePourERE filtreEre = new FiltreDemandePourERE("ASU_28");
    
    filtre.ajouterFiltre(filtreEre);
    
    Chronologie chronoAsu = OutilRecherche.rechercherDemandesPrecedentes(p_demandeur.getChronoDemandeAssurance(), Damj.FIN_DES_TEMPS, filtre);
    
    chronoAsu.iterer();
    Demande demandeCourante;
    while (chronoAsu.encoreSuivant())
    {
      demandeCourante = (Demande)chronoAsu.elementSuivant();
      if (demandeCourante.getClassementAdministratif() == null)
      {
        List<TravailSpec> listeFcts = getListeFctsAssociees(demandeCourante);
        for (TravailSpec travail : listeFcts) {
          mapRetour.put(travail, demandeCourante);
        }
      }
    }
    return mapRetour;
  }
  
  public static List<TravailSpec> getListeFctsAssociees(IndividuSpec p_demandeur)
  {
    List<TravailSpec> listeRetour = new ArrayList();
    
    FiltreOU filtre = new FiltreOU();
    FiltreDemandePourERE filtreEre = new FiltreDemandePourERE("ASU_28");
    filtre.ajouterFiltre(filtreEre);
    
    Chronologie chronoAsu = OutilRecherche.rechercherDemandesPrecedentes(p_demandeur.getChronoDemandeAssurance(), Damj.FIN_DES_TEMPS, filtre);
    
    chronoAsu.iterer();
    while (chronoAsu.encoreSuivant())
    {
      Demande demandeCourante = (Demande)chronoAsu.elementSuivant();
      if (demandeCourante.getClassementAdministratif() == null) {
        listeRetour.addAll(getListeFctsAssociees(demandeCourante));
      }
    }
    return listeRetour;
  }
  
  public static List<TravailSpec> getListeFctsAssociees(Demande p_demandeRevision)
  {
    List<TravailSpec> listeRetour = new ArrayList();
    List<DemandeAssuranceSpec> listeDemandesAssociees = getListeDemandesAssociees(p_demandeRevision);
    for (DemandeAssuranceSpec demandeCourante : listeDemandesAssociees) {
      listeRetour.add(demandeCourante.getDonneesTemporaires().getPeriodeRevision());
    }
    return listeRetour;
  }
  
  public static List<TravailSpec> getListeFctsAssocieesAdmission(Demande p_demandeRevision)
  {
    List<TravailSpec> listeRetour = new ArrayList();
    List<DemandeAssuranceSpec> listeDemandesAssociees = getListeDemandesAssocieesAdmission(p_demandeRevision);
    for (DemandeAssuranceSpec demandeCourante : listeDemandesAssociees) {
      listeRetour.add(demandeCourante.getDonneesTemporaires().getPeriodeRevision());
    }
    return listeRetour;
  }
  
  public static List<DemandeAssuranceSpec> getListeDemandesAssociees(Demande p_demandeRevision)
  {
    List<DemandeAssuranceSpec> listeRetour = new ArrayList();
    
    Demande demandeAssocieeCourante = null;
    if (p_demandeRevision.getDonneesDemandeAssociee() != null) {
      demandeAssocieeCourante = p_demandeRevision.getDonneesDemandeAssociee().getDemandeAssociee();
    }
    while (demandeAssocieeCourante != null)
    {
      listeRetour.add(demandeAssocieeCourante);
      if (demandeAssocieeCourante.getDonneesDemandeAssociee() != null) {
        demandeAssocieeCourante = demandeAssocieeCourante.getDonneesDemandeAssociee().getDemandeAssociee();
      } else {
        demandeAssocieeCourante = null;
      }
    }
    return listeRetour;
  }
  
  public static List<DemandeAssuranceSpec> getListeDemandesAssocieesAdmission(Demande p_demandeRevision)
  {
    List<DemandeAssuranceSpec> listeRetour = new ArrayList();
    
    Demande demandeAssocieeCourante = null;
    if (p_demandeRevision.getDonneesDemandeAssociee() != null) {
      demandeAssocieeCourante = p_demandeRevision.getDonneesDemandeAssociee().getDemandeAssociee();
    }
    while (demandeAssocieeCourante != null)
    {
      if (demandeAssocieeCourante.getAttribution() != null) {
        listeRetour.add(demandeAssocieeCourante);
      }
      if (demandeAssocieeCourante.getDonneesDemandeAssociee() != null) {
        demandeAssocieeCourante = demandeAssocieeCourante.getDonneesDemandeAssociee().getDemandeAssociee();
      } else {
        demandeAssocieeCourante = null;
      }
    }
    return listeRetour;
  }
  
  public static boolean estContexteAttributionEnCoursRevisionAre14AvecRejetDv(DemandeSpec pDemande)
  {
    boolean retour = false;
    if (GammeAsu.getInstance().getLibelle().equals(pDemande.getGamme().getLibelle()))
    {
      Demande demande = (Demande)pDemande;
      boolean estRevisionAre14 = "ASU_28".equals(pDemande.getEvenementReferenceExamen().getTypeExamen());
      boolean estContexteAreSousJacentRevision = OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ARESJREV");
      
      boolean estDemandeLiquidationRevision14 = (estRevisionAre14) || (estContexteAreSousJacentRevision);
      AttributionAssuranceSpec attribution = demande.getAttribution();
      retour = (estDemandeLiquidationRevision14) && (attribution != null) && (attribution.getConditionChomageInvolontaire() != null) && (!attribution.getConditionChomageInvolontaire().estSatisfait());
    }
    return retour;
  }
  
  public static List<TravailSpec> trouverListeFctReviseesAre14(Demande p_demandePostRevision)
  {
    List<TravailSpec> listeChronoRevisees = new ArrayList();
    Chronologie chronologieRevisionAre14 = OutilRecherche.rechercherDemandesPrecedentes(p_demandePostRevision.getChronologieDemandesAssuranceSansCourante(), p_demandePostRevision, new FiltreRevisionAre14(true));
    
    Iterator<Demande> iterateur = chronologieRevisionAre14.iterer();
    while (iterateur.hasNext())
    {
      Demande demandeRevision = (Demande)iterateur.next();
      
      List<TravailSpec> listeFctDonnantAdmission = getListeFctsAssocieesAdmission(demandeRevision);
      listeChronoRevisees.addAll(listeFctDonnantAdmission);
    }
    FiltreET filtreOdAsp = new FiltreET();
    filtreOdAsp.ajouterFiltre(new FiltreOuvertureDroitSurDecision());
    filtreOdAsp.ajouterFiltre(new FiltreDecisionPourProduit(ProduitAsuCva10P02.getInstance().getCode()));
    Chronologie chronologieAspDc = OutilRecherche.rechercherDecisionsPrecedentes(p_demandePostRevision.getChronologieDemandesAssuranceSansCourante(), p_demandePostRevision, filtreOdAsp);
    
    Iterator<Attribution> it = chronologieAspDc.iterer();
    while (it.hasNext())
    {
      Attribution odAsp = (Attribution)it.next();
      listeChronoRevisees.addAll(odAsp.getListeActiviteConserveePerduesRevisees());
    }
    return listeChronoRevisees;
  }
}

/* Location:
 * Qualified Name:     OutilsRevisions
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */