package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAvecChomageTotalSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301NonFrontalier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFctPrincipale;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreTravailSpec;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreOU;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFct;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalariePourChampApplication;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieSurObjetChronoPeriode;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinActivite;
import fr.unedic.util.temps.FiltreFinApresOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltreMemeDateFin;
import fr.unedic.util.temps.FiltresTemporel;

public class RechercherDernierSinistre
{
  public static TravailSpec rechercherDernierSinistrePourQualificationPeriode(Damj date, Chronologie chronologie, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    TravailSpec dernierSinistre = null;
    if ((chronologie != null) && (!chronologie.estVide()))
    {
      FiltresTemporel filtres = new FiltresTemporel();
      FiltreTravailSpec filtrePas = new FiltreTravailSpec();
      FiltreFinActivite filtreFin = new FiltreFinActivite();
      filtres.ajouterFiltre(filtrePas);
      filtres.ajouterFiltre(filtreFin);
      Chronologie chronoPeriodeActiviteSalarieFinies = chronologie.copier(filtres);
      
      Chronologie chronoSinistres = chronoPeriodeActiviteSalarieFinies.copier(new FiltreFinAvantOuCoincideAvecDate(date));
      
      chronoSinistres = chronoSinistres.copier(new FiltrePeriodeActiviteSalarieeE301NonFrontalier(false));
      
      controlerFctPrincipale(chronoSinistres, demande);
      
      dernierSinistre = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.recupererDernierSinistreDansChronoSinistres(chronoSinistres);
    }
    return dernierSinistre;
  }
  
  private static void controlerFctPrincipale(Chronologie chronoSinistres, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    if ((chronoSinistres != null) && (!chronoSinistres.estVide()))
    {
      Damj dateFaitGenerateurOdPrecedente = ((Demande)demande).getDateFaitGenerateurOdPrecedente();
      Chronologie sinistreAPrendreEnCompte = null;
      if (dateFaitGenerateurOdPrecedente != null)
      {
        FiltreFinApresOuCoincideAvecDate debutapresFgOdPrec = new FiltreFinApresOuCoincideAvecDate(dateFaitGenerateurOdPrecedente.lendemain());
        
        sinistreAPrendreEnCompte = chronoSinistres.copier(debutapresFgOdPrec);
      }
      else
      {
        sinistreAPrendreEnCompte = chronoSinistres;
      }
      if ((sinistreAPrendreEnCompte != null) && (!sinistreAPrendreEnCompte.estVide()))
      {
        sinistreAPrendreEnCompte.iterer();
        while (sinistreAPrendreEnCompte.encoreSuivant())
        {
          TravailSpec sinistreCourant = (TravailSpec)sinistreAPrendreEnCompte.elementSuivant();
          FiltresTemporel filtreFCT = new FiltresTemporel();
          filtreFCT.ajouterFiltre(new FiltreMemeDateFin(sinistreCourant.getDateFin()));
          Chronologie chronoFctMemeDateFin = sinistreAPrendreEnCompte.copier(filtreFCT);
          if ((chronoFctMemeDateFin != null) && (chronoFctMemeDateFin.getTaille() == 1))
          {
            FiltresTemporel filtre = new FiltresTemporel();
            filtre.ajouterFiltre(new FiltrePeriodeFctPrincipale(sinistreCourant.getDateFin()));
            Chronologie chronoFctPrincipale = chronoFctMemeDateFin.copier(filtre);
            if ((chronoFctPrincipale != null) && (!chronoFctPrincipale.estVide()))
            {
              Damj dateFctTopeePrincipale = ((TravailSpec)chronoFctPrincipale.premierElement()).getDateFin();
              
              GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ERR_PAS_SELECTION_FCT_PRINCIPALE", new Object[] { dateFctTopeePrincipale.toString() });
            }
          }
        }
      }
    }
  }
  
  public static TravailSpec rechercherDernierSinistre(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantes)
    throws CoucheLogiqueException
  {
    TravailSpec dernierSinistre = null;
    Chronologie chronoPeriodesParticipantesBornee = null;
    
    Damj dateFgdOdPrecedente = demandeAssurance.getDateFaitGenerateurOdPrecedente();
    if ((dateFgdOdPrecedente != null) && (chronoPeriodesParticipantes != null))
    {
      FiltreFinApresOuCoincideAvecDate filtre = new FiltreFinApresOuCoincideAvecDate(dateFgdOdPrecedente.lendemain());
      chronoPeriodesParticipantesBornee = chronoPeriodesParticipantes.copier(filtre);
    }
    else
    {
      chronoPeriodesParticipantesBornee = chronoPeriodesParticipantes;
    }
    if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demandeAssurance))
    {
      dernierSinistre = determinerDernierSinitrePourChomageSansRCT(demandeAssurance, chronoPeriodesParticipantesBornee, chronoPeriodesParticipantes);
    }
    else
    {
      FiltreOU filtreExclureNonFctOuHorsChamps = new FiltreOU();
      
      filtreExclureNonFctOuHorsChamps.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieSurObjetChronoPeriode()));
      FiltreET filtreEt = new FiltreET();
      filtreEt.ajouterFiltre(new FiltreActiviteSalarieSurObjetChronoPeriode());
      filtreEt.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalariePourChampApplication(2)));
      filtreEt.ajouterFiltre(new FiltreActiviteSalarieFct());
      filtreExclureNonFctOuHorsChamps.ajouterFiltre(filtreEt);
      if (chronoPeriodesParticipantesBornee != null) {
        chronoPeriodesParticipantesBornee = chronoPeriodesParticipantesBornee.copier(filtreExclureNonFctOuHorsChamps);
      }
      dernierSinistre = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance.getDateExamen(), chronoPeriodesParticipantesBornee);
    }
    return dernierSinistre;
  }
  
  public static TravailSpec determinerDernierSinitrePourChomageSansRCT(DemandeAssuranceSpec demandeAssurance, Chronologie chronoPeriodesParticipantesBornee, Chronologie chronoPeriodesParticipantesNonBornee)
    throws CoucheLogiqueException
  {
    Damj dateRecherche = demandeAssurance.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRecherche == null)
    {
      TravailSpec dernierSinistre = fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre.rechercherDernierSinistre(demandeAssurance.getDateExamen(), chronoPeriodesParticipantesBornee);
      while (((dernierSinistre instanceof ActiviteSalarie)) && (((ActiviteSalarie)dernierSinistre).getChampApplication() == 2)) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_HORS_CHAMP_PAS_MORT");
      }
      return dernierSinistre;
    }
    Chronologie chronoChomageTotalSansRupture = chronoPeriodesParticipantesNonBornee.copier(new FiltreActiviteSalarieAvecChomageTotalSansRupture());
    
    Chronologie chronoChomageTotalSansRuptureAuJourForce = chronoChomageTotalSansRupture.copier(new FiltreFinDansBornes(dateRecherche, dateRecherche));
    if (chronoChomageTotalSansRuptureAuJourForce.estVide()) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_CSR_NON_VALIDE");
    }
    return (TravailSpec)chronoChomageTotalSansRuptureAuJourForce.premierElement();
  }
}

/* Location:
 * Qualified Name:     RechercherDernierSinistre
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */