package fr.unedic.cali.asu.outilsfonctionnels.examenfileau;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.parcours.DomExamenAuFilEau;
import fr.unedic.cali.autresdoms.cohab.sigma.demande.dom.Demande;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireAbstrait;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuFds12P02;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSsp07P03;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.fabriques.FabriqueGammes;
import fr.unedic.cali.fabriques.FabriqueIdentifiantDemandeCojac;
import fr.unedic.cali.outilsfonctionnels.ConstructionCSOIA;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301;
import fr.unedic.cali.parcours.DomCreationDemandePrestation;
import fr.unedic.cali.parcours.DomCreationFormulaires;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatCreationDemandePrestation;
import fr.unedic.cali.parcours.ResultatCreationFormulaires;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

public class ConstructionDemande
{
  private Damj m_dateDepot = null;
  private String m_typeDemande = null;
  public static final Integer DUREE_ANCIENNETE_FILIERE_COURTE_AFD = new Integer(1800);
  
  public ConstructionDemande(Damj p_dateDepot, String p_typeDemande)
  {
    m_dateDepot = p_dateDepot;
    m_typeDemande = p_typeDemande;
  }
  
  public DemandeSpec installerDemande(Contexte p_contexte)
    throws ApplicativeException
  {
    DomExamenAuFilEau dom = (DomExamenAuFilEau)p_contexte.getDonnees();
    IndividuSpec individu = dom.getIndividu();
    
    DemandeSpec demandeCreee = creerDemande(individu, p_contexte, dom.getContexteService());
    
    positionnerDonneesForceesSurDemande((DemandeAssuranceSpec)demandeCreee, dom);
    
    individu.ajouterDemande(demandeCreee);
    
    return demandeCreee;
  }
  
  public DemandeSpec creerDemande(IndividuSpec p_individu, Contexte p_contexte, ContexteService p_contexteService)
    throws ApplicativeException
  {
    DemandeSpec demandeCreee = null;
    String typeDemande = m_typeDemande;
    Damj dateDepot = m_dateDepot;
    
    GammeSpec gamme = FabriqueGammes.getInstance().getGamme(typeDemande);
    
    Demande demandeCojac = new Demande();
    
    demandeCojac.setGamme(gamme.getNomUnique());
    
    demandeCojac.setLigne(determinerLigne(typeDemande));
    demandeCojac.setDateDepot(dateDepot);
    demandeCojac.setIdentifiantDemande(FabriqueIdentifiantDemandeCojac.getInstance().getIdentifiantDemandeCojac(p_individu, typeDemande));
    demandeCojac.setTypeExamen(ConstructionCSOIA.getCSOIADepuisTypeExamen(typeDemande));
    
    demandeCojac.setPresenceAE("O");
    
    DomCreationFormulaires domCreationFormulaire = new DomCreationFormulaires();
    domCreationFormulaire.setIndividu(p_individu);
    
    Collection collectionDemandesCojac = new ArrayList();
    collectionDemandesCojac.add(demandeCojac);
    
    domCreationFormulaire.setCollectionDemandesCojac(collectionDemandesCojac);
    
    Contexte contexteCreationFormulaire = new Contexte();
    contexteCreationFormulaire.setDonnees(domCreationFormulaire);
    contexteCreationFormulaire.setCodeService(p_contexte.getCodeService());
    contexteCreationFormulaire.setModeTrace(false);
    
    Parcours parcoursFabricationFormulairesCali = gamme.getParcoursCreationFormulaire();
    ResultatCreationFormulaires resultatCreationFormulaire = (ResultatCreationFormulaires)parcoursFabricationFormulairesCali.demarrer(contexteCreationFormulaire);
    
    Collection listeNouveauxFormulairesNcp = resultatCreationFormulaire.getCollectionFormulairesCali();
    
    FormulaireAbstrait formulaire = (FormulaireAbstrait)listeNouveauxFormulairesNcp.iterator().next();
    
    DomCreationDemandePrestation domCreationDemande = new DomCreationDemandePrestation();
    domCreationDemande.setFormulaire(formulaire);
    domCreationDemande.setIndividu(p_individu);
    domCreationDemande.setContexteService(p_contexteService);
    
    Contexte contexteCreationDemande = new Contexte();
    contexteCreationDemande.setDonnees(domCreationDemande);
    contexteCreationDemande.setCodeService(p_contexte.getCodeService());
    contexteCreationDemande.setModeTrace(false);
    
    ParcoursCali parcoursCreationDemande = formulaire.getGamme().getParcoursCreationDemande();
    ResultatCreationDemandePrestation resultatCreationDemandePrestation = (ResultatCreationDemandePrestation)parcoursCreationDemande.effectuerParcours(contexteCreationDemande);
    
    demandeCreee = resultatCreationDemandePrestation.getDemande();
    
    return demandeCreee;
  }
  
  private void positionnerDonneesForceesSurDemande(DemandeAssuranceSpec p_demande, DomExamenAuFilEau p_dom)
    throws CoucheLogiqueException
  {
    TravailSpec fct = RechercherDernierSinistre.rechercherDernierSinistre(p_dom.getDateEvenement(), p_demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltreActiviteSalarie()));
    
    p_demande.getDonneesTemporaires().setIdentifiantPeriodeFctARetenir(fct.getIdentifiant());
    if (p_demande.estUneDemandeAtAfd())
    {
      p_demande.getDonneesTemporaires().setSaisieCasSpectacleDonneesTemporaire(true);
      
      p_demande.getDonneesTemporaires().setDureeAncienneteIntermittantSpectacle(DUREE_ANCIENNETE_FILIERE_COURTE_AFD);
    }
    if ((fct instanceof ActiviteSalarie))
    {
      ProduitAsuSpec produitAssurance = null;
      String typeExamenEfe = p_demande.getEvenementReferenceExamen().getTypeExamen();
      if ("ASU_13".equalsIgnoreCase(typeExamenEfe)) {
        produitAssurance = (ProduitAsuSpec)((ActiviteSalarie)fct).getReglement().getProduit();
      } else if ("ASU_14".equalsIgnoreCase(typeExamenEfe)) {
        produitAssurance = ProduitAsuSsp07P03.getInstance();
      } else if ("ASU_15".equalsIgnoreCase(typeExamenEfe)) {
        produitAssurance = ProduitAsuFds12P02.getInstance();
      }
      if (produitAssurance != null)
      {
        Periode periodePraLaPlusLongue = produitAssurance.determinerPraLaPlusLongue(p_demande, (ActiviteSalarie)fct);
        if (periodePraLaPlusLongue != null)
        {
          FiltresTemporel filtres = new FiltresTemporel();
          filtres.ajouterFiltre(new FiltreChevauchePeriode(periodePraLaPlusLongue));
          filtres.ajouterFiltre(new FiltrePeriodeActiviteSalarieeE301());
          Chronologie chronoPeriodesE301 = p_demande.getDemandeur().getChronoPeriodePasseProfessionnel().copier(filtres);
          if ((chronoPeriodesE301 != null) && (!chronoPeriodesE301.estVide())) {
            p_demande.getDonneesTemporaires().setTypeCoordinationEuropeenne(1);
          }
        }
      }
    }
  }
  
  private String determinerLigne(String p_typeDemande)
  {
    String nomLigne = null;
    if (p_typeDemande.equalsIgnoreCase("ASU_14")) {
      nomLigne = "ASU_SSP07";
    } else if (p_typeDemande.equalsIgnoreCase("ASU_15")) {
      nomLigne = "ASU_FDS12";
    } else if (p_typeDemande.equalsIgnoreCase("ASU_01")) {
      nomLigne = "ASU_CGE01";
    }
    return nomLigne;
  }
}

/* Location:
 * Qualified Name:     ConstructionDemande
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */