package fr.unedic.cali.asu.outilsfonctionnels.liquidationauto;

import fr.pe.cali.crem.dom.ObjetMetierCrem;
import fr.pe.cali.crem.outils.OutilGenerationObjetMetierDalLiquidation;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesSortieNPDE;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.dom.JustificationAffiliation;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieDroitOptionApresARE14;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.ConditionAttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesSortieNPDESpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.NaturesDecisions;
import fr.unedic.cali.dom.OdAssuranceSpec;
import fr.unedic.cali.dom.RepriseSecteurPublicSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuExp03P01;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.IOutilFonctionnelTraitementsErreurs;
import fr.unedic.cali.outilsfonctionnels.OutilFluxInstruction;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalariePourCategorieParticuliere;
import fr.unedic.cali.parcours.DomCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class OutilFonctionnelTraitementsErreurs
  implements IOutilFonctionnelTraitementsErreurs
{
  private static final int TAILLE_MAX_MOTIF_ECHEC = 49;
  private static Map<String, String> mapCodeErreurs = new HashMap();
  private static Map<String, String> mapCodeErreursSimplifiee;
  
  static
  {
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_REJET_DV", "A");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_ASS_MAT", "B");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_REJET_9A9B", "C");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_REJET_A8", "D");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_REJET_A10", "E");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_PRA_FRONTALIER", "F");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_STATUT_PARTICULIER", "G");
    
    mapCodeErreurs.put("ASU_PR_CALI_L_ALERTE_A8MB16", "G");
    mapCodeErreurs.put("ASU_PR_N_CALI_NPDE_DECISION_PREC_SP", "H");
    
    mapCodeErreurs.put("ASU_PR_CALI_L_CONTEXTE_ABSENCE_ELEMENTS_DROIT", "H");
    
    mapCodeErreursSimplifiee = new HashMap();
    mapCodeErreursSimplifiee.put("ASU_PR_CALI_L_LS_ENVOI_DAL_AMB19BO", "I");
    mapCodeErreursSimplifiee.put("ASU_PR_CALI_L_ALERTE_A11MB4", "I");
    mapCodeErreursSimplifiee.put("ASU_PR_CALI_L_ALERTE_A11MB4_BS", "I");
    mapCodeErreursSimplifiee.put("ASU_PR_CALI_L_ALERTE_A11MB4_DNJ", "I");
    mapCodeErreursSimplifiee.put("ASU_PR_CALI_L_ALERTE_A14MB1_DNJ", "I");
    mapCodeErreursSimplifiee.put("ASU_PR_CALI_L_DEMANDE_EXPRESSE_SIMPL", "I");
  }
  
  public static OutilFonctionnelTraitementsErreurs getInstance()
  {
    return new OutilFonctionnelTraitementsErreurs();
  }
  
  public boolean estBlocageLieAContexteNonEligibiliteNPDE(CoucheLogiqueException exception)
  {
    return mapCodeErreurs.containsKey(exception.getCode());
  }
  
  public String traiterAttentesSpecifiques(String modeTraitementDemande, String codeErreur)
  {
    String attente = (String)mapCodeErreurs.get(codeErreur);
    if ((attente == null) && ("S".equals(modeTraitementDemande))) {
      attente = (String)mapCodeErreursSimplifiee.get(codeErreur);
    }
    return attente;
  }
  
  public void verifierPresenceAlertesNonBloquantes(Demande demande)
    throws CoucheLogiqueException
  {
    List<String> listANB = alimenterListANBMiseEnAttente();
    Map<?, ?> mapANBDemande = demande.getAlertesNonBloquantes();
    for (int i = 0; i < listANB.size(); i++)
    {
      String anb = (String)listANB.get(i);
      if (mapANBDemande.containsKey(anb))
      {
        boolean autoriserLiquidationAuto = detecterContexteLiquidationAutorise(anb, demande);
        if (!autoriserLiquidationAuto) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException(anb);
        }
      }
    }
  }
  
  protected boolean detecterContexteLiquidationAutorise(String anb, Demande demande)
  {
    boolean estLiquidationAutorise = false;
    boolean echecAbsenceFgOuHorsChampTrouve = false;
    if (demande.getDossierExamen() != null)
    {
      List<ConditionAttributionSpec> conditionAttribution = demande.getDossierExamen().getListConditionsAttribution();
      Iterator<ConditionAttributionSpec> iter = conditionAttribution.iterator();
      echecAbsenceFgOuHorsChampTrouve = estEchecAbsenceFgOuHorsChamp(echecAbsenceFgOuHorsChampTrouve, iter);
      int natureDecision = ((DecisionSpec)demande.getDossierExamen()).getNatureDecision();
      if (("A8MNB6".equals(anb)) && ((NaturesDecisions.estdeTypeReprise(natureDecision)) || ((NaturesDecisions.estdeTypeRejet(natureDecision)) && (echecAbsenceFgOuHorsChampTrouve)))) {
        estLiquidationAutorise = true;
      }
    }
    return estLiquidationAutorise;
  }
  
  private boolean estEchecAbsenceFgOuHorsChamp(boolean echecAbsenceFgOuHorsChampTrouve, Iterator<ConditionAttributionSpec> iter)
  {
    boolean resultat = echecAbsenceFgOuHorsChampTrouve;
    while ((iter.hasNext()) && (!resultat))
    {
      ConditionAttributionSpec condition = (ConditionAttributionSpec)iter.next();
      if (condition != null)
      {
        int codeEchec = condition.getCodeMotifEchec();
        if ((42 == codeEchec) || (41 == codeEchec)) {
          resultat = true;
        }
      }
    }
    return resultat;
  }
  
  private List<String> alimenterListANBMiseEnAttente()
  {
    ArrayList<String> listANB = new ArrayList();
    
    listANB.add("A6MNB1");
    
    listANB.add("A8MNB4");
    
    listANB.add("AMNB8");
    
    listANB.add("A8MNB6");
    
    listANB.add("AMNB2");
    
    listANB.add("A11MNB11");
    
    listANB.add("A14MNB2");
    
    listANB.add("A14MBN3");
    
    listANB.add("AMNB7");
    
    listANB.add("A16MNB4");
    
    listANB.add("A16MNB6");
    
    listANB.add("AFFI_SP_PMVS");
    
    listANB.add("BORNES_PEC_A_DEPLACER");
    
    listANB.add("SALAIRE_CT_INCOHERENT");
    
    listANB.add("REPRISE_CRA");
    
    listANB.add("ANB_PJI_ATTRIB_PRECEDENTE_APRES");
    
    listANB.add("ANB_OD_AVEC_OD_PREC_EN_CRS_DISPO");
    return listANB;
  }
  
  public void verifierPresenceContexteNonEligible(Demande demande)
    throws CoucheLogiqueException
  {
    verifierContexteVNE7();
    verifierContexteVNE6(demande);
    verifierContexteVNE5(demande);
    verifierContexteVNE4(demande);
    verifierContexteVNE3(demande);
    verifierContexteVNE2(demande);
    verifierContexteVNE1(demande);
    verifierContexteCompetenceSP(demande);
    verifierContexteEnCoursDeDisponibilite(demande);
  }
  
  public void controlesPostLiquidationAutomatique(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    Demande demandeAsu = (Demande)demande;
    
    verifierPresenceContexteNonEligible(demandeAsu);
    
    verifierPresenceAlertesNonBloquantes(demandeAsu);
    
    verifierDroitApprenti(demandeAsu);
  }
  
  protected void verifierContexteVNE4(Demande demande)
    throws CoucheLogiqueException
  {
    if (demande.getDossierExamen() != null)
    {
      int natureDecision = ((DecisionSpec)demande.getDossierExamen()).getNatureDecision();
      if (((NaturesDecisions.estdeTypeAttribution(natureDecision)) || (NaturesDecisions.estdeTypeRejet(natureDecision))) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getReglementApplicable() != null))
      {
        Reglement reglementApp = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getReglementApplicable();
        if ("A8".equals(reglementApp.getNomReglement())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_REJET_A8");
        } else if ("A10".equals(reglementApp.getNomReglement())) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_REJET_A10");
        }
      }
    }
  }
  
  public void verifierContexteReglementSpectacle(Demande demande)
  {
    if (demande.getDossierExamen() != null)
    {
      int natureDecision = ((DecisionSpec)demande.getDossierExamen()).getNatureDecision();
      if (((NaturesDecisions.estdeTypeAttribution(natureDecision)) || (NaturesDecisions.estdeTypeRejet(natureDecision))) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getReglementApplicable() != null))
      {
        Reglement reglementApp = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getReglementApplicable();
        if (("A8".equals(reglementApp.getNomReglement())) || ("A10".equals(reglementApp.getNomReglement()))) {
          demande.setCodeAttente("J");
        }
      }
    }
  }
  
  protected void verifierContexteVNE3(Demande demande)
    throws CoucheLogiqueException
  {
    if (demande.getDossierExamen() != null)
    {
      int natureDecision = ((DecisionSpec)demande.getDossierExamen()).getNatureDecision();
      if ((NaturesDecisions.estdeTypeAttribution(natureDecision)) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().isEstProduitValide()))
      {
        Reglement reglementApp = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getReglementApplicable();
        if (("A9A".equals(reglementApp.getNomReglement())) || ("A9B".equals(reglementApp.getNomReglement()))) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_REJET_9A9B");
        }
      }
      if ((NaturesDecisions.estdeTypeRejet(natureDecision)) && (ProduitAsuExp03P01.getInstance().getNomUnique().equals(demande.getDossierAffectation().getProduit().getNomUnique()))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_REJET_9A9B");
      }
    }
  }
  
  protected void verifierContexteVNE6(Demande demande)
    throws CoucheLogiqueException
  {
    String codeErreurANB = "AMNB8";
    if (demande.getAlertesNonBloquantes().containsKey("AMNB8")) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_STATUT_PARTICULIER");
    }
  }
  
  protected void verifierContexteVNE2(Demande demande)
    throws CoucheLogiqueException
  {
    Periode periode = recupererPra(demande);
    if (periode != null)
    {
      ChronologiePeriodes passePro = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
      
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreChevauchePeriode(periode));
      filtres.ajouterFiltre(new FiltreActiviteSalariePourCategorieParticuliere(23));
      Chronologie chrono = passePro.copier(filtres);
      if (!chrono.estVide()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_ASS_MAT");
      }
    }
  }
  
  private Periode recupererPra(Demande demande)
  {
    Periode periode = null;
    if ((demande.getDossierAffectation() != null) && (((DossierAffectation)demande.getDossierAffectation()).getValidationProduit() != null))
    {
      ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
      periode = validationProduit.getPeriodePra();
      if ((periode == null) && (validationProduit.getJustificationCalculAffiliation() != null)) {
        periode = validationProduit.getJustificationCalculAffiliation().getPeriodeRechercheAffiliation();
      }
    }
    return periode;
  }
  
  protected void verifierContexteVNE1(Demande demande)
    throws CoucheLogiqueException
  {
    if (demande.getDossierExamen() != null)
    {
      boolean estEnRejetDV = ((DossierExamenAssuranceSpec)demande.getDossierExamen()).estRejetDV();
      if (estEnRejetDV) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_REJET_DV");
      }
    }
  }
  
  protected void verifierContexteVNE5(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    String anbContexte = "A8MNB4";
    Map<?, ?> mapANBDemande = demande.getAlertesNonBloquantes();
    if (mapANBDemande.containsKey("A8MNB4")) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_NPDE_PRA_FRONTALIER");
    }
  }
  
  protected void verifierContexteCompetenceSP(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    boolean bloquer = false;
    if (demande.getAttribution() != null)
    {
      AttributionAssuranceSpec attribution = demande.getAttribution();
      ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
      if (!produit.estCompetenceAdministrativeRac(attribution)) {
        bloquer = true;
      }
    }
    if ((demande.getDossierExamen() instanceof RepriseSecteurPublicSpec)) {
      bloquer = true;
    }
    if (bloquer) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_COMPETENCE_AMD_SP");
    }
  }
  
  protected void verifierContexteEnCoursDeDisponibilite(DemandeAssuranceSpec demande)
    throws CoucheLogiqueException
  {
    if (demande.estEnContexteDemande("COURSDISPO")) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_CONTEXTE_EN_COURS_DE_DISPO");
    }
  }
  
  public void traitementBlocagesFonctionnelsLiquidationAutoNPDE(DemandeSpec demande, CoucheLogiqueException ex)
    throws CoucheLogiqueException
  {
    Demande demandeAsu = (Demande)demande;
    nettoyerDemande(demande);
    String modeTraitement = demande.getDonneesSortieNPDE().getModeTraitementDemande();
    String codeException = ex.getCode();
    String attente = getInstance().traiterAttentesSpecifiques(modeTraitement, codeException);
    
    demande.setCodeAttente(attente);
    demandeAsu.getDonneesSortieNPDE().setMotifEchecTraitempent(codeException);
    if (estDemandeEligibleASynchronisationCouleurDal(attente, demandeAsu.getFormulaireAsu().getReferenceExterne(), demandeAsu.getEvenementReferenceExamen().getLibelleLong())) {
      OutilFluxInstruction.creerTraceTrackerPourD12DalSynchronisationCouleurDal(demandeAsu.getDemandeur(), demandeAsu.getFormulaireAsu().getReferenceExterne(), attente);
    }
  }
  
  private boolean estDemandeEligibleASynchronisationCouleurDal(String attente, String referenceExterne, String nomEre)
  {
    ArrayList<String> listeEreNonAutorise = new ArrayList();
    listeEreNonAutorise.add("Rechargement");
    listeEreNonAutorise.add("Demande de Perte act. cons.");
    return (attente != null) && (referenceExterne != null) && (!listeEreNonAutorise.contains(nomEre));
  }
  
  public void traitementBlocagesTechniquesLiquidationAuto(DemandeSpec demande, Exception ex)
  {
    Demande demandeAsu = (Demande)demande;
    nettoyerDemande(demande);
    if (ex.getMessage() != null)
    {
      String messageErreur = ex.getMessage();
      if (messageErreur.length() > 49) {
        messageErreur = messageErreur.substring(0, 49);
      }
      demandeAsu.getDonneesSortieNPDE().setMotifEchecTraitempent(messageErreur);
    }
  }
  
  protected void verifierDroitApprenti(Demande demande)
  {
    int natureDecision = ((DecisionSpec)demande.getDossierExamen()).getNatureDecision();
    if ((demande.getAttribution() != null) && (NaturesDecisions.estdeTypeReprise(natureDecision)))
    {
      OdAssuranceSpec ouvertureDroit = demande.getAttribution().getOuvertureDroit();
      ValidationProduit validationProduit = ((DossierAffectation)ouvertureDroit.getDossierAffecte()).getValidationProduit();
      if (validationProduit != null)
      {
        ActiviteSalarie fctRetenue = validationProduit.getPeriodeValidationProduit();
        if ((fctRetenue != null) && (StrategieDroitOptionApresARE14.estApprenti(fctRetenue))) {
          demande.setCodeAttente("Z");
        }
      }
    }
  }
  
  public void creerTraceCrem(DemandeSpec demande, Contexte contexte)
    throws ApplicativeException
  {
    ObjetMetierCrem crem = creerCrem(demande, contexte);
    ajouterCremSurIndividu(demande, crem);
  }
  
  public void ajouterCremSurIndividu(DemandeSpec demande, ObjetMetierCrem crem)
  {
    if ((crem != null) && (demande.getDemandeur() != null) && (demande.getDemandeur().getListeCrem() != null)) {
      demande.getDemandeur().getListeCrem().add(crem);
    }
  }
  
  private ObjetMetierCrem creerCrem(DemandeSpec demande, Contexte contexte)
    throws ApplicativeException
  {
    return OutilGenerationObjetMetierDalLiquidation.getInstance().genererObjetMetier(demande, getContexteService(contexte));
  }
  
  private ContexteService getContexteService(Contexte contexte)
  {
    DomCali domCali = (DomCali)contexte.getDonnees();
    return domCali.getContexteService();
  }
  
  public void nettoyerDemande(DemandeSpec demande)
  {
    demande.setValide(false);
    
    demande.annulerDecisions();
    
    demande.setListeMotifsReexamen(null);
  }
  
  protected void verifierContexteVNE7() {}
}

/* Location:
 * Qualified Name:     OutilFonctionnelTraitementsErreurs
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */