package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.outilsfonctionnels.OutilVerificationPreconditions;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreAttributionSurDecisions;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourERE;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreReexamenSurDemande;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreET;
import fr.unedic.cali.utilitaire.filtres.logiques.FiltreNegation;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.util.List;
import java.util.ListIterator;

public class DeterminationContexte
{
  public String determinerContexte(DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    boolean retour = true;
    
    IndividuSpec individu = dom.getIndividu();
    Demande demande = (Demande)dom.getDemande();
    
    verificationDemandeExpresse(demande);
    if ("R".equalsIgnoreCase(dom.getContexteAppel())) {
      retour = false;
    }
    if (retour) {
      retour = verificationPreconditions(demande);
    }
    if (retour) {
      retour = verificationDerniereDecisionSP(individu, demande);
    }
    if (retour) {
      retour = verificationAntecedentDemandeBanalisee(individu, demande);
    }
    return retour ? "S" : "D";
  }
  
  private void verificationDemandeExpresse(Demande demande)
    throws CoucheLogiqueException
  {
    if ("ASU_02".equals(demande.getEvenementReferenceExamen().getTypeExamen())) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DEMANDE_EXPRESSE_SIMPL");
    }
  }
  
  private boolean verificationPreconditions(Demande demande)
  {
    try
    {
      OutilVerificationPreconditions.getInstance().verifierPreconditions(demande);
      return true;
    }
    catch (CoucheLogiqueException ex) {}
    return false;
  }
  
  private boolean verificationDerniereDecisionSP(IndividuSpec individu, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    boolean retour = true;
    
    boolean demandeAsuPrecedenteClasseeEnCompetenceSp = false;
    
    DemandeAssuranceSpec dernierDroit = null;
    
    ChronologieDebuts chronoDemandesAssurancePrecedentes = (ChronologieDebuts)individu.getChronoDemandeAssurance().copier(new FiltreDateDeclenchementExamenAvantOuCoincideDateEtInclusParPriorite(demande.getDateRecherche(), demande));
    
    chronoDemandesAssurancePrecedentes.supprimer(demande);
    if (!chronoDemandesAssurancePrecedentes.estVide())
    {
      chronoDemandesAssurancePrecedentes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
      
      dernierDroit = rechercheDernierDroit(chronoDemandesAssurancePrecedentes);
      if (dernierDroit != null) {
        demandeAsuPrecedenteClasseeEnCompetenceSp = dernierDroit.estClasseeEnCompetenceSecteurPublic();
      }
    }
    AttributionAssuranceSpec attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(demande.getDemandeur().getChronoDemandesNonTriees(), demande, new FiltreAttributionStandardAssurance(false, true, false, false, null));
    
    boolean attributionAsuPrecedenteDeCompetenceSp = (attributionAssurancePrecedente != null) && (attributionAssurancePrecedente.getCompetence().getCompetenceAdministrative() != 1);
    if (((demandeAsuPrecedenteClasseeEnCompetenceSp) || (attributionAsuPrecedenteDeCompetenceSp)) && (!((DemandeAssuranceSpec)demande).estEnContexteDroitAnterieurSecteurPublic()) && (!presenceDemandeAssSuiteFinDroitSP(individu, demande, dernierDroit))) {
      retour = false;
    }
    return retour;
  }
  
  private DemandeAssuranceSpec rechercheDernierDroit(Chronologie chronoDemandesAssurancePrecedentes)
  {
    DemandeAssuranceSpec dernierDroit = null;
    
    ListIterator<Demande> it = chronoDemandesAssurancePrecedentes.iterer();
    while ((it.hasNext()) && (dernierDroit == null))
    {
      Demande courante = (Demande)it.next();
      if ((courante.estDecisionnee()) && (!courante.getListeDossiersExamen().isEmpty()) && ((courante.getListeDossiersExamen().get(0) instanceof AttributionSpec)))
      {
        dernierDroit = courante;
      }
      else if (courante.estClasseeEnCompetenceSecteurPublic())
      {
        dernierDroit = courante;
        break;
      }
    }
    return dernierDroit;
  }
  
  private boolean presenceDemandeAssSuiteFinDroitSP(IndividuSpec individu, DemandeSpec demande, DemandeAssuranceSpec derniereDemande)
  {
    FiltreET filtreET = new FiltreET();
    filtreET.ajouterFiltre(new FiltreNegation(new FiltreReexamenSurDemande()));
    filtreET.ajouterFiltre(new FiltreAttributionSurDecisions());
    filtreET.ajouterFiltre(new FiltreDemandePourERE("SOL_04"));
    AttributionSpec attribAssPrecedente = (AttributionSpec)OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), demande, filtreET);
    if (attribAssPrecedente != null)
    {
      Periode periodeRecherche = new Periode();
      periodeRecherche.setDebut(derniereDemande.getDateRecherche());
      periodeRecherche.setFin(demande.getDateRecherche());
      if (attribAssPrecedente.getDateAttribution().estContenueDans(periodeRecherche)) {
        return true;
      }
    }
    return false;
  }
  
  private boolean verificationAntecedentDemandeBanalisee(IndividuSpec individu, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    boolean retour = true;
    
    DecisionSpec derniereDecision = OutilRecherche.rechercherDecisionPrecedente(individu.getChronoDemandesNonTriees(), demande, new FiltreNegation(new FiltreReexamenSurDemande()));
    
    DemandeSpec demandePrecedente = null;
    if (derniereDecision != null) {
      demandePrecedente = derniereDecision.getDemande();
    }
    if ((demandePrecedente != null) && (demandePrecedente.getEvenementReferenceExamen() != null) && (demandePrecedente.getEvenementReferenceExamen().getTypeExamen() != null) && (demandePrecedente.getEvenementReferenceExamen().getTypeExamen().equals("ARI_01"))) {
      retour = false;
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     DeterminationContexte
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */