package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.pe.cali.crem.outils.OutilAjoutCremDalLiquidation;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.SituationDemandeur;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.asu.produits.liquidation.dom.ParametreLiquidationSimplifiee;
import fr.unedic.cali.autresdoms.ga.services.AppelServicesGaec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilFluxSigma;
import fr.unedic.cali.outilsfonctionnels.reexecution.FabriqueGestionnaireReexecution;
import fr.unedic.cali.outilsfonctionnels.reexecution.GestionnaireReexecutionSpec;
import fr.unedic.cali.outilsfonctionnels.reexecution.ResultatGestionnaireReexecutionSpec;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJoursCalendaires;
import fr.unedic.util.Unite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;

public class LiquidationSimplifiee
{
  private static final BigDecimal CONVERSION_HEURE = new BigDecimal("5");
  private static final BigDecimal CONVERSION_MOIS = new BigDecimal("30");
  private static final BigDecimal CONVERSION_SEMAINE = new BigDecimal("7");
  
  public String liquider(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
    
    String retour = null;
    if (dom.isEstPrimoDemandeur()) {
      retour = liquiderPrimoDemandeur(dom);
    } else {
      retour = liquiderReinscription(dom);
    }
    return retour;
  }
  
  public String valider(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationSimplifiee dom = recupererDom(contexte);
    IndividuSpec individu = dom.getIndividu();
    DemandeSpec demande = dom.getDemande();
    ContexteService contexteService = dom.getContexteService();
    
    miseAJourDemande(contexte, dom, demande);
    
    validationDemande(demande, contexteService);
    
    ResultatGestionnaireReexecutionSpec resultatReexecution = null;
    if (((DomLiquidationSimplifiee)contexte.getDonnees()).isAppelGestionnaireReexecution())
    {
      resultatReexecution = reexecution(demande);
      if (!resultatReexecution.getDemandesReliquidees().contains(demande)) {
        resultatReexecution.getDemandesReliquidees().add(demande);
      }
      OutilAjoutCremDalLiquidation outilAjoutCrem = initialisationOutilAjouCREM();
      outilAjoutCrem.ajouterCREMDemandesReexecutes(resultatReexecution.getDemandesReliquidees(), individu);
    }
    positionnerALiquidableDemandesPosterieures(demande);
    
    controleTopInvestigationFrauduleuse(demande, dom);
    if ((((DomLiquidationSimplifiee)contexte.getDonnees()).isAppelGestionnaireReexecution()) && (((DomLiquidationSimplifiee)contexte.getDonnees()).isEnvoieSigma())) {
      notifierSigma(individu, resultatReexecution);
    }
    demande.setModeLiquidation("C");
    
    return "V";
  }
  
  protected void controleTopInvestigationFrauduleuse(DemandeSpec demande, DomLiquidationSimplifiee dom)
  {
    DomLiquidationDemande domLiquidationDemande = new DomLiquidationDemande();
    domLiquidationDemande.setContexteService(dom.getContexteService());
    domLiquidationDemande.setDemande(demande);
    
    demande.getGamme().controlerInvestigationFrauduleuse(domLiquidationDemande);
  }
  
  protected DomLiquidationSimplifiee recupererDom(Contexte contexte)
  {
    return (DomLiquidationSimplifiee)contexte.getDonnees();
  }
  
  protected void miseAJourDemande(Contexte contexte, DomLiquidationSimplifiee dom, DemandeSpec demande)
    throws CoucheLogiqueException
  {
    AppelServicesGaec.enregistrerAbonnementGaec(contexte);
    
    notificationDemande(demande, dom.getCodeMotifEchecANotifier(), dom.isNotifierCourrier());
  }
  
  protected void validationDemande(DemandeSpec demande, ContexteService contexteService)
  {
    demande.validerDecision();
    
    demande.supprimerDossiersAffectations();
    demande.definirDateValidation(contexteService.getDateTraitement());
    
    demande.setDateDerniereNotification(contexteService.getDateTraitement());
  }
  
  protected ResultatGestionnaireReexecutionSpec reexecution(DemandeSpec demande)
    throws ApplicativeException
  {
    return FabriqueGestionnaireReexecution.getGestionnaire().executerSurValidation(demande);
  }
  
  protected OutilAjoutCremDalLiquidation initialisationOutilAjouCREM()
  {
    return OutilAjoutCremDalLiquidation.getInstance();
  }
  
  protected void notifierSigma(IndividuSpec individu, ResultatGestionnaireReexecutionSpec resultatReexecution)
    throws ApplicativeException
  {
    OutilFluxSigma.notifierSigma(individu, resultatReexecution.getDemandesReliquidees(), false);
  }
  
  private void positionnerALiquidableDemandesPosterieures(DemandeSpec demandeSpec)
    throws ApplicativeException
  {
    DemandeSpec demandeAValider = demandeSpec;
    DemandeSpec demande = null;
    if (demandeAValider.estLiquidable())
    {
      Chronologie listeDemandesARendreLiquidable = OutilRecherche.rechercherDemandesSuivantes(demandeSpec.getDemandeur().getChronoDemandesNonTriees(), demandeSpec, null);
      
      listeDemandesARendreLiquidable.ajouter(demandeSpec);
      
      listeDemandesARendreLiquidable.iterer();
      while (listeDemandesARendreLiquidable.encoreSuivant())
      {
        demande = (DemandeSpec)listeDemandesARendreLiquidable.elementSuivant();
        if (demande.estMigree()) {
          demande.setEstLiquidable(true);
        }
      }
    }
  }
  
  private void notificationDemande(DemandeSpec demande, String codeMotifRejetANotifier, boolean estNotifierCourrier)
    throws CoucheLogiqueException
  {
    demande.setNotifieeCourrier(estNotifierCourrier);
    
    demande.setLiquideeEnEtat(true);
    
    demande.setCodeMotifEchecPourSigma(codeMotifRejetANotifier);
  }
  
  private String liquiderPrimoDemandeur(DomLiquidationSimplifiee dom)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)dom.getDemande();
    Entretien entretien = demande.getEntretien();
    IndividuSpec individu = dom.getIndividu();
    SituationDemandeur situationDemandeur = dom.getSituationDemandeur();
    String contexteRetour = null;
    if ((dom.getContexteAppel().equals("L")) || (dom.getContexteAppel().equals("V")) || ("LSSI".equalsIgnoreCase(dom.getContexteAppel())))
    {
      if (!entretien.isAExerceActiviteSalarie())
      {
        contexteRetour = proposerRejet(dom, 41);
      }
      else
      {
        int nombreJoursAffiliation = conversionEnJours(entretien.getQuantiteAffiliation());
        situationDemandeur.setNombreJourQuantiteTravailCalcule(nombreJoursAffiliation);
        
        ParametreLiquidationSimplifiee parametre = Parametres.determinerPraEligible(situationDemandeur, entretien.getDateFinContrat(), individu);
        if (parametre.getNombreJoursQuantiteAffiliation() < nombreJoursAffiliation) {
          contexteRetour = proposerEnvoiDal();
        } else if (entretien.isASuiviFormation()) {
          contexteRetour = proposerEnvoiDal();
        } else {
          contexteRetour = proposerRejet(dom, 300);
        }
      }
    }
    else {
      contexteRetour = proposerEntretien();
    }
    return contexteRetour;
  }
  
  private String liquiderReinscription(DomLiquidationSimplifiee dom)
    throws CoucheLogiqueException
  {
    String contexteRetour = null;
    Demande demandeOrigine = (Demande)dom.getDemande();
    IndividuSpec individu = dom.getIndividu();
    Entretien entretien = demandeOrigine.getEntretien();
    SituationDemandeur situationDemandeur = dom.getSituationDemandeur();
    if (situationDemandeur.getEtatReliquat() == 3) {
      contexteRetour = liquiderReinscriptionAvecAntecedentValide(situationDemandeur, entretien, dom, individu, demandeOrigine);
    } else {
      contexteRetour = liquiderReinscriptionSansAntecedentValide(situationDemandeur, entretien, dom, individu);
    }
    return contexteRetour;
  }
  
  private String liquiderReinscriptionAvecAntecedentValide(SituationDemandeur situationDemandeur, Entretien entretien, DomLiquidationSimplifiee dom, IndividuSpec individu, Demande demandeOrigine)
    throws CoucheLogiqueException
  {
    String contexteRetour = null;
    boolean estPresenceEntretien = verificationPresenceEntretien(entretien);
    if (situationDemandeur.getDateInscription().coincideAvec(situationDemandeur.getDateDerniereCessation())) {
      contexteRetour = proposerReprise(dom, entretien, demandeOrigine);
    } else if (estPresenceEntretien)
    {
      if (calculAffiliation(situationDemandeur, entretien, individu)) {
        contexteRetour = proposerEnvoiDal();
      } else if (entretien.isASuiviFormation()) {
        contexteRetour = proposerEnvoiDal();
      } else {
        contexteRetour = proposerReprise(dom, entretien, demandeOrigine);
      }
    }
    else {
      contexteRetour = proposerEntretien();
    }
    return contexteRetour;
  }
  
  private String liquiderReinscriptionSansAntecedentValide(SituationDemandeur situationDemandeur, Entretien entretien, DomLiquidationSimplifiee dom, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    String contexteRetour = null;
    boolean estPresenceEntretien = verificationPresenceEntretien(entretien);
    if (situationDemandeur.getDateInscription().coincideAvec(situationDemandeur.getDateDerniereCessation())) {
      contexteRetour = proposerRejet(dom, 41);
    } else if (estPresenceEntretien)
    {
      if ((!entretien.isAExerceActiviteSalarie()) && ((situationDemandeur.getDateFinDernierePeriodeGaec() == null) || (situationDemandeur.getDateFinDernierePeriodeGaec().estAvant(situationDemandeur.getDateDerniereCessation())))) {
        contexteRetour = proposerRejet(dom, 41);
      } else if (calculAffiliation(situationDemandeur, entretien, individu)) {
        contexteRetour = proposerEnvoiDal();
      } else if (entretien.isASuiviFormation()) {
        contexteRetour = proposerEnvoiDal();
      } else {
        contexteRetour = proposerRejet(dom, 300);
      }
    }
    else {
      contexteRetour = proposerEntretien();
    }
    return contexteRetour;
  }
  
  private boolean calculAffiliation(SituationDemandeur situationDemandeur, Entretien entretien, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    boolean retour = false;
    
    Damj derniereFct = situationDemandeur.getDateFinDernierePeriodeGaec();
    int nombreJoursAffiliation = 0;
    if (entretien.isAExerceActiviteSalarie())
    {
      nombreJoursAffiliation = conversionEnJours(entretien.getQuantiteAffiliation());
      derniereFct = entretien.getDateFinContrat();
    }
    Damj dateFGDAsuPrecedent = situationDemandeur.getDateFgdAsuPrecedent();
    Damj dateFinPra = DeterminationSituationDemandeur.calculerDateFinPra(derniereFct, situationDemandeur, dateFGDAsuPrecedent);
    
    ParametreLiquidationSimplifiee parametre = Parametres.determinerPraEligible(situationDemandeur, dateFinPra, individu);
    
    Damj dateDebutPra = DeterminationSituationDemandeur.calculerDateDebutPra(parametre, dateFinPra, dateFGDAsuPrecedent);
    
    Periode pra = new Periode(dateDebutPra, dateFinPra);
    int nombreJoursAffiliationCalcule = CalculAffiliation.calculerAffiliation(individu, pra);
    int nombreJoursAffiliationRequis = parametre.getNombreJoursQuantiteAffiliation();
    nombreJoursAffiliation += nombreJoursAffiliationCalcule;
    if (nombreJoursAffiliationRequis < nombreJoursAffiliation) {
      retour = true;
    }
    situationDemandeur.setNombreJourQuantiteTravailCalcule(nombreJoursAffiliationCalcule);
    
    return retour;
  }
  
  private boolean verificationPresenceEntretien(Entretien entretien)
  {
    boolean retour = false;
    if (entretien != null) {
      retour = true;
    }
    return retour;
  }
  
  private int conversionEnJours(Quantite quantite)
  {
    BigDecimal nombreJours = quantite.getValeur();
    if (quantite.getUnite().getCode().equalsIgnoreCase("18")) {
      nombreJours = quantite.getValeur().divide(CONVERSION_HEURE, 0);
    } else if (quantite.getUnite().getCode().equalsIgnoreCase("20")) {
      nombreJours = quantite.getValeur().multiply(CONVERSION_SEMAINE);
    } else if (quantite.getUnite().getCode().equalsIgnoreCase("19")) {
      nombreJours = quantite.getValeur().multiply(CONVERSION_MOIS);
    }
    return nombreJours.intValue();
  }
  
  private String proposerEntretien()
  {
    return "E";
  }
  
  private String proposerEnvoiDal()
  {
    return "D";
  }
  
  private String proposerReprise(DomLiquidationSimplifiee dom, Entretien entretien, Demande demandeOrigine)
    throws CoucheLogiqueException
  {
    int nombreJoursAffiliation = 0;
    if ((entretien != null) && (entretien.getQuantiteAffiliation() != null)) {
      nombreJoursAffiliation = conversionEnJours(entretien.getQuantiteAffiliation());
    }
    BigDecimal nbMois = new BigDecimal("12");
    BigDecimal nbJours = new BigDecimal("7");
    BigDecimal nbJoursOuvres = new BigDecimal("6");
    BigDecimal nbJoursAffiliation = new BigDecimal(String.valueOf(nombreJoursAffiliation));
    BigDecimal iccp = Mathematiques.diviseASup(nbJoursAffiliation, nbMois, 0).multiply(Mathematiques.diviseASup(nbJours, nbJoursOuvres, 0));
    
    ProduitAsuSpec produit = (ProduitAsuSpec)dom.getSituationDemandeur().getProduitReliquat();
    if ((iccp.signum() == 1) && (produit.estProduitGerantIccpEnContexteRepriseSimplifiee()))
    {
      demandeOrigine.getDonneesTemporaires().setQuantiteJoursDiffereIccpConservatoire(new QuantiteJoursCalendaires(iccp));
      
      demandeOrigine.getDonneesTemporaires().setSaisieCasGeneralDonneesTemporaire(true);
    }
    else
    {
      demandeOrigine.getDonneesTemporaires().setQuantiteJoursDiffereIccpConservatoire(null);
      demandeOrigine.getDonneesTemporaires().setSaisieCasGeneralDonneesTemporaire(false);
    }
    dom.setNatureDecisionAttendue(34);
    return "P";
  }
  
  private String proposerRejet(DomLiquidationSimplifiee dom, int codeMotifRejet)
    throws CoucheLogiqueException
  {
    dom.setCodeMotifEchecANotifier(String.valueOf(codeMotifRejet));
    dom.setNatureDecisionAttendue(33);
    return "R";
  }
}

/* Location:
 * Qualified Name:     LiquidationSimplifiee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */