package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationSimplifiee;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.autresdoms.cohab.dom.PreInscriptionAude;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.PreInscription;
import fr.unedic.cali.outilsfonctionnels.AppelServicesCojac;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.text.NumberFormat;
import java.util.List;

public class OutilSimulation
{
  private static final int ID_PEC_MINIMAL = 0;
  private static final int ECART_ID_PEC = 10;
  private static final int TAILLE_IDPEC = 4;
  private static final String ID_DEMANDE = "001";
  
  public static ObjetChronoPeriodePriseEnCharge preTraitement(DomLiquidationSimplifiee p_dom)
    throws CoucheLogiqueException
  {
    ObjetChronoPeriodePriseEnCharge pec = creerPEC(p_dom);
    
    PreInscriptionAude preInscriptionAude = p_dom.getPreInscriptionAude();
    
    pec.setDateDebut(preInscriptionAude.getDatePreInscription());
    pec.setDateFin(Damj.FIN_DES_TEMPS);
    pec.setTypePec(preInscriptionAude.getTypePEC());
    pec.setSousType(preInscriptionAude.getSousTypePEC());
    pec.setDemandeurEmploi(true);
    
    p_dom.getIndividu().getChronologiePecNonFusionneesFinCI().ajouter(pec);
    p_dom.getIndividu().getChronologiePecFusionneesFinCI().ajouter(pec);
    
    p_dom.setReferenceExterne(creerReferenceExterne(pec));
    
    return pec;
  }
  
  public static void creerDemandeV2(Contexte p_contexte, ObjetChronoPeriodePriseEnCharge p_pec)
    throws ApplicativeException
  {
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)p_contexte.getDonnees();
    DemandeSpec demande = InstallationDemande.creerDemandeV2(p_pec.getDateDebut(), dom.getIndividu(), dom.getContexteService(), p_pec.getIdentifiantPec());
    
    demande.setModeLiquidation("S");
    dom.setDemande(demande);
    
    Damj datePreinscription = dom.getPreInscriptionAude().getDatePreInscription();
    if (!dom.getContexteAppel().equals("LSSI"))
    {
      List listePreinscription = dom.getIndividu().getListPreInscription();
      PreInscription preinscription = OutilEntretien.getPreInscription(listePreinscription, datePreinscription);
      if ((preinscription != null) && (preinscription.getEntretien() != null))
      {
        Entretien entretien = (Entretien)preinscription.getEntretien().copie();
        ((Demande)demande).setEntretien(entretien);
      }
    }
    else
    {
      OutilEntretien.mettreAJourEntretien(p_contexte, datePreinscription);
    }
  }
  
  public static void postTraitement(DomLiquidationSimplifiee p_dom, ObjetChronoPeriodePriseEnCharge p_pec)
  {
    p_dom.getIndividu().supprimerDemande(p_dom.getDemande());
    
    Chronologie listePec = p_dom.getIndividu().getChronologiePecFusionneesFinCI();
    listePec.supprimer(p_pec);
    
    Chronologie listePec2 = p_dom.getIndividu().getChronologiePecNonFusionneesFinCI();
    listePec2.supprimer(p_pec);
  }
  
  private static ObjetChronoPeriodePriseEnCharge creerPEC(DomLiquidationSimplifiee p_dom)
    throws CoucheLogiqueException
  {
    Chronologie listePec = p_dom.getIndividu().getChronologiePecNonFusionneesFinCI();
    Chronologie listePec2 = p_dom.getIndividu().getChronologiePecFusionneesFinCI();
    
    int idPec = 0;
    if (listePec != null)
    {
      listePec.iterer();
      while (listePec.encoreSuivant())
      {
        int idCourant = ((ObjetChronoPeriodePriseEnChargeSansFiltre)listePec.elementSuivant()).getIdentifiantPec();
        if (idCourant > idPec) {
          idPec = idCourant;
        }
      }
      idPec += 10;
    }
    else
    {
      listePec = new ChronologiePeriodes();
      p_dom.getIndividu().setChronologiePecNonFusionneesFinCI(listePec);
      listePec2 = new ChronologiePeriodes();
      p_dom.getIndividu().setChronologiePecFusionneesFinCI(listePec2);
    }
    ObjetChronoPeriodePriseEnCharge pec = new ObjetChronoPeriodePriseEnChargeSansFiltre();
    
    PreInscriptionAude preInscriptionAude = p_dom.getPreInscriptionAude();
    
    pec.setDateDebut(preInscriptionAude.getDatePreInscription());
    pec.setDateFin(Damj.FIN_DES_TEMPS);
    pec.setTypePec(preInscriptionAude.getTypePEC());
    pec.setSousType(preInscriptionAude.getSousTypePEC());
    pec.setDemandeurEmploi(true);
    pec.setIdentifiantPec(idPec);
    
    return pec;
  }
  
  private static String creerReferenceExterne(ObjetChronoPeriodePriseEnCharge p_pec)
  {
    NumberFormat nf = NumberFormat.getIntegerInstance();
    nf.setGroupingUsed(false);
    nf.setMinimumIntegerDigits(4);
    String refExterne = nf.format(p_pec.getIdentifiantPec()) + "001";
    return refExterne;
  }
  
  public static PreInscriptionAude recupererInformationsPreinscription(DomLiquidationSimplifiee p_dom)
    throws CoucheLogiqueException
  {
    if (p_dom.getPreInscriptionAude() != null) {
      return p_dom.getPreInscriptionAude();
    }
    PreInscriptionAude preinscription = AppelServicesCojac.lireRestitutionInscriptionDude(p_dom.getIndividu().getNumeroAllocataire(), p_dom.getContexteService().getRsin(), p_dom.getContexteService().getAssedicAllocataire());
    if ((preinscription.getDatePreInscription() == null) || (preinscription.getSousTypePEC() == null) || (preinscription.getTypePEC() == null)) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_LS_APPEL_D98", new Object[] { preinscription.getDatePreInscription() == null ? "null" : preinscription.getDatePreInscription().toString(), preinscription.getTypePEC() == null ? "null" : preinscription.getTypePEC(), preinscription.getSousTypePEC() == null ? "null" : preinscription.getSousTypePEC() });
    }
    return preinscription;
  }
}

/* Location:
 * Qualified Name:     OutilSimulation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */