package fr.unedic.cali.asu.outilsfonctionnels.strategies;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.ComparateurSurDateDeclenchementDemandeDecroissante;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFinApresDate;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreActiviteSalarieFinAvantDate;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltresTemporel;
import java.util.Iterator;

public class StrategieBlocageDemandeExpresseAvecReliquatValideApres
  implements StrategieBlocageDemandeExpresseAvecReliquatValideSpec
{
  public void leverBlocage(Demande demande)
    throws ApplicativeException
  {
    boolean leveeBlocage = (autoriserLiquidationDecisionPrecedenteDv(demande)) && (autoriserLiquidationDroitOption(demande)) && (autoriserLiquidationExamenFinPeriodeParticuliere(demande)) && (autoriserBlocageContexteEnCoursDeDisponibilite(demande));
    if (leveeBlocage) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DMD_EXP_RLQ");
    }
  }
  
  private boolean autoriserLiquidationExamenFinPeriodeParticuliere(Demande demande)
  {
    boolean leveeBlocage = true;
    DonneesTemporaires donneesForcees = demande.getDonneesTemporaires();
    
    boolean estMotifExamenClcaOuPi = (donneesForcees != null) && ((donneesForcees.getMotifExamen() == 1) || (donneesForcees.getMotifExamen() == 2));
    if ((estMotifExamenClcaOuPi) && (donneesForcees.getDateFinEvenement() != null)) {
      leveeBlocage = false;
    }
    return leveeBlocage;
  }
  
  private boolean autoriserLiquidationDroitOption(Demande demande)
  {
    boolean leveeBlocage = true;
    DonneesTemporaires donneesForcees = demande.getDonneesTemporaires();
    if ((donneesForcees != null) && (donneesForcees.isDroitOptionForce())) {
      leveeBlocage = false;
    }
    return leveeBlocage;
  }
  
  private boolean autoriserLiquidationDecisionPrecedenteDv(Demande demande)
  {
    boolean leveeBlocage = true;
    Chronologie chronoDemandesPrecedentes = OutilRecherche.rechercherDemandesPrecedentes(demande.getChronologieDemandesAssuranceSansCourante(), demande, null);
    
    chronoDemandesPrecedentes.setComparateur(new ComparateurSurDateDeclenchementDemandeDecroissante());
    
    boolean estDecisionPrecedentDV = false;
    
    DemandeSpec demandePrecedente = null;
    if (chronoDemandesPrecedentes != null)
    {
      Iterator<?> iterateurDemandes = chronoDemandesPrecedentes.iterer();
      while (iterateurDemandes.hasNext())
      {
        demandePrecedente = (DemandeSpec)iterateurDemandes.next();
        if (demandePrecedente.getClassementAdministratif() != null)
        {
          if ("SP".equals(demandePrecedente.getClassementAdministratif().getTypeClassement())) {
            break;
          }
        }
        else if ((demandePrecedente.estDecisionnee()) && (((DossierExamenAssuranceSpec)demandePrecedente.getDossierAffectation().getDossierExamen()).estRejetDV())) {
          estDecisionPrecedentDV = true;
        }
      }
    }
    if (estDecisionPrecedentDV)
    {
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteSalarieFinApresDate(demandePrecedente.getDateExamen().veille(), "MVS"));
      filtres.ajouterFiltre(new FiltreActiviteSalarieFinAvantDate(demande.getDateDepot(), "MVS"));
      Chronologie activitesPresentes = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
      if (!activitesPresentes.estVide()) {
        leveeBlocage = false;
      }
    }
    return leveeBlocage;
  }
  
  private boolean autoriserBlocageContexteEnCoursDeDisponibilite(Demande demande)
  {
    boolean leveeBlocage = true;
    if (demande.estEnContexteDemande(11)) {
      leveeBlocage = false;
    }
    return leveeBlocage;
  }
}

/* Location:
 * Qualified Name:     StrategieBlocageDemandeExpresseAvecReliquatValideApres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */