package fr.unedic.cali.asu.parametres;

import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Iterator;
import java.util.ListIterator;

public class ParametresIndemnisation
{
  private ChronologieStandard m_chronoEvenementsParametre = null;
  private static ParametresIndemnisation s_parametreIndemnisation = new ParametresIndemnisation();
  private static ThreadLocal s_initHolder = new ThreadLocal();
  private AccesTauxAvantageVieillesse m_accesTauxAvantageVieillesse = null;
  private boolean m_initialisationOK = false;
  
  private void dedoublonner()
  {
    ListIterator iterateur = m_chronoEvenementsParametre.iterer();
    EvenementParametre evtCourant = null;
    EvenementParametre evtSuivant = null;
    Damj dateEvtCourant = null;
    Damj dateEvtSuivant = null;
    if (iterateur.hasNext())
    {
      evtCourant = (EvenementParametre)iterateur.next();
      dateEvtCourant = evtCourant.getDateEffet();
    }
    while (iterateur.hasNext())
    {
      evtSuivant = (EvenementParametre)iterateur.next();
      dateEvtSuivant = evtSuivant.getDateEffet();
      if (dateEvtCourant.coincideAvec(dateEvtSuivant))
      {
        iterateur.previous();
        iterateur.previous();
        iterateur.remove();
        iterateur.next();
      }
      evtCourant = evtSuivant;
      dateEvtCourant = dateEvtSuivant;
    }
  }
  
  public EvenementParametre getElementActif(Damj p_date)
  {
    EvenementParametre evtCourant = null;
    
    Iterator it = m_chronoEvenementsParametre.iterer();
    while (it.hasNext())
    {
      EvenementParametre evt = (EvenementParametre)it.next();
      if (!evt.getDateEffet().estAvantOuCoincideAvec(p_date)) {
        break;
      }
      evtCourant = evt;
      
      evtCourant.setDateDeRecherche(p_date);
    }
    return evtCourant;
  }
  
  public Chronologie getParametresActifs(Periode p_periode)
  {
    return m_chronoEvenementsParametre.elementsDeDebutDans(p_periode);
  }
  
  public static ParametresIndemnisation getParametresIndemnisation()
  {
    if (s_initHolder.get() == null) {
      synchronized (ParametresIndemnisation.class)
      {
        if (!s_parametreIndemnisation.isInitialisationOK()) {
          s_parametreIndemnisation.initialiser();
        }
        s_initHolder.set(Boolean.TRUE);
      }
    }
    return s_parametreIndemnisation;
  }
  
  public BigDecimal getTauxAvantageViellesse(DureeCalendaire p_age)
  {
    return m_accesTauxAvantageVieillesse.getTauxAvantageViellesse(p_age);
  }
  
  private void initialiser()
  {
    AccesAllocationMinimale allocationMini = new AccesAllocationMinimale();
    AccesAllocationMinimaleMayotte allocationMiniMayotte = new AccesAllocationMinimaleMayotte();
    AccesPartieFixe partieFixe = new AccesPartieFixe();
    AccesPlafond plafond = new AccesPlafond();
    AccesPlafondMayotte plafondMayotte = new AccesPlafondMayotte();
    AccesPlafondASP plafondASP = new AccesPlafondASP();
    AccesSmicHoraire smicHoraire = new AccesSmicHoraire();
    AccesRevalorisationSjr revalSjr = new AccesRevalorisationSjr();
    AccesRevalorisationSjrMayotte revalSjrMayotte = new AccesRevalorisationSjrMayotte();
    AccesCotisationRetraiteComplementaire cotisationRetraite = new AccesCotisationRetraiteComplementaire();
    AccesSeuilMinimalAREF seuilMinimalAREF = new AccesSeuilMinimalAREF();
    AccesSeuilMinimalAREFM seuilMinimalAREFM = new AccesSeuilMinimalAREFM();
    
    ChronologieStandard chronoAllocMini = allocationMini.getChronoValeursParametre();
    ChronologieStandard chronoAllocMiniMayotte = allocationMiniMayotte.getChronoValeursParametre();
    ChronologieStandard chronoPartieFixe = partieFixe.getChronoValeursParametre();
    ChronologieStandard chronoPlafond = plafond.getChronoValeursParametre();
    ChronologieStandard chronoPlafondMayotte = plafondMayotte.getChronoValeursParametre();
    ChronologieStandard chronoPlafondASP = plafondASP.getChronoValeursParametre();
    ChronologieStandard chronoSmicHoraire = smicHoraire.getChronoValeursParametre();
    ChronologieStandard chronoRevalSjr = revalSjr.getChronoValeursParametre();
    ChronologieStandard chronoRevalSjrMayotte = revalSjrMayotte.getChronoValeursParametre();
    ChronologieStandard chronoCotisationRetraite = cotisationRetraite.getChronoValeursParametre();
    ChronologieStandard chronoSeuilMinimalAREF = seuilMinimalAREF.getChronoValeursParametre();
    ChronologieStandard chronoSeuilMinimalAREFM = seuilMinimalAREFM.getChronoValeursParametre();
    
    m_chronoEvenementsParametre = new ChronologieStandard();
    m_chronoEvenementsParametre.ajouter(chronoAllocMini);
    m_chronoEvenementsParametre.ajouter(chronoAllocMiniMayotte);
    m_chronoEvenementsParametre.ajouter(chronoPartieFixe);
    m_chronoEvenementsParametre.ajouter(chronoPlafond);
    m_chronoEvenementsParametre.ajouter(chronoPlafondMayotte);
    m_chronoEvenementsParametre.ajouter(chronoPlafondASP);
    m_chronoEvenementsParametre.ajouter(chronoSmicHoraire);
    m_chronoEvenementsParametre.ajouter(chronoRevalSjr);
    m_chronoEvenementsParametre.ajouter(chronoRevalSjrMayotte);
    m_chronoEvenementsParametre.ajouter(chronoCotisationRetraite);
    m_chronoEvenementsParametre.ajouter(chronoSeuilMinimalAREF);
    m_chronoEvenementsParametre.ajouter(chronoSeuilMinimalAREFM);
    
    Iterator iterateurChrono = m_chronoEvenementsParametre.iterer();
    EvenementParametre evtCourant = null;
    EvenementParametre evtPrecedent = null;
    if (iterateurChrono.hasNext())
    {
      evtPrecedent = (EvenementParametre)iterateurChrono.next();
    }
    else
    {
      m_initialisationOK = true;
      return;
    }
    while (iterateurChrono.hasNext())
    {
      evtCourant = (EvenementParametre)iterateurChrono.next();
      evtCourant.repercuter(evtPrecedent);
      evtPrecedent = evtCourant;
    }
    dedoublonner();
    
    m_accesTauxAvantageVieillesse = new AccesTauxAvantageVieillesse();
    
    m_initialisationOK = true;
  }
  
  public boolean isInitialisationOK()
  {
    return m_initialisationOK;
  }
  
  public void setInitialisationOK(boolean p_initialisationOK)
  {
    m_initialisationOK = p_initialisationOK;
  }
}

/* Location:
 * Qualified Name:     ParametresIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */