package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.spec.DossierAffectationAssuranceSpec;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieControlePostAffectationApres;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieControlePostAffectationAvant;
import fr.unedic.cali.asu.outilsfonctionnels.strategies.StrategieControlePostAffectationSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.fabriques.outilsfonctionnels.FabriqueStrategieGenerique;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteBrouillon;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;

public class AffectationDemandeAsu
  extends ParcoursCali
{
  public static final int JUSTIFICATION_AUCUNE = 0;
  public static final int JUSTIFICATION_AFFECTE_PRODUIT = 1;
  public static final int JUSTIFICATION_PAS_DE_DERNIER_SINISTRE = 2;
  public static final int JUSTIFICATION_DERNIER_SINISTRE_HORS_DELAI = 3;
  public static final int JUSTIFICATION_AFFECTATION_CLAUSE_DE_SAUVEGARDE = 4;
  public static final int JUSTIFICATION_AFFECTATION_PRODUIT_SECOURS = 5;
  public static final int JUSTIFICATION_AFFECTATION_PRODUIT_SECOURS_ORIGINE_PAS = 6;
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    ParcoursAffectationDemandeAssurance parcoursAffectation = FabriqueAffectationDemandeASU.getParcoursAffectationDemandeAsu(getDemande(contexte));
    
    Resultat resultat = parcoursAffectation.effectuerParcours(contexte);
    
    controlerPostAffectation(contexte);
    
    return resultat;
  }
  
  protected Demande getDemande(Contexte contexte)
  {
    return (Demande)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
  }
  
  protected void controlerPostAffectation(Contexte contexte)
    throws CoucheLogiqueException
  {
    Demande demande = getDemande(contexte);
    DossierAffectationAssuranceSpec dossierAffectation = (DossierAffectationAssuranceSpec)demande.getDossierAffectation();
    ValidationProduitSpec validationProduit = dossierAffectation.getValidationProduit();
    
    StrategieControlePostAffectationSpec strategie = (StrategieControlePostAffectationSpec)FabriqueStrategieGenerique.choisirStrategie(demande.getDateExamen(), "Blocage en presence AE brouillon IN0973035", new StrategieControlePostAffectationAvant(), new StrategieControlePostAffectationApres());
    if (strategie.estActiviteBrouillonBloquante()) {
      controlerPresenceAeBrouillon(demande, validationProduit);
    }
  }
  
  private void controlerPresenceAeBrouillon(Demande demande, ValidationProduitSpec validationProduit)
    throws CoucheLogiqueException
  {
    if ((validationProduit != null) && (validationProduit.getPeriodePra() != null))
    {
      Periode pra = validationProduit.getPeriodePra();
      ChronologiePeriodes chronoPeriodesParticipantes = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
      
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteBrouillon());
      filtres.ajouterFiltre(new FiltreFinDansBornes(pra));
      if ((chronoPeriodesParticipantes != null) && (!chronoPeriodesParticipantes.copier(filtres).estVide())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_ERR_PRESENCE_AE_BROUILLON");
      }
    }
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeAsu
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */