package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.EreRechargement;
import fr.unedic.cali.asu.dom.EreTypeRechargementSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;

public class AffectationDemandeAsuRechargement
  extends AffectationDemandeASUClassique
{
  protected void determinerDelaiRecherche(DossierAffectation p_dossierAffectation, DureeCalendaire p_delaiAllongement, ProduitAsuSpec p_produit)
  {
    Demande demandeCourante = (Demande)p_dossierAffectation.getDemande();
    Damj dateDebutDelaiRecherche = demandeCourante.getDateFaitGenerateurOdPrecedente().lendemain();
    Damj dateFinDelaiRecherche = demandeCourante.getDateRecherche().veille();
    DelaiRechercheProduit delaiRetourne = new DelaiRechercheProduit(dateDebutDelaiRecherche, dateFinDelaiRecherche);
    p_dossierAffectation.setDelaiRecherche(delaiRetourne);
  }
  
  protected ProduitAsuSpec determinerProduitParDefaut(DemandeAssuranceSpec p_demande)
    throws CoucheLogiqueException
  {
    ProduitAsuSpec retour = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)p_demande, "RECHARGE")) {
      retour = determinerProduitAAppliquer(p_demande);
    } else {
      retour = super.determinerProduitParDefaut(p_demande);
    }
    return retour;
  }
  
  private ProduitAsuSpec determinerProduitAAppliquer(DemandeSpec p_demande)
  {
    EreTypeRechargementSpec ereRechargement = (EreTypeRechargementSpec)p_demande.getEvenementReferenceExamen();
    return (ProduitAsuSpec)ereRechargement.getReglementForcePourRechargement().getProduit();
  }
  
  protected void validerProduit(DemandeAssuranceSpec p_demandeAsuCourante, Chronologie p_chronoPeriodesParticipantes, ProduitAsuSpec p_produitDernierSinistre)
    throws ApplicativeException
  {
    boolean produitAffecte = validerProduitParFct(p_demandeAsuCourante, p_chronoPeriodesParticipantes);
    DossierAffectation dossierAffectation = p_demandeAsuCourante.getDossierAffectationAdmission();
    DecorReglementaire decorReglementaire = dossierAffectation.getDecorReglementaire();
    dossierAffectation.setJustificationAffectation(0);
    dossierAffectation.setProduitSecours(null);
    dossierAffectation.setDerniereFctEtudiee(null);
    EreRechargement ereRechargement = (EreRechargement)p_demandeAsuCourante.getEvenementReferenceExamen();
    
    boolean tentativeDeRechargement = (!produitAffecte) || (p_demandeAsuCourante.getDossierAffectationAdmission().getValidationProduit() == null) || (!p_demandeAsuCourante.getDossierAffectationAdmission().getValidationProduit().isEstProduitValide());
    if ((tentativeDeRechargement) && (!"A9B".equals(ereRechargement.getNomReglementARecharger())))
    {
      ajouterContexteRechargement(p_demandeAsuCourante);
      ereRechargement.initialiserReglementForce(decorReglementaire);
      
      VerificationDonneesForcees.getInstance().verifierUniteAffiForcee((Demande)p_demandeAsuCourante);
      
      produitAffecte = validerProduitParFct(p_demandeAsuCourante, p_chronoPeriodesParticipantes);
      p_produitDernierSinistre = determinerProduitAAppliquer(p_demandeAsuCourante);
    }
    if (!produitAffecte) {
      affectationProduitSecours(p_demandeAsuCourante, p_produitDernierSinistre);
    }
  }
  
  protected boolean validationClauseDeSauvegarde(DemandeAssuranceSpec p_demandeAsuCourante)
    throws ApplicativeException
  {
    boolean retour = false;
    if ("A9B".equals(((EreRechargement)p_demandeAsuCourante.getEvenementReferenceExamen()).getNomReglementARecharger())) {
      retour = super.validationClauseDeSauvegarde(p_demandeAsuCourante);
    }
    return retour;
  }
  
  private void ajouterContexteRechargement(DemandeAssuranceSpec p_demandeAsuCourante)
  {
    Demande demande = (Demande)p_demandeAsuCourante;
    ContexteDemande contexte = new ContexteDemande();
    contexte.setTypeContexteDemande("RECHARGE");
    demande.ajouterContexteDemande(contexte);
  }
  
  protected ProduitAsuSpec determinerProduitRelatifAuSinistre(TravailSpec p_sinistre, DossierAffectation p_dossierAffectationCourant)
    throws CoucheLogiqueException
  {
    Demande demande = (Demande)p_dossierAffectationCourant.getDemande();
    ProduitAsuSpec retour = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "RECHARGE")) {
      retour = determinerProduitAAppliquer(demande);
    } else {
      retour = super.determinerProduitRelatifAuSinistre(p_sinistre, p_dossierAffectationCourant);
    }
    return retour;
  }
}

/* Location:
 * Qualified Name:     AffectationDemandeAsuRechargement
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */