package fr.unedic.cali.asu.parcours;

import fr.pe.cali.liquidation.outilsfonctionnels.liquidationautomatique.IOutilLiquidationAutomatique;
import fr.pe.cali.parcours.abstrait.CreerDemandePrestationAbstrait;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.outilsfonctionnels.ConstitutionEvenementReferenceExamen;
import fr.unedic.cali.asu.outilsfonctionnels.ControlePrescription;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationauto.DonneesEntreeFabriqueLiquidationAutomatique;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationauto.FabriqueOutilLiquidationAutomatique;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.parcours.DomCreationDemandePrestation;
import fr.unedic.cali.parcours.ResultatCreationDemandePrestation;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;

public class CreerDemandePrestation
  extends CreerDemandePrestationAbstrait
{
  public void controlerContexte(Contexte pcontexte)
    throws ContexteException
  {
    if (DomCreationDemandePrestation.getIndividu(pcontexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Creation demande assurance impossible : individu absent du contexte");
    }
    if (DomCreationDemandePrestation.getFormulaire(pcontexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Creation demande assurance impossible : formulaire absent du contexte");
    }
  }
  
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    ResultatCreationDemandePrestation resultat = new ResultatCreationDemandePrestation();
    DomCreationDemandePrestation dom = (DomCreationDemandePrestation)contexte.getDonnees();
    IndividuSpec individu = getIndividu(contexte);
    FormulaireAsu formulaire = (FormulaireAsu)dom.getFormulaire();
    
    Demande demandeAssurance = rechercherDemandeAssurance(formulaire.getReferenceExterne(), individu);
    
    boolean nouvelleDemande = false;
    if (demandeAssurance == null)
    {
      demandeAssurance = new Demande();
      nouvelleDemande = true;
    }
    if (nouvelleDemande)
    {
      demandeAssurance.setFormulaire(formulaire);
      demandeAssurance.setEstFormulaireCharge(true);
      
      demandeAssurance.setDemandeur(individu);
      
      ConstitutionEvenementReferenceExamen.constituerEvenementReferenceExamen(demandeAssurance);
      
      demandeAssurance.createDonneesTemporaires();
    }
    alimenterDateDepotOrigine(demandeAssurance);
    if (formulaire.getDateDepot() == null) {
      ((FormulaireAsu)demandeAssurance.getFormulaire()).setDateDepot(dom.getDateDepotDerniereDemande());
    }
    if ((dom.isIdeDerniereDemande()) && (demandeAssurance.getFormulaire().getDateDepot() != null)) {
      ControlePrescription.controlerPrescription(demandeAssurance.getFormulaire());
    }
    liquidationAutomatique(individu, demandeAssurance, contexte);
    
    OutilDemande outilDemande = new OutilDemande();
    outilDemande.creerDemandeAssocieeSurDemandeAtp(demandeAssurance);
    
    resultat.setDemande(demandeAssurance);
    return resultat;
  }
  
  private void alimenterDateDepotOrigine(Demande demandeAssurance)
  {
    if ("ASU_02".equals(demandeAssurance.getEvenementReferenceExamen().getTypeExamen()))
    {
      FormulaireAsu formulaire = demandeAssurance.getFormulaireAsu();
      if (formulaire.getDateDepotOrigine() == null) {
        formulaire.setDateDepotOrigine(formulaire.getDateDepot());
      }
    }
  }
  
  protected void liquidationAutomatique(IndividuSpec individu, Demande demandeAssurance, Contexte contexte)
    throws ApplicativeException
  {
    DomCreationDemandePrestation dom = (DomCreationDemandePrestation)contexte.getDonnees();
    DonneesEntreeFabriqueLiquidationAutomatique donneesEntreeFabriqueLiquidationAutomatique = creerDonneeEntreFabriqueLiquidationAutomatique(individu, demandeAssurance, dom);
    
    IOutilLiquidationAutomatique outilLiquidationAutomatique = FabriqueOutilLiquidationAutomatique.getInstance().recupererOutilLiquidationAutomatique(donneesEntreeFabriqueLiquidationAutomatique);
    
    outilLiquidationAutomatique.demarerLiquidationAutomatique(demandeAssurance, contexte);
  }
  
  protected DonneesEntreeFabriqueLiquidationAutomatique creerDonneeEntreFabriqueLiquidationAutomatique(IndividuSpec individu, Demande demandeAssurance, DomCreationDemandePrestation dom)
  {
    DonneesEntreeFabriqueLiquidationAutomatique donneesEntreeFabriqueLiquidationAutomatique = new DonneesEntreeFabriqueLiquidationAutomatique();
    
    donneesEntreeFabriqueLiquidationAutomatique.setEstLiquidationAutomatiqueActive((!individu.isEstNonExecutionReceptionFlux()) && (dom.isLiquidationAutomatiqueActivee()));
    if (dom.getContexteService() != null) {
      donneesEntreeFabriqueLiquidationAutomatique.setContexteEmission(dom.getContexteService().getContexteEmission());
    }
    boolean estDemandeAttenteDecision = (demandeAssurance.getClassementAdministratif() == null) && (!demandeAssurance.estDecisionnee()) && (demandeAssurance.getDatePremiereValidation() == null);
    
    donneesEntreeFabriqueLiquidationAutomatique.setEstDemandeEnAttenteDeDecision(estDemandeAttenteDecision);
    donneesEntreeFabriqueLiquidationAutomatique.setEstPresenceDonneesNpde(demandeAssurance.getDonneesNPDE() != null);
    donneesEntreeFabriqueLiquidationAutomatique.setEstTopDeploiementNpde(demandeAssurance.isDemandeNPDE());
    donneesEntreeFabriqueLiquidationAutomatique.setTypeExamenDemande(demandeAssurance.getEvenementReferenceExamen().getTypeExamen());
    return donneesEntreeFabriqueLiquidationAutomatique;
  }
  
  private Demande rechercherDemandeAssurance(String pReferenceExterne, IndividuSpec pIndividu)
  {
    Demande demandeRecherche = null;
    boolean demandeTrouve = false;
    Chronologie listeDemandeAssurance = pIndividu.getChronoDemandeAssurance();
    if (!listeDemandeAssurance.estVide())
    {
      listeDemandeAssurance.iterer();
      do
      {
        Demande demandeAssuranceIndividu = (Demande)listeDemandeAssurance.elementSuivant();
        if (demandeAssuranceIndividu.getFormulaire().getReferenceExterne().equalsIgnoreCase(pReferenceExterne))
        {
          demandeRecherche = demandeAssuranceIndividu;
          demandeTrouve = true;
        }
      } while ((!demandeTrouve) && (listeDemandeAssurance.encoreSuivant()));
    }
    return demandeRecherche;
  }
}

/* Location:
 * Qualified Name:     CreerDemandePrestation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */