package fr.unedic.cali.asu.parcours;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.autresdoms.cohab.outilsfonctionnels.CreationDemande;
import fr.unedic.cali.autresdoms.cohab.outilsfonctionnels.FabriqueFormulairesCali;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.CompteurIndexPASContratTravail;
import fr.unedic.cali.dom.ClassementAdministratif;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieSurMemeContratGAEC;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.utilitaire.filtres.generiques.FiltreDemandePourReferenceExterne;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologieDebuts;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.FiltreTemporel;
import fr.unedic.util.temps.FiltresTemporel;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import org.apache.commons.lang.StringUtils;

public class EnregistrerAntecedentMigration
  extends EnregistrerDemandeAssurance
{
  private static ContexteService s_contexteService = null;
  
  protected fr.unedic.cali.dom.DemandeSpec rechercherDemande(IndividuSpec p_individu, String p_idDemandeAMettreAJour, fr.unedic.cali.dom.DemandeSpec p_demandeTemporaire)
    throws CoucheLogiqueException
  {
    Individu individu = (Individu)p_individu;
    
    fr.unedic.cali.dom.DemandeSpec demandeExistante = null;
    if ((p_idDemandeAMettreAJour != null) && (!p_idDemandeAMettreAJour.equals(""))) {
      demandeExistante = individu.rechercherDemande(p_idDemandeAMettreAJour);
    }
    miseAjourDemandeTemporaire(p_demandeTemporaire, individu);
    
    String referenceExterne = ((Demande)p_demandeTemporaire).getSaisieAntecedent().getReferenceExterne();
    if (demandeExistante == null)
    {
      FiltreTemporel filtre = new FiltreDemandePourReferenceExterne(referenceExterne);
      Chronologie chronologieDemandeRecherchee = p_individu.getChronoDemandeAssurance().copier(filtre);
      if (!chronologieDemandeRecherchee.estVide())
      {
        chronologieDemandeRecherchee.iterer();
        demandeExistante = (Demande)chronologieDemandeRecherchee.elementSuivant();
      }
    }
    if (demandeExistante == null)
    {
      fr.unedic.cali.autresdoms.cohab.sigma.demande.dom.spec.DemandeSpec demandeRecue = individu.getUneDemandeV1(referenceExterne);
      if (demandeRecue == null) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_PR_CALI_L_ERR_CTX_REF_EXTERNE_INCONNUE", new Object[] { referenceExterne }, 1);
      }
      Collection listeDemandesCojac = new ArrayList();
      listeDemandesCojac.add(demandeRecue);
      
      Collection listeNouvellesDemandesNcp = null;
      try
      {
        Collection listeNouveauxFormulairesNcp = FabriqueFormulairesCali.creerFormulairesNcp(listeDemandesCojac, p_individu, s_contexteService);
        listeNouvellesDemandesNcp = CreationDemande.getInstance().creerNouvellesDemandesNcp(individu, s_contexteService, listeNouveauxFormulairesNcp);
      }
      catch (Exception e)
      {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException(null, e);
      }
      Iterator iterDemandes = listeNouvellesDemandesNcp.iterator();
      while (iterDemandes.hasNext())
      {
        demandeExistante = (fr.unedic.cali.dom.DemandeSpec)iterDemandes.next();
        ((Demande)demandeExistante).createDonneesDAL();
      }
    }
    return demandeExistante;
  }
  
  private void miseAjourDemandeTemporaire(fr.unedic.cali.dom.DemandeSpec p_demandeTemporaire, IndividuSpec p_individu)
    throws CoucheLogiqueException
  {
    String idFGD = ((Demande)p_demandeTemporaire).getSaisieAntecedent().getIdentifiantFaitGenerateur();
    if ((idFGD != null) && (!"".equalsIgnoreCase(idFGD))) {
      ((Demande)p_demandeTemporaire).getSaisieAntecedent().setIdentifiantFaitGenerateur(rechercherIdentifiantGaec(idFGD, p_individu));
    }
    String idFCT = ((Demande)p_demandeTemporaire).getSaisieAntecedent().getIdentifiantFCTRetenue();
    if ((idFCT != null) && (!"".equalsIgnoreCase(idFCT))) {
      ((Demande)p_demandeTemporaire).getSaisieAntecedent().setIdentifiantFCTRetenue(rechercherIdentifiantGaec(idFCT, p_individu));
    }
  }
  
  private String rechercherIdentifiantGaec(String p_identifiantGaec, IndividuSpec p_individu)
    throws CoucheLogiqueException
  {
    int suffixeMax = 0;
    
    ActiviteSalarie activiteMax = null;
    ActiviteSalarie activite = (ActiviteSalarie)p_individu.rechercherPeriodePasseProfessionnel(p_identifiantGaec);
    if (activite == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_N_CALI_ANTECEDENT_PAS_DE_PAS_TROUVE", new Object[] { p_identifiantGaec });
    }
    int suffixeDepart = Integer.parseInt(CompteurIndexPASContratTravail.recupererSuffixeIdentifiant(activite.getIdentifiant()));
    
    FiltresTemporel filtre = new FiltresTemporel();
    filtre.ajouterFiltre(new FiltreActiviteSalarieSurMemeContratGAEC(activite));
    
    Chronologie chronoPeriodes = p_individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtre);
    chronoPeriodes.iterer();
    while ((chronoPeriodes.encoreSuivant()) && (!chronoPeriodes.estVide()))
    {
      activiteMax = (ActiviteSalarie)chronoPeriodes.elementSuivant();
      suffixeMax = Integer.parseInt(CompteurIndexPASContratTravail.recupererSuffixeIdentifiant(activiteMax.getIdentifiant()));
      if (suffixeMax > suffixeDepart)
      {
        p_identifiantGaec = activiteMax.getIdentifiant();
        suffixeDepart = suffixeMax;
      }
    }
    return p_identifiantGaec;
  }
  
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    DomLiquidationDemande dom = (DomLiquidationDemande)p_contexte.getDonnees();
    ContexteService contexteService = dom.getContexteService();
    s_contexteService = contexteService;
    fr.unedic.cali.dom.DemandeSpec demande = null;
    if (p_contexte != null)
    {
      String idDemande = getIdDemande(p_contexte);
      
      IndividuSpec demandeur = getIndividu(p_contexte);
      if ((idDemande != null) && (!idDemande.equals("")))
      {
        demande = demandeur.rechercherDemande(idDemande);
        String referenceExterne = ((Demande)getDemande(p_contexte)).getSaisieAntecedent().getReferenceExterne();
        if ((referenceExterne != null) && (!"".equalsIgnoreCase(referenceExterne)) && 
          (!demande.getFormulaire().getReferenceExterne().equalsIgnoreCase(referenceExterne))) {
          throw new ContexteException("ASU_PR_CALI_L_ERR_CTX_REF_EXTERNE_INCOHERENTE", "Les données en entrée Identifiant demande et référence externe sont incohérentes");
        }
      }
      if ((getDemande(p_contexte).getClassementAdministratif() != null) && (StringUtils.equalsIgnoreCase(getDemande(p_contexte).getClassementAdministratif().getTypeClassement(), "SO"))) {
        if ((demande.estDecisionnee()) && (!demande.estEnReExamen())) {
          throw new ContexteException("HG_PR_CALI_L_ERR_CLASSEMENT_SO_SUR_DEMANDE", "Le classement de la demande en sans objet est impossible, veuillez mettre en réexamen la décision");
        }
      }
      if ((getDemande(p_contexte).getClassementAdministratif() != null) && (StringUtils.equalsIgnoreCase(getDemande(p_contexte).getClassementAdministratif().getTypeClassement(), "SP"))) {
        if ((demande.estDecisionnee()) && (!demande.estEnReExamen())) {
          throw new ContexteException("HG_PR_CALI_L_ERR_CLASSEMENT_SP_SUR_DEMANDE", "Impossible de classer la demande en secteur public, demande déja décisionnée.");
        }
      }
    }
    else
    {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE_ABSENT");
    }
  }
}

/* Location:
 * Qualified Name:     EnregistrerAntecedentMigration
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */