package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.affectation.parametres.AccesDecorReglementaire;
import fr.unedic.cali.affectation.parametres.CriteresQualification;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilFinDroit;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.AppelGaecReduit;
import fr.unedic.cali.dom.ConteneurAccesDecorReglementaire;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.EvenementReferenceExamenAntecedentSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.DecorReglementaire;
import fr.unedic.cali.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePASOrigineContratTravail;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesQualifiables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomQualificationPeriode;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ComparateurTemporelsSurDateFin;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreDebutDansBornes;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.Collection;

public class LireQualificationPeriode
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (getIndividu(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "L'allocataire demandeur est obligatoire");
    }
  }
  
  public Resultat demarrerParcours(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(LireQualificationPeriode.class, Niveau.DEBUG)) {
      Log.ecritTrace(Niveau.DEBUG, LireQualificationPeriode.class, "demarrer", "\t\t******** Début Parcours EnregistrerQualificationPeriode ********\n");
    }
    ResultatLireQualificationPeriode resultatLireQualificationPeriode = new ResultatLireQualificationPeriode();
    
    ChronologiePeriodes chronoPeriodeActiviteSalariee = null;
    ChronologiePeriodes chronoPeriodeActiviteSalarieeBornee = null;
    ChronologiePeriodes chronoPeriodeChomageTotalSansRupture = null;
    
    DecorReglementaire decorReglementaire = null;
    
    IndividuSpec individu = getIndividu(p_contexte);
    Damj dateFinDernierSinistre = getDateFinDernierSinistre(p_contexte);
    
    DemandeSpec demandeCourante = individu.rechercherDemande(((DomQualificationPeriode)p_contexte.getDonnees()).getIdDemande());
    ((DomQualificationPeriode)p_contexte.getDonnees()).setDemande(demandeCourante);
    if (dateFinDernierSinistre == null) {
      dateFinDernierSinistre = getDateFinPeriodeConcommittante(p_contexte);
    }
    if (dateFinDernierSinistre != null)
    {
      ConteneurAccesDecorReglementaire conteneur = new ConteneurAccesDecorReglementaire();
      conteneur.setDateRecherche(dateFinDernierSinistre);
      
      decorReglementaire = AccesDecorReglementaire.getInstance().getDecor(conteneur);
      
      CriteresQualification critereQualification = new CriteresQualification(decorReglementaire, dateFinDernierSinistre, false, false);
      
      AccesDecorReglementaire.getInstance().positionnerCriteresQualifSurPas(critereQualification, (Individu)individu);
      
      AttributionAssuranceSpec odPrecedente = null;
      if (demandeCourante != null) {
        odPrecedente = ((DemandeAssuranceSpec)demandeCourante).rechercherOuvertureDroitPrecedenteDuMemeType();
      }
      Damj dateDebut = Damj.NUIT_DES_TEMPS;
      if (odPrecedente != null) {
        if ((odPrecedente.getFaitGenerateur() != null) && (odPrecedente.getFaitGenerateur().getDateFaitGenerateur() != null)) {
          dateDebut = odPrecedente.getFaitGenerateur().getDateFaitGenerateur().lendemain();
        }
      }
      if ((demandeCourante != null) && (OutilDemande.estUneDemandeFinDroitAsp(demandeCourante)))
      {
        AttributionAssuranceSpec attribAspLiee = (AttributionAssuranceSpec)OutilFinDroit.rechercherAttributionOrigineCorrespondante(demandeCourante);
        if ((attribAspLiee != null) && (attribAspLiee.getDemande().getEvenementReferenceExamen() != null) && ((attribAspLiee.getDemande().getEvenementReferenceExamen() instanceof EvenementReferenceExamenAntecedentSpec))) {
          dateDebut = attribAspLiee.getFaitGenerateur().getDateFaitGenerateur();
        }
      }
      FiltresTemporel filtresSansBorne = new FiltresTemporel();
      filtresSansBorne.ajouterFiltre(new FiltrePASOrigineContratTravail());
      filtresSansBorne.ajouterFiltre(new FiltrePeriodesQualifiables());
      chronoPeriodeActiviteSalariee = (ChronologiePeriodes)individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtresSansBorne);
      
      FiltrePeriodesSurFiltresExclusifs listeFiltresBornes = new FiltrePeriodesSurFiltresExclusifs();
      Periode periodeBorne = new Periode(dateDebut, dateFinDernierSinistre);
      FiltreDebutDansBornes filtredebutDansBornes = new FiltreDebutDansBornes(periodeBorne);
      
      FiltreFinDansBornes filtreFinDansBornes = new FiltreFinDansBornes(periodeBorne);
      
      listeFiltresBornes.ajouterFiltre(filtredebutDansBornes);
      listeFiltresBornes.ajouterFiltre(filtreFinDansBornes);
      if (dateDebut.estAvantOuCoincideAvec(dateFinDernierSinistre)) {
        chronoPeriodeActiviteSalarieeBornee = (ChronologiePeriodes)chronoPeriodeActiviteSalariee.copier(listeFiltresBornes);
      }
      FiltreFinDansBornes filtreBornerPeriodesChomageSansRCT = new FiltreFinDansBornes(new Periode(dateFinDernierSinistre, Damj.FIN_DES_TEMPS));
      FiltresTemporel filtresRCT = new FiltresTemporel();
      filtresRCT.ajouterFiltre(new FiltrePASOrigineContratTravail());
      filtresRCT.ajouterFiltre(new FiltrePeriodesQualifiables());
      filtresRCT.ajouterFiltre(filtreBornerPeriodesChomageSansRCT);
      filtresRCT.ajouterFiltre(new FiltreActiviteSalarieRuptureContratSuiteChomageSansRupture());
      chronoPeriodeChomageTotalSansRupture = (ChronologiePeriodes)individu.getChronoPeriodePasseProfessionnelLiquidation().copier(filtresRCT);
      if (chronoPeriodeActiviteSalarieeBornee != null) {
        chronoPeriodeActiviteSalarieeBornee.setComparateur(new ComparateurTemporelsSurDateFin());
      }
      if (chronoPeriodeActiviteSalariee != null) {
        chronoPeriodeActiviteSalariee.setComparateur(new ComparateurTemporelsSurDateFin());
      }
      if (chronoPeriodeChomageTotalSansRupture != null) {
        chronoPeriodeChomageTotalSansRupture.setComparateur(new ComparateurTemporelsSurDateFin());
      }
    }
    resultatLireQualificationPeriode.setChronoPeriodeActiviteAQualifierNonFiltree(chronoPeriodeActiviteSalariee);
    resultatLireQualificationPeriode.setChronoPeriodeActiviteAQualifier(chronoPeriodeActiviteSalarieeBornee);
    resultatLireQualificationPeriode.setChronoPeriodeChomageTotalSansRupture(chronoPeriodeChomageTotalSansRupture);
    if (decorReglementaire != null) {
      resultatLireQualificationPeriode.setDecorReglementaire(decorReglementaire);
    }
    resultatLireQualificationPeriode.setEtat(0);
    if (Log.isTraceActive(LireQualificationPeriode.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, LireQualificationPeriode.class, "demarrer", "\t\t******** Résultat Parcours LireQualificationPeriode ********\n" + resultatLireQualificationPeriode);
      
      Log.ecritTrace(Niveau.DEBUG, LireQualificationPeriode.class, "demarrer", "\t\t******** Fin Parcours LireQualificationPeriode ********\n");
    }
    return resultatLireQualificationPeriode;
  }
  
  private Damj getDateFinDernierSinistre(Contexte p_contexte)
  {
    return ((DomQualificationPeriode)p_contexte.getDonnees()).getDateFinDernierSinistre();
  }
  
  private Damj getDateFinPeriodeConcommittante(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (getDemande(p_contexte) == null) {
      return Damj.FIN_DES_TEMPS;
    }
    TravailSpec periodeConcommittante = RechercherDernierSinistre.rechercherUneDesPeriodesConcommittantes(getDemande(p_contexte).getDateRecherche().veille(), getIndividu(p_contexte).getChronoPeriodePasseProfessionnelLiquidation());
    if (periodeConcommittante != null) {
      return periodeConcommittante.getDateFin();
    }
    return null;
  }
  
  protected Demande getDemande(Contexte p_contexte)
  {
    return (Demande)((DomQualificationPeriode)p_contexte.getDonnees()).getDemandeSpec();
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    if (p_individu != null)
    {
      Collection typePeriodesGaec = new ArrayList();
      ajouterSiNouveau("9", typePeriodesGaec);
      
      p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(1);
      p_individu.getDonneesChargementGaec().getAgregatGaec().setTypePeriodesGaec(typePeriodesGaec);
    }
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    AppelGaecReduit gaecReduit = p_individu.getDonneesChargementGaec().getAppelGaecReduit();
    
    controlerModeAppel(gaecReduit, 1);
    
    controlerTypePeriode(gaecReduit.getTypePeriodes(), "9");
  }
}

/* Location:
 * Qualified Name:     LireQualificationPeriode
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */