package fr.unedic.cali.asu.parcours;

import fr.pe.cali.crem.outils.OutilAjoutCremDalLiquidation;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.dom.persistance.util.ContextePersistance;
import fr.unedic.cali.outilsfonctionnels.OutilFluxSigma;
import fr.unedic.cali.outilsfonctionnels.reexecution.FabriqueGestionnaireReexecution;
import fr.unedic.cali.outilsfonctionnels.reexecution.GestionnaireReexecutionSpec;
import fr.unedic.cali.outilsfonctionnels.reexecution.ResultatGestionnaireReexecutionSpec;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.cali.parcours.ResultatInstallerDroitOptionAss;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.Resultat;
import java.util.ArrayList;
import java.util.Collection;

public class ParcoursInstallerDroitOptionAss
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    IndividuSpec individuCourant = getIndividu(contexte);
    if (individuCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Individu absent à tort");
    }
    String idDemande = ((DomLiquidationAssurance)contexte.getDonnees()).getIdDemande();
    if (idDemande == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Demande absente à tort");
    }
    mettreAJourContexte(contexte);
  }
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    ResultatInstallerDroitOptionAss resultatInstallerDroitOptionAss = new ResultatInstallerDroitOptionAss(0);
    IndividuSpec individu = recupererIndividu(contexte);
    
    Demande demandeAssurance = traiterDemande(contexte);
    
    ResultatGestionnaireReexecutionSpec resultatReexecution = reexecution(demandeAssurance);
    
    OutilAjoutCremDalLiquidation outilAjoutCREM = initialisationOutilAjouCREM();
    outilAjoutCREM.ajouterCREMDemandesReexecutes(resultatReexecution.getDemandesReliquidees(), individu);
    
    notifierSigma(demandeAssurance);
    
    resultatInstallerDroitOptionAss.setDemande(demandeAssurance);
    return resultatInstallerDroitOptionAss;
  }
  
  protected IndividuSpec recupererIndividu(Contexte contexte)
  {
    return getIndividu(contexte);
  }
  
  protected void mettreAJourContexte(Contexte contexte)
    throws ContexteException
  {
    DomLiquidationAssurance domCourant = (DomLiquidationAssurance)contexte.getDonnees();
    
    IndividuSpec individu = getIndividu(contexte);
    
    DemandeSpec demandeCourante = individu.rechercherDemande(domCourant.getIdDemande());
    if (demandeCourante == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CONTEXTE", "Demande inexistante en base");
    }
    domCourant.setDemande(demandeCourante);
  }
  
  protected ResultatGestionnaireReexecutionSpec reexecution(DemandeSpec demande)
    throws ApplicativeException
  {
    return FabriqueGestionnaireReexecution.getGestionnaire().executerSurValidation(demande);
  }
  
  protected void notifierSigma(Demande demandeAssurance)
    throws ApplicativeException
  {
    Collection<Demande> demandesModifiees = new ArrayList(1);
    demandesModifiees.add(demandeAssurance);
    if (ContextePersistance.isPersistant()) {
      OutilFluxSigma.notifierSigma(demandeAssurance.getDemandeur(), demandesModifiees, false);
    }
  }
  
  protected OutilAjoutCremDalLiquidation initialisationOutilAjouCREM()
  {
    return OutilAjoutCremDalLiquidation.getInstance();
  }
  
  protected Demande traiterDemande(Contexte contexte)
    throws ApplicativeException
  {
    Demande demandeAssurance = (Demande)getDemande(contexte);
    
    Parcours parcours = demandeAssurance.getGamme().getParcoursLiquidation(demandeAssurance);
    parcours.effectuerParcours(contexte);
    if (demandeAssurance.getAttribution() != null) {
      demandeAssurance.getAttribution().setTopRenoncement(true);
    }
    ContexteService contexteService = ((DomLiquidationAssurance)contexte.getDonnees()).getContexteService();
    demandeAssurance.validerDecision();
    
    demandeAssurance.supprimerDossiersAffectations();
    
    demandeAssurance.definirDateValidation(contexteService.getDateTraitement());
    
    demandeAssurance.setDroitOptionASS(true);
    
    return demandeAssurance;
  }
  
  protected DemandeSpec getDemande(Contexte contexte)
  {
    return ((DomLiquidationAssurance)contexte.getDonnees()).getDemandeSpec();
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    if (individu != null) {
      individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
    }
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
}

/* Location:
 * Qualified Name:     ParcoursInstallerDroitOptionAss
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */