package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.EreRevisionConvention2014;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.spec.ObjectifExamenAssuranceSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.utilitaire.filtres.composites.FiltreAttributionStandardAssurance;
import fr.unedic.cali.utilitaire.outils.OutilRecherche;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.Iterator;

public class ParcoursLiquidationAssuranceRevisionAdmission
  extends ParcoursLiquidationAssurance
{
  protected void controlerDonneesSecteurPublic(IndividuSpec p_individu, DemandeAssuranceSpec p_demande)
    throws ContexteException
  {}
  
  public Resultat demarrerTraitement(Contexte p_contexte)
    throws ApplicativeException
  {
    ResultatLiquidationAssurance resultatLiquidation = new ResultatLiquidationAssurance(2);
    OutilTrace.tracerDebutParcours();
    
    DemandeSpec demandeCourante = getDemande(p_contexte);
    
    verifierContexte(demandeCourante);
    
    initialiserRegimeEuropeen((Demande)demandeCourante);
    
    initialisationPasseProfessionnelLiquidation(p_contexte);
    if (demandeCourante.estDecisionnee()) {
      sauvegarderDonneesAvantReexamen(p_contexte);
    }
    Damj dateExamen = determinerDateExamen(p_contexte);
    if (dateExamen == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ERR_DATE_EXAMEN_NON_DETERMINEE");
    }
    verifierPreconditions(p_contexte);
    
    determinationContexteParticulier(p_contexte);
    
    constaterContexteInitial(p_contexte);
    
    chargementListePNDSIndividu(demandeCourante, dateExamen);
    
    affecterProduit(p_contexte);
    
    determinerContexteExamen(p_contexte);
    
    determinerContextesLiquidation(p_contexte);
    
    controlerDonneesForcees(p_contexte);
    
    liquiderDemande(p_contexte);
    
    controlerDonneesForceesPostLiquidation(p_contexte);
    
    alimenterDecisionsReexamen(p_contexte, resultatLiquidation);
    
    verifierPostContexte(getDemande(p_contexte));
    
    resultatLiquidation.setDemande(getDemandeAsu(p_contexte));
    
    determinerCREMModificationLiquidation(p_contexte, resultatLiquidation);
    
    effectuerControlesEligibiliteSurDecisionAuto(p_contexte, demandeCourante);
    
    OutilTrace.tracerFinParcours();
    return resultatLiquidation;
  }
  
  protected void chargementListePNDSIndividu(DemandeSpec p_demandeCourante, Damj p_dateExamen)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec odPourRevision = ((DemandeAssuranceSpec)p_demandeCourante).rechercherOuvertureDroitPrecedenteDuMemeType();
    if (odPourRevision != null) {
      super.chargermentListePNDSIndividu(odPourRevision.getDemande(), odPourRevision.getDateExamen());
    }
  }
  
  private void initialiserRegimeEuropeen(Demande p_demande)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec attributionAssurancePrecedente = null;
    if ("REVAUTO".equals(((EreRevisionConvention2014)p_demande.getEvenementReferenceExamen()).getContexteDemande())) {
      attributionAssurancePrecedente = p_demande.rechercherAttributionPrecedenteDuMemeType();
    } else {
      attributionAssurancePrecedente = (AttributionAssuranceSpec)OutilRecherche.rechercherDecisionPrecedente(p_demande.getChronologieDemandesAssuranceSansCourante(), p_demande, new FiltreAttributionStandardAssurance(true, true, false, true, p_demande));
    }
    if (attributionAssurancePrecedente != null)
    {
      AttributionAssuranceSpec attribMaitre = (AttributionAssuranceSpec)attributionAssurancePrecedente.getOuvertureDroit();
      if (attribMaitre != null) {
        p_demande.getDonneesTemporaires().setTypeCoordinationEuropeenne(((Demande)attribMaitre.getDemande()).getDonneesTemporaires().getTypeCoordinationEuropeenne());
      }
    }
  }
  
  protected void verifierPreconditions(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (!"REVAUTO".equals(((EreRevisionConvention2014)getDemande(p_contexte).getEvenementReferenceExamen()).getContexteDemande())) {
      super.verifierPreconditions(p_contexte);
    }
  }
  
  protected void determinerContextesLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    super.determinerContextesLiquidation(contexte);
    if (!getDom(contexte).getAttributionPrecedente().estMaintenue()) {
      switch (getDom(contexte).getContexteExamen())
      {
      case 1: 
      case 2: 
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_BLOQUANTE_A10MB2");
      }
    }
  }
  
  protected void liquiderDemande(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demande = getDemandeAsu(p_contexte);
    ActiviteSalarie activite = (ActiviteSalarie)demande.getDonneesTemporaires().getPeriodeRevision();
    IndividuSpec individu = demande.getDemandeur();
    ChronologiePeriodes chrono = new ChronologiePeriodes();
    chrono.ajouter(activite);
    
    individu.setChronoPeriodePasseProfessionnelLiquidationRevision(chrono);
    individu.activerChronoPasseProPourLiquidationRevision();
    
    determinerOrdreObjectifs(p_contexte);
    
    traiterObjectifs(p_contexte);
    
    individu.desactiverChronoPasseProPourLiquidationRevision();
  }
  
  protected void determinerOrdreObjectifs(Contexte p_contexte)
    throws ApplicativeException
  {
    ProduitAsuSpec produit = (ProduitAsuSpec)getDemandeAsu(p_contexte).getDossierAffectation().getProduit();
    produit.determinerOrdreObjectifs(p_contexte);
  }
  
  private void traiterObjectifs(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demandeCourante = getDemandeAsu(p_contexte);
    
    ObjectifExamen objectifCourant = demandeCourante.getObjectifParNumeroOrdre(1);
    
    boolean traitementFini = false;
    while (!traitementFini)
    {
      lancerParcoursObjectif(p_contexte, objectifCourant);
      if (objectifCourant.getEtat() == 21)
      {
        proposerRevision(p_contexte);
        objectifCourant.setEtat(23);
        traitementFini = true;
      }
      else
      {
        ObjectifExamen objectifNonTraite = verifierExistenceObjectifNonTraite(p_contexte);
        if (objectifNonTraite == null)
        {
          proposerEchec(p_contexte);
          traitementFini = true;
        }
        else
        {
          objectifCourant = objectifNonTraite;
        }
      }
    }
    getDemandeAsu(p_contexte).setObjectifCourant(null);
  }
  
  private void proposerRevision(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demande = getDemandeAsu(p_contexte);
    
    ((DecisionSpec)demande.getDossierExamen()).setNatureDecision(getDemandeAsu(p_contexte).getObjectifCourant().getSousType());
    if (getDom(p_contexte).getAttributionPrecedente() != null) {
      demande.setDemandeOrigine(getDom(p_contexte).getAttributionPrecedente().getDemandeAssurance());
    }
    alimenterTranchesExecutables(p_contexte);
    
    demande.setListeMotifsReexamen(null);
  }
  
  private void proposerEchec(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    Demande demande = getDemandeAsu(p_contexte);
    
    demande.setListeMotifsReexamen(null);
    
    DossierExamenSpec dossierExamen = demande.getDossierAffectation().getDossierExamen();
    ((DossierExamenAssuranceSpec)dossierExamen).setContributionParticuliere(null);
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)p_contexte.getDonnees();
    demande.setDemandeOrigine((DemandeAssuranceSpec)dom.getAttributionPrecedente().getDemande());
    
    Collection<ObjectifExamenAssuranceSpec> listeObjectifs = demande.getListeObjectifsExamen();
    for (Iterator<ObjectifExamenAssuranceSpec> iter = listeObjectifs.iterator(); iter.hasNext();)
    {
      ObjectifExamen objectif = (ObjectifExamen)iter.next();
      if ((objectif.getType() == 4) || (objectif.getType() == 1))
      {
        demande.getDossierAffectationAdmission().getDossierExamen().changerEtat(29);
        ((DecisionSpec)demande.getDossierAffectationAdmission().getDossierExamen()).setNatureDecision(29);
      }
    }
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu p_individu)
  {
    return 0;
  }
  
  protected void alimenterAgregatGaec(Individu p_individu, String p_idDemande)
  {
    p_individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(0);
  }
  
  protected void controlerPostTraitement(Individu p_individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(p_individu.getDonneesChargementGaec().getAppelGaecReduit(), 0);
  }
  
  protected void positionnerPasseProRevisionAvecExclusionFctReviseesAre14(Demande pDemande) {}
  
  protected void activerChronoPasseProPourLiquidationRevision(IndividuSpec pIndividu) {}
  
  protected void desactiverChronoPasseProPourLiquidationRevision(IndividuSpec pIndividu) {}
  
  protected void reinitialiserCacheDemande(DemandeAssuranceSpec p_demande)
  {
    if (!"REVAUTO".equals(((EreRevisionConvention2014)p_demande.getEvenementReferenceExamen()).getContexteDemande())) {
      super.reinitialiserCacheDemande(p_demande);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationAssuranceRevisionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */