package fr.unedic.cali.asu.parcours;

import fr.pe.cali.crem.dom.ObjetMetierCrem;
import fr.pe.cali.crem.outils.OutilGenerationObjetMetierDalLiquidation;
import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.ComparateurDecision;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.DeterminationContexte;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.DeterminationSituationDemandeur;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.InstallationDemande;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.LiquidationSimplifiee;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.OutilEntretien;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.OutilSimulation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.Parametres;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.dom.AgregatGaec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DonneesChargementGaec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.GammeSpec;
import fr.unedic.cali.outilsfonctionnels.OutilDeterminationDateExamen;
import fr.unedic.cali.outilsfonctionnels.OutilFluxSigma;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.AccesDonneesGaecException;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ParcoursLiquidation;
import fr.unedic.cali.parcours.ParcoursServiceAbstrait;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import java.util.List;

public class ParcoursLiquidationSimplifiee
  extends ParcoursServiceAbstrait
{
  public void controlerContexte(Contexte contexte)
    throws ContexteException
  {
    DomLiquidationSimplifiee domCourant = (DomLiquidationSimplifiee)contexte.getDonnees();
    
    IndividuSpec individuCourant = getIndividu(contexte);
    if (individuCourant == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Individu absent du contexte");
    }
    String idDemande = getIdDemande(contexte);
    if ((idDemande != null) && (domCourant.getDemande() == null))
    {
      DemandeSpec demandeCourante = domCourant.getIndividu().rechercherDemande(domCourant.getIdDemande());
      domCourant.setDemande(demandeCourante);
    }
  }
  
  private void traitementPreLiquidationSimplifiee(DomLiquidationSimplifiee dom)
  {
    DemandeSpec demande = dom.getDemande();
    demande.setDemandeLiquidee(true);
  }
  
  public Resultat demarrerParcours(Contexte contexte)
    throws ApplicativeException
  {
    ResultatLiquidationSimplifiee resultat = new ResultatLiquidationSimplifiee();
    resultat.setEtat(1);
    
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
    resultat.setDomLiquidationSimplifiee(dom);
    
    Parametres.chargerParametres(contexte);
    
    ObjetChronoPeriodePriseEnCharge pecTemporaire = preTraitementSimulation(dom);
    
    creerDemandeV2(contexte, dom, pecTemporaire);
    
    situationDemandeur(dom, resultat);
    if (resultat.getContexteRetour() == null)
    {
      if ("L".equalsIgnoreCase(dom.getContexteAppel())) {
        OutilEntretien.mettreAJourEntretien(contexte, null);
      }
      if ("ENR".equalsIgnoreCase(dom.getContexteAppel()))
      {
        OutilEntretien.mettreAJourEntretienPreInscription(contexte);
      }
      else if ("E".equalsIgnoreCase(dom.getContexteAppel()))
      {
        positionnerContexteRetourEnvoiDal(resultat, contexte, dom);
      }
      else if (!"R".equalsIgnoreCase(dom.getContexteAppel()))
      {
        DeterminationContexte determinationContexte = new DeterminationContexte();
        resultat.setContexteRetour(determinationContexte.determinerContexte(dom));
        if (estUneDemandeALiquiderEnModeSimplifiee(resultat)) {
          traiterLiquidationSimplifiee(resultat, contexte, dom);
        } else {
          resultat.setContexteRetour("D");
        }
      }
      else
      {
        resultat.setContexteRetour("D");
      }
    }
    else if (("E".equalsIgnoreCase(dom.getContexteAppel())) && ("D".equalsIgnoreCase(resultat.getContexteRetour())))
    {
      positionnerContexteRetourEnvoiDal(resultat, contexte, dom);
    }
    executerPostsTraitements(resultat, dom, pecTemporaire);
    
    resultat.setEtat(0);
    
    OutilTrace.tracerFinParcours(Niveau.DEBUG);
    
    return resultat;
  }
  
  private void positionnerContexteRetourEnvoiDal(ResultatLiquidationSimplifiee resultat, Contexte contexte, DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    resultat.setContexteRetour(envoiDal(contexte));
    
    OutilEntretien.supprimerPreInscriptions(dom);
  }
  
  private void traiterLiquidationSimplifiee(ResultatLiquidationSimplifiee resultat, Contexte contexte, DomLiquidationSimplifiee dom)
    throws ApplicativeException
  {
    LiquidationSimplifiee liquidationSimplifiee = new LiquidationSimplifiee();
    resultat.setContexteRetour(liquidationSimplifiee.liquider(contexte));
    if (estUneDemandeALiquiderEnModeStandard(resultat))
    {
      controlerDemandeExistante(contexte);
      try
      {
        liquiderDemande(contexte);
        
        resultat.setContexteRetour(ComparateurDecision.comparerDecision(dom));
      }
      catch (ApplicativeException ex)
      {
        OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "Exception levée lors de la liquidation standard" }, ex);
        
        getDemande(contexte).annulerDecisions();
        if ("V".equalsIgnoreCase(dom.getContexteAppel())) {
          resultat.setContexteRetour("E");
        } else {
          resultat.setContexteRetour("D");
        }
      }
      if (("V".equalsIgnoreCase(dom.getContexteAppel())) && (!"E".equals(resultat.getContexteRetour())) && (!"D".equals(resultat.getContexteRetour())))
      {
        resultat.setContexteRetour(liquidationSimplifiee.valider(contexte));
        
        OutilEntretien.supprimerPreInscriptions(dom);
      }
    }
  }
  
  protected void liquiderEnSimplifier(Contexte contexte, ResultatLiquidationSimplifiee resultat, DomLiquidationSimplifiee dom)
    throws ApplicativeException, CoucheLogiqueException
  {
    LiquidationSimplifiee liquidationSimplifiee = new LiquidationSimplifiee();
    resultat.setContexteRetour(liquidationSimplifiee.liquider(contexte));
    if (estUneDemandeALiquiderEnModeStandard(resultat))
    {
      controlerDemandeExistante(contexte);
      try
      {
        liquiderDemande(contexte);
        
        resultat.setContexteRetour(ComparateurDecision.comparerDecision(dom));
      }
      catch (ApplicativeException ex)
      {
        OutilTrace.ecrireTrace(Niveau.ERROR, new Object[] { "Exception levée lors de la liquidation standard" }, ex);
        
        getDemande(contexte).annulerDecisions();
        if ("V".equalsIgnoreCase(dom.getContexteAppel())) {
          resultat.setContexteRetour("E");
        } else {
          resultat.setContexteRetour("D");
        }
      }
      if (("V".equalsIgnoreCase(dom.getContexteAppel())) && (!"E".equals(resultat.getContexteRetour())) && (!"D".equals(resultat.getContexteRetour())))
      {
        resultat.setContexteRetour(liquidationSimplifiee.valider(contexte));
        
        OutilEntretien.supprimerPreInscriptions(dom);
      }
    }
  }
  
  protected void mettreAJourEntretien(Contexte contexte, DomLiquidationSimplifiee dom)
    throws CoucheLogiqueException
  {
    if ("L".equalsIgnoreCase(dom.getContexteAppel())) {
      OutilEntretien.mettreAJourEntretien(contexte, null);
    }
  }
  
  protected void executerPostsTraitements(ResultatLiquidationSimplifiee resultat, DomLiquidationSimplifiee dom, ObjetChronoPeriodePriseEnCharge pecTemporaire)
  {
    if (("SIMU".equalsIgnoreCase(dom.getContexteAppel())) || ("LSSI".equalsIgnoreCase(dom.getContexteAppel()))) {
      OutilSimulation.postTraitement(dom, pecTemporaire);
    }
    resultat.setDomLiquidationSimplifiee(dom);
    if (!"ENR".equalsIgnoreCase(dom.getContexteAppel())) {
      traitementPostLiquidationSimplifiee(dom);
    }
  }
  
  protected void situationDemandeur(DomLiquidationSimplifiee dom, ResultatLiquidationSimplifiee resultat)
    throws ApplicativeException
  {
    try
    {
      if (!"ENR".equalsIgnoreCase(dom.getContexteAppel()))
      {
        DeterminationSituationDemandeur situationDemandeur = new DeterminationSituationDemandeur();
        situationDemandeur.rechercherSituationdemandeur(dom);
        
        traitementPreLiquidationSimplifiee(dom);
        
        OutilDeterminationDateExamen.getInstance().determinerDateExamen(dom.getDemande());
      }
    }
    catch (ApplicativeException ex)
    {
      resultat.setContexteRetour("D");
    }
  }
  
  protected void creerDemandeV2(Contexte contexte, DomLiquidationSimplifiee dom, ObjetChronoPeriodePriseEnCharge pecTemporaire)
    throws ApplicativeException
  {
    if ("C".equalsIgnoreCase(dom.getContexteAppel())) {
      InstallationDemande.installerDemande(dom);
    } else if (("SIMU".equalsIgnoreCase(dom.getContexteAppel())) || ("LSSI".equalsIgnoreCase(dom.getContexteAppel()))) {
      OutilSimulation.creerDemandeV2(contexte, pecTemporaire);
    }
  }
  
  protected ObjetChronoPeriodePriseEnCharge preTraitementSimulation(DomLiquidationSimplifiee dom)
    throws CoucheLogiqueException
  {
    ObjetChronoPeriodePriseEnCharge pecTemporaire = null;
    if (("SIMU".equalsIgnoreCase(dom.getContexteAppel())) || ("LSSI".equalsIgnoreCase(dom.getContexteAppel())) || ("ENR".equalsIgnoreCase(dom.getContexteAppel())))
    {
      dom.setPreInscriptionAude(OutilSimulation.recupererInformationsPreinscription(dom));
      if (!"ENR".equalsIgnoreCase(dom.getContexteAppel())) {
        pecTemporaire = OutilSimulation.preTraitement(dom);
      }
    }
    return pecTemporaire;
  }
  
  private void controlerDemandeExistante(Contexte contexte)
    throws CoucheLogiqueException
  {
    DemandeSpec demande = getDemande(contexte);
    if ((demande.estMigree()) || (demande.estDecisionnee()))
    {
      DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
      InstallationDemande.leverBlocageInstallation(dom);
    }
  }
  
  private void traitementPostLiquidationSimplifiee(DomLiquidationSimplifiee dom)
  {
    DemandeSpec demande = dom.getDemande();
    demande.setDemandeLiquidee(false);
  }
  
  private void liquiderDemande(Contexte contexte)
    throws ApplicativeException
  {
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
    DemandeSpec demande = getDemande(contexte);
    
    DomLiquidationDemande domContexte = null;
    Contexte contexteParcours = null;
    ParcoursLiquidation parcoursLiquidationDemande = null;
    
    domContexte = demande.getGamme().creerDomLiquidationDemande();
    domContexte.setDemande(demande);
    domContexte.setIdDemande(demande.getIdentifiant());
    domContexte.setIndividu(demande.getDemandeur());
    domContexte.setContexteService(demande.getDemandeur().getContexteService());
    contexteParcours = new Contexte();
    contexteParcours.setDonnees(domContexte);
    
    parcoursLiquidationDemande = demande.getGamme().getParcoursLiquidation(demande);
    parcoursLiquidationDemande.effectuerParcours(contexteParcours);
    
    dom.setDemandeStandard((DemandeSpec)demande.copie());
    if (!"V".equalsIgnoreCase(dom.getContexteAppel())) {
      demande.annulerDecisions();
    }
  }
  
  protected String envoiDal(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)getDemande(contexte);
    
    demande.getFormulaireAsu().setDateDepot(null);
    demande.getFormulaireAsu().miseAjour(demande.getFormulaireAsu());
    
    ContexteService contexteService = ((DomLiquidationSimplifiee)contexte.getDonnees()).getContexteService();
    ObjetMetierCrem crem = OutilGenerationObjetMetierDalLiquidation.getInstance().genererObjetMetier(demande, contexteService);
    if (crem != null) {
      demande.getDemandeur().getListeCrem().add(crem);
    }
    notifierEnvoiDal(demande);
    
    demande.setModeLiquidation("C");
    
    return "A";
  }
  
  protected void notifierEnvoiDal(Demande demande)
    throws ApplicativeException
  {
    OutilFluxSigma.notifierSigmaPourDecisionAutomatique(demande);
  }
  
  private DemandeSpec getDemande(Contexte contexte)
  {
    DomLiquidationSimplifiee dom = (DomLiquidationSimplifiee)contexte.getDonnees();
    return dom.getDemande();
  }
  
  private String getIdDemande(Contexte contexte)
  {
    return ((DomLiquidationSimplifiee)contexte.getDonnees()).getIdDemande();
  }
  
  private boolean estUneDemandeALiquiderEnModeStandard(ResultatLiquidationSimplifiee resultat)
  {
    if (("R".equalsIgnoreCase(resultat.getContexteRetour())) || ("P".equalsIgnoreCase(resultat.getContexteRetour()))) {
      return true;
    }
    return false;
  }
  
  private boolean estUneDemandeALiquiderEnModeSimplifiee(ResultatLiquidationSimplifiee resultat)
  {
    if ("S".equalsIgnoreCase(resultat.getContexteRetour())) {
      return true;
    }
    return false;
  }
  
  protected int getModeChargementDebrayageDossiersLourds(Individu individu)
  {
    return 2;
  }
  
  protected void alimenterAgregatGaec(Individu individu, String idDemande)
  {
    if (individu != null) {
      individu.getDonneesChargementGaec().getAgregatGaec().setModeAppel(2);
    }
  }
  
  protected void controlerPostTraitement(Individu individu)
    throws AccesDonneesGaecException
  {
    controlerModeAppel(individu.getDonneesChargementGaec().getAppelGaecReduit(), 2);
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationSimplifiee
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */