package fr.unedic.cali.asu.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.outilsfonctionnels.RechercherDernierSinistre;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ParcoursObjectifPoursuiteIndemnisation
  extends ParcoursCali
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatObjectifPoursuiteIndemnisation = new Resultat();
    resultatObjectifPoursuiteIndemnisation.setEtat(1);
    
    DomLiquidationAssurance dom = (DomLiquidationAssurance)contexte.getDonnees();
    Demande demandeCourante = dom.getDemande();
    
    controleExistenceFG(demandeCourante, dom.getAttributionPrecedente());
    
    boolean caprSatisfaites = verifierCapr(contexte);
    if (caprSatisfaites)
    {
      changerEtatDossierExamen((DossierExamenAssuranceSpec)demandeCourante.getDossierExamen());
      resultatObjectifPoursuiteIndemnisation.setEtat(0);
    }
    else
    {
      demandeCourante.getDossierExamen().changerEtat(16);
    }
    determinerCompetence((DossierExamenAssuranceSpec)demandeCourante.getDossierExamen(), dom.getAttributionPrecedente());
    
    OutilTrace.tracerFinParcours();
    
    return resultatObjectifPoursuiteIndemnisation;
  }
  
  protected DemandeAssuranceSpec getDemande(Contexte contexte)
  {
    return DomLiquidationAssurance.getDemande(contexte);
  }
  
  protected boolean verifierCapr(Contexte contexte)
    throws ApplicativeException
  {
    boolean caprSatisfaites = false;
    Resultat resultatCapr01 = null;
    Resultat resultatCapr09 = null;
    
    ProduitAsuSpec produitCourant = getProduit(contexte);
    
    resultatCapr01 = produitCourant.verifierConditionRechercheEmploi(contexte);
    
    resultatCapr09 = produitCourant.verifierConditionChomageInvolontaire(contexte);
    if ((resultatCapr01.estSatisfait()) && (resultatCapr09.estSatisfait())) {
      caprSatisfaites = true;
    }
    return caprSatisfaites;
  }
  
  protected ProduitAsuSpec getProduit(Contexte contexte)
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    return (ProduitAsuSpec)demande.getDossierAffectation().getProduit();
  }
  
  protected void controleExistenceFG(Demande demande, AttributionAssuranceSpec attributionPrecedente)
    throws CoucheLogiqueException
  {
    AttributionAssuranceSpec odOrigine = attributionPrecedente;
    if (!(attributionPrecedente instanceof OdSpec)) {
      odOrigine = (AttributionAssuranceSpec)attributionPrecedente.getOuvertureDroit();
    }
    if ((odOrigine.getFaitGenerateur() == null) || (odOrigine.getFaitGenerateur().getPeriodeFaitGenerateur() == null)) {
      controleExistenceDernierSinistre(demande);
    }
  }
  
  protected void controleExistenceDernierSinistre(Demande demande)
    throws CoucheLogiqueException
  {
    TravailSpec dernierSinistre = RechercherDernierSinistre.rechercherDernierSinistre(demande.getDateExamen(), demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation());
    if (dernierSinistre == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_REPRISE_SANS_FGD");
    }
  }
  
  protected void changerEtatDossierExamen(DossierExamenAssuranceSpec dossierExamenCourant)
    throws CoucheLogiqueException
  {
    dossierExamenCourant.changerEtat(49);
  }
  
  private void determinerCompetence(DossierExamenAssuranceSpec dossierExamen, AttributionAssuranceSpec attributionPrecedente)
  {
    CompetenceSpec competencePrecedente = attributionPrecedente.getCompetence();
    if (competencePrecedente != null)
    {
      CompetenceSpec copieCompetence = (CompetenceSpec)competencePrecedente.copie();
      dossierExamen.setCompetence(copieCompetence);
    }
  }
}

/* Location:
 * Qualified Name:     ParcoursObjectifPoursuiteIndemnisation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */