package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AccesseurDroitsSpec;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RecuperationElementIndemnisation;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class AccesseurDroits
  implements AccesseurDroitsSpec
{
  private DossierExamen dossierExamen;
  
  public AccesseurDroits(DossierExamen dossierExamen)
  {
    this.dossierExamen = dossierExamen;
  }
  
  public Quantite getDureeIndemnisationTheorique()
  {
    if ((((DecisionSpec)dossierExamen).getNatureDecision() == 11) || (((DecisionSpec)dossierExamen).getNatureDecision() == 26)) {
      return dossierExamen.getConstitutionProduitResultant().getDureeTheorique();
    }
    return dossierExamen.getConstitutionDurees().getDureeIndemnisation().getDureeTheorique();
  }
  
  public Quantite getDureeIndemnisationInitiale()
  {
    if ((((DecisionSpec)dossierExamen).getNatureDecision() == 11) || (((DecisionSpec)dossierExamen).getNatureDecision() == 26)) {
      return dossierExamen.getConstitutionProduitResultant().getDureeEffective();
    }
    return dossierExamen.getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
  }
  
  public QuantiteEuro getSjrInitial()
  {
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 12) {
      return dossierExamen.getConstitutionSjr().getSjrip().getSjrInitial();
    }
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 11) {
      return dossierExamen.getAttributionPrecedente().getAccesseurDroits().getSjrInitial();
    }
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 26)
    {
      if (dossierExamen.getConstitutionProduitResultant().getTypeMontantRetenu() == 1) {
        return dossierExamen.getConstitutionSjr().getSjrip().getSjrInitial();
      }
      Demande demande = (Demande)dossierExamen.getDemande();
      if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
        return new QuantiteEuro(getSjrInitial(demande).getSalaire());
      }
      return dossierExamen.getAttributionPrecedente().getAccesseurDroits().getSjrInitial();
    }
    return dossierExamen.getConstitutionSjr().getSjrip().getSjrInitial();
  }
  
  public String getContexteParticulierSjr()
  {
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 12) {
      return dossierExamen.getConstitutionSjr().getSjrip().getContexteParticulierSjr();
    }
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 11) {
      return dossierExamen.getAttributionPrecedente().getAccesseurDroits().getContexteParticulierSjr();
    }
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 26)
    {
      if (dossierExamen.getConstitutionProduitResultant().getTypeMontantRetenu() == 1) {
        return dossierExamen.getConstitutionSjr().getSjrip().getContexteParticulierSjr();
      }
      Demande demande = (Demande)dossierExamen.getDemande();
      if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
        return null;
      }
      return dossierExamen.getAttributionPrecedente().getAccesseurDroits().getContexteParticulierSjr();
    }
    return dossierExamen.getConstitutionSjr().getSjrip().getContexteParticulierSjr();
  }
  
  private Sjr getSjrInitial(Demande demande)
  {
    return RecuperationElementIndemnisation.recupererElementBaseIndemnisation(demande.getDonneesTemporaires()).getSjr();
  }
  
  public QuantiteEuro getMontantBrutJournalier()
  {
    if ((((DecisionSpec)dossierExamen).getNatureDecision() == 11) || (((DecisionSpec)dossierExamen).getNatureDecision() == 26)) {
      return (QuantiteEuro)dossierExamen.getConstitutionProduitResultant().getMontantJournalierBrut();
    }
    return (QuantiteEuro)dossierExamen.getConstitutionMontantsBruts().getMontantJournalierBrut();
  }
  
  public Damj getDateEffetSjr()
  {
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 12) {
      return dossierExamen.getConstitutionSjr().getSjrip().getDateEffet();
    }
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 11) {
      return dossierExamen.getAttributionPrecedente().getAccesseurDroits().getDateEffetSjr();
    }
    if (((DecisionSpec)dossierExamen).getNatureDecision() == 26)
    {
      if (dossierExamen.getConstitutionProduitResultant().getTypeMontantRetenu() == 1) {
        return dossierExamen.getConstitutionSjr().getSjrip().getDateEffet();
      }
      Demande demande = (Demande)dossierExamen.getDemande();
      if (demande.estEnContexteDroitAnterieurSecteurPublicValide()) {
        return getSjrInitial(demande).getDateDepart();
      }
      return dossierExamen.getAttributionPrecedente().getAccesseurDroits().getDateEffetSjr();
    }
    return dossierExamen.getConstitutionSjr().getSjrip().getDateEffet();
  }
  
  public Damj getDateFinDiffere()
  {
    return dossierExamen.getConstitutionDelais().getTermeCarenceDiffere();
  }
  
  public Quantite getDureeProlongation()
  {
    return new QuantiteJour(new BigDecimal(dossierExamen.getConstitutionDurees().getDureeIndemnisation().getDureeAllongementAREF()));
  }
}

/* Location:
 * Qualified Name:     AccesseurDroits
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */