package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.AntecedentGen;
import fr.unedic.cali.dom.AntecedentSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.affectation.ProduitAbstrait;
import fr.unedic.cali.dom.affectation.ProduitAsuCge01P05;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitDelegueSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.temps.Damj;

public class Antecedent
  extends AntecedentGen
  implements AntecedentSpec
{
  private static final long serialVersionUID = 1L;
  
  public Antecedent(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public Antecedent() {}
  
  public Antecedent(Damj p_dateEvenement)
  {
    super(p_dateEvenement);
  }
  
  public Antecedent(Damj p_dateEvenement, DossierExamen p_dossierExamen)
  {
    super(p_dateEvenement);
    copie(p_dossierExamen);
  }
  
  protected void copie(Attribution p_source)
  {
    if (p_source == null) {
      return;
    }
    super.copie(p_source);
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Od copie = (Od)p_copie;
    super.copieElements(copie);
  }
  
  public ObjetMetierSpec copie()
  {
    Antecedent copie = new Antecedent();
    copieElements(copie);
    return copie;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean estExecutable()
  {
    return false;
  }
  
  public SaisieAntecedent getSaisieAntecedent()
  {
    return ((Demande)getDemande()).getSaisieAntecedent();
  }
  
  public boolean estMaintenue()
  {
    if (!getSaisieAntecedent().isEstDroitMaintenu()) {
      return super.estMaintenue();
    }
    return getSaisieAntecedent().isEstDroitMaintenu();
  }
  
  public boolean estPresenceDiffere()
  {
    return getSaisieAntecedent().isDelaiAttente();
  }
  
  public ElementBaseIndemnisation getElementBaseIndemnisation()
  {
    controleTrancheExecutableActivee();
    if ((getConstitutionProduitResultant() == null) || (getConstitutionProduitResultant().getTypeMontantRetenu() != 2)) {
      ebiAttribution = super.getElementBaseIndemnisation();
    } else {
      ebiAttribution = ((ElementBaseIndemnisation)((ProduitAsuSpec)getProduit()).recupererElementBaseIndemnisationPourReadmissionAvecMontantRetenuPrecedent(getNatureDecision(), getConstitutionProduitResultant().getTypeMontantRetenu(), getDemande(), this));
    }
    ebiAttribution.setListePensionInvalidite(getListePensionInvalidite());
    
    return (ElementBaseIndemnisation)ebiAttribution.copie();
  }
  
  public DemandeSpec getDemandeMontantRetenu()
  {
    DemandeSpec demandeRetenu = null;
    if ((getConstitutionProduitResultant() == null) || (getConstitutionProduitResultant().getTypeMontantRetenu() != 2)) {
      demandeRetenu = getDemande();
    } else {
      demandeRetenu = getAttributionPrecedente().getDemandeMontantRetenu();
    }
    return demandeRetenu;
  }
  
  public FormuleMontantSpec getFormuleMontant(String p_code)
  {
    FormuleMontantSpec formuleRetour = null;
    if ("2".equals(getSaisieAntecedent().getMontantReadmissionRetenu())) {
      formuleRetour = ProduitAsuCge01P05.getInstance().getFormuleMontant(p_code);
    } else if ((getConstitutionProduitResultant() == null) || (getConstitutionProduitResultant().getTypeMontantRetenu() != 2)) {
      formuleRetour = super.getFormuleMontant(p_code);
    } else {
      formuleRetour = getAttributionPrecedente().getProduitMontantRetenu().getFormuleMontant(p_code);
    }
    return formuleRetour;
  }
  
  public ProduitDelegueSpec getProduitDelegueMontantRetenu()
  {
    DemandeSpec demandeRetenu = getDemandeMontantRetenu();
    return ((ProduitAbstrait)demandeRetenu.getDossierAffectation().getProduit()).getProduitDelegue();
  }
  
  public ProduitAsuSpec getProduitMontantRetenu()
  {
    ProduitAsuSpec produitARetourner = ProduitAsuCge01P05.getInstance();
    if (!"2".equals(getSaisieAntecedent().getMontantReadmissionRetenu()))
    {
      DemandeSpec demandeRetenu = getDemandeMontantRetenu();
      produitARetourner = (ProduitAsuSpec)demandeRetenu.getDossierAffectation().getProduit();
    }
    return produitARetourner;
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    return ((Demande)getDemande()).getSaisieAntecedent().getDateAdmission();
  }
}

/* Location:
 * Qualified Name:     Antecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */