package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.produits.liquidation.dom.gen.ConditionsAttributionRepriseGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec;
import fr.unedic.cali.dom.ElementDroitSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class ConditionsAttributionReprise
  extends ConditionsAttributionRepriseGen
  implements ConditionsAttributionSpec
{
  private static final long serialVersionUID = -8832272657493975180L;
  private transient ConditionDureeNonNulle m_conditionDureeNonNulle;
  
  public ConditionsAttributionReprise(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ConditionsAttributionReprise() {}
  
  public List getListeConditionsAttribution()
  {
    List listeConditions = new ArrayList();
    if (getConditionRechercheEmploi() != null) {
      listeConditions.add(getConditionRechercheEmploi());
    }
    if (getConditionAge() != null) {
      listeConditions.add(getConditionAge());
    }
    if (getConditionChomageInvolontaire() != null) {
      listeConditions.add(getConditionChomageInvolontaire());
    }
    if (getConditionMontantNonNul() != null) {
      listeConditions.add(getConditionMontantNonNul());
    }
    if (getConditionCumulPrestationFamiliale() != null) {
      listeConditions.add(getConditionCumulPrestationFamiliale());
    }
    if (getConditionValiditeReliquat() != null) {
      listeConditions.add(getConditionValiditeReliquat());
    }
    if (getConditionActiviteConservee() != null) {
      listeConditions.add(getConditionActiviteConservee());
    }
    if (getConditionCSRAccordCP() != null) {
      listeConditions.add(getConditionCSRAccordCP());
    }
    if (getConditionCSR28Jours() != null) {
      listeConditions.add(getConditionCSR28Jours());
    }
    return listeConditions;
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(getConditionAge());
    DomManager.persisterEnProfondeur(getConditionChomageInvolontaire());
    DomManager.persisterEnProfondeur(getConditionCumulPrestationFamiliale());
    DomManager.persisterEnProfondeur(getConditionMontantNonNul());
    DomManager.persisterEnProfondeur(getConditionCSRAccordCP());
    DomManager.persisterEnProfondeur(getConditionCSR28Jours());
    DomManager.persisterEnProfondeur(getConditionValiditeReliquat());
    DomManager.persisterEnProfondeur(getConditionActiviteConservee());
    DomManager.persisterEnProfondeur(getConditionRechercheEmploi());
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ConditionsAttributionReprise copie = (ConditionsAttributionReprise)p_copie;
    
    super.copieElements(copie);
    if (getConditionAge() != null)
    {
      ConditionAge copieCondition = copie.createConditionAge();
      getConditionAge().copieElements(copieCondition);
    }
    if (getConditionChomageInvolontaire() != null)
    {
      ConditionChomageInvolontaire copieCondition = copie.createConditionChomageInvolontaire();
      getConditionChomageInvolontaire().copieElements(copieCondition);
    }
    if (getConditionMontantNonNul() != null)
    {
      ConditionMontantNonNul copieCondition = copie.createConditionMontantNonNul();
      getConditionMontantNonNul().copieElements(copieCondition);
    }
    if (getConditionRechercheEmploi() != null)
    {
      ConditionRechercheEmploi copieCondition = copie.createConditionRechercheEmploi();
      getConditionRechercheEmploi().copieElements(copieCondition);
    }
    if (getConditionCumulPrestationFamiliale() != null)
    {
      ConditionCumulPrestationFamiliale copieCondition = copie.createConditionCumulPrestationFamiliale();
      getConditionCumulPrestationFamiliale().copieElements(copieCondition);
    }
    if (getConditionValiditeReliquat() != null)
    {
      ConditionValiditeReliquat copieCondition = copie.createConditionValiditeReliquat();
      getConditionValiditeReliquat().copieElements(copieCondition);
    }
    if (getConditionCSRAccordCP() != null)
    {
      ConditionCSRAccordCP copieCondition = copie.createConditionCSRAccordCP();
      getConditionCSRAccordCP().copieElements(copieCondition);
    }
    if (getConditionActiviteConservee() != null)
    {
      ConditionActiviteConservee copieCondition = copie.createConditionActiviteConservee();
      getConditionActiviteConservee().copieElements(copieCondition);
    }
  }
  
  public ConditionAnciennete createConditionAnciennete()
  {
    throw new UnsupportedOperationException("Cette méthode ne devrait pas être appeler dans le contexte de Reprise");
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public boolean estSatisfait()
  {
    for (Iterator iter = getListeConditionsAttribution().iterator(); iter.hasNext();)
    {
      ElementDroitSpec droit = (ElementDroitSpec)iter.next();
      if ((droit != null) && 
        (!(droit instanceof ConditionChomageInvolontaire)) && (!droit.estSatisfait())) {
        return false;
      }
    }
    return true;
  }
  
  public ConditionDureeNonNulle getConditionDureeNonNulle()
  {
    return m_conditionDureeNonNulle;
  }
  
  public ConditionDureeNonNulle createConditionDureeNonNulle()
  {
    return new ConditionDureeNonNulle();
  }
}

/* Location:
 * Qualified Name:     ConditionsAttributionReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */