package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.ContributionParticuliereSpec;
import fr.unedic.cali.asu.dom.DecisionAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.JustificationAffiliationSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsRevisions;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.RevisionAdmissionGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConditionsAttributionSpec;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnCharge;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.calcul.OutillagePeriodes;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.RevisionSpec;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ResultatAvant;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class RevisionAdmission
  extends RevisionAdmissionGen
  implements RevisionSpec
{
  private static final long serialVersionUID = 1686903921698230206L;
  private static final String DEBUG_ATTRIBUTION_PRECEDENTE_NON_TROUVEE = "Impossible de trouver l'attribution précédente.";
  
  public RevisionAdmission(DomPCSpec pc)
  {
    super(pc);
  }
  
  public RevisionAdmission() {}
  
  public RevisionAdmission(Damj dateEvenement)
  {
    super(dateEvenement);
  }
  
  public RevisionAdmission(Damj dateEvenement, DossierExamen dossierExamen)
  {
    this(dateEvenement);
    copie(dossierExamen);
  }
  
  public ObjetMetierSpec copie()
  {
    RevisionAdmission copie = new RevisionAdmission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copie)
  {
    RevisionAdmission copieRevisionAdmission = (RevisionAdmission)copie;
    if (getConditionsAttributionAdmission() == null) {
      setConditionsAttributionAdmission(new ConditionsAttributionAdmission());
    }
    getConditionsAttributionAdmission().copieElements(copieRevisionAdmission.getConditionsAttributionAdmission());
    if (getConstitutionElementsAdmission() == null) {
      setConstitutionElementsAdmission(new ConstitutionElementsAdmission());
    }
    getConstitutionElementsAdmission().copieElements(copieRevisionAdmission.getConstitutionElementsAdmission());
    if (getConditionsAttributionReprise() == null) {
      setConditionsAttributionReprise(new ConditionsAttributionReprise());
    }
    getConditionsAttributionReprise().copieElements(copieRevisionAdmission.getConditionsAttributionReprise());
    if (getConstitutionElementsReprise() == null) {
      setConstitutionElementsReprise(new ConstitutionElementsReprise());
    }
    getConstitutionElementsReprise().copieElements(copieRevisionAdmission.getConstitutionElementsReprise());
    if (getConditionsAttributionRevision() == null) {
      setConditionsAttributionRevision(new ConditionsAttributionRevision());
    }
    getConditionsAttributionRevision().copieElements(copieRevisionAdmission.getConditionsAttributionRevision());
    if (getConstitutionElementsRevision() == null) {
      setConstitutionElementsRevision(new ConstitutionElementsRevision());
    }
    getConstitutionElementsRevision().copieElements(copieRevisionAdmission.getConstitutionElementsRevision());
    
    copieRevisionAdmission.setContexteDdeExpresse(getContexteDdeExpresse());
    if (getContributionParticuliere() != null) {
      copieRevisionAdmission.setContributionParticuliere((ContributionParticuliere)getContributionParticuliere().copie());
    }
    copieRevisionAdmission.setDateEvenement(getDateEvenement());
    copieRevisionAdmission.setNatureDecision(getNatureDecision());
    copieRevisionAdmission.setAttributionPrecedente(getAttributionPrecedente());
    
    copieRevisionAdmission.setReferenceExterne(getReferenceExterne());
  }
  
  public String getSituationParticuliere()
  {
    return "";
  }
  
  public boolean isInvestigationFraude()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().isInvestigationFraude();
    }
    return false;
  }
  
  public String getRsod()
  {
    String rsod = getReferenceExterne();
    if (OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(getDemande())) {
      rsod = getAttributionPrecedente().getRsod();
    }
    return rsod;
  }
  
  public String getRsrp()
  {
    return "0";
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public JustificationAffiliationSpec getJustificationAffiliation()
  {
    return null;
  }
  
  public Quantite getMontantAttributionPrecedente()
    throws CoucheLogiqueException
  {
    Attribution attribution = recupererAttributionPrecedente();
    if (attribution != null)
    {
      MontantBaseSpec montantPrecedent = null;
      try
      {
        GammeAsuSpec gamme = (GammeAsuSpec)attribution.getGamme();
        DonneesEntreesRecuperationMontant donneesEntree = gamme.mapperDonneesEntreesRecuperationMontant(attribution);
        donneesEntree.setDateCalculMontant(getDateAttribution());
        montantPrecedent = DeterminationMontant.determinerMontant(donneesEntree);
      }
      catch (ApplicativeException ex)
      {
        throw new CoucheLogiqueException(ex.getCode());
      }
      if (montantPrecedent != null) {
        return montantPrecedent.getMontantPrecompteEffectif();
      }
    }
    return null;
  }
  
  public ReglementApplicableSpec getConstitutionReglementApplicable()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionReglementApplicable();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  private Attribution recupererAttributionPrecedente()
  {
    if ((getAttributionPrecedente() instanceof Attribution)) {
      return (Attribution)getAttributionPrecedente();
    }
    return null;
  }
  
  public FaitGenerateurSpec getConditionFaitGenerateur()
  {
    return getConditionsAttributionAdmission().getConditionFaitGenerateur();
  }
  
  public CompetenceSpec getCompetence()
  {
    CompetenceSpec competenceRetour = null;
    if (estCompetencePersistee())
    {
      competenceRetour = super.getCompetence();
    }
    else
    {
      Attribution attributionPrecedente = recupererAttributionPrecedente();
      if ((attributionPrecedente != null) && (!attributionPrecedente.getDemande().estEnReExamen()) && (!attributionPrecedente.getDemande().estDemandeLiquidee()))
      {
        CompetenceSpec competence = (CompetenceSpec)attributionPrecedente.getCompetence().copie();
        setCompetence(competence);
        return competence;
      }
      setAttributionPrecedente(null);
      CompetenceSpec competenceAdministrativeParDefaut = new Competence();
      competenceAdministrativeParDefaut.setCompetenceFinanciere(1);
      competenceAdministrativeParDefaut.setCompetenceAdministrative(1);
      setCompetence(competenceAdministrativeParDefaut);
      return competenceAdministrativeParDefaut;
    }
    return competenceRetour;
  }
  
  public ConstitutionDurees getConstitutionDurees()
  {
    return getConstitutionElementsAdmission().getConstitutionDurees();
  }
  
  public ConstitutionQuantiteAffiliation getConstitutionQuantiteAffiliation()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionQuantiteAffiliation();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConstitutionCaractereSaisonnier getConstitutionCaractereSaisonnier()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionCaractereSaisonnier();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConstitutionCoefficientSaisonnier getConstitutionCoefficientSaisonnier()
  {
    Attribution attributionPrecedente = recupererAttributionPrecedente();
    if (attributionPrecedente != null) {
      return attributionPrecedente.getConstitutionCoefficientSaisonnier();
    }
    OutilTrace.ecrireTrace(Niveau.DEBUG, new Object[] { "Impossible de trouver l'attribution précédente." });
    
    return null;
  }
  
  public ConstitutionSjr getConstitutionSjr()
  {
    return getConstitutionElementsAdmission().getConstitutionSjr();
  }
  
  public ConstitutionDelais getConstitutionDelais()
  {
    return getConstitutionElementsAdmission().getConstitutionDelais();
  }
  
  public ConstitutionSjc getConstitutionSjc()
  {
    return getConstitutionElementsAdmission().getConstitutionSjc();
  }
  
  public ConstitutionDateAttribution getConstitutionDateAttribution()
  {
    return getConstitutionElementsAdmission().getConstitutionDateAttribution();
  }
  
  public ConstitutionMontantsBruts getConstitutionMontantsBruts()
  {
    return getConstitutionElementsAdmission().getConstitutionMontantsBruts();
  }
  
  public ConstitutionPointDepartIndemnisation getConstitutionPointDepartIndemnisation()
  {
    return getConstitutionElementsAdmission().getConstitutionPointDepartIndemnisation();
  }
  
  public ConstitutionCoefficientTempsPartiel getConstitutionCoefficientTempsPartiel()
  {
    return getConstitutionElementsAdmission().getConstitutionCoefficientTempsPartiel();
  }
  
  public ConstitutionProduitResultant getConstitutionProduitResultant()
  {
    return null;
  }
  
  public ConstitutionElementsSpec getConstitutionElementsActifs()
  {
    return getConstitutionElementsAdmission();
  }
  
  public ConditionsAttributionSpec getConditionsAttributionActives()
  {
    return getConditionsAttributionAdmission();
  }
  
  public ConditionMontantRevise getConditionMontantRevise()
  {
    return null;
  }
  
  public Sjc getSJC()
  {
    Sjc sjcTemporaire = null;
    if ((getConstitutionSjc() != null) && (getConstitutionSjc().getSjcip() != null)) {
      sjcTemporaire = getConstitutionSjc().getSjci();
    } else {
      sjcTemporaire = new Sjc(BigDecimal.ZERO, getConstitutionSjr().getSjrip().getDateEffet(), getConstitutionSjr().getSjrip().getContexteParticulierSjr());
    }
    return sjcTemporaire;
  }
  
  public AttributionSpec getAttributionMaitre()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getAttributionMaitre();
    }
    return null;
  }
  
  public AttributionAssuranceSpec getAttributionOrigine()
  {
    return this;
  }
  
  public Damj getDateFaitGenerateurDroit()
  {
    return getAttributionPrecedente().getDateFaitGenerateurDroit();
  }
  
  public ConditionActiviteConservee getConditionActiviteConservee()
  {
    return ((DossierExamen)getOuvertureDroit()).getConditionsAttributionAdmission().getConditionActiviteConservee();
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    if ((maintienEuropeen == null) && (recupererAttributionPrecedente() != null)) {
      if (recupererAttributionPrecedente().getMaintienEuropeen() == null) {
        maintienEuropeen = MaintienEuropeen.getInstanceMaintienEuropeen(this);
      } else {
        maintienEuropeen = recupererAttributionPrecedente().getMaintienEuropeen();
      }
    }
    return maintienEuropeen;
  }
  
  public boolean estRejetDV()
  {
    boolean retour = false;
    if ((getConditionChomageInvolontaire() != null) && (!getConditionChomageInvolontaire().estSatisfait())) {
      retour = true;
    }
    return retour;
  }
  
  protected void verifierCoherenceReferenceExterne() {}
  
  public Collection getListePlafonnementAffiliation()
  {
    return new ArrayList();
  }
  
  public int getTypeMontantRetenu()
  {
    return getAttributionPrecedente().getTypeMontantRetenu();
  }
  
  public int getTypeCapitalRetenu()
  {
    throw new UnsupportedOperationException("HG_PR_L_METHODE_NON_IMPLEMENTEE_ATTRIBUTION");
  }
  
  public fr.unedic.cali.dom.OdAssuranceSpec getOuvertureDroit()
  {
    fr.unedic.cali.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroit();
    }
    return ouvertureDeDroit;
  }
  
  public fr.unedic.cali.asu.dom.OdAssuranceSpec getOuvertureDroitCapitalRetenu()
  {
    fr.unedic.cali.asu.dom.OdAssuranceSpec ouvertureDeDroit = null;
    AttributionAssuranceSpec attributionPrecedente = getAttributionPrecedente();
    if (attributionPrecedente != null) {
      ouvertureDeDroit = attributionPrecedente.getOuvertureDroitCapitalRetenu();
    }
    return ouvertureDeDroit;
  }
  
  public ConditionCSRAccordCP getConditionCSRAccordCP()
  {
    return ((Attribution)getAttributionPrecedente()).getConditionCSRAccordCP();
  }
  
  public ReglementApplicableSpec getReglementApplicableMontantRetenu()
  {
    if (getAttributionPrecedente() != null) {
      return getAttributionPrecedente().getReglementApplicableMontantRetenu();
    }
    return null;
  }
  
  public ReglementApplicableSpec getReglementApplicable()
  {
    ReglementApplicableSpec reglement = super.getReglementApplicable();
    if ((reglement == null) && (getAttributionPrecedente() != null)) {
      reglement = getAttributionPrecedente().getReglementApplicable();
    }
    return reglement;
  }
  
  public ResultatAvant determinationEtatACT()
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public int getType()
  {
    return 2;
  }
  
  public Chronologie getListeActiviteConservee()
  {
    return ((Decision)getOuvertureDroit()).getListeActiviteConservee();
  }
  
  public Chronologie getListeActiviteConserveePerdues()
  {
    return ((Decision)getOuvertureDroit()).getListeActiviteConserveePerdues();
  }
  
  public boolean porteUnRejetDv()
  {
    return OutilsRevisions.estContexteAttributionEnCoursRevisionAre14AvecRejetDv(getDemande());
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConservee()
  {
    return ((Decision)getOuvertureDroit()).getCollectionSjrActiviteConservee();
  }
  
  public Collection<SjrActiviteConservee> getCollectionSjrActiviteConserveePerdue()
  {
    return ((Decision)getOuvertureDroit()).getCollectionSjrActiviteConserveePerdue();
  }
  
  public List<TravailSpec> getListeActiviteConserveePerduesRevisees()
  {
    return ((Decision)getOuvertureDroit()).getListeActiviteConserveePerduesRevisees();
  }
  
  public Damj getDateDebutDelaiDecheance()
  {
    return getDateAttribution();
  }
  
  public Quantite getDureeTheoriquePourDelaiDecheance()
  {
    return getDureeTheorique();
  }
  
  public boolean estExecutable()
  {
    boolean resultat = false;
    if (super.estExecutable())
    {
      ObjetChronoPeriodePriseEnCharge periodePEC = OutillagePeriodes.recupererPeriodePECContenant(getDemandeur(), getDateAttribution());
      if ((periodePEC != null) && ((periodePEC.getTypePec() == null) || (periodePEC.getSousType() == null) || (nestPasDeTypeAdrOuArce(periodePEC)))) {
        resultat = true;
      }
    }
    return resultat;
  }
  
  private boolean nestPasDeTypeAdrOuArce(ObjetChronoPeriodePriseEnCharge periodePEC)
  {
    return (!periodePEC.estDeTypeAdr()) && (!periodePEC.estDeTypeArce());
  }
  
  protected ConstitutionDateLimiteIndemnisation getConstitutionDateLimiteIndemnisationAttributionOrigine()
  {
    ConstitutionDateLimiteIndemnisation cepaDateLimite = null;
    Attribution attributionPrecedente = (Attribution)getAttributionPrecedente();
    if (attributionPrecedente != null) {
      cepaDateLimite = attributionPrecedente.getConstitutionDateLimiteIndemnisationAttributionOrigine();
    }
    return cepaDateLimite;
  }
}

/* Location:
 * Qualified Name:     RevisionAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */