package fr.unedic.cali.asu.produits.liquidation.dom;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.PensionInvaliditeChainee;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.Sjc;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilTranchesExecutables;
import fr.unedic.cali.asu.produits.liquidation.dom.gen.TrancheExecutableGen;
import fr.unedic.cali.dom.ContexteDemande;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.MaintienEuropeen;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.affectation.Parametres;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.DureeCalendaire;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class TrancheExecutable
  extends TrancheExecutableGen
  implements ObjetPersistantSpec
{
  private static final int INDEFINI = 0;
  private static final int VRAI = 1;
  private static final int FAUX = 2;
  private ElementChomageSansRupture elementChomageSansRupture = null;
  private transient Attribution attribution;
  private transient ProduitAsuSpec produitAreActif = null;
  private static final long serialVersionUID = -4814148776624480403L;
  
  public TrancheExecutable(DomPCSpec pc)
  {
    super(pc);
  }
  
  public TrancheExecutable() {}
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionContextes());
    DomManager.persisterEnProfondeur(super.getCollectionDelaisReports());
    DomManager.persisterEnProfondeur(super.getCollectionDurees());
    DomManager.persisterEnProfondeur(super.getCollectionListeSousTrancheExecutable());
    DomManager.persisterEnProfondeur(super.getCollectionPensionsInvalidites());
  }
  
  public ObjetMetierSpec copie()
  {
    TrancheExecutable copie = new TrancheExecutable();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec copieSpec)
  {
    TrancheExecutable copie = (TrancheExecutable)copieSpec;
    super.copieElements(copie);
    
    copie.setA3ansActiviteEn5ans(isA3ansActiviteEn5ans());
    copie.setCapitalAServir(getCapitalAServir());
    copie.setCodeAffectationCG(getCodeAffectationCG());
    copie.setCodeEmploiA2B(getCodeEmploiA2B());
    copie.setCodeProduit(getCodeProduit());
    copie.setCodeProduitReglement(getCodeProduitReglement());
    copie.setCoefficientSaisonnier(getCoefficientSaisonnier());
    copie.setCoefficientTempsPartiel(getCoefficientTempsPartiel());
    copie.setCompetenceFinanciere(getCompetenceFinanciere());
    copie.setCompetenceAdministrative(getCompetenceAdministrative());
    copie.setContexteParticulierSJC(getContexteParticulierSJC());
    copie.setContexteParticulierSJI(getContexteParticulierSJI());
    copie.setDateAttribution(getDateAttribution());
    copie.setDateDebutMaintientEuropeen(getDateDebutMaintientEuropeen());
    copie.setDateLimiteIndemnisation(getDateLimiteIndemnisation());
    copie.setDateSJC(getDateSJC());
    copie.setDateSJI(getDateSJI());
    copie.setDureeMaxIndemnisation(getDureeMaxIndemnisation());
    copie.setEstSjrBaseSmic(isEstSjrBaseSmic());
    copie.setEtablissementFinanceurCG(getEtablissementFinanceurCG());
    copie.setIdFaitGenerateur(getIdFaitGenerateur());
    copie.setMontantPreavis(getMontantPreavis());
    copie.setMontantSJC(getMontantSJC());
    copie.setMontantSJI(getMontantSJI());
    copie.setNatureCoefficientSaisonnier(getNatureCoefficientSaisonnier());
    copie.setNatureDecision(getNatureDecision());
    copie.setPrecompterCRC(getPrecompterCRC());
    copie.setProduitMontantRetenu(getProduitMontantRetenu());
    copie.setRang(getRang());
    copie.setReglementApplicable(getReglementApplicable());
    copie.setDateRepriseActivite(getDateRepriseActivite());
    copie.setJoursDureeMaintienEuropeen(getJoursDureeMaintienEuropeen());
    copie.setMoisDureeMaintienEuropeen(getMoisDureeMaintienEuropeen());
    copie.setAnneeDureeMaintienEuropeen(getAnneeDureeMaintienEuropeen());
    copie.setDateMaxIndemnisation(getDateMaxIndemnisation());
    copie.setDateDebutPeriodeSuspension(getDateDebutPeriodeSuspension());
    copie.setDateFinPeriodeSuspension(getDateFinPeriodeSuspension());
    copie.setTypeCapitalRetenu(getTypeCapitalRetenu());
    copie.setTypeMontantRetenu(getTypeMontantRetenu());
    copie.setSeuilMensuelPansConservees(getSeuilMensuelPansConservees());
    copie.setNombreHeuresTravailleesEtendu(getNombreHeuresTravailleesEtendu());
    copie.setNombreHeuresTravailleesPlafonne(getNombreHeuresTravailleesPlafonne());
    copie.setDateLimiteIndemnisation(super.getDateLimiteIndemnisation());
    copie.setContextePAPPresent(isContextePAPPresent());
    copie.setEligibleAllongementAREF(isEligibleAllongementAREF());
    
    copie.clearCollectionPensionsInvalidites();
    Iterator iter = getListePensionsInvalidites().iterator();
    while (iter.hasNext())
    {
      PensionInvaliditeChainee element = (PensionInvaliditeChainee)iter.next();
      copie.ajouterPensionsInvalidites((PensionInvaliditeChainee)element.copie());
    }
    copie.clearCollectionDelaisReports();
    iter = getListeDelaisReports().iterator();
    while (iter.hasNext())
    {
      CarencePrefixeAFixer element = (CarencePrefixeAFixer)iter.next();
      copie.ajouterDelaisReports((CarencePrefixeAFixer)element.copie());
    }
    copie.clearCollectionDurees();
    iter = getListeDurees().iterator();
    while (iter.hasNext())
    {
      Duree element = (Duree)iter.next();
      copie.ajouterDurees((Duree)element.copie());
    }
    copie.clearCollectionContextes();
    iter = getListeContextes().iterator();
    while (iter.hasNext())
    {
      ContexteDemande element = (ContexteDemande)iter.next();
      copie.ajouterContextes((ContexteDemande)element.copie());
    }
    copie.clearCollectionListeSousTrancheExecutable();
    iter = getListeSousTranchesExecutable().iterator();
    while (iter.hasNext())
    {
      SousTrancheExecutable element = (SousTrancheExecutable)iter.next();
      copie.ajouterListeSousTrancheExecutable((SousTrancheExecutable)element.copie());
    }
  }
  
  public Collection getListeSousTranchesExecutable()
  {
    return super.getCollectionListeSousTrancheExecutable();
  }
  
  public void clearCollectionSousTranchesExecutable()
  {
    for (Iterator iter = getListeSousTranchesExecutable().iterator(); iter.hasNext();)
    {
      SousTrancheExecutable element = (SousTrancheExecutable)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionListeSousTrancheExecutable();
  }
  
  public void remplacerCollectionListeSousTrancheExecutable(Collection collectionACopier)
  {
    for (Iterator iter = getListeSousTranchesExecutable().iterator(); iter.hasNext();)
    {
      SousTrancheExecutable element = (SousTrancheExecutable)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionListeSousTrancheExecutable(collectionACopier);
  }
  
  public void setListeSousTranchesExecutable(Collection listeSousTranchesExecutable)
  {
    remplacerCollectionListeSousTrancheExecutable(listeSousTranchesExecutable);
  }
  
  public Collection getListeDurees()
  {
    return super.getCollectionDurees();
  }
  
  public void clearCollectionDurees()
  {
    for (Iterator iter = getListeDurees().iterator(); iter.hasNext();)
    {
      Duree element = (Duree)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionDurees();
  }
  
  public void remplacerCollectionDurees(Collection collectionACopier)
  {
    for (Iterator iter = getListeDurees().iterator(); iter.hasNext();)
    {
      Duree element = (Duree)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionDurees(collectionACopier);
  }
  
  public void setListeDurees(Collection listeDurees)
  {
    remplacerCollectionDurees(listeDurees);
  }
  
  public Collection getListeDelaisReports()
  {
    return super.getCollectionDelaisReports();
  }
  
  public void clearCollectionDelaisReports()
  {
    for (Iterator iter = getListeDurees().iterator(); iter.hasNext();)
    {
      CarencePrefixeAFixer element = (CarencePrefixeAFixer)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionDurees();
  }
  
  public void remplacerCollectionDelaisReports(Collection collectionACopier)
  {
    for (Iterator iter = getListeDurees().iterator(); iter.hasNext();)
    {
      CarencePrefixeAFixer element = (CarencePrefixeAFixer)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionDelaisReports(collectionACopier);
  }
  
  public void setListeDelaisReports(Collection listeDelaisReports)
  {
    remplacerCollectionDurees(listeDelaisReports);
  }
  
  public Collection getListePensionsInvalidites()
  {
    return super.getCollectionPensionsInvalidites();
  }
  
  public void clearCollectionPensionsInvalidites()
  {
    for (Iterator iter = getListeDurees().iterator(); iter.hasNext();)
    {
      PensionInvaliditeChainee element = (PensionInvaliditeChainee)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionDurees();
  }
  
  public void remplacerCollectionPensionsInvalidites(Collection collectionACopier)
  {
    for (Iterator iter = getListeDurees().iterator(); iter.hasNext();)
    {
      PensionInvaliditeChainee element = (PensionInvaliditeChainee)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPensionsInvalidites(collectionACopier);
  }
  
  public void setListePensionsInvalidites(Collection listePensionsInvalidites)
  {
    remplacerCollectionDurees(listePensionsInvalidites);
  }
  
  public Boolean getPrecompteCRC()
  {
    Boolean retour = null;
    switch (getPrecompterCRC())
    {
    case 1: 
      retour = Boolean.TRUE;
      break;
    case 2: 
      retour = Boolean.FALSE;
      break;
    }
    return retour;
  }
  
  public void setPrecompteCRC(Boolean etat)
  {
    if (etat == null) {
      setPrecompterCRC(0);
    } else if (Boolean.TRUE.equals(etat)) {
      setPrecompterCRC(1);
    } else {
      setPrecompterCRC(2);
    }
  }
  
  public Collection getListeContextes()
  {
    return super.getCollectionContextes();
  }
  
  public void clearCollectionContextes()
  {
    for (Iterator iter = getListeContextes().iterator(); iter.hasNext();)
    {
      ContexteDemande element = (ContexteDemande)iter.next();
      DomManager.supprimer(element);
    }
    super.clearCollectionContextes();
  }
  
  public void remplacerCollectionContextes(Collection collectionACopier)
  {
    for (Iterator iter = getListeContextes().iterator(); iter.hasNext();)
    {
      ContexteDemande element = (ContexteDemande)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionContextes(collectionACopier);
  }
  
  public void setListeContextes(Collection listeContextes)
  {
    remplacerCollectionContextes(listeContextes);
  }
  
  public Sjr getSjr()
  {
    Sjr sjr;
    Sjr sjr;
    if (OutilTranchesExecutables.estUnProduitSpectacle(Parametres.getProduit(getProduitMontantRetenu())))
    {
      sjr = attribution.getElementBaseIndemnisation().getSjr();
    }
    else
    {
      sjr = new Sjr(getMontantSJI().getValeur());
      sjr.setDateDepart(getDateSJI());
      sjr.setContexteParticulier(getContexteParticulierSJI());
    }
    return sjr;
  }
  
  public Sjc getSjc()
  {
    Sjc sjc;
    if (getMontantSJC() != null)
    {
      Sjc sjc = new Sjc(getMontantSJC().getValeur());
      sjc.setDateDepart(getDateSJC());
    }
    else
    {
      sjc = new Sjc(BigDecimal.valueOf(0L));
      sjc.setDateDepart(getDateSJI());
    }
    sjc.setContexteParticulier(getContexteParticulierSJI());
    return sjc;
  }
  
  public ElementChomageSansRupture getElementChomageSansRupture()
  {
    if ((getDateDebutPeriodeSuspension() != null) && (getDateFinPeriodeSuspension() != null) && (elementChomageSansRupture == null)) {
      elementChomageSansRupture = new ElementChomageSansRupture(this, (Demande)attribution.getDemande());
    }
    return elementChomageSansRupture;
  }
  
  public MaintienEuropeen getMaintienEuropeen()
  {
    return new MaintienEuropeen(getDateDebutMaintientEuropeen(), getDureeMaintienEuropeen());
  }
  
  public DureeCalendaire getDureeMaintienEuropeen()
  {
    return new DureeCalendaire(getAnneeDureeMaintienEuropeen(), getMoisDureeMaintienEuropeen(), getJoursDureeMaintienEuropeen());
  }
  
  public Quantite getDuree(int typeDuree)
  {
    Quantite duree = null;
    Collection durees = getCollectionDurees();
    Iterator iter = durees.iterator();
    boolean trouvee = false;
    while ((iter.hasNext()) && (!trouvee))
    {
      Duree dureeTemp = (Duree)iter.next();
      if (dureeTemp.getTypeDuree() == typeDuree)
      {
        duree = new Quantite(dureeTemp.getNombreJour().intValue(), Unite.getParCode("4"));
        trouvee = true;
      }
    }
    return duree;
  }
  
  public Attribution getAttribution()
  {
    return attribution;
  }
  
  public void setAttribution(Attribution attributionParametre)
  {
    attribution = attributionParametre;
    Iterator iter = getListeSousTranchesExecutable().iterator();
    while (iter.hasNext())
    {
      SousTrancheExecutable element = (SousTrancheExecutable)iter.next();
      element.setAttribution(attributionParametre);
    }
  }
  
  public ConventionGestionSpec getConventionGestion()
  {
    return getAttribution().getConventionGestion();
  }
  
  public SalaireReference getSalaireReferenceInitialSpectacle()
  {
    SalaireReference salaireReference = null;
    if ((getMontantSJI() != null) && (getDateSJI() != null)) {
      salaireReference = new SalaireReference(getMontantSJI().getValeur(), getDateSJI());
    }
    return salaireReference;
  }
  
  public boolean isMontantRetenuCourant()
  {
    return getTypeMontantRetenu().equals(Integer.valueOf(1));
  }
  
  public boolean isCapitalRetenuCourant()
  {
    return getTypeMontantRetenu().equals(Integer.valueOf(1));
  }
  
  public Reglement getReglement()
  {
    Reglement reglement = null;
    if (super.getReglementApplicable() != null) {
      reglement = Reglement.getInstance(super.getReglementApplicable(), Parametres.getProduit(getCodeProduitReglement()));
    }
    return reglement;
  }
  
  public Reglement getReglementMontantRetenu()
  {
    Reglement reglement = null;
    if (getReglementApplicableMontantRetenu() != null) {
      reglement = Reglement.getInstance(getReglementApplicableMontantRetenu(), Parametres.getProduit(getCodeProduit()));
    }
    return reglement;
  }
  
  public String getContexteDateLimiteIndemnisation()
  {
    String contexte = super.getContexteDateLimiteIndemnisation();
    if (contexte == null) {
      contexte = attribution.getContexteDateLimiteIndemnisation();
    }
    return contexte;
  }
  
  public ProduitAsuSpec getProduitAreActif()
  {
    if ((produitAreActif == null) && (attribution != null) && ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "AREENTRCSP")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)attribution.getDemande(), "ARECOURCSP")))) {
      produitAreActif = ((ProduitAsuSpec)attribution.getProduit());
    }
    return produitAreActif;
  }
  
  public ProduitSpec getProduit()
  {
    return Parametres.getProduit(getCodeProduit());
  }
  
  public boolean estContextePapParlementaire()
  {
    return (attribution != null) && (attribution.getDemande().estEnContexteDemande("PAPPARLEM"));
  }
}

/* Location:
 * Qualified Name:     TrancheExecutable
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */