package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsActiviteConserve;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.PeriodeChomageAtteste;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreeConstructionChronologie;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieeMotifDvNonLegitime;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreBulletinSalaire;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeMemeReglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeDsmTravail;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationIjss;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeServiceNational;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSansConflit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.util.OutillageChronologiePeriodes;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.Periode;

public class ConstructionChronologie
{
  public static Chronologie determinerChronoActivitesPrc(Demande demande, Periode prc)
  {
    return determinerChronoActivitesPrc(alimenterDonneesEntree(demande, prc));
  }
  
  public static Chronologie determinerChronoPeriodesDeductiblesPrc(Demande demande, Periode prc)
    throws CoucheLogiqueException
  {
    return determinerChronoPeriodesDeductiblesPrc(alimenterDonneesEntree(demande, prc));
  }
  
  public static Chronologie determinerChronoPeriodesDeductiblesCommunes(Demande demande, Periode prc)
    throws CoucheLogiqueException
  {
    return determinerChronoPeriodesDeductiblesCommunes(alimenterDonneesEntree(demande, prc));
  }
  
  public static Chronologie determinerChronoActivitesPrcPourInappartenance(Demande demande, Periode prc)
  {
    return determinerChronoActivitesPrcPourInappartenance(alimenterDonneesEntree(demande, prc));
  }
  
  public static Chronologie determinerChronoActivitesPrc(DonneesEntreeConstructionChronologie donneesEntree)
  {
    Chronologie chronoActivitesPrcAyantFinAvantFaitGenerateur = determinerChronoActivitesPrcAyantFinAvantFaitGenerateur(donneesEntree);
    return traiterRegimeDifferentA2bEtA7(chronoActivitesPrcAyantFinAvantFaitGenerateur);
  }
  
  public static Chronologie determinerChronoPeriodesDeductiblesPrc(DonneesEntreeConstructionChronologie donneesEntree)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesDeductibles = new ChronologiePeriodes();
    Chronologie chronoPeriodesDeductiblesSansConflit = new ChronologiePeriodes();
    
    Reglement reglementApplicableCourant = donneesEntree.getReglement();
    if ((reglementApplicableCourant.estNomReglementIdentique("A3")) || (reglementApplicableCourant.estNomReglementIdentique("A4")) || (reglementApplicableCourant.estNomReglementIdentique("A5")))
    {
      chronoPeriodesDeductibles.ajouter(determinerChronoPeriodesDeductiblesCommunes(donneesEntree));
      
      chronoPeriodesDeductiblesSansConflit = chronoPeriodesDeductibles.copier(new FiltrePeriodesSansConflit());
    }
    return chronoPeriodesDeductiblesSansConflit;
  }
  
  public static Chronologie determinerChronoActivitesPrcPourInappartenance(DonneesEntreeConstructionChronologie donneesEntree)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
    
    filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreChevauchePeriodeAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), donneesEntree.getPeriodePrc(), true));
    
    Damj dateFgOdPrecedente = donneesEntree.getDateFgdOdPrecedente();
    Damj dateFgOdCourante;
    Damj dateFgOdCourante;
    if (donneesEntree.isEstUneDemandeRevision()) {
      dateFgOdCourante = donneesEntree.getDateExamen();
    } else {
      dateFgOdCourante = donneesEntree.getDateFgd();
    }
    if (dateFgOdPrecedente != null) {
      filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreFinApresDateAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), dateFgOdPrecedente, true));
    }
    filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreFinAvantDateAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), dateFgOdCourante.lendemain(), true));
    
    Chronologie chronoActivitesRetenuesPrcPourInappartenance = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    
    FiltresTemporel filtresRegimeDifferentA2bEtA7 = new FiltresTemporel();
    filtresRegimeDifferentA2bEtA7.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteSalarieeMemeReglement("A2b")));
    
    filtresRegimeDifferentA2bEtA7.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteSalarieeMemeReglement("A7")));
    
    chronoActivitesRetenuesPrcPourInappartenance = chronoActivitesRetenuesPrcPourInappartenance.copier(filtresRegimeDifferentA2bEtA7);
    
    FiltresTemporel filtresPeriodesDnj = new FiltresTemporel();
    filtresPeriodesDnj.ajouterFiltre(new FiltrePeriodeDsmTravail());
    filtresPeriodesDnj.ajouterFiltre(new FiltreChevauchePeriode(donneesEntree.getPeriodePrc()));
    if (dateFgOdPrecedente != null) {
      filtresPeriodesDnj.ajouterFiltre(new FiltreFinDansBornes(dateFgOdPrecedente.lendemain(), dateFgOdCourante));
    } else {
      filtresPeriodesDnj.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(dateFgOdCourante));
    }
    Chronologie chronoPeriodesDnjRetenuesPrcPourInappartenance = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtresPeriodesDnj);
    
    chronoActivitesRetenuesPrcPourInappartenance.ajouter(chronoPeriodesDnjRetenuesPrcPourInappartenance);
    
    FiltresTemporel filtresPeriodesBs = new FiltresTemporel();
    filtresPeriodesBs.ajouterFiltre(new FiltreBulletinSalaire());
    filtresPeriodesBs.ajouterFiltre(new FiltreChevauchePeriode(donneesEntree.getPeriodePrc()));
    if (dateFgOdPrecedente != null) {
      filtresPeriodesBs.ajouterFiltre(new FiltreFinDansBornes(dateFgOdPrecedente.lendemain(), dateFgOdCourante));
    } else {
      filtresPeriodesBs.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(dateFgOdCourante));
    }
    Chronologie chronoPeriodesBsRetenuesPrcPourInappartenance = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtresPeriodesBs);
    
    chronoActivitesRetenuesPrcPourInappartenance.ajouter(chronoPeriodesBsRetenuesPrcPourInappartenance);
    
    return chronoActivitesRetenuesPrcPourInappartenance;
  }
  
  private static Chronologie determinerChronoActivitesPrcAyantFinAvantFaitGenerateur(DonneesEntreeConstructionChronologie donneesEntree)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    completerFiltresTypeActivitesPrc(filtres);
    
    Damj dateFaitGenerateur = donneesEntree.getDateFgd();
    Damj dateFgOdPrecedente = donneesEntree.getDateFgdOdPrecedente();
    Periode periodeFinActivite;
    Periode periodeFinActivite;
    if (dateFgOdPrecedente != null) {
      periodeFinActivite = new Periode(dateFgOdPrecedente.lendemain(), dateFaitGenerateur);
    } else {
      periodeFinActivite = new Periode(Damj.NUIT_DES_TEMPS, dateFaitGenerateur);
    }
    completerFiltresBorneActivitesPrc(donneesEntree, filtres, periodeFinActivite);
    
    return donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
  }
  
  private static Chronologie determinerChronoActivitesPrcLegitimeAyantFinAvantDateExamen(DonneesEntreeConstructionChronologie donneesEntree)
  {
    FiltresTemporel filtres = new FiltresTemporel();
    completerFiltresTypeActivitesPrc(filtres);
    
    filtres.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieeMotifDvNonLegitime()));
    Damj lendemainDateFaitGenerateur = donneesEntree.getDateFgd().lendemain();
    Damj veilleDateExamen = donneesEntree.getDateExamen().veille();
    completerFiltresBorneActivitesPrc(donneesEntree, filtres, new Periode(lendemainDateFaitGenerateur, veilleDateExamen));
    Chronologie chronoActivitesRetenues;
    Chronologie chronoActivitesRetenues;
    if (lendemainDateFaitGenerateur.estApres(veilleDateExamen)) {
      chronoActivitesRetenues = new ChronologiePeriodes();
    } else {
      chronoActivitesRetenues = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    }
    return chronoActivitesRetenues;
  }
  
  protected static Chronologie traiterRegimeDifferentA2bEtA7(Chronologie chronoActiviteRetenues)
  {
    FiltresTemporel filtresRegimeDifferentA2bEtA7 = new FiltresTemporel();
    filtresRegimeDifferentA2bEtA7.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteSalarieeMemeReglement("A2b")));
    
    filtresRegimeDifferentA2bEtA7.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteSalarieeMemeReglement("A7")));
    
    return chronoActiviteRetenues.copier(filtresRegimeDifferentA2bEtA7);
  }
  
  protected static void completerFiltresTypeActivitesPrc(FiltresTemporel filtres)
  {
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltrePeriodesAttestees());
    filtres.ajouterFiltre(new FiltrePeriodesSansConflit());
    filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
  }
  
  protected static void completerFiltresBorneActivitesPrc(DonneesEntreeConstructionChronologie donneesEntree, FiltresTemporel filtres, Periode periodeFinActivite)
  {
    Periode prc = donneesEntree.getPeriodePrc();
    filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreChevauchePeriodeAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), prc, true));
    
    filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreFinAvantDateAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), periodeFinActivite.getFin().lendemain(), true));
    
    filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreFinApresDateAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), periodeFinActivite.getDebut().veille(), true));
  }
  
  public static Chronologie determinerChronoPeriodesDeductiblesCommunes(DonneesEntreeConstructionChronologie donneesEntree)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodesDeductibles = new ChronologiePeriodes();
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    filtres.ajouterFiltre(new FiltreChevauchePeriode(donneesEntree.getPeriodePrc()));
    Chronologie chronoPeriodesFiltrees = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (!chronoPeriodesFiltrees.estVide()) {
      chronoPeriodesDeductibles.ajouter(chronoPeriodesFiltrees);
    }
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltrePeriodeServiceNational());
    filtres.ajouterFiltre(new FiltreChevauchePeriode(donneesEntree.getPeriodePrc()));
    chronoPeriodesFiltrees = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (!chronoPeriodesFiltrees.estVide()) {
      chronoPeriodesDeductibles.ajouter(chronoPeriodesFiltrees);
    }
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltrePeriodeIndemnisationIjss());
    filtres.ajouterFiltre(new FiltreChevauchePeriode(donneesEntree.getPeriodePrc()));
    chronoPeriodesFiltrees = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (!chronoPeriodesFiltrees.estVide()) {
      chronoPeriodesDeductibles.ajouter(chronoPeriodesFiltrees);
    }
    Chronologie chronoPeriodeChomageAtteste = determinerChronoPeriodeChomageAtteste(donneesEntree);
    if (!chronoPeriodeChomageAtteste.estVide()) {
      chronoPeriodesDeductibles.ajouter(chronoPeriodeChomageAtteste);
    }
    FiltrePeriodesSurFiltresExclusifs listeFiltresExclusifs = new FiltrePeriodesSurFiltresExclusifs();
    listeFiltresExclusifs.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A2b"));
    listeFiltresExclusifs.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement("A7"));
    
    filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie.filtreChevauchePeriodeAvecPriseEnComptePmvs(donneesEntree.getListeContexteDemande(), donneesEntree.getPeriodePrc(), true));
    
    filtres.ajouterFiltre(listeFiltresExclusifs);
    chronoPeriodesFiltrees = donneesEntree.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if (!chronoPeriodesFiltrees.estVide()) {
      chronoPeriodesDeductibles.ajouter(chronoPeriodesFiltrees);
    }
    return chronoPeriodesDeductibles;
  }
  
  private static Chronologie determinerChronoPeriodeChomageAtteste(DonneesEntreeConstructionChronologie donneesEntree)
    throws CoucheLogiqueException
  {
    Chronologie chronoPeriodeCaRetournee = new ChronologiePeriodes();
    ChronologiePeriodes chronoPeriodesNonDeductibles = new ChronologiePeriodes();
    
    ChronologiePeriodes chronoPeriodesTravailRetenues = OutilSjrJoursDeductibles.determinerChronoActivitesPourChomageAtteste(donneesEntree);
    
    ChronologiePeriodes chronoPeriodesAbsencePointage = donneesEntree.getIndividu().getChronoPeriodeEvtActualisation();
    
    chronoPeriodesNonDeductibles.ajouter(chronoPeriodesTravailRetenues);
    chronoPeriodesNonDeductibles.ajouter(chronoPeriodesAbsencePointage);
    
    Chronologie chronoPeriodesPecRetenues = OutillagePEC.getPeriodesPecDebutAvantDate(donneesEntree.getIndividu(), donneesEntree.getDateExamen());
    chronoPeriodesPecRetenues = OutillagePEC.getPeriodesPecChevauchePeriode(chronoPeriodesPecRetenues, donneesEntree.getPeriodePrc());
    if (!chronoPeriodesPecRetenues.estVide())
    {
      chronoPeriodesPecRetenues.iterer();
      while (chronoPeriodesPecRetenues.encoreSuivant())
      {
        ObjetChronoPeriodePriseEnChargeSansFiltre objetChronoPecCourante = (ObjetChronoPeriodePriseEnChargeSansFiltre)chronoPeriodesPecRetenues.elementSuivant();
        
        Periode periodeReference = objetChronoPecCourante.periodeIntersection(donneesEntree.getPeriodePrc());
        ChronologiePeriodes chronoPeriodeChomageAtteste = OutillageChronologiePeriodes.donnerPeriodesComplementaires(chronoPeriodesNonDeductibles, periodeReference);
        if (chronoPeriodeChomageAtteste != null)
        {
          chronoPeriodeChomageAtteste.iterer();
          while (chronoPeriodeChomageAtteste.encoreSuivant())
          {
            ObjetChronoPeriode objetChronoPeriodeChomageAttesteCourant = (ObjetChronoPeriode)chronoPeriodeChomageAtteste.elementSuivant();
            
            chronoPeriodeCaRetournee.ajouter(new PeriodeChomageAtteste(objetChronoPeriodeChomageAttesteCourant.getDateDebut(), objetChronoPeriodeChomageAttesteCourant.getDateFin()));
          }
        }
      }
    }
    return chronoPeriodeCaRetournee;
  }
  
  public static DonneesEntreeConstructionChronologie alimenterDonneesEntree(Demande demande, Periode prc)
  {
    DonneesEntreeConstructionChronologie donneesEntree = new DonneesEntreeConstructionChronologie();
    AttributionAssuranceSpec dossierExamen = (AttributionAssuranceSpec)((AttributionAssuranceSpec)demande.getDossierExamen()).getOuvertureDroit();
    
    donneesEntree.setDateDeclenchementExamen(demande.getDateDeclenchementExamen());
    donneesEntree.setDateExamen(demande.getDateExamen());
    donneesEntree.setDateFgd(demande.getFaitGenerateur().getDateFaitGenerateur());
    donneesEntree.setEstUneDemandeRevision(OutilsActiviteConserve.estUneDemandeDeRevision(demande));
    if (donneesEntree.isEstUneDemandeRevision())
    {
      Demande demandeOrigine = (Demande)dossierExamen.getDemande();
      donneesEntree.setDateFgdOdPrecedente(demandeOrigine.getDateFaitGenerateurOdPrecedente());
    }
    else
    {
      donneesEntree.setDateFgdOdPrecedente(demande.getDateFaitGenerateurOdPrecedente());
    }
    donneesEntree.setIndividu((Individu)demande.getDemandeur());
    donneesEntree.setPeriodePrc(prc);
    Reglement reglementApplicableCourant = ((DossierExamen)demande.getDossierExamen()).getReglementApplicable().getReglement();
    donneesEntree.setReglement(reglementApplicableCourant);
    donneesEntree.setListeContexteDemande(demande.getListContexteDemande());
    
    return donneesEntree;
  }
}

/* Location:
 * Qualified Name:     ConstructionChronologie
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */