package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilAsp;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.JustificationPrc;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDelaiRecherche;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.fabriques.FabriqueStrategieDelaiRechercheConventionTransitoire2014;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.StrategieCoordinationEuropeennePointDepartPrcApres;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.StrategieDelaiRechercheSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.spec.StrategieCoordinationEuropeennePointDepartPrcSpec;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.strategies.spec.StrategieDureeDelaiRechercheSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Preavis;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.Individu;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.conteneurs.DonneesEntreePRC;
import fr.unedic.cali.outilsfonctionnels.DeterminationRemuneration;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteBrouillon;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieEtantFCT;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeMemeReglement;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.CriteresStrategieDelaiRecherche;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreMemeDateFin;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class DelaiRecherche
{
  private static final int DUREE_MOIS_PRC = 12;
  private static final int DUREE_MOIS_PRC_MAYOTTE = 6;
  private static final int PREMIER_JOUR_MOIS = 1;
  private static final int DERNIER_MOIS_TRIMESTRE_CIVIL_1 = 3;
  private static final int DERNIER_MOIS_TRIMESTRE_CIVIL_2 = 6;
  private static final int DERNIER_MOIS_TRIMESTRE_CIVIL_3 = 9;
  private static final int DERNIER_MOIS_TRIMESTRE_CIVIL_4 = 12;
  protected static DelaiRecherche instanceUnique = null;
  
  public static DelaiRecherche getInstance()
  {
    if (instanceUnique == null) {
      instanceUnique = new DelaiRecherche();
    }
    return instanceUnique;
  }
  
  public Periode deplacerDepartDelai(Damj dateBorneDepart, Periode periodeInitiale)
    throws CoucheLogiqueException
  {
    Damj dateDebutPeriode = periodeInitiale.getDebut();
    if ((dateBorneDepart != null) && (dateDebutPeriode.estAvantOuCoincideAvec(dateBorneDepart))) {
      dateDebutPeriode = dateBorneDepart.lendemain();
    }
    return new Periode(dateDebutPeriode, periodeInitiale.getFin());
  }
  
  public Periode determinerDelaiRechercheCarences(Demande demande)
    throws CoucheLogiqueException
  {
    Periode periodeReference = null;
    
    Damj termePeriode = demande.getDateFaitGenerateurOuDernierSinistrePourCarences();
    
    Damj borneDebutPeriode = null;
    
    AttributionSpec attributionAssurancePrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
    while ((attributionAssurancePrecedente != null) && (((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre() == null)) {
      attributionAssurancePrecedente = ((Demande)attributionAssurancePrecedente.getDemande()).rechercherAttributionPrecedenteDuMemeType();
    }
    if ((attributionAssurancePrecedente != null) && (((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre() != null)) {
      borneDebutPeriode = ((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre();
    }
    if ((termePeriode != null) && ((borneDebutPeriode == null) || (borneDebutPeriode.estAvant(termePeriode))))
    {
      CritereStrategie critere = new CritereStrategie();
      critere.setDatePivot(termePeriode);
      StrategieSpec strategie = FabriqueStrategieDelaiRechercheConventionTransitoire2014.getInstance().getStrategie(critere);
      int delaiRecherche = ((StrategieDureeDelaiRechercheSpec)strategie).determinerDelaiRecherche();
      DureeCalendaire dureeMaximale = new DureeCalendaire(0, 0, delaiRecherche);
      periodeReference = CalculDelais.determinerDelai(termePeriode, dureeMaximale);
      periodeReference.setDebut(periodeReference.getDebut().lendemain());
      if (borneDebutPeriode != null) {
        periodeReference = deplacerDepartDelai(borneDebutPeriode, periodeReference);
      }
      if ((OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPARE")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "POSTCSPDC")))
      {
        Damj finDispositif = OutilAsp.getInstance().determinerDateFinDernierDispositifCSP(demande.getDemandeur(), demande.getDateExamen());
        if (finDispositif != null) {
          if (finDispositif.lendemain().estApres(periodeReference.getFin())) {
            periodeReference = null;
          } else {
            periodeReference = deplacerDepartDelai(finDispositif.lendemain(), periodeReference);
          }
        }
      }
    }
    return periodeReference;
  }
  
  public Periode determinerDelaiRechercheComplementairePMC(Demande demande)
    throws CoucheLogiqueException
  {
    Periode periodeReference = null;
    
    Periode periodeReferenceDelaisReports91j = determinerDelaiRechercheCarences(demande);
    if (periodeReferenceDelaisReports91j != null)
    {
      Periode periodeReferenceGlobalePMC = determinerDelaiRecherchePMC(demande);
      
      Damj dateDebutPeriodeReferenceComplementaire = periodeReferenceGlobalePMC.getDebut();
      if (dateDebutPeriodeReferenceComplementaire.estAvant(periodeReferenceDelaisReports91j.getDebut())) {
        periodeReference = new Periode(dateDebutPeriodeReferenceComplementaire, periodeReferenceDelaisReports91j.getDebut().veille());
      }
    }
    return periodeReference;
  }
  
  protected JustificationPrc determinerDepartPrc(DonneesEntreePRC donneesEntreePRC, Damj termePrc, int dureePrc)
    throws CoucheLogiqueException
  {
    Periode periodeReference = termePrc.soustraireNombreMois(dureePrc);
    JustificationPrc justificationPrcRetour = new JustificationPrc(periodeReference);
    
    Damj borneDebutPrc = donneesEntreePRC.getDateFgdOdPrecedente();
    
    bornerDepartPrcAuLendemain(borneDebutPrc, periodeReference, justificationPrcRetour, 1);
    
    boolean coordCee = donneesEntreePRC.isCoordCee();
    if (coordCee)
    {
      StrategieCoordinationEuropeennePointDepartPrcSpec strategie = getStrategieDepartPrc();
      
      borneDebutPrc = strategie.determinerBornePointDepartPrc(donneesEntreePRC, termePrc);
      if (borneDebutPrc != null) {
        bornerDepartPrcAuLendemain(borneDebutPrc, periodeReference, justificationPrcRetour, 2);
      }
    }
    if ((borneDebutPrc != null) && (donneesEntreePRC.getTermePrcSaisi() != null) && (donneesEntreePRC.getTermePrcSaisi().estAvant(borneDebutPrc.lendemain()))) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_ASU_PRC_FORCEE_AVANT_BORNE", new Object[] { borneDebutPrc.lendemain() });
    }
    return justificationPrcRetour;
  }
  
  protected StrategieCoordinationEuropeennePointDepartPrcSpec getStrategieDepartPrc()
  {
    return new StrategieCoordinationEuropeennePointDepartPrcApres();
  }
  
  private Damj determinerDjtpSimultaneiteFctRa(DonneesEntreePRC donneesEntreePRC, ActiviteSalarie periodeActiviteSalarieRaOuFgd)
  {
    Damj djtpLePlusRecent = null;
    
    FiltresTemporel filtres = new FiltresTemporel();
    filtres.ajouterFiltre(new FiltreActiviteSalarie());
    filtres.ajouterFiltre(new FiltreMemeDateFin(periodeActiviteSalarieRaOuFgd.getDateFin()));
    filtres.ajouterFiltre(new FiltrePeriodeActiviteSalarieeMemeReglement(donneesEntreePRC.getReglementApplicableCourant().getNomReglement()));
    filtres.ajouterFiltre(new FiltreActiviteBrouillon(false));
    filtres.ajouterFiltre(new FiltreActiviteSalarieEtantFCT());
    Chronologie chronoActivitesRa = donneesEntreePRC.getIndividu().getChronoPeriodePasseProfessionnelLiquidation().copier(filtres);
    if ((chronoActivitesRa != null) && (!chronoActivitesRa.estVide()))
    {
      chronoActivitesRa.iterer();
      while (chronoActivitesRa.encoreSuivant())
      {
        ActiviteSalarie periodeActiviteSalarieCourante = (ActiviteSalarie)chronoActivitesRa.elementSuivant();
        if ((djtpLePlusRecent == null) || (periodeActiviteSalarieCourante.getDernierJourTravaillePaye().estApres(djtpLePlusRecent))) {
          djtpLePlusRecent = periodeActiviteSalarieCourante.getDernierJourTravaillePaye();
        }
      }
    }
    return djtpLePlusRecent;
  }
  
  private Damj determinerDjtpPourPrc(DonneesEntreePRC donneesEntreePRC)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeActiviteSalarieRaOuFgd = recupererStrategieDelaiRecherche(donneesEntreePRC).trouverPeriodeActiviteSalarieRaouFgd(donneesEntreePRC);
    
    Damj djtpCourant = periodeActiviteSalarieRaOuFgd.getDernierJourTravaillePaye();
    
    Damj djtpLePlusRecent = determinerDjtpSimultaneiteFctRa(donneesEntreePRC, periodeActiviteSalarieRaOuFgd);
    if (djtpLePlusRecent != null) {
      djtpCourant = djtpLePlusRecent;
    }
    if (djtpCourant == null)
    {
      Damj dateDebut = periodeActiviteSalarieRaOuFgd.getDateDebut();
      Damj dateFin = periodeActiviteSalarieRaOuFgd.getDateFin();
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_ABSENCE_SALAIRE_SUSPENSION", new Object[] { dateDebut.toString(), dateFin.toString() }, 2);
    }
    return djtpCourant;
  }
  
  private ActiviteSalarie trouverPeriodeActiviteSalarieRa(Demande demande)
    throws ApplicativeException
  {
    ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    ActiviteSalarie periodeActiviteSalarieRa = null;
    if (validationProduit != null) {
      periodeActiviteSalarieRa = validationProduit.getPeriodeValidationProduit();
    }
    return periodeActiviteSalarieRa;
  }
  
  public int determinerDureePrc(List<ContexteDemandeSpec> contexteParticulier)
  {
    int duree = 12;
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteParticulier, "AREMAYOTTE")) {
      duree = 6;
    }
    return duree;
  }
  
  public Periode determinerPrc(DonneesEntreePRC donneesEntreePRC)
    throws CoucheLogiqueException
  {
    JustificationPrc justificationPrc = determinerEtJustifierPrc(donneesEntreePRC);
    
    return justificationPrc.getPeriodePrcEffective();
  }
  
  public Periode determinerPrc(Demande demande)
    throws CoucheLogiqueException
  {
    DonneesEntreePRC donneesEntreePRC = alimenterDonneesEntreePrc(demande);
    
    return determinerPrc(donneesEntreePRC);
  }
  
  public DonneesEntreePRC alimenterDonneesEntreePrc(Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateFgd = ((DossierExamen)demande.getDossierExamen()).getConditionFaitGenerateur().getDateFaitGenerateur();
    Damj dateDebut = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit().getDateDebut();
    Damj dateFin = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit().getPeriodeValidationProduit().getDateFin();
    int typeCoordinationEuropeenne = demande.getDonneesTemporaires().getTypeCoordinationEuropeenne();
    Damj termePrcSaisi = demande.getDonneesTemporaires().getTermePrc();
    ActiviteSalarie periodeActiviteSalarieFgd = ((DossierExamen)demande.getDossierExamen()).getConditionFaitGenerateur().getPeriodeFaitGenerateur();
    ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    ActiviteSalarie periodeActiviteSalarieRa = null;
    if (validationProduit != null) {
      periodeActiviteSalarieRa = validationProduit.getPeriodeValidationProduit();
    }
    Individu individu = (Individu)demande.getDemandeur();
    Reglement reglementApplicableCourant = ((DossierExamen)demande.getDossierExamen()).getReglementApplicable().getReglement();
    
    Damj dateFgdOdPrecedente = demande.getDateFaitGenerateurOdPrecedente();
    boolean coordCee = demande.getDonneesTemporaires().isEstCoordCee();
    
    Quantite sjrForce = demande.getDonneesTemporaires().getSjr();
    
    DonneesEntreePRC donneesEntreePRC = new DonneesEntreePRC();
    donneesEntreePRC.setCoordCee(coordCee);
    donneesEntreePRC.setDateDebut(dateDebut);
    donneesEntreePRC.setDateFgd(dateFgd);
    donneesEntreePRC.setDateFgdOdPrecedente(dateFgdOdPrecedente);
    donneesEntreePRC.setDateFin(dateFin);
    donneesEntreePRC.setIndividu(individu);
    donneesEntreePRC.setPeriodeActiviteSalarieFgd(periodeActiviteSalarieFgd);
    donneesEntreePRC.setReglementApplicableCourant(reglementApplicableCourant);
    donneesEntreePRC.setTermePrcSaisi(termePrcSaisi);
    donneesEntreePRC.setTypeCoordinationEuropeenne(typeCoordinationEuropeenne);
    donneesEntreePRC.setValidationProduit(validationProduit);
    donneesEntreePRC.setPeriodeActiviteSalarieRa(periodeActiviteSalarieRa);
    donneesEntreePRC.setSjrForce(sjrForce);
    if (demande.getListContexteDemande() != null) {
      donneesEntreePRC.setContexteParticulier(demande.getListContexteDemande());
    }
    return donneesEntreePRC;
  }
  
  public JustificationPrc determinerEtJustifierPrc(Demande demande)
    throws ApplicativeException
  {
    DonneesEntreePRC donneesEntreePRC = alimenterDonneesEntreePrc(demande);
    
    return determinerEtJustifierPrc(donneesEntreePRC);
  }
  
  public JustificationPrc determinerEtJustifierPrc(DonneesEntreePRC donneesEntreePRC)
    throws CoucheLogiqueException
  {
    int dureePrc = determinerDureePrc(donneesEntreePRC.getContexteParticulier());
    Damj termePrc;
    Damj termePrc;
    if (donneesEntreePRC.getTermePrcSaisi() == null) {
      termePrc = determinerTermePrc(donneesEntreePRC, dureePrc);
    } else {
      termePrc = recupererStrategieDelaiRecherche(donneesEntreePRC).determinerTermePrcForce(donneesEntreePRC);
    }
    return determinerDepartPrc(donneesEntreePRC, termePrc, dureePrc);
  }
  
  private Damj determinerTermePrcRaRg(DonneesEntreePRC donneesEntreePRC, int dureePrc)
    throws CoucheLogiqueException
  {
    Damj djtpCourant = determinerDjtpPourPrc(donneesEntreePRC);
    Damj termePrc = djtpCourant;
    if (!termePrc.estLaFinDuMois()) {
      termePrc = djtpCourant.getFinMoisPrecedent();
    }
    Periode periodeTemporairePrc = termePrc.soustraireNombreMois(dureePrc);
    
    ActiviteSalarie periodeActiviteSalarieRa = recupererStrategieDelaiRecherche(donneesEntreePRC).trouverPeriodeActiviteSalarieRaouFgd(donneesEntreePRC);
    
    BigDecimal remunerationSalairesActiviteRa = DeterminationRemuneration.determinerRemunerationActiviteSalarie(periodeActiviteSalarieRa, periodeTemporairePrc);
    if (remunerationSalairesActiviteRa.compareTo(BigDecimal.ZERO) == 0) {
      termePrc = djtpCourant;
    }
    return termePrc;
  }
  
  private Damj determinerTermePrcRaA1(DonneesEntreePRC donneesEntreePRC)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeActiviteSalarieRa = recupererStrategieDelaiRecherche(donneesEntreePRC).trouverPeriodeActiviteSalarieRaouFgd(donneesEntreePRC);
    
    Preavis preavisRa = null;
    if (periodeActiviteSalarieRa.getContrat() != null) {
      preavisRa = periodeActiviteSalarieRa.getContrat().getPreavis();
    }
    Damj termePrc;
    if ((preavisRa == null) || (preavisRa.estEffectue()) || ((preavisRa.getPeriodeNonEffectueeNonPayee() == null) && (preavisRa.getPeriodeNonEffectueePayee() == null)))
    {
      Damj termePrc = periodeActiviteSalarieRa.getDateFin();
      if (!termePrc.estLaFinDuMois()) {
        termePrc = termePrc.getFinMoisPrecedent();
      }
    }
    else
    {
      termePrc = preavisRa.getDebut();
      if (!termePrc.estLaFinDuMois()) {
        termePrc = termePrc.getFinMoisPrecedent();
      }
    }
    return termePrc;
  }
  
  private Damj determinerTermePrcRaA3(DonneesEntreePRC donneesEntreePRC)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeActiviteSalarieRa = recupererStrategieDelaiRecherche(donneesEntreePRC).trouverPeriodeActiviteSalarieRaouFgd(donneesEntreePRC);
    
    Damj termePrc = periodeActiviteSalarieRa.getDateFin();
    if (!termePrc.estLaFinDuMois()) {
      termePrc = periodeActiviteSalarieRa.getDateFin().getFinMoisPrecedent();
    }
    return termePrc;
  }
  
  private Damj determinerTermePrcRaA9B(DonneesEntreePRC donneesEntreePRC, int dureePrc)
    throws CoucheLogiqueException
  {
    ActiviteSalarie periodeActiviteSalarieRa = recupererStrategieDelaiRecherche(donneesEntreePRC).trouverPeriodeActiviteSalarieRaouFgd(donneesEntreePRC);
    
    Damj dernierJourActiviteSalarieRaCourante = periodeActiviteSalarieRa.getDateFin();
    
    Damj termePrc = determinerDernierJourTrimestrePrecedentDate(dernierJourActiviteSalarieRaCourante);
    
    Periode periodeTemporairePrc = termePrc.soustraireNombreMois(dureePrc);
    
    BigDecimal remunerationSalairesActiviteRa = DeterminationRemuneration.determinerRemunerationActiviteSalarie(periodeActiviteSalarieRa, periodeTemporairePrc);
    if (remunerationSalairesActiviteRa.compareTo(BigDecimal.ZERO) == 0) {
      termePrc = dernierJourActiviteSalarieRaCourante;
    }
    return termePrc;
  }
  
  private Damj determinerTermePrcRaA9A(DonneesEntreePRC donneesEntreePRC)
    throws CoucheLogiqueException
  {
    Damj djtpCourant = determinerDjtpPourPrc(donneesEntreePRC);
    
    Damj termePrc = determinerDernierJourTrimestrePrecedentDate(djtpCourant);
    
    return termePrc;
  }
  
  private Damj determinerDernierJourTrimestrePrecedentDate(Damj date)
  {
    int moisDateCourante = date.getMois();
    int dernierMoisTrimestrePrecedent = determinerDernierMoisTrimestrePrecedent(moisDateCourante);
    
    int anneeDernierMoisTrimestrePrecedent = date.getAnnee();
    if (dernierMoisTrimestrePrecedent > moisDateCourante) {
      anneeDernierMoisTrimestrePrecedent -= 1;
    }
    Damj dernierJourTrimestreRetourne = new Damj(anneeDernierMoisTrimestrePrecedent, dernierMoisTrimestrePrecedent, 1).getFinMois();
    return dernierJourTrimestreRetourne;
  }
  
  private int determinerDernierMoisTrimestrePrecedent(int moisCourant)
  {
    int dernierMoisTrimestreRetourne = 0;
    switch (moisCourant)
    {
    case 1: 
    case 2: 
    case 3: 
      dernierMoisTrimestreRetourne = 12;
      break;
    case 4: 
    case 5: 
    case 6: 
      dernierMoisTrimestreRetourne = 3;
      break;
    case 7: 
    case 8: 
    case 9: 
      dernierMoisTrimestreRetourne = 6;
      break;
    case 10: 
    case 11: 
    case 12: 
      dernierMoisTrimestreRetourne = 9;
      break;
    }
    return dernierMoisTrimestreRetourne;
  }
  
  private Damj determinerTermePrc(DonneesEntreePRC donneesEntreePRC, int dureePrc)
    throws CoucheLogiqueException
  {
    Damj termePrc = null;
    if (estReglementPourPrcRaRg(donneesEntreePRC.getReglementApplicableCourant().getNomReglement())) {
      termePrc = determinerTermePrcRaRg(donneesEntreePRC, dureePrc);
    } else if (donneesEntreePRC.getReglementApplicableCourant().estNomReglementIdentique("A1")) {
      termePrc = determinerTermePrcRaA1(donneesEntreePRC);
    } else if (donneesEntreePRC.getReglementApplicableCourant().estNomReglementIdentique("A3")) {
      termePrc = determinerTermePrcRaA3(donneesEntreePRC);
    } else if (donneesEntreePRC.getReglementApplicableCourant().estNomReglementIdentique("A9A")) {
      termePrc = determinerTermePrcRaA9A(donneesEntreePRC);
    } else if (donneesEntreePRC.getReglementApplicableCourant().estNomReglementIdentique("A9B")) {
      termePrc = determinerTermePrcRaA9B(donneesEntreePRC, dureePrc);
    }
    return termePrc;
  }
  
  private boolean estReglementPourPrcRaRg(String reglement)
  {
    Collection<String> listeReglements = new ArrayList();
    
    listeReglements.add("RG");
    listeReglements.add("OP");
    listeReglements.add("A2a");
    listeReglements.add("A4");
    listeReglements.add("A5");
    listeReglements.add("A6");
    
    return listeReglements.contains(reglement);
  }
  
  public Periode determinerPrcSjcipRaA2b(Demande demande)
    throws ApplicativeException
  {
    ActiviteSalarie periodeValidationProduit = trouverPeriodeActiviteSalarieRa(demande);
    Damj termePrc;
    Damj termePrc;
    if (periodeValidationProduit.getContrat().getDateRuptureContratTravail() != null) {
      termePrc = periodeValidationProduit.getContrat().getDateRuptureContratTravail();
    } else {
      termePrc = periodeValidationProduit.getDateFin();
    }
    if (!termePrc.estLaFinDuMois()) {
      termePrc = termePrc.getFinMoisPrecedent();
    }
    int dureePrc = determinerDureePrc(demande.getListContexteDemande());
    
    Periode periodeReference = termePrc.soustraireNombreMois(dureePrc);
    Damj borneDebutPrc = demande.getDateFaitGenerateurOdPrecedente();
    if (borneDebutPrc != null) {
      periodeReference = deplacerDepartDelai(borneDebutPrc, periodeReference);
    }
    Damj debutPrc = periodeReference.getDebut();
    
    return new Periode(debutPrc, termePrc);
  }
  
  public Periode determinerDelaiRecherchePMC(Demande demande)
    throws CoucheLogiqueException
  {
    Periode periodeReference = null;
    
    Periode periodeReferenceDelaisReports91j = determinerDelaiRechercheCarences(demande);
    if (periodeReferenceDelaisReports91j != null)
    {
      AttributionSpec attributionAssurancePrecedente = demande.rechercherAttributionPrecedenteDuMemeType();
      Damj borneDebutPeriode;
      Damj borneDebutPeriode;
      if ((attributionAssurancePrecedente != null) && (((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre() != null))
      {
        borneDebutPeriode = ((Demande)attributionAssurancePrecedente.getDemande()).getDateFaitGenerateurOuDernierSinistre().lendemain();
      }
      else
      {
        borneDebutPeriode = demande.getDateFaitGenerateurOdPrecedente();
        if (borneDebutPeriode == null) {
          borneDebutPeriode = Damj.NUIT_DES_TEMPS;
        } else {
          borneDebutPeriode = borneDebutPeriode.lendemain();
        }
      }
      periodeReference = new Periode(borneDebutPeriode, periodeReferenceDelaisReports91j.getFin());
    }
    return periodeReference;
  }
  
  private StrategieDelaiRechercheSpec recupererStrategieDelaiRecherche(DonneesEntreePRC donneesEntreePRC)
  {
    CriteresStrategieDelaiRecherche critereStrategie = new CriteresStrategieDelaiRecherche();
    
    critereStrategie.setDatePivot(donneesEntreePRC.getDateFgd());
    critereStrategie.setTypeCoordinationEuropeenne(donneesEntreePRC.getTypeCoordinationEuropeenne());
    critereStrategie.setSjrForce(donneesEntreePRC.getSjrForce());
    return (StrategieDelaiRechercheSpec)FabriqueStrategieDelaiRecherche.getInstance().getStrategie(critereStrategie);
  }
  
  protected Periode bornerDepartPrcAuLendemain(Damj dateBorneDepartPrc, Periode periodePrcInitiale, JustificationPrc justificationPrc, int typeBornagePrc)
    throws CoucheLogiqueException
  {
    Periode periodePrcRetour = periodePrcInitiale;
    
    Damj dateDebutPeriode = periodePrcInitiale.getDebut();
    if ((dateBorneDepartPrc != null) && (dateDebutPeriode.estAvantOuCoincideAvec(dateBorneDepartPrc)))
    {
      if (dateBorneDepartPrc.estApresOuCoincideAvec(periodePrcInitiale.getFin())) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_BLOCAGE_PRC_AVANT_FGD", "Bornage de la PRC impossible : le DJTP est antérieur au fait générateur de l'OD précédente. Veuillez forcer le SJR et le SJC.");
      }
      dateDebutPeriode = dateBorneDepartPrc.lendemain();
      
      periodePrcRetour = new Periode(dateDebutPeriode, periodePrcInitiale.getFin());
      
      justificationPrc.setPeriodePrcBornee(periodePrcRetour);
      justificationPrc.setTypeBornagePrc(typeBornagePrc);
    }
    return periodePrcRetour;
  }
}

/* Location:
 * Qualified Name:     DelaiRecherche
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */