package fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationCafTauxPartiel;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationCafTauxPlein;
import fr.unedic.cali.parametres.GestionnaireDateApplication;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;

public class RechercheConditionCumulPrestationFamiliale
{
  public static RechercheConditionCumulPrestationFamiliale getInstance()
  {
    return new RechercheConditionCumulPrestationFamiliale();
  }
  
  public ResultatElementDroit rechercherConditionCumulPrestationFamiliale(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatElementDroit resultat = estConditionContournementCLCAForcee(demande);
    if (!resultat.estSatisfait())
    {
      resultat = conditionCumulPrestationFamilialeTauxPlein(demande);
      if ((resultat.estSatisfait()) && (!estClcaNonVerifie(demande))) {
        resultat = conditionCumulPrestationFamilialeTauxPartiel(demande);
      }
    }
    return resultat;
  }
  
  private ResultatElementDroit conditionCumulPrestationFamilialeTauxPlein(Demande demande)
  {
    ResultatElementDroit resultat = new ResultatElementDroit();
    
    ChronologiePeriodes chronoPeriodesActivesDateRefExamen = null;
    
    Damj dateRefExamen = demande.getDateExamen();
    
    ChronologiePeriodes chronoPeriodesFiltrees = (ChronologiePeriodes)demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltrePeriodeIndemnisationCafTauxPlein());
    
    chronoPeriodesActivesDateRefExamen = (ChronologiePeriodes)chronoPeriodesFiltrees.elementsActifsA(dateRefExamen);
    if ((chronoPeriodesActivesDateRefExamen == null) || (chronoPeriodesActivesDateRefExamen.estVide()))
    {
      resultat.setEtatSatisfait(true);
    }
    else
    {
      resultat.setEtatSatisfait(false);
      resultat.setCodeMotifEchec(171);
    }
    return resultat;
  }
  
  private ResultatElementDroit conditionCumulPrestationFamilialeTauxPartiel(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatElementDroit resultat = new ResultatElementDroit();
    ChronologiePeriodes chronoPeriodesActivesDateRefExamen = null;
    
    Damj dateRefExamen = demande.getDateExamen();
    
    ChronologiePeriodes chronoPeriodesFiltrees = (ChronologiePeriodes)demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation().copier(new FiltrePeriodeIndemnisationCafTauxPartiel());
    
    chronoPeriodesActivesDateRefExamen = (ChronologiePeriodes)chronoPeriodesFiltrees.elementsActifsA(dateRefExamen);
    
    Damj dateFaitGenerateur = determinerDateFaitGenerateur(demande);
    if ((chronoPeriodesActivesDateRefExamen == null) || (chronoPeriodesActivesDateRefExamen.estVide()))
    {
      resultat.setEtatSatisfait(true);
    }
    else
    {
      ChronologiePeriodes chronoPeriodesActivesDateFg = (ChronologiePeriodes)chronoPeriodesActivesDateRefExamen.elementsActifsA(dateFaitGenerateur);
      if ((chronoPeriodesActivesDateFg != null) && (!chronoPeriodesActivesDateFg.estVide()))
      {
        resultat.setEtatSatisfait(true);
      }
      else
      {
        resultat.setEtatSatisfait(false);
        resultat.setCodeMotifEchec(172);
      }
    }
    return resultat;
  }
  
  private Damj determinerDateFaitGenerateur(Demande demande)
  {
    Damj dateFaitGenerateur = null;
    if ((1 == demande.getObjectifCourant().getType()) && (!"ASU_28".equals(demande.getEvenementReferenceExamen().getTypeExamen())))
    {
      dateFaitGenerateur = demande.getFaitGenerateur().getDateFaitGenerateur();
    }
    else
    {
      AttributionAssuranceSpec odOrigine = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      dateFaitGenerateur = odOrigine.getDateFaitGenerateur();
    }
    return dateFaitGenerateur;
  }
  
  private ResultatElementDroit estConditionContournementCLCAForcee(Demande demande)
    throws CoucheLogiqueException
  {
    ResultatElementDroit resultat = new ResultatElementDroit();
    if ((demande.getDonneesTemporaires().isLeveeConditionCLCA()) && (demande.getDateExamen().estApresOuCoincideAvec(GestionnaireDateApplication.getInstance().recupererDateApplication("Date d'application de la nouvelle convention ARE 2014")))) {
      resultat.setEtatSatisfait(true);
    }
    return resultat;
  }
  
  private boolean estClcaNonVerifie(Demande demande)
    throws CoucheLogiqueException
  {
    Damj dateApplication = GestionnaireDateApplication.getInstance().recupererDateApplication("Lever la condition CLCA");
    if ((dateApplication.estAvantOuCoincideAvec(demande.getDateExamen())) && ((2 == demande.getObjectifCourant().getType()) || (4 == demande.getObjectifCourant().getType()) || (45 == demande.getObjectifCourant().getSousType()))) {
      return true;
    }
    return false;
  }
}

/* Location:
 * Qualified Name:     RechercheConditionCumulPrestationFamiliale
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */