package fr.unedic.cali.asu.spe02.p03;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SalaireReference;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.mnt.dom.ConditionAppartenanceMaintien;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.outilsfonctionnels.OutilsMaintien;
import fr.unedic.cali.asu.occasionnel.FabriqueTraitementPopulation;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.outilsfonctionnels.ConstructionChronologie;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionCoordinationEuropeenne;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.outilsfonctionnels.RechercherDemandeMaintien;
import fr.unedic.cali.asu.outilsfonctionnels.VerificationDonneesForcees;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.parcours.ParcoursContexteExamen;
import fr.unedic.cali.asu.spe02.p03.antecedent.GrapheAntecedent;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.DureeIndemnisation;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.RevalorisationSalaire;
import fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.TraitementActiviteReduite;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Examen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.FabriqueObjectifExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.FabriqueObjectifExamenSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ObjectifExamenSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.OutilPeriodeElementaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.dom.ComportementCalculAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.AlimentationBaseEchanges;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.AlimentationBasePivot;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.ComparateurDecision;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.ComparateurDecisionSpeSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.ConstitutionCREMConstituant;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DelaiRechercheSinistres;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSituationParticuliere;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilCalculDiffereStandard;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilDeterminationPensionInvaliditeSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilSimulationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.OutilTraitementReliquat;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.RechercheConditionNombreTrimestresMaintien;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.RechercheValiditeProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.RecuperationFormuleMontant;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.VerificationDonneesForceesPostLiquidation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.fabriques.FabriqueStrategiePensionInvalidite;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.formules.ParametresCarenceIndemnisationStandard;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.ParametresCarenceIndemnisationStandardSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstructionPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionActivitePourMaintien;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionAgePourMaintien;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionDecisionCPPourMaintien;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionNombreTrimestresPourMaintien;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ParcoursDeterminationOrdreObjectifs;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ParcoursValiderObjectif;
import fr.unedic.cali.asu.spe02.p03.migration.FabriqueGraphe;
import fr.unedic.cali.asu.spe02.p03.parametres.AccesAllocationMaximale;
import fr.unedic.cali.asu.spe02.p03.parametres.AccesAllocationMinimale;
import fr.unedic.cali.asu.spe02.p03.parametres.AccesCotisationRetraiteComplementaire;
import fr.unedic.cali.asu.spe02.p03.parametres.EvenementParametre;
import fr.unedic.cali.asu.spe02.p03.parametres.Parametres;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.Entreprise;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.ConstituantsCalculActiviteReduiteSpec;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ResultatActiviteReduite;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DecisionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DomSimulationAffiliation;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.DureeIndemnisationAbstraite;
import fr.unedic.cali.dom.ElementBaseIndemnisationSpec;
import fr.unedic.cali.dom.FormuleMontantSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.JustificationAppelGaecReduit;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.SalaireJournalierSpec;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.dom.affectation.DelaiRechercheProduitSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuDelegueSpectacleSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.cali.dom.conteneurs.spec.DonneesEntreeDeterminationSjrSpec;
import fr.unedic.cali.dom.conteneurs.spec.DonneesResultatDeterminationSjrSpec;
import fr.unedic.cali.dom.pivot.DemandePivot;
import fr.unedic.cali.dom.spec.CalculAppartenanceSpec;
import fr.unedic.cali.dom.spec.ComportementAffiliationSpec;
import fr.unedic.cali.dom.spec.ConstructionPRASpec;
import fr.unedic.cali.dom.spec.ConventionGestionSpec;
import fr.unedic.cali.dom.spec.ParametresAffiliationSpec;
import fr.unedic.cali.fabriques.FabriqueOutilFonctionnelSpec;
import fr.unedic.cali.liquidation.outilsfonctionnels.spec.OutilCalculDiffereStandardSpec;
import fr.unedic.cali.liquidation.outilsfonctionnels.spec.OutilPeriodeElementaireSpectacleSpec;
import fr.unedic.cali.migration.GrapheLiquidationSpec;
import fr.unedic.cali.occasionnel.outilsfonctionnels.CriteresExecutionPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.CriteresTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.ResultatTraitementPopulation;
import fr.unedic.cali.occasionnel.outilsfonctionnels.TraitementPopulationSpec;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.outilsfonctionnels.ConvertisseurUniteAffiliation;
import fr.unedic.cali.outilsfonctionnels.OutilReliquat;
import fr.unedic.cali.outilsfonctionnels.strategies.CritereStrategie;
import fr.unedic.cali.outilsfonctionnels.strategies.StrategieSpec;
import fr.unedic.cali.parcours.DomCali;
import fr.unedic.cali.parcours.DomLiquidationDemande;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.cali.util.TableQuantites;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteService;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.ChronologieStandard;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Hashtable;
import java.util.List;

public class ProduitDelegue
  implements ProduitAsuDelegueSpectacleSpec
{
  private static final String DATE = "Date";
  private static final String ALLOC_MINI = "allocationMinimale";
  private static final String ALLOC_MAX = "allocationMaximale";
  private static final String COTISATION_RETR_COMPL = "cotisationRetraiteCompl";
  public static final int NB_JOUR_STANDARD_MAINTIEN = 364;
  
  protected Resultat effectuerParcours(Parcours parcours, Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultat = null;
    if (parcours != null) {
      resultat = parcours.effectuerParcours(contexte);
    }
    return resultat;
  }
  
  protected ObjectifExamenSpec recupererObjectifCourant(Contexte contexte)
  {
    ObjectifExamen objectifCourant = null;
    if ((contexte != null) && (contexte.getDonnees() != null)) {
      objectifCourant = DomLiquidationAssurance.getDemande(contexte).getObjectifCourant();
    }
    return (ObjectifExamenSpec)objectifCourant;
  }
  
  public void controlerContexteDonneesForcees(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
    DomCali domCali = (DomCali)contexte.getDonnees();
    Damj dateTraitement = domCali.getContexteService().getDateTraitement();
    VerificationDonneesForcees.getInstance().verifierDonneesForcees(demande, dateTraitement);
  }
  
  public void controlerContexteDonneesForceesPostLiquidation(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = (Demande)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
    
    VerificationDonneesForceesPostLiquidation.verifierDonneesForceesPostLiquidationAreSpectacle(demande);
    VerificationDonneesForcees.getInstance().verifierDonneesForceesPostLiquidation(demande);
  }
  
  public void alimenterBaseEchangesProduit(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.echange.Decision demandeEchange)
    throws CoucheLogiqueException
  {
    AlimentationBaseEchanges.getInstance().alimenterDonneesProduit(dossierExamen, demandeEchange);
  }
  
  public void alimenterBasePivotProduit(DossierExamenSpec dossierExamen, DemandePivot demandePivot)
    throws ApplicativeException
  {
    AlimentationBasePivot.getInstance().alimenterDonneesProduit(dossierExamen, demandePivot);
  }
  
  public ArrayList alimenterDecisionsReexamen(Contexte contexte)
    throws CoucheLogiqueException
  {
    if ((contexte != null) && (contexte.getDonnees() != null))
    {
      DomLiquidationAssurance domCourant = (DomLiquidationAssurance)contexte.getDonnees();
      DecisionSpec decisionAvantReexamen = (DecisionSpec)domCourant.getDemandeAvantReexamen().getDossierAffectation().getDossierExamen();
      DecisionSpec decisionApresReexamen = (DecisionSpec)domCourant.getDemande().getDossierAffectation().getDossierExamen();
      ComparateurDecisionSpeSpec comparateur = recupererComparateurDecision();
      return comparateur.rechercheDifferencesComparaisonDecision(decisionAvantReexamen, decisionApresReexamen);
    }
    return null;
  }
  
  protected ComparateurDecisionSpeSpec recupererComparateurDecision()
  {
    return ComparateurDecision.getInstance();
  }
  
  public boolean comparerDecisions(DecisionSpec decision1, DecisionSpec decision2)
  {
    ComparateurDecisionSpeSpec comparateur = ComparateurDecision.getInstance();
    return comparateur.estEgal(decision1, decision2);
  }
  
  public GrapheLiquidationSpec creerGraphe(int natureDecision, boolean classement)
  {
    return FabriqueGraphe.creegraphe(natureDecision, classement);
  }
  
  private void ajouterChrono(ChronologieStandard cg01C, ChronologieStandard chrono)
  {
    chrono.iterer();
    while (chrono.encoreSuivant())
    {
      EvenementParametre evtPf = (EvenementParametre)chrono.elementSuivant();
      ajouterEvenement(cg01C, evtPf);
    }
  }
  
  private void ajouterEvenement(ChronologieStandard cg01C, EvenementParametre evtParam)
  {
    Damj damjParam = evtParam.getDateEffet();
    boolean trouve = false;
    cg01C.iterer();
    while ((cg01C.encoreSuivant()) && (!trouve))
    {
      EvenementParametre evtAsu = (EvenementParametre)cg01C.elementSuivant();
      Damj damjAsu = evtAsu.getDateEffet();
      if (damjParam.equals(damjAsu))
      {
        evtAsu.repercuter(evtParam);
        trouve = true;
      }
    }
    if (!trouve) {
      cg01C.ajouter(evtParam);
    }
  }
  
  private ArrayList retourneArrayList(ChronologieStandard asuC)
  {
    ArrayList resultat = new ArrayList();
    
    asuC.iterer();
    while (asuC.encoreSuivant())
    {
      EvenementParametre evtAsu = (EvenementParametre)asuC.elementSuivant();
      Damj damjAsu = evtAsu.getDateEffet();
      
      Hashtable<String, Object> params = new Hashtable();
      
      params.put("Date", damjAsu);
      BigDecimal am = evtAsu.getAllocationMinimale(false);
      BigDecimal pc = evtAsu.getAllocationMaximale(false);
      BigDecimal crc = evtAsu.getCotisationRetraiteComplementaire(false);
      if (am != null) {
        params.put("allocationMinimale", am);
      }
      if (pc != null) {
        params.put("allocationMaximale", pc);
      }
      if (crc != null) {
        params.put("cotisationRetraiteCompl", crc);
      }
      resultat.add(params);
    }
    return resultat;
  }
  
  public ArrayList getParametres()
  {
    AccesAllocationMinimale allocMini = new AccesAllocationMinimale();
    AccesAllocationMaximale allocMax = new AccesAllocationMaximale();
    AccesCotisationRetraiteComplementaire retrCompl = new AccesCotisationRetraiteComplementaire();
    
    ChronologieStandard allocMiniC = allocMini.getChronoValeursParametre();
    ChronologieStandard allocMaxC = allocMax.getChronoValeursParametre();
    ChronologieStandard retrComplC = retrCompl.getChronoValeursParametre();
    
    ChronologieStandard asuC = (ChronologieStandard)allocMiniC.copier();
    
    ajouterChrono(asuC, allocMaxC);
    ajouterChrono(asuC, retrComplC);
    
    return retourneArrayList(asuC);
  }
  
  public Hashtable recupererElementsConstituant(DossierExamenSpec dossierExamen)
    throws CoucheLogiqueException
  {
    return ConstitutionCREMConstituant.recupererElementsConstituant(dossierExamen);
  }
  
  public Resultat constituerCaractereSaisonnier(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerCoefficientSaisonnier(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerCoefficientTempsPartiel(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerDateAttribution(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursDateAttribution();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerDelaisReports(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursDelaisReports();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerDureesReglementaires(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursDurees();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerMontantsBruts(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursMontantsBruts();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerPointDeDepart(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursPointDeDepart();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerProduitResultant(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerQuantiteAffiliation(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerReglementApplicable(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursReglementApplicable();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerSalaireJournalierConserve(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerSalaireJournalierDeReference(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursSalaireJournalierMoyen();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerNbHeuresTravaillees(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursNbHeuresTravaillees();
    return effectuerParcours(parcours, contexte);
  }
  
  public Object creerObjectifExamen(int sousType, List<ContexteDemandeSpec> contexteDemande)
  {
    FabriqueObjectifExamenSpec fabrique = FabriqueObjectifExamen.getInstance();
    return fabrique.creerObjectif(sousType, contexteDemande);
  }
  
  public Resultat detecterContributionParticuliere(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public void determinerCompetencesDroitCourant(Contexte contexte)
    throws ApplicativeException
  {}
  
  public void determinerCompetencesDroitResultant(Contexte contexte)
    throws ApplicativeException
  {}
  
  public void determinerOrdreObjectifs(Contexte contexte)
    throws ApplicativeException
  {
    ParcoursDeterminationOrdreObjectifs parcours = new ParcoursDeterminationOrdreObjectifs();
    parcours.effectuerParcours(contexte);
  }
  
  public Periode determinerPraLaPlusLongue(DemandeSpec demandeCourante, ActiviteSalarie periodeFctCourante)
    throws CoucheLogiqueException
  {
    return ConstructionPra.determinerPraLaPlusLongue(demandeCourante, periodeFctCourante);
  }
  
  public Quantite determinerReliquatHorsMaintien(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attribution, dateCalcul, true, true);
    Quantite reliquatAre;
    Quantite reliquatAre;
    if (resultat.getReliquatDureeIndemnisation() == null) {
      reliquatAre = getDureeAServirEffective(attribution);
    } else {
      reliquatAre = resultat.getReliquatDureeIndemnisation();
    }
    return reliquatAre;
  }
  
  public Quantite determinerReliquatAvecMaintien(AttributionSpec attribution, Damj dateCalcul)
    throws ApplicativeException
  {
    ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(attribution, dateCalcul, true, true);
    Quantite reliquatAre;
    Quantite reliquatAre;
    if ((resultat.getReliquatAREAvecMaintien() == null) && (dateCalcul.estAvant(resultat.getPji()))) {
      reliquatAre = getDureeAServirEffective(attribution);
    } else {
      reliquatAre = resultat.getReliquatAREAvecMaintien();
    }
    return reliquatAre;
  }
  
  public boolean estCompetenceAdministrativeRac(AttributionSpec attribution)
  {
    return ((Attribution)attribution).getCompetence().getCompetenceAdministrative() == 1;
  }
  
  public boolean estFiliereCourte(AttributionSpec attribution)
  {
    return false;
  }
  
  public boolean estRejetChomageVolontaire(DecisionSpec decision)
  {
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)decision;
    return dossierExamen.estRejetDV();
  }
  
  public Damj getDateFaitGenerateur(AttributionSpec attribution)
  {
    Attribution attributionAsu = (Attribution)attribution;
    if (attributionAsu.getFaitGenerateur() != null) {
      return attributionAsu.getFaitGenerateur().getDateFaitGenerateur();
    }
    return null;
  }
  
  public Damj getDateObtentionAgePourMaintien(DemandeSpec demande)
  {
    return demande.getDemandeur().getDateNaissance().deplacerVersAvant(getAgeMinimumObtentionMaintien(demande));
  }
  
  public Damj getDateObtentionDesTrimestres(DemandeSpec pDemande)
  {
    DemandeMaintien demande = (DemandeMaintien)pDemande;
    return RechercheConditionNombreTrimestresMaintien.getDateObtentionConditionTrimestres(demande);
  }
  
  public Damj getDateObtentionIndemnisation(DemandeSpec demande)
    throws ApplicativeException
  {
    DemandeMaintien demandeMaintien = (DemandeMaintien)demande;
    DemandeAssuranceSpec demandeAsuMaintenue = RechercherDemandeMaintien.rechercherDemandeMaintenuePortantPji(demandeMaintien);
    if (((AttributionAssuranceSpec)((DossierAffecte)demandeAsuMaintenue.getDossierAffectation()).getDossierExamen()).getCalendrierExecutionCalcul() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_MNT_OBTENTION_DATE_INDEMN_SPEC", new Object[] { ((AttributionAssuranceSpec)((DossierAffecte)demandeAsuMaintenue.getDossierAffectation()).getDossierExamen()).getDateAttribution() });
    }
    return ((AttributionAssuranceSpec)((DossierAffecte)demandeAsuMaintenue.getDossierAffectation()).getDossierExamen()).getCalendrierExecutionCalcul().getPremierJourIndemnisable();
  }
  
  public Damj getDateRuptureContratTravail(AttributionSpec pAttribution)
  {
    Attribution attribution = (Attribution)pAttribution;
    Damj dateRuptureContratTravail = null;
    if ((attribution != null) && (attribution.getDossierAffecte() != null))
    {
      FaitGenerateurSpec cdtFaitGenerateur = attribution.getConditionFaitGenerateur();
      if ((cdtFaitGenerateur != null) && (cdtFaitGenerateur.getPeriodeFaitGenerateur() != null))
      {
        ContratTravail contrat = cdtFaitGenerateur.getPeriodeFaitGenerateur().getContrat();
        if (contrat != null) {
          dateRuptureContratTravail = contrat.getDateRuptureContratTravail();
        }
      }
    }
    return dateRuptureContratTravail;
  }
  
  public FormuleMontantSpec getFormuleMontant(String code)
  {
    return RecuperationFormuleMontant.getInstanceFormuleMontant(code);
  }
  
  public BigDecimal getSJR(AttributionSpec attribution)
  {
    return null;
  }
  
  public void initialiserDossierExamen(DossierAffectationSpec dossierAffecte)
  {
    dossierAffecte.setDossierExamen(new Examen());
  }
  
  public void miseAJourDossierExamen(DossierExamenSpec dossier, AttributionSpec attribution)
  {
    ((fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen)dossier).setAttributionPrecedente((AttributionAssuranceSpec)attribution);
  }
  
  public DelaiRechercheProduitSpec obtenirDelaiRechercheProduit(DossierAffectationSpec dossierAffectation, DureeCalendaire delaiAllongement)
    throws CoucheLogiqueException
  {
    return DelaiRechercheSinistres.determinerDelaiRechercheSinistre(dossierAffectation, delaiAllongement);
  }
  
  public ValidationProduitSpec obtenirValidationProduit(ActiviteSalarie activiteSalarie, IndividuSpec individu, DemandeSpec demande, boolean avecPeriodeNonAttestee)
    throws ApplicativeException
  {
    return RechercheValiditeProduit.getInstance().validerProduit(activiteSalarie, (DemandeAssuranceSpec)demande);
  }
  
  public void postTraiterPourJustificationAffiliation(DemandeSpec demande) {}
  
  public Damj recupererDJIParEpuisement(DemandeSpec demande, AttributionSpec attribution, boolean verifierEpuisementHPec)
    throws ApplicativeException
  {
    return OutilReliquat.recupererDJIParEpuisement(demande, attribution, verifierEpuisementHPec);
  }
  
  public void sauvegardeElementsJustificatifs(DossierExamenSpec decision)
    throws CoucheLogiqueException
  {}
  
  public Resultat traiterReliquat(ResultatExecutionCalculSpec resultatExecutionCalcul, Damj dateEtude)
    throws ApplicativeException
  {
    return OutilTraitementReliquat.getInstance().traiterReliquat(resultatExecutionCalcul, dateEtude);
  }
  
  public boolean verifierCapasPreliminaires(Contexte contexte)
    throws ApplicativeException
  {
    return true;
  }
  
  public Resultat verifierCondition28JoursSuspension(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionActivitePourMaintien(Contexte contexte)
    throws ApplicativeException
  {
    Parcours parcours = new DeterminationConditionActivitePourMaintien();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionAge(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionAge();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionAgePourMaintien(Contexte contexte)
    throws ApplicativeException
  {
    Parcours parcours = new DeterminationConditionAgePourMaintien();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionAppartenancePourMaintien(Contexte contexte)
    throws ApplicativeException
  {
    ConditionAppartenanceMaintien condition = new ConditionAppartenanceMaintien();
    condition.setEtatSatisfait(true);
    DemandeMaintien demandeMaintien = (DemandeMaintien)((DomLiquidationDemande)contexte.getDonnees()).getDemandeSpec();
    demandeMaintien.getDossierExamen().setConditionAppartenance(condition);
    return new Resultat(0);
  }
  
  public Resultat verifierConditionCSRAccordCP(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionCSRDateAttributionPendantSuspension(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionChomageInvolontaire(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionChomageInvolontaire();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionChomageTotal(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionCumulActiviteConservee(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionCumulPrestationFamiliale(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionCumulPrestationFamiliale();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionDecisionCPPourMaintien(Contexte contexte)
    throws ApplicativeException
  {
    Parcours parcours = new DeterminationConditionDecisionCPPourMaintien();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionDureeIndemnisationPourMaintien(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionFaitGenerateur(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionFaitGenerateur();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionMontant(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionMontantProduitNonNul();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionNombreTrimestresPourMaintien(Contexte contexte)
    throws ApplicativeException
  {
    Parcours parcours = new DeterminationConditionNombreTrimestresPourMaintien();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionQuantiteAffiliation(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionAffiliation();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat verifierConditionDureeNonNulle(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public Resultat verifierConditionRechercheEmploi(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionRechercheEmploi();
    return effectuerParcours(parcours, contexte);
  }
  
  public void verifierValiditeObjectif(Contexte contexte)
    throws ApplicativeException
  {
    ParcoursValiderObjectif parcours = new ParcoursValiderObjectif();
    parcours.effectuerParcours(contexte);
  }
  
  public Quantite getDureeInitiale(AttributionSpec pAttribution)
  {
    AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
    return attribution.getDureeInitiale();
  }
  
  public boolean estReexecutable(CriteresExecutionPopulation criteres)
  {
    return false;
  }
  
  public Resultat constituerDureeEffective(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursDureeEffective();
    return effectuerParcours(parcours, contexte);
  }
  
  public Resultat constituerCapitalAvecDureeEffective(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursCapitalAvecDureeEffective();
    return effectuerParcours(parcours, contexte);
  }
  
  public Quantite getDureeAServirTheorique(AttributionSpec attribution)
  {
    return ((AttributionAssuranceSpec)attribution).getDureeTheorique();
  }
  
  public Quantite getDureeAServirEffective(AttributionSpec attribution)
  {
    return ((AttributionAssuranceSpec)attribution).getDureeIndemnisationEffective();
  }
  
  public boolean determinerRepriseInvalide(DemandeSpec demande)
  {
    return false;
  }
  
  public boolean estEntameDiffereStandard(DemandeSpec demande)
    throws ApplicativeException
  {
    boolean estConsommeDiffere = false;
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen dossierExamen = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen)((Demande)demande).getDossierExamen();
    if (dossierExamen != null)
    {
      ResultatExecutionCalculSpec resultatCalcul = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit((Attribution)dossierExamen, null, true);
      
      estConsommeDiffere = resultatCalcul.isDiffereEntame();
    }
    return estConsommeDiffere;
  }
  
  public void installerCompetenceConventionGestion(AttributionSpec attribution) {}
  
  public Resultat verifierConditionBeneficeAutreProduit(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public void recalculerSurAnnulerReexamen(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public int getDureeMinimumPourImputationFormation()
  {
    return 0;
  }
  
  public void recalculerActivitesConserveesPourDemandeMigree(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public ObjetMetierSpec recupererSJRPourDelaisReport(DemandeSpec demande)
  {
    return null;
  }
  
  public ConstructionPRASpec getOutilConstructionPRA()
  {
    return null;
  }
  
  public Resultat executerSimulationAffiliation(DomSimulationAffiliation domSimulationAffiliation)
    throws ApplicativeException
  {
    return new OutilSimulationAffiliation().calculAffi(domSimulationAffiliation);
  }
  
  public void positionnerQuantiteAssimilationMaximum(Periode periode, TableQuantites tableQuantitesAffiliationAcquises) {}
  
  public BigDecimal plafonnerDiviseurPrc(BigDecimal dureePRC)
  {
    return dureePRC;
  }
  
  public int getNombreJoursIndemnisationNecessairesMaintien()
  {
    return 364;
  }
  
  public boolean estCompetenceFinanciereSecteurPublic(AttributionSpec attribution)
  {
    return ((Attribution)attribution).getCompetenceFinanciere() == 2;
  }
  
  public MontantBaseSpec obtenirMontantDroitPrecedentSecteurPublicProduitResultant(DemandeSpec demande, DossierExamenSpec dossierExamen, IndividuSpec individu)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public SalaireJournalierSpec revaloriserSalaireJournalier(ElementBaseIndemnisationSpec pEbi, Damj date)
  {
    ElementBaseIndemnisation ebi = (ElementBaseIndemnisation)pEbi;
    
    SalaireReference srrp = RevalorisationSalaire.determinerSrrp(ebi.getSalaireReference(), ebi.getNbJoursEmploiSurPrc(), date);
    
    return RevalorisationSalaire.determinerSjmrp(srrp, ebi.getCoefficientHoraireJour(), ebi.getNombreHeuresTravailleesPlafonnees(), date);
  }
  
  public Resultat constituerDateLimiteIndemnisation(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat verifierConditionAnciennete(Contexte contexte)
    throws ApplicativeException
  {
    return new Resultat(0);
  }
  
  public boolean estCapitalPrecedentRetenu(AttributionSpec attribution)
  {
    return false;
  }
  
  public Resultat constituerRevisionAutomatique(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public DureeCalendaire getAgeMinimumObtentionMaintien(DemandeSpec demande)
  {
    return Parametres.AGE_MINIMUM_MAINTIEN;
  }
  
  public Reglement recupererReglementApplicable(AttributionSpec pAttribution)
  {
    Attribution attribution = (Attribution)pAttribution;
    if (attribution.getReglementApplicable() != null) {
      return attribution.getReglementApplicable().getReglement();
    }
    return null;
  }
  
  public boolean estPresenceDiffere(AttributionSpec attribution)
  {
    return ((AttributionAssuranceSpec)attribution).estPresenceDiffere();
  }
  
  public SalaireJournalierSpec getSalaireJournalier(AttributionSpec attribution, Damj date)
  {
    SalaireJournalierSpec salaireJournalier;
    SalaireJournalierSpec salaireJournalier;
    if (((ProduitAsuSpec)attribution.getProduit()).estTrancheActivee(attribution.getDemande()))
    {
      salaireJournalier = RevalorisationSalaire.revaloriserSjrTranche(attribution, date);
    }
    else
    {
      ElementBaseIndemnisation ebi = ((AttributionAssuranceSpec)attribution).getElementBaseIndemnisation();
      salaireJournalier = revaloriserSalaireJournalier(ebi, date);
    }
    return salaireJournalier;
  }
  
  public Chronologie getListeActivitesConserveesAttributionAreLiee(AttributionSpec attribution)
  {
    return ((AttributionAssuranceSpec)attribution).getListeActiviteConservee();
  }
  
  public String getCodeSirenEmployeurFaitGenerateur(AttributionSpec attribution)
  {
    if ((attribution instanceof RepriseSpec))
    {
      AttributionAssuranceSpec attributionPrecedente = ((Attribution)attribution).getAttributionPrecedente();
      ProduitAsuSpec produitDelegue = (ProduitAsuSpec)attributionPrecedente.getProduit();
      return produitDelegue.getCodeSirenEmployeurFaitGenerateur(attributionPrecedente);
    }
    return ((Attribution)attribution).getFaitGenerateur().getPeriodeFaitGenerateur().getEntreprise().getSiren();
  }
  
  public BigDecimal recupererCoeficientTempsPartielMontantRetenu(AttributionSpec attribution)
  {
    return ((Attribution)attribution).getElementBaseIndemnisation().getCoefficientTempsPartiel();
  }
  
  public int getCodeEmploiA2b(DemandeSpec demande)
  {
    return 0;
  }
  
  public int getCodeEmploiA2b(DonneesEntreeDeterminationSjrSpec donneesEntreeDeterminationSjr)
  {
    return 0;
  }
  
  public BigDecimal recupererSeuilMensuelHoraireActiviteReduite()
  {
    return null;
  }
  
  public int recupererNombreMoisCumulMaxActiviteReduite()
  {
    return 15;
  }
  
  public int recupererNombreMoisCumulCourrierKC6F()
  {
    return 13;
  }
  
  public int recupererNombreMoisIndemnisation(AttributionSpec attribution, Damj dateEtude)
    throws ApplicativeException
  {
    return AppelCalculParLiquidationAsu.determinerNombreMoisIndemnise(attribution, dateEtude);
  }
  
  public Damj getDateFaitGenerateurAttributionMaitre(AttributionSpec attribution)
  {
    AttributionAssuranceSpec attributionAsu = (AttributionAssuranceSpec)attribution;
    Attribution attributionOrigine = (Attribution)attributionAsu.getOuvertureDroit();
    if (attributionOrigine != null) {
      return attributionOrigine.getFaitGenerateur().getDateFaitGenerateur();
    }
    return null;
  }
  
  public List recupererParametresPourLiquidationSimplifiee(Periode periode)
  {
    return null;
  }
  
  public BigDecimal recupererSeuilRemuneration(AttributionSpec attribution, Damj dateCalcul)
    throws CoucheLogiqueException
  {
    return AppelCalculParLiquidationAsu.getSeuilRenumeration(attribution, dateCalcul);
  }
  
  public JustificationAppelGaecReduit getDateDebutFenetrageAppelGaec(DemandeSpec demande)
  {
    return null;
  }
  
  public boolean recupererLeverBornageRetraite(AttributionSpec attribution)
  {
    return false;
  }
  
  public Damj getDateFinDelaiDecheance(AttributionSpec attributionOrigine, DemandeSpec demandeCourante)
  {
    return OutilTraitementReliquat.getInstance().getDateFinDelaiDecheance(attributionOrigine, demandeCourante);
  }
  
  public boolean determinePriseEnCompteObjectifReprise(DemandeSpec demandeCourante)
  {
    return true;
  }
  
  public void traitementPeriodesDecalantes(AttributionSpec attribution, ChronologiePeriodes periodesDecalantes, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    TraitementActiviteReduite traitementActiviteReduite = new TraitementActiviteReduite();
    traitementActiviteReduite.traitementPeriodesDecalantes(attribution, periodesDecalantes, ut);
  }
  
  public void traitementPeriodesGelantes(AttributionSpec attribution, ChronologiePeriodes periodesGelantes, ConstituantsCalculActiviteReduiteSpec constituantsCalculActiviteReduite, UniteTraitement ut)
    throws CoucheLogiqueException
  {
    TraitementActiviteReduite traitementActiviteReduite = new TraitementActiviteReduite();
    traitementActiviteReduite.traitementPeriodesGelantes(attribution, periodesGelantes, ut);
  }
  
  public SalaireJournalierSpec getSalaireConserve(AttributionSpec attribution, Damj date)
  {
    return null;
  }
  
  public Resultat liquiderDemandeAssociee(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public void alimenterDonneesComplementairesDossierExamen(DossierExamenSpec dossierExamenDecisionne) {}
  
  public String determinerPeriodeGaecAChargerSurLectureDecision(DemandeSpec demandeDecisionne)
  {
    if (demandeDecisionne == null) {
      return null;
    }
    DossierExamenSpec dossierExamen;
    DossierExamenSpec dossierExamen;
    if ((demandeDecisionne instanceof DemandeMaintien)) {
      dossierExamen = ((DemandeMaintien)demandeDecisionne).getDossierExamen();
    } else {
      dossierExamen = ((DemandeAssuranceSpec)demandeDecisionne).getDossierExamen();
    }
    if ((dossierExamen instanceof fr.unedic.cali.asu.mnt.dom.Decision)) {
      return OutilsMaintien.determinerPeriodeFaitGenerateurACharger((fr.unedic.cali.asu.mnt.dom.DossierExamen)dossierExamen);
    }
    return null;
  }
  
  public void alimenterBasePivotAidesProduit(DossierExamenSpec dossierExamen, DemandePivot demandePivot)
    throws ApplicativeException
  {}
  
  public SalaireJournalierSpec getSJC(AttributionSpec attribution)
  {
    return null;
  }
  
  public Resultat creerGrapheDemandeAntecedent(Contexte contexte)
    throws CoucheLogiqueException
  {
    GrapheAntecedent.getInstance().alimenterGrapheDecisionAntecedent(contexte);
    return new Resultat(0);
  }
  
  public BigDecimal determinerDureeMaximumPourProduit()
  {
    return new BigDecimal(243);
  }
  
  public ResultatTraitementPopulation effectuerTraitementOccasionnel(CriteresTraitementPopulation criteres)
    throws ApplicativeException
  {
    FabriqueTraitementPopulation fabrique = new FabriqueTraitementPopulation();
    TraitementPopulationSpec traitement = fabrique.getInstance(criteres.getNomPopulation());
    if (traitement != null) {
      return traitement.effectuerTraitement(criteres);
    }
    return null;
  }
  
  public void verifierPropositionAttribution(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    ValidationProduit validationProduit = ((DossierAffectation)demande.getDossierAffectation()).getValidationProduit();
    if (validationProduit != null)
    {
      Periode periodePra = validationProduit.getPeriodePra();
      if (periodePra != null) {
        OutilGestionCoordinationEuropeenne.getInstance().controlerCoordinationEuropeenneATord((Demande)demande, periodePra);
      }
    }
  }
  
  public SalaireJournalierSpec revaloriserSalaireJournalierReference(BigDecimal montantSjr, Damj dateEffetSjr, Damj dateRevalorisation, String contexteParticulier)
    throws CoucheLogiqueException
  {
    throw new CoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE", "Méthode non implémenté pour ce produit");
  }
  
  public FabriqueOutilFonctionnelSpec determinerFabriqueOutilFonctionnelDeterminationSjr(Damj dateFaitGenerateur)
    throws CoucheLogiqueException
  {
    throw new CoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE", "Méthode non implémenté pour ce produit");
  }
  
  public DonneesResultatDeterminationSjrSpec determinerSjrip(DonneesEntreeDeterminationSjrSpec donneesEntree)
    throws CoucheLogiqueException
  {
    throw new CoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE", "Méthode non implémenté pour ce produit");
  }
  
  public boolean estUnProduitGerantA9()
  {
    return false;
  }
  
  public boolean estUnProduitLevantAlerteA8A10()
  {
    return false;
  }
  
  public void verifierPropositionRejet(DemandeSpec demande)
    throws CoucheLogiqueException
  {}
  
  public MontantBaseSpec recupererMontant(DonneesEntreesRecuperationMontant donneeEntreeRecuperationMontant)
    throws ApplicativeException
  {
    return DeterminationMontant.determinerMontant(donneeEntreeRecuperationMontant);
  }
  
  public ConventionGestionSpec getConventionGestion(AttributionSpec attribution)
  {
    return ((Attribution)attribution).getConventionGestion();
  }
  
  public Convertisseur determinerConvertisseurUniteAffiliation()
  {
    return ConvertisseurUniteAffiliation.getInstance();
  }
  
  public Collection determinerListePlafonnementAffiliation(AttributionSpec attribution)
    throws ApplicativeException
  {
    throw new CoucheLogiqueException("HG_PR_CALI_PRODUIT_METHODE_NON_IMPLEMENTE", "Méthode non implémenté pour ce produit");
  }
  
  public boolean isPlafonnementAffiliationActif()
  {
    return false;
  }
  
  public ElementBaseIndemnisationSpec recupererElementBaseIndemnisationPourReadmissionAvecMontantRetenuPrecedent(int natureDecision, int montantRetenu, DemandeSpec demande, AttributionSpec attribution)
  {
    return null;
  }
  
  public ProduitAsuSpec getProduitMontantRetenu(AttributionSpec attribution)
  {
    AttributionAssuranceSpec attributionAssurance = (AttributionAssuranceSpec)attribution;
    return attributionAssurance.getProduitMontantRetenu();
  }
  
  public String getSituationParticuliere(AttributionSpec attribution)
  {
    return DeterminationSituationParticuliere.getSituationParticuliere();
  }
  
  public Resultat verifierConditionValiditeReliquat(Contexte contexte)
    throws ApplicativeException
  {
    ObjectifExamenSpec objectifCourant = recupererObjectifCourant(contexte);
    Parcours parcours = objectifCourant.creerParcoursConditionValiditeReliquat();
    return effectuerParcours(parcours, contexte);
  }
  
  public String determinerCodeSousProduitPourSigma(DecisionSpec pAttribution)
  {
    String codeSousProduitRetourne = null;
    if ((pAttribution instanceof AttributionAssuranceSpec))
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)pAttribution;
      codeSousProduitRetourne = "";
      Demande demande = (Demande)attribution.getDemande();
      if (OutilsChomageSansRCT.estDemandeEnContexteDeChomageEnCoursDeSuspension(demande))
      {
        boolean estSinistreOuCalamiteNaturelle = attribution.isEstSinistreOuCalamiteNaturelle();
        if (estSinistreOuCalamiteNaturelle) {
          codeSousProduitRetourne = "02";
        } else {
          codeSousProduitRetourne = "01";
        }
      }
      else if (demande.getDonneesTemporaires().isEstCoordCee())
      {
        codeSousProduitRetourne = "03";
      }
      else if (attribution.isTopContratsRemuneresBaseSmic())
      {
        codeSousProduitRetourne = "24";
      }
    }
    return codeSousProduitRetourne;
  }
  
  public CalculAppartenanceSpec getOutilCalculAppartenance(DemandeSpec demande, boolean utiliserNouveauOutilCalcul)
  {
    return null;
  }
  
  public void initialiserComportementCalculAffiliation(ComportementAffiliationSpec comportement, ParametresAffiliationSpec parametres) {}
  
  public String determinerSituationParticuliere(AttributionSpec attribution)
  {
    return DeterminationSituationParticuliere.getSituationParticuliere();
  }
  
  public boolean estProduitGerantPensionInvalidite(DemandeSpec demande)
  {
    Damj dateFaitGenerateur = null;
    DossierExamenAssuranceSpec dossierExamen = (DossierExamenAssuranceSpec)demande.getDossierAffectation().getDossierExamen();
    if ((dossierExamen instanceof RepriseSpec)) {
      dateFaitGenerateur = getDateFaitGenerateurAttributionMaitre((AttributionSpec)dossierExamen);
    } else if (dossierExamen.getFaitGenerateur() != null) {
      dateFaitGenerateur = dossierExamen.getFaitGenerateur().getDateFaitGenerateur();
    }
    if (dateFaitGenerateur == null) {
      return false;
    }
    return getOutilDeterminationPensionInvalidite(dateFaitGenerateur).estProduitGerantPensionInvalidite();
  }
  
  public Collection determinerPensionInvaliditeDroitCourant(AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return getOutilDeterminationPensionInvalidite(getDateFaitGenerateur(attribution)).determinerPensionInvaliditeDroitCourant(attribution);
  }
  
  public Collection determinerPensionInvaliditeDroitResultant(AttributionSpec attribution)
  {
    return new ArrayList();
  }
  
  protected OutilDeterminationPensionInvaliditeSpec getOutilDeterminationPensionInvalidite(Damj dateFaitGenerateur)
  {
    CritereStrategie critere = new CritereStrategie();
    critere.setDatePivot(dateFaitGenerateur);
    FabriqueStrategiePensionInvalidite fabrique = new FabriqueStrategiePensionInvalidite();
    return (OutilDeterminationPensionInvaliditeSpec)fabrique.getStrategie(critere);
  }
  
  public boolean estProduitGerantIccpEnContexteRepriseSimplifiee()
  {
    return false;
  }
  
  public Damj determinerDateExclueAuPlusTardDebutActiviteConservee(ActiviteSalarie pas, Damj dateFaitGenerateur)
    throws CoucheLogiqueException
  {
    return ConstructionChronologie.determinerDateExclueAuPlusTardDebutActiviteConservee(pas);
  }
  
  public Resultat determinerContexteExamen(Contexte contexte)
    throws ApplicativeException
  {
    ParcoursContexteExamen parcours = new ParcoursContexteExamen();
    return parcours.effectuerParcours(contexte);
  }
  
  public DureeIndemnisationAbstraite creerDureeCalcul(AttributionSpec attribution)
  {
    AttributionAssuranceSpec attributionAssurance = (AttributionAssuranceSpec)attribution;
    return new DureeIndemnisation(attributionAssurance.getDureeTheorique().getValeurEntiere());
  }
  
  public Resultat constituerTranchesExecutables(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public boolean estTrancheActivee(DemandeSpec demande)
  {
    return false;
  }
  
  public BigDecimal recupererCoefficientSaisonnierMontantRetenu(AttributionSpec attribution)
  {
    return new BigDecimal("1");
  }
  
  public DureeIndemnisationAbstraite creerDureeCalculTranche(Quantite quantite)
  {
    return null;
  }
  
  public boolean effectuerTraitementSpecifiqueAssistanceMaternellePourAffiliation()
  {
    return false;
  }
  
  public OutilCalculDiffereStandardSpec getOutilCalculDiffereStandard()
  {
    return new OutilCalculDiffereStandard();
  }
  
  public ResultatActiviteReduite calculActiviteReduite(BigDecimal allocationJournalierBrute, BigDecimal remunerationReprise, BigDecimal areBrute, BigDecimal sjr, String justificationCalculMontant, Periode periode)
  {
    return null;
  }
  
  public BigDecimal getCrcSimuActiviteReduite(BigDecimal salaire, BigDecimal montantBrutJournalier, Damj dateCalcul)
  {
    return null;
  }
  
  public StrategieSpec retournerStrategieAvantDeterminationChomageInvolontaire()
  {
    return null;
  }
  
  public boolean estForcerTempsPleinPourPeriodeA8A10(Damj dateExamen)
  {
    return false;
  }
  
  public Quantite getDiffereStandard(DemandeSpec demande, BigDecimal remuneration)
    throws PasAssezInformationException
  {
    return null;
  }
  
  public CalendrierExecutionCalculSpec creerCalendrierCalcul()
  {
    return null;
  }
  
  public UniteTraitement creerUT(Periode periodeUT, AttributionSpec attribution)
    throws CoucheLogiqueException
  {
    return null;
  }
  
  public Resultat constituerCapitalDroitCourant(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerMontantsEffectifs(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public Resultat constituerNouvelleRevisionAutomatique(Contexte contexte)
    throws ApplicativeException
  {
    return null;
  }
  
  public ParametresCarenceIndemnisationStandardSpec recupererParametresCarenceIndemnisationDiffereStandard()
  {
    return new ParametresCarenceIndemnisationStandard();
  }
  
  public ComportementAffiliationSpec getComportementAffiliation()
  {
    return ComportementCalculAffiliation.creerInstance();
  }
  
  public OutilPeriodeElementaireSpectacleSpec getOutilPeriodeElementaire()
  {
    return OutilPeriodeElementaire.getInstance();
  }
  
  public String recupererIdAeBatimentPourICCPConservatoire(AttributionSpec attribution)
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     ProduitDelegue
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */