package fr.unedic.cali.asu.spe02.p03.calcul.dom;

import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.gen.MontantGen;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import java.math.BigDecimal;

public class Montant
  extends MontantGen
  implements MontantAsuSpec
{
  private static final long serialVersionUID = -501457023601046533L;
  public static final String PLAFOND = "03";
  public static final String MINI = "02";
  protected transient Quantite m_mini = null;
  protected transient Quantite m_plafond = null;
  protected transient Quantite m_base = null;
  protected transient Quantite m_partieA = null;
  protected transient Quantite m_partieB = null;
  protected transient Quantite m_partieC = null;
  protected transient BigDecimal m_coefA1 = null;
  protected transient BigDecimal m_coefA2 = null;
  protected transient BigDecimal m_coefB1 = null;
  protected transient BigDecimal m_coefB2 = null;
  protected transient BigDecimal m_coefC = null;
  protected transient BigDecimal m_nhf = null;
  protected transient BigDecimal m_srf = null;
  protected transient BigDecimal m_tauxCrc = null;
  protected transient BigDecimal m_sjrNonReduit = null;
  protected transient BigDecimal m_baseCalculCrc = null;
  protected transient String m_positionExonerationCrc = null;
  protected transient Quantite m_csg = null;
  protected transient Quantite m_crds = null;
  protected transient Quantite m_totalCotisationContribution = null;
  protected transient Quantite m_montantBrutSansPensionInvaliditeADeduire = null;
  protected transient Quantite m_pensionInvaliditeADeduirePriseEnCompte = null;
  protected transient Quantite m_montantJournalierAvantageVieillesse = null;
  protected transient Quantite m_montantJournalierAvantageVieillesseDeduit = null;
  protected transient Quantite m_montantBrutSansAvantageVieillesseDeduit = null;
  protected transient String m_justificationCalculMontant = null;
  protected transient String m_type = "NORMAL";
  
  public Montant()
  {
    setAvecPrecompteCRC(true);
  }
  
  public Montant(DomPCSpec p_montantPC)
  {
    super(p_montantPC);
  }
  
  public Quantite getBase()
  {
    return m_base;
  }
  
  public BigDecimal getBaseCalculCrc()
  {
    return m_baseCalculCrc;
  }
  
  public Quantite getCotisationContribution()
  {
    return m_totalCotisationContribution;
  }
  
  public Quantite getCrds()
  {
    return m_crds;
  }
  
  public Quantite getCsg()
  {
    return m_csg;
  }
  
  public String getJustificationCalculMontant()
  {
    return m_justificationCalculMontant;
  }
  
  public Quantite getMini()
  {
    return m_mini;
  }
  
  public Quantite getMontantBrutSansPensionInvaliditeADeduire()
  {
    return m_montantBrutSansPensionInvaliditeADeduire;
  }
  
  public Quantite getMontantJournalierAvantageVieillesse()
  {
    if (m_montantJournalierAvantageVieillesse == null) {
      m_montantJournalierAvantageVieillesse = new QuantiteEuro("0");
    }
    return m_montantJournalierAvantageVieillesse;
  }
  
  public Quantite getMontantJournalierAvantageVieillesseDeduit()
  {
    if (m_montantJournalierAvantageVieillesseDeduit == null) {
      m_montantJournalierAvantageVieillesseDeduit = new QuantiteEuro("0");
    }
    return m_montantJournalierAvantageVieillesseDeduit;
  }
  
  public Quantite getMontantBrutSansAvantageVieillesseDeduit()
  {
    if (m_montantBrutSansAvantageVieillesseDeduit == null) {
      m_montantBrutSansAvantageVieillesseDeduit = new QuantiteEuro("0");
    }
    return m_montantBrutSansAvantageVieillesseDeduit;
  }
  
  public void setMontantBrutSansAvantageVieillesseDeduit(Quantite p_quantite)
  {
    m_montantBrutSansAvantageVieillesseDeduit = p_quantite;
  }
  
  public Quantite getMontantNet()
  {
    return null;
  }
  
  public BigDecimal getMontantPrecompte()
  {
    return getMontantBrut().getValeur().subtract(getCrc().getValeur());
  }
  
  public Quantite getMontantPrecompteEffectif()
  {
    if (getAvecPrecompteCRC()) {
      return new Quantite(getMontantBrut().getValeur().subtract(getCrc().getValeur()), getMontantBrut().getUnite());
    }
    return getMontantBrut();
  }
  
  public Quantite getPensionInvaliditeADeduirePriseEnCompte()
  {
    if (m_pensionInvaliditeADeduirePriseEnCompte == null) {
      m_pensionInvaliditeADeduirePriseEnCompte = new QuantiteEuro("0");
    }
    return m_pensionInvaliditeADeduirePriseEnCompte;
  }
  
  public Quantite getPlafond()
  {
    return m_plafond;
  }
  
  public Quantite getPlancher()
  {
    return null;
  }
  
  public String getPositionExonerationCrc()
  {
    return m_positionExonerationCrc;
  }
  
  public BigDecimal getSjrNonReduit()
  {
    return m_sjrNonReduit;
  }
  
  public BigDecimal getTauxCrc()
  {
    return m_tauxCrc;
  }
  
  public String getType()
  {
    return m_type;
  }
  
  public ObjetMetierSpec copie()
  {
    Montant copie = new Montant();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Montant copie = (Montant)p_copie;
    super.copieElements(copie);
    copie.setMini(getMini());
    copie.setPlafond(getPlafond());
    copie.setBase(getBase());
    copie.setPartieA(getPartieA());
    copie.setPartieB(getPartieB());
    copie.setPartieC(getPartieC());
    copie.setCoefA1(getCoefA1());
    copie.setCoefA2(getCoefA2());
    copie.setCoefB1(getCoefB1());
    copie.setCoefB2(getCoefB2());
    copie.setCoefC(getCoefC());
    copie.setNhf(getNhf());
    copie.setSrf(getSrf());
    copie.setTauxCrc(getTauxCrc());
    copie.setSjrNonReduit(getSjrNonReduit());
    copie.setBaseCalculCrc(getBaseCalculCrc());
    copie.setPositionExonerationCrc(getPositionExonerationCrc());
    copie.setCsg(getCsg());
    copie.setCrds(getCrds());
    copie.setTotalCotisationContribution(getTotalCotisationContribution());
    copie.setMontantBrutSansPensionInvaliditeADeduire(getMontantBrutSansPensionInvaliditeADeduire());
    copie.setPensionInvaliditeADeduirePriseEnCompte(getPensionInvaliditeADeduirePriseEnCompte());
    copie.setMontantJournalierAvantageVieillesse(getMontantJournalierAvantageVieillesse());
    copie.setMontantJournalierAvantageVieillesseDeduit(getMontantJournalierAvantageVieillesseDeduit());
    copie.setMontantBrutSansAvantageVieillesseDeduit(getMontantBrutSansAvantageVieillesseDeduit());
    copie.setJustificationCalculMontant(getJustificationCalculMontant());
    copie.setType(getType());
  }
  
  public BigDecimal getCoefA1()
  {
    return m_coefA1;
  }
  
  public void setCoefA1(BigDecimal p_coefA1)
  {
    m_coefA1 = p_coefA1;
  }
  
  public BigDecimal getCoefA2()
  {
    return m_coefA2;
  }
  
  public void setCoefA2(BigDecimal p_coefA2)
  {
    m_coefA2 = p_coefA2;
  }
  
  public BigDecimal getCoefB1()
  {
    return m_coefB1;
  }
  
  public void setCoefB1(BigDecimal p_coefB1)
  {
    m_coefB1 = p_coefB1;
  }
  
  public BigDecimal getCoefB2()
  {
    return m_coefB2;
  }
  
  public void setCoefB2(BigDecimal p_coefB2)
  {
    m_coefB2 = p_coefB2;
  }
  
  public BigDecimal getCoefC()
  {
    return m_coefC;
  }
  
  public void setCoefC(BigDecimal p_coefC)
  {
    m_coefC = p_coefC;
  }
  
  public BigDecimal getNhf()
  {
    return m_nhf;
  }
  
  public void setNhf(BigDecimal p_nhf)
  {
    m_nhf = p_nhf;
  }
  
  public Quantite getPartieA()
  {
    return m_partieA;
  }
  
  public void setPartieA(Quantite p_partieA)
  {
    m_partieA = p_partieA;
  }
  
  public Quantite getPartieB()
  {
    return m_partieB;
  }
  
  public void setPartieB(Quantite p_partieB)
  {
    m_partieB = p_partieB;
  }
  
  public Quantite getPartieC()
  {
    return m_partieC;
  }
  
  public void setPartieC(Quantite p_partieC)
  {
    m_partieC = p_partieC;
  }
  
  public BigDecimal getSrf()
  {
    return m_srf;
  }
  
  public void setSrf(BigDecimal p_srf)
  {
    m_srf = p_srf;
  }
  
  public Quantite getTotalCotisationContribution()
  {
    return m_totalCotisationContribution;
  }
  
  public void setTotalCotisationContribution(Quantite p_totalCotisationContribution)
  {
    m_totalCotisationContribution = p_totalCotisationContribution;
  }
  
  public void setBase(Quantite p_base)
  {
    m_base = p_base;
  }
  
  public void setBaseCalculCrc(BigDecimal p_baseCalculCrc)
  {
    m_baseCalculCrc = p_baseCalculCrc;
  }
  
  public void setCrds(Quantite p_crds)
  {
    m_crds = p_crds;
  }
  
  public void setCsg(Quantite p_csg)
  {
    m_csg = p_csg;
  }
  
  public void setJustificationCalculMontant(String p_justificationCalculMontant)
  {
    m_justificationCalculMontant = p_justificationCalculMontant;
  }
  
  public void setMini(Quantite p_mini)
  {
    m_mini = p_mini;
  }
  
  public void setMontantBrutSansPensionInvaliditeADeduire(Quantite p_montantBrutSansPensionInvaliditeADeduire)
  {
    m_montantBrutSansPensionInvaliditeADeduire = p_montantBrutSansPensionInvaliditeADeduire;
  }
  
  public void setMontantJournalierAvantageVieillesse(Quantite p_montantJournalierAvantageVieillesse)
  {
    m_montantJournalierAvantageVieillesse = p_montantJournalierAvantageVieillesse;
  }
  
  public void setMontantJournalierAvantageVieillesseDeduit(Quantite p_montantJournalierAvantageVieillesseDeduit)
  {
    m_montantJournalierAvantageVieillesseDeduit = p_montantJournalierAvantageVieillesseDeduit;
  }
  
  public void setPensionInvaliditeADeduirePriseEnCompte(Quantite p_pensionInvaliditeADeduirePriseEnCompte)
  {
    m_pensionInvaliditeADeduirePriseEnCompte = p_pensionInvaliditeADeduirePriseEnCompte;
  }
  
  public void setPlafond(Quantite p_plafond)
  {
    m_plafond = p_plafond;
  }
  
  public void setPositionExonerationCrc(String p_positionExonerationCrc)
  {
    m_positionExonerationCrc = p_positionExonerationCrc;
  }
  
  public void setSjrNonReduit(BigDecimal p_sjrNonReduit)
  {
    m_sjrNonReduit = p_sjrNonReduit;
  }
  
  public void setTauxCrc(BigDecimal p_tauxCrc)
  {
    m_tauxCrc = p_tauxCrc;
  }
  
  public void setType(String p_type)
  {
    m_type = p_type;
  }
  
  public Quantite getCsgEstimee()
  {
    return null;
  }
  
  public Quantite getCrdsEstimee()
  {
    return null;
  }
  
  public Quantite getCcamEstimee(boolean p_topAlsaceMoselle)
  {
    return null;
  }
  
  public Quantite getMontantNetEstime(boolean p_topAlsaceMoselle)
  {
    return null;
  }
  
  public MontantAsuSpec getMontantAreExecute()
  {
    return null;
  }
  
  public MontantAsuSpec getMontantAreNonExecute()
  {
    return null;
  }
  
  public BigDecimal getSjrMontantMax()
  {
    return null;
  }
  
  public BigDecimal getPlafondASP()
  {
    return null;
  }
  
  public Montant getMontantSJR()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     Montant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */