package fr.unedic.cali.asu.spe02.p03.liquidation.dom;

import fr.unedic.cali.asu.dom.ObjectifExamen;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.ParcoursObjectifAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen.ObjectifExamenAdmissionGen;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionCapitalAvecDureeEffective;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDateAttribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDureeEffective;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionReglementApplicable;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.ConstitutionSalaireReferenceEtSjm;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionAge;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionChomageInvolontaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionCumulPrestationFamiliale;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionFaitGenerateur;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionMontantProduitNonNul;
import fr.unedic.cali.asu.spe02.p03.liquidation.parcours.DeterminationConditionRechercheEmploi;
import fr.unedic.cali.dom.affectation.ContexteDemandeSpec;
import fr.unedic.cali.parcours.ParcoursTraitementSatisfait;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Parcours;
import java.util.List;

public class ObjectifExamenAdmission
  extends ObjectifExamenAdmissionGen
  implements ObjectifExamenSpec
{
  private static final long serialVersionUID = 1L;
  private List<ContexteDemandeSpec> contexteDemande;
  
  public ObjectifExamenAdmission(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public ObjectifExamenAdmission() {}
  
  public ObjectifExamenAdmission(List<ContexteDemandeSpec> contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public ObjetMetierSpec copie()
  {
    ObjectifExamenAdmission copie = new ObjectifExamenAdmission();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    ObjectifExamenAdmission copie = (ObjectifExamenAdmission)p_copie;
    super.copieElements(copie);
  }
  
  public void marquerGraphePersistant() {}
  
  public Parcours creerParcoursObjectif()
  {
    return new ParcoursObjectifAdmission();
  }
  
  public ObjectifExamen getObjectifSauvegarde()
    throws CoucheLogiqueException
  {
    ObjectifExamen objectif = null;
    objectif = (ObjectifExamen)copie();
    return objectif;
  }
  
  public int getType()
  {
    return 1;
  }
  
  public Parcours creerParcoursConditionAffiliation()
  {
    return new DeterminationConditionAffiliation();
  }
  
  public Parcours creerParcoursConditionAge()
  {
    return new DeterminationConditionAge();
  }
  
  public Parcours creerParcoursConditionChomageInvolontaire()
  {
    return new DeterminationConditionChomageInvolontaire();
  }
  
  public Parcours creerParcoursConditionCumulPrestationFamiliale()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionCumulPrestationFamiliale();
  }
  
  public Parcours creerParcoursConditionFaitGenerateur()
  {
    return new DeterminationConditionFaitGenerateur();
  }
  
  public Parcours creerParcoursConditionMontantProduitNonNul()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionMontantProduitNonNul();
  }
  
  public Parcours creerParcoursConditionRechercheEmploi()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return new ParcoursTraitementSatisfait();
    }
    return new DeterminationConditionRechercheEmploi();
  }
  
  public Parcours creerParcoursConditionDureeNonNulle()
  {
    return null;
  }
  
  public Parcours creerParcoursDateAttribution()
  {
    return new ConstitutionDateAttribution();
  }
  
  public Parcours creerParcoursDelaisReports()
  {
    if (OutilGestionContexteDemande.estUnContexteDemandeAssurancePresent(contexteDemande, "ARESJREV")) {
      return null;
    }
    return new ConstitutionDelaisReport();
  }
  
  public Parcours creerParcoursDurees()
  {
    return new ConstitutionDurees();
  }
  
  public Parcours creerParcoursMontantsBruts()
  {
    return new ConstitutionMontantsBruts();
  }
  
  public Parcours creerParcoursNbHeuresTravaillees()
  {
    return new ConstitutionNbHeuresTravaillees();
  }
  
  public Parcours creerParcoursPointDeDepart()
  {
    return new ConstitutionPointDepartIndemnisation();
  }
  
  public Parcours creerParcoursReglementApplicable()
  {
    return new ConstitutionReglementApplicable();
  }
  
  public Parcours creerParcoursSalaireJournalierMoyen()
  {
    return new ConstitutionSalaireReferenceEtSjm();
  }
  
  public Parcours creerParcoursDureeEffective()
  {
    return new ConstitutionDureeEffective();
  }
  
  public Parcours creerParcoursCapitalAvecDureeEffective()
  {
    return new ConstitutionCapitalAvecDureeEffective();
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Parcours creerParcoursConditionBeneficeAutreProduit()
  {
    return null;
  }
  
  public Parcours creerParcoursConditionValiditeReliquat()
  {
    return null;
  }
  
  public Parcours creerParcoursConstitutionDureePostPrime()
  {
    return null;
  }
  
  public List<ContexteDemandeSpec> getContexteDemande()
  {
    return contexteDemande;
  }
  
  public void setContexteDemande(List<ContexteDemandeSpec> contexteDemande)
  {
    this.contexteDemande = contexteDemande;
  }
  
  public Parcours creerParcoursDateLimiteIndemnisation()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     ObjectifExamenAdmission
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */