package fr.unedic.cali.asu.spe02.p03.liquidation.dom;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen.PeriodeElementaireAffiliationGen;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpectacleSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.cali.dom.spec.PeriodeElementaireAffiliationSpec;
import fr.unedic.cali.liquidation.outilsfonctionnels.spec.OutilPeriodeElementaireSpectacleSpec;
import fr.unedic.cali.util.OutilDomToString;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.Quantite;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class PeriodeElementaireAffiliation
  extends PeriodeElementaireAffiliationGen
  implements ObjetPersistantSpec, PeriodeElementaireAffiliationSpec
{
  private static final long serialVersionUID = 453578132338918763L;
  
  public PeriodeElementaireAffiliation(DomPCSpec pc)
  {
    super(pc);
  }
  
  public PeriodeElementaireAffiliation() {}
  
  public static PeriodeElementaireAffiliation getInstance()
  {
    return new PeriodeElementaireAffiliation();
  }
  
  public ObjetMetierSpec copie()
  {
    PeriodeElementaireAffiliation copie = new PeriodeElementaireAffiliation();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec pCopie)
  {
    PeriodeElementaireAffiliation copie = (PeriodeElementaireAffiliation)pCopie;
    super.copieElements(copie);
    copie.setMois(getMois() != null ? new Periode(getMois().getDebut(), getMois().getFin()) : null);
    
    copie.setAffiliationRetenue(super.getAffiliationRetenue());
    copie.setHeuresA8(getHeuresA8());
    copie.setHeuresA10(getHeuresA10());
    copie.setCachetIsoleA8(getCachetIsoleA8());
    copie.setCachetGroupeA8(getCachetGroupeA8());
    copie.setCachetIsoleA10(getCachetIsoleA10());
    copie.setCachetGroupeA10(getCachetGroupeA10());
    copie.setHeuresComplementairesA10(getHeuresComplementairesA10());
    copie.setMontantPlafondCachets(getMontantPlafondCachets());
    copie.setMontantPlafondHeures(getMontantPlafondHeures());
    copie.setQuantiteHeureExercee(getQuantiteHeureExercee());
    copie.setQuantiteCachetGroupeIsoleHeureExercee(getQuantiteCachetGroupeIsoleHeureExercee());
    copie.setHeuresApresPlafonnementMonoEmployeur(getHeuresApresPlafonnementMonoEmployeur());
    copie.setEstPlafonneMultiEmployeur(isEstPlafonneMultiEmployeur());
    if (super.getCollectionPeriodeElementaireEmployeur() != null)
    {
      Iterator<?> it = super.getCollectionPeriodeElementaireEmployeur().iterator();
      while (it.hasNext())
      {
        PeriodeElementaireEmployeur periode = (PeriodeElementaireEmployeur)it.next();
        if (periode != null) {
          copie.ajouterPeriodeElementaireEmployeur((PeriodeElementaireEmployeur)periode.copie());
        }
      }
    }
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getCollectionPeriodeElementaireEmployeur());
  }
  
  public void ajouterQuantiteHeureA8(BigDecimal quantite)
  {
    if (getHeuresA8() == null) {
      setHeuresA8(quantite);
    } else {
      setHeuresA8(ajouter(getHeuresA8(), quantite));
    }
  }
  
  public void ajouterQuantiteHeureA10(BigDecimal quantite)
  {
    if (getHeuresA10() == null) {
      setHeuresA10(quantite);
    } else {
      setHeuresA10(ajouter(getHeuresA10(), quantite));
    }
  }
  
  public void ajouterQuantiteHeureA10Complementaire(BigDecimal quantite)
  {
    if (getHeuresComplementairesA10() == null) {
      setHeuresComplementairesA10(quantite);
    } else {
      setHeuresComplementairesA10(ajouter(getHeuresComplementairesA10(), quantite));
    }
  }
  
  public void ajouterQuantiteCachetGroupeA8(BigDecimal quantite)
  {
    if (getCachetGroupeA8() == null) {
      setCachetGroupeA8(quantite);
    } else {
      setCachetGroupeA8(ajouter(getCachetGroupeA8(), quantite));
    }
  }
  
  public void ajouterQuantiteCachetGroupeA10(BigDecimal quantite)
  {
    if (getCachetGroupeA10() == null) {
      setCachetGroupeA10(quantite);
    } else {
      setCachetGroupeA10(ajouter(getCachetGroupeA10(), quantite));
    }
  }
  
  public void ajouterQuantiteCachetIsoleA8(BigDecimal quantite)
  {
    if (getCachetIsoleA8() == null) {
      setCachetIsoleA8(quantite);
    } else {
      setCachetIsoleA8(ajouter(getCachetIsoleA8(), quantite));
    }
  }
  
  public void ajouterQuantiteCachetIsoleA10(BigDecimal quantite)
  {
    if (getCachetIsoleA10() == null) {
      setCachetIsoleA10(quantite);
    } else {
      setCachetIsoleA10(ajouter(getCachetIsoleA10(), quantite));
    }
  }
  
  private BigDecimal ajouter(BigDecimal quantite1, BigDecimal quantite2)
  {
    return quantite1.add(quantite2);
  }
  
  public boolean isPlafondHeuresDepasse()
  {
    return getQuantiteHeureExercee().compareTo(getMontantPlafondHeures()) > 0;
  }
  
  public boolean isPlafondCachetsDepasse()
  {
    return getSommeCachetA10().compareTo(getMontantPlafondCachets()) > 0;
  }
  
  public BigDecimal getSommeCachetA10()
  {
    BigDecimal sommeCachetA10 = new BigDecimal(0);
    if (getCachetGroupeA10() != null) {
      sommeCachetA10 = sommeCachetA10.add(getCachetGroupeA10());
    }
    if (getCachetIsoleA10() != null) {
      sommeCachetA10 = sommeCachetA10.add(getCachetIsoleA10());
    }
    return sommeCachetA10;
  }
  
  public BigDecimal getSommeCachetA8()
  {
    BigDecimal sommeCachetA8 = new BigDecimal(0);
    if (getCachetGroupeA8() != null) {
      sommeCachetA8 = sommeCachetA8.add(getCachetGroupeA8());
    }
    if (getCachetIsoleA8() != null) {
      sommeCachetA8 = sommeCachetA8.add(getCachetIsoleA8());
    }
    return sommeCachetA8;
  }
  
  public String toString()
  {
    return OutilDomToString.toString(this);
  }
  
  public Quantite getAffiliationRetenue()
  {
    throw new UnsupportedOperationException("il manque le produit en paramètre");
  }
  
  public Quantite getAffiliationRetenue(ProduitAsuSpec produit)
  {
    Convertisseur convertisseurUniteAffiliation = produit.determinerConvertisseurUniteAffiliation();
    
    Quantite affi = ((ProduitAsuSpectacleSpec)produit).getOutilPeriodeElementaire().calculerQuantiteAppartenanceARetenir(this, convertisseurUniteAffiliation);
    setAffiliationRetenue(affi);
    return affi;
  }
  
  public void remplacerCollectionPeriodeElementaireEmployeur(Collection collectionACopier)
  {
    for (Iterator<?> iter = super.getCollectionPeriodeElementaireEmployeur().iterator(); iter.hasNext();)
    {
      PeriodeElementaireEmployeur element = (PeriodeElementaireEmployeur)iter.next();
      DomManager.supprimer(element);
    }
    super.remplacerCollectionPeriodeElementaireEmployeur(collectionACopier);
  }
}

/* Location:
 * Qualified Name:     PeriodeElementaireAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */