package fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ActiviteParticipante;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationSupplementaire;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AllongementPra;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.pc.ValidationProduitPC;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public abstract class JustificationAffiliationGen
  implements DomGenSpec
{
  protected transient DomPCSpec m_validationProduitPC;
  private Collection m_listeAllongementsPra;
  private Collection m_listeActivitesParticipantes;
  private Collection m_listeAffiliationsAssimilees;
  private Collection m_listeAffiliationsSupplementaires;
  private Collection m_listePeriodesElementairesAffiliation;
  
  public JustificationAffiliationGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public JustificationAffiliationGen() {}
  
  public DomPCSpec getPC()
  {
    return m_validationProduitPC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_validationProduitPC)
  {
    m_validationProduitPC = p_validationProduitPC;
  }
  
  private final Collection getCollectionModifiableAllongementPra()
  {
    Iterator itCollectionPC;
    if (m_listeAllongementsPra == null)
    {
      m_listeAllongementsPra = new ArrayList();
      for (itCollectionPC = ((ValidationProduitPC)getPC()).getCollectionAllongementPra().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeAllongementsPra.add(currentOM);
      }
    }
    return m_listeAllongementsPra;
  }
  
  public Collection getCollectionAllongementPra()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableAllongementPra());
  }
  
  public List getListAllongementPra()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableAllongementPra());
  }
  
  public void remplacerCollectionAllongementPra(Collection p_collectionACopier)
  {
    clearCollectionAllongementPra();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      AllongementPra objet = (AllongementPra)i.next();
      ajouterAllongementPra(objet);
    }
  }
  
  public void supprimerSousCollectionAllongementPra(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      AllongementPra objet = (AllongementPra)i.next();
      supprimerAllongementPra(objet);
    }
  }
  
  public void ajouterAllongementPra(AllongementPra p_allongementsPra)
    throws NullPointerException
  {
    if (p_allongementsPra == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_allongementsPra ne devrait pas être nul.", p_allongementsPra);
    }
    getCollectionModifiableAllongementPra().add(p_allongementsPra);
    ((ValidationProduitPC)getPC()).ajouterAllongementPra(p_allongementsPra.getPC());
  }
  
  public void supprimerAllongementPra(AllongementPra p_allongementsPra)
    throws NullPointerException
  {
    if (p_allongementsPra == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_allongementsPra ne devrait pas être nul.", p_allongementsPra);
    }
    getCollectionModifiableAllongementPra().remove(p_allongementsPra);
    ((ValidationProduitPC)getPC()).supprimerAllongementPra(p_allongementsPra.getPC());
  }
  
  public void recopierCollectionAllongementPraVers(ObjetMetierSpec p_copie)
  {
    JustificationAffiliationGen copie = (JustificationAffiliationGen)p_copie;
    Collection listeACopier = getCollectionAllongementPra();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterAllongementPra((AllongementPra)objet);
    }
  }
  
  public void clearCollectionAllongementPra()
  {
    getCollectionModifiableAllongementPra().clear();
    ((ValidationProduitPC)getPC()).getCollectionAllongementPra().clear();
  }
  
  private final Collection getCollectionModifiableActiviteParticipante()
  {
    Iterator itCollectionPC;
    if (m_listeActivitesParticipantes == null)
    {
      m_listeActivitesParticipantes = new ArrayList();
      for (itCollectionPC = ((ValidationProduitPC)getPC()).getCollectionActiviteParticipante().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeActivitesParticipantes.add(currentOM);
      }
    }
    return m_listeActivitesParticipantes;
  }
  
  public Collection getCollectionActiviteParticipante()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableActiviteParticipante());
  }
  
  public List getListActiviteParticipante()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableActiviteParticipante());
  }
  
  public void remplacerCollectionActiviteParticipante(Collection p_collectionACopier)
  {
    clearCollectionActiviteParticipante();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      ActiviteParticipante objet = (ActiviteParticipante)i.next();
      ajouterActiviteParticipante(objet);
    }
  }
  
  public void supprimerSousCollectionActiviteParticipante(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      ActiviteParticipante objet = (ActiviteParticipante)i.next();
      supprimerActiviteParticipante(objet);
    }
  }
  
  public void ajouterActiviteParticipante(ActiviteParticipante p_activitesParticipantes)
    throws NullPointerException
  {
    if (p_activitesParticipantes == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_activitesParticipantes ne devrait pas être nul.", p_activitesParticipantes);
    }
    getCollectionModifiableActiviteParticipante().add(p_activitesParticipantes);
    ((ValidationProduitPC)getPC()).ajouterActiviteParticipante(p_activitesParticipantes.getPC());
  }
  
  public void supprimerActiviteParticipante(ActiviteParticipante p_activitesParticipantes)
    throws NullPointerException
  {
    if (p_activitesParticipantes == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_activitesParticipantes ne devrait pas être nul.", p_activitesParticipantes);
    }
    getCollectionModifiableActiviteParticipante().remove(p_activitesParticipantes);
    ((ValidationProduitPC)getPC()).supprimerActiviteParticipante(p_activitesParticipantes.getPC());
  }
  
  public void recopierCollectionActiviteParticipanteVers(ObjetMetierSpec p_copie)
  {
    JustificationAffiliationGen copie = (JustificationAffiliationGen)p_copie;
    Collection listeACopier = getCollectionActiviteParticipante();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterActiviteParticipante((ActiviteParticipante)objet);
    }
  }
  
  public void clearCollectionActiviteParticipante()
  {
    getCollectionModifiableActiviteParticipante().clear();
    ((ValidationProduitPC)getPC()).getCollectionActiviteParticipante().clear();
  }
  
  private final Collection getCollectionModifiableAssimilation()
  {
    Iterator itCollectionPC;
    if (m_listeAffiliationsAssimilees == null)
    {
      m_listeAffiliationsAssimilees = new ArrayList();
      for (itCollectionPC = ((ValidationProduitPC)getPC()).getCollectionAssimilation().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeAffiliationsAssimilees.add(currentOM);
      }
    }
    return m_listeAffiliationsAssimilees;
  }
  
  public Collection getCollectionAssimilation()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableAssimilation());
  }
  
  public List getListAssimilation()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableAssimilation());
  }
  
  public void remplacerCollectionAssimilation(Collection p_collectionACopier)
  {
    clearCollectionAssimilation();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      AffiliationAssimilee objet = (AffiliationAssimilee)i.next();
      ajouterAssimilation(objet);
    }
  }
  
  public void supprimerSousCollectionAssimilation(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      AffiliationAssimilee objet = (AffiliationAssimilee)i.next();
      supprimerAssimilation(objet);
    }
  }
  
  public void ajouterAssimilation(AffiliationAssimilee p_affiliationsAssimilees)
    throws NullPointerException
  {
    if (p_affiliationsAssimilees == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_affiliationsAssimilees ne devrait pas être nul.", p_affiliationsAssimilees);
    }
    getCollectionModifiableAssimilation().add(p_affiliationsAssimilees);
    ((ValidationProduitPC)getPC()).ajouterAssimilation(p_affiliationsAssimilees.getPC());
  }
  
  public void supprimerAssimilation(AffiliationAssimilee p_affiliationsAssimilees)
    throws NullPointerException
  {
    if (p_affiliationsAssimilees == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_affiliationsAssimilees ne devrait pas être nul.", p_affiliationsAssimilees);
    }
    getCollectionModifiableAssimilation().remove(p_affiliationsAssimilees);
    ((ValidationProduitPC)getPC()).supprimerAssimilation(p_affiliationsAssimilees.getPC());
  }
  
  public void recopierCollectionAssimilationVers(ObjetMetierSpec p_copie)
  {
    JustificationAffiliationGen copie = (JustificationAffiliationGen)p_copie;
    Collection listeACopier = getCollectionAssimilation();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterAssimilation((AffiliationAssimilee)objet);
    }
  }
  
  public void clearCollectionAssimilation()
  {
    getCollectionModifiableAssimilation().clear();
    ((ValidationProduitPC)getPC()).getCollectionAssimilation().clear();
  }
  
  private final Collection getCollectionModifiableAffiliationSupplementaire()
  {
    Iterator itCollectionPC;
    if (m_listeAffiliationsSupplementaires == null)
    {
      m_listeAffiliationsSupplementaires = new ArrayList();
      for (itCollectionPC = ((ValidationProduitPC)getPC()).getCollectionAffiliationSupplementaire().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeAffiliationsSupplementaires.add(currentOM);
      }
    }
    return m_listeAffiliationsSupplementaires;
  }
  
  public Collection getCollectionAffiliationSupplementaire()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableAffiliationSupplementaire());
  }
  
  public List getListAffiliationSupplementaire()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableAffiliationSupplementaire());
  }
  
  public void remplacerCollectionAffiliationSupplementaire(Collection p_collectionACopier)
  {
    clearCollectionAffiliationSupplementaire();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      AffiliationSupplementaire objet = (AffiliationSupplementaire)i.next();
      ajouterAffiliationSupplementaire(objet);
    }
  }
  
  public void supprimerSousCollectionAffiliationSupplementaire(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      AffiliationSupplementaire objet = (AffiliationSupplementaire)i.next();
      supprimerAffiliationSupplementaire(objet);
    }
  }
  
  public void ajouterAffiliationSupplementaire(AffiliationSupplementaire p_affiliationsSupplementaires)
    throws NullPointerException
  {
    if (p_affiliationsSupplementaires == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_affiliationsSupplementaires ne devrait pas être nul.", p_affiliationsSupplementaires);
    }
    getCollectionModifiableAffiliationSupplementaire().add(p_affiliationsSupplementaires);
    ((ValidationProduitPC)getPC()).ajouterAffiliationSupplementaire(p_affiliationsSupplementaires.getPC());
  }
  
  public void supprimerAffiliationSupplementaire(AffiliationSupplementaire p_affiliationsSupplementaires)
    throws NullPointerException
  {
    if (p_affiliationsSupplementaires == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_affiliationsSupplementaires ne devrait pas être nul.", p_affiliationsSupplementaires);
    }
    getCollectionModifiableAffiliationSupplementaire().remove(p_affiliationsSupplementaires);
    ((ValidationProduitPC)getPC()).supprimerAffiliationSupplementaire(p_affiliationsSupplementaires.getPC());
  }
  
  public void recopierCollectionAffiliationSupplementaireVers(ObjetMetierSpec p_copie)
  {
    JustificationAffiliationGen copie = (JustificationAffiliationGen)p_copie;
    Collection listeACopier = getCollectionAffiliationSupplementaire();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterAffiliationSupplementaire((AffiliationSupplementaire)objet);
    }
  }
  
  public void clearCollectionAffiliationSupplementaire()
  {
    getCollectionModifiableAffiliationSupplementaire().clear();
    ((ValidationProduitPC)getPC()).getCollectionAffiliationSupplementaire().clear();
  }
  
  private final Collection getCollectionModifiablePeriodeElementaireAffiliation()
  {
    Iterator itCollectionPC;
    if (m_listePeriodesElementairesAffiliation == null)
    {
      m_listePeriodesElementairesAffiliation = new ArrayList();
      for (itCollectionPC = ((ValidationProduitPC)getPC()).getCollectionPeriodeElementaireAffiliation().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listePeriodesElementairesAffiliation.add(currentOM);
      }
    }
    return m_listePeriodesElementairesAffiliation;
  }
  
  public Collection getCollectionPeriodeElementaireAffiliation()
  {
    return Collections.unmodifiableCollection(getCollectionModifiablePeriodeElementaireAffiliation());
  }
  
  public List getListPeriodeElementaireAffiliation()
  {
    return Collections.unmodifiableList((List)getCollectionModifiablePeriodeElementaireAffiliation());
  }
  
  public void remplacerCollectionPeriodeElementaireAffiliation(Collection p_collectionACopier)
  {
    clearCollectionPeriodeElementaireAffiliation();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      PeriodeElementaireAffiliation objet = (PeriodeElementaireAffiliation)i.next();
      ajouterPeriodeElementaireAffiliation(objet);
    }
  }
  
  public void supprimerSousCollectionPeriodeElementaireAffiliation(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      PeriodeElementaireAffiliation objet = (PeriodeElementaireAffiliation)i.next();
      supprimerPeriodeElementaireAffiliation(objet);
    }
  }
  
  public void ajouterPeriodeElementaireAffiliation(PeriodeElementaireAffiliation p_periodesElementairesAffiliation)
    throws NullPointerException
  {
    if (p_periodesElementairesAffiliation == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_periodesElementairesAffiliation ne devrait pas être nul.", p_periodesElementairesAffiliation);
    }
    getCollectionModifiablePeriodeElementaireAffiliation().add(p_periodesElementairesAffiliation);
    ((ValidationProduitPC)getPC()).ajouterPeriodeElementaireAffiliation(p_periodesElementairesAffiliation.getPC());
  }
  
  public void supprimerPeriodeElementaireAffiliation(PeriodeElementaireAffiliation p_periodesElementairesAffiliation)
    throws NullPointerException
  {
    if (p_periodesElementairesAffiliation == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_periodesElementairesAffiliation ne devrait pas être nul.", p_periodesElementairesAffiliation);
    }
    getCollectionModifiablePeriodeElementaireAffiliation().remove(p_periodesElementairesAffiliation);
    ((ValidationProduitPC)getPC()).supprimerPeriodeElementaireAffiliation(p_periodesElementairesAffiliation.getPC());
  }
  
  public void recopierCollectionPeriodeElementaireAffiliationVers(ObjetMetierSpec p_copie)
  {
    JustificationAffiliationGen copie = (JustificationAffiliationGen)p_copie;
    Collection listeACopier = getCollectionPeriodeElementaireAffiliation();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterPeriodeElementaireAffiliation((PeriodeElementaireAffiliation)objet);
    }
  }
  
  public void clearCollectionPeriodeElementaireAffiliation()
  {
    getCollectionModifiablePeriodeElementaireAffiliation().clear();
    ((ValidationProduitPC)getPC()).getCollectionPeriodeElementaireAffiliation().clear();
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    for (Iterator iter = getCollectionAllongementPra().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionActiviteParticipante().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionAssimilation().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionAffiliationSupplementaire().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
    for (Iterator iter = getCollectionPeriodeElementaireAffiliation().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
  }
  
  public void initEnProfondeur()
    throws TechniqueException
  {
    for (Iterator iter = getCollectionAllongementPra().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if (item != null) {
        DomManager.supprimer(item);
      }
    }
    clearCollectionAllongementPra();
    for (Iterator iter = getCollectionActiviteParticipante().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if (item != null) {
        DomManager.supprimer(item);
      }
    }
    clearCollectionActiviteParticipante();
    for (Iterator iter = getCollectionAssimilation().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if (item != null) {
        DomManager.supprimer(item);
      }
    }
    clearCollectionAssimilation();
    for (Iterator iter = getCollectionAffiliationSupplementaire().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if (item != null) {
        DomManager.supprimer(item);
      }
    }
    clearCollectionAffiliationSupplementaire();
    for (Iterator iter = getCollectionPeriodeElementaireAffiliation().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if (item != null) {
        DomManager.supprimer(item);
      }
    }
    clearCollectionPeriodeElementaireAffiliation();
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     JustificationAffiliationGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */