package fr.unedic.cali.asu.spe02.p03.liquidation.dom.gen;

import fr.unedic.archi.commun.exception.TechniqueException;
import fr.unedic.archi.commun.lang.ExceptionUtil;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationReductionSalaireMoisCivil;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.spec.ConstitutionElementsAbstraitPC;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.ContexteSuppressionEnProfondeur;
import fr.unedic.transverse.dom.spec.DomGenSpec;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public abstract class JustificationReductionSalaireGen
  implements DomGenSpec
{
  protected transient DomPCSpec m_constitutionElementsAbstraitPC;
  private Collection m_listeMoisCivils;
  
  public JustificationReductionSalaireGen(DomPCSpec p_pc)
  {
    setPC(p_pc);
  }
  
  public JustificationReductionSalaireGen() {}
  
  public DomPCSpec getPC()
  {
    return m_constitutionElementsAbstraitPC;
  }
  
  public Object getGenericPC()
  {
    return getPC();
  }
  
  public void setPC(DomPCSpec p_constitutionElementsAbstraitPC)
  {
    m_constitutionElementsAbstraitPC = p_constitutionElementsAbstraitPC;
  }
  
  private final Collection getCollectionModifiableMoisCivils()
  {
    Iterator itCollectionPC;
    if (m_listeMoisCivils == null)
    {
      m_listeMoisCivils = new ArrayList();
      for (itCollectionPC = ((ConstitutionElementsAbstraitPC)getPC()).getCollectionMoisCivils().iterator(); itCollectionPC.hasNext();)
      {
        DomPCSpec currentPC = (DomPCSpec)itCollectionPC.next();
        Object currentOM = currentPC.createOM();
        m_listeMoisCivils.add(currentOM);
      }
    }
    return m_listeMoisCivils;
  }
  
  public Collection getCollectionMoisCivils()
  {
    return Collections.unmodifiableCollection(getCollectionModifiableMoisCivils());
  }
  
  public List getListMoisCivils()
  {
    return Collections.unmodifiableList((List)getCollectionModifiableMoisCivils());
  }
  
  public void remplacerCollectionMoisCivils(Collection p_collectionACopier)
  {
    clearCollectionMoisCivils();
    for (Iterator i = p_collectionACopier.iterator(); i.hasNext();)
    {
      JustificationReductionSalaireMoisCivil objet = (JustificationReductionSalaireMoisCivil)i.next();
      ajouterMoisCivils(objet);
    }
  }
  
  public void supprimerSousCollectionMoisCivils(Collection p_collectionASupprimer)
  {
    for (Iterator i = p_collectionASupprimer.iterator(); i.hasNext();)
    {
      JustificationReductionSalaireMoisCivil objet = (JustificationReductionSalaireMoisCivil)i.next();
      supprimerMoisCivils(objet);
    }
  }
  
  public void ajouterMoisCivils(JustificationReductionSalaireMoisCivil p_moisCivilsJustificationReductionSalaire)
    throws NullPointerException
  {
    if (p_moisCivilsJustificationReductionSalaire == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_moisCivilsJustificationReductionSalaire ne devrait pas être nul.", p_moisCivilsJustificationReductionSalaire);
    }
    getCollectionModifiableMoisCivils().add(p_moisCivilsJustificationReductionSalaire);
    ((ConstitutionElementsAbstraitPC)getPC()).ajouterMoisCivils(p_moisCivilsJustificationReductionSalaire.getPC());
  }
  
  public void supprimerMoisCivils(JustificationReductionSalaireMoisCivil p_moisCivilsJustificationReductionSalaire)
    throws NullPointerException
  {
    if (p_moisCivilsJustificationReductionSalaire == null) {
      ExceptionUtil.assertInternalNotNull("Le paramètre p_moisCivilsJustificationReductionSalaire ne devrait pas être nul.", p_moisCivilsJustificationReductionSalaire);
    }
    getCollectionModifiableMoisCivils().remove(p_moisCivilsJustificationReductionSalaire);
    ((ConstitutionElementsAbstraitPC)getPC()).supprimerMoisCivils(p_moisCivilsJustificationReductionSalaire.getPC());
  }
  
  public void recopierCollectionMoisCivilsVers(ObjetMetierSpec p_copie)
  {
    JustificationReductionSalaireGen copie = (JustificationReductionSalaireGen)p_copie;
    Collection listeACopier = getCollectionMoisCivils();
    for (Iterator i = listeACopier.iterator(); i.hasNext();)
    {
      ObjetMetierSpec objet = ((ObjetMetierSpec)i.next()).copie();
      copie.ajouterMoisCivils((JustificationReductionSalaireMoisCivil)objet);
    }
  }
  
  public void clearCollectionMoisCivils()
  {
    getCollectionModifiableMoisCivils().clear();
    ((ConstitutionElementsAbstraitPC)getPC()).getCollectionMoisCivils().clear();
  }
  
  public void supprimerEnProfondeur(ContexteSuppressionEnProfondeur p_contexteSuppression)
    throws TechniqueException
  {
    p_contexteSuppression.addElementEnCoursDeSuppression(this);
    for (Iterator iter = getCollectionMoisCivils().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if ((item != null) && (!p_contexteSuppression.isAlreadyEnlistedForDeletion(item))) {
        DomManager.supprimer(item, p_contexteSuppression);
      }
    }
  }
  
  public void initEnProfondeur()
    throws TechniqueException
  {
    for (Iterator iter = getCollectionMoisCivils().iterator(); iter.hasNext();)
    {
      DomGenSpec item = (DomGenSpec)iter.next();
      if (item != null) {
        DomManager.supprimer(item);
      }
    }
    clearCollectionMoisCivils();
  }
  
  public void copieElements(ObjetMetierSpec p_copie) {}
}

/* Location:
 * Qualified Name:     JustificationReductionSalaireGen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */