package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.CalculAffiliationSupplementaireSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.JustifierAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ParametresAffiliationSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.spec.IncidentSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilActiviteSalarie;
import fr.unedic.util.Quantite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriodeConcrete;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class CalculAffiliationSupplementaire
  implements CalculAffiliationSupplementaireSpec
{
  private static final Quantite ZERO = CalculAppartenance.ZERO;
  
  public Quantite determinerAffiliationSupplementaire(IndividuSpec p_individu, ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
    throws CoucheLogiqueException
  {
    Quantite affiliationSupplementaire = ZERO;
    Quantite quantiteNonExecution = null;
    Quantite quantiteSuspension = null;
    Quantite quantiteMaterniteAdoptionAccidentTravail = null;
    if (p_comportementCalcul.isCalculAffiliationSupplementaireNonExecution())
    {
      verifierComportementPourNonExecution(p_comportementCalcul);
      if (p_comportementCalcul.getReglementCandidat().getLibelleCourt().equals("A8")) {
        quantiteNonExecution = determinerAppartenancePourNonExecution(p_comportementCalcul, p_justification, p_chronologies);
      }
    }
    if (p_comportementCalcul.isCalculAffiliationSupplementaireSuspension())
    {
      verifierComportementPourSuspension(p_comportementCalcul);
      
      quantiteSuspension = determinerAppartenancePourSuspension(p_individu, p_comportementCalcul, p_justification, p_chronologies);
    }
    if (p_comportementCalcul.isCalculAffiliationSupplementaireMaterniteAdoptionAccidentTravail())
    {
      verifierComportementMaterniteAdoptionAccidentTravail(p_comportementCalcul);
      
      quantiteMaterniteAdoptionAccidentTravail = calculerMaterniteAdoptionAccidentTravailSurChevauchementAffiliationA(p_comportementCalcul, p_justification, p_chronologies);
    }
    if (quantiteNonExecution != null) {
      affiliationSupplementaire = affiliationSupplementaire.ajouter(quantiteNonExecution);
    }
    if (quantiteSuspension != null) {
      affiliationSupplementaire = affiliationSupplementaire.ajouter(quantiteSuspension);
    }
    if (quantiteMaterniteAdoptionAccidentTravail != null) {
      affiliationSupplementaire = affiliationSupplementaire.ajouter(quantiteMaterniteAdoptionAccidentTravail);
    }
    return affiliationSupplementaire;
  }
  
  private Quantite determinerAppartenancePourSuspension(IndividuSpec p_individu, ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
  {
    ChronologiePeriodes chronoPeriodesAssimilables = new ChronologiePeriodes();
    
    ParametresAffiliationSpec parametresAffiliation = p_comportementCalcul.getOutilParametreAffiliation();
    JustifierAffiliationSpec justifierAffiliation = p_comportementCalcul.getOutilJustifierAffiliation();
    
    Chronologie chronoAffiliationSuspension = (Chronologie)p_chronologies.get("chronoAffiSuspension");
    
    Iterator itChronoSuspension = chronoAffiliationSuspension.iterer();
    while (itChronoSuspension.hasNext())
    {
      IncidentSpec incident = (IncidentSpec)itChronoSuspension.next();
      if (estUnCongesSabbatiqueOuCongesPourCreationEntreprise(incident))
      {
        chronoPeriodesAssimilables.ajouter(new ObjetChronoPeriodeConcrete(incident.getPeriode()));
      }
      else
      {
        Chronologie chronoActivitesHorsChampApplication = p_comportementCalcul.getOutilConstructionChronologie().determinerChronologieActiviteExcluesDuChampApplication(p_individu, incident.getPeriode());
        if ((chronoActivitesHorsChampApplication == null) || (chronoActivitesHorsChampApplication.estVide())) {
          chronoPeriodesAssimilables.ajouter(new ObjetChronoPeriodeConcrete(incident.getPeriode()));
        } else {
          determinerListePeriodesAvecChevauchement(incident, chronoActivitesHorsChampApplication, chronoPeriodesAssimilables);
        }
      }
    }
    Quantite quantiteAffiliationSuspension = ZERO;
    if ((chronoPeriodesAssimilables != null) && (!chronoPeriodesAssimilables.estVide()))
    {
      int nombreJoursARetenir = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(chronoPeriodesAssimilables, p_comportementCalcul.getPeriodeRecherche());
      
      quantiteAffiliationSuspension = parametresAffiliation.calculerQuantiteHeureSuspension(nombreJoursARetenir);
      
      justifierAffiliation.ajouterAffiliationSupplementaire(p_justification, 9, quantiteAffiliationSuspension);
    }
    return quantiteAffiliationSuspension;
  }
  
  private void determinerListePeriodesAvecChevauchement(IncidentSpec p_incident, Chronologie p_chronoActivitesHorsChampApplication, Chronologie p_chronoPeriodesAssimilables)
  {
    ChronologiePeriodes chronoPeriodesAvecActivitesHorsChamp = new ChronologiePeriodes();
    Iterator itChronoPeriodeHorsChamp = p_chronoActivitesHorsChampApplication.iterer();
    while (itChronoPeriodeHorsChamp.hasNext())
    {
      Temporel activiteHorsChamp = (Temporel)itChronoPeriodeHorsChamp.next();
      Periode periodeHorsChamp = new Periode(activiteHorsChamp.getDateDebut(), activiteHorsChamp.getDateFin());
      Periode periodeIntersection = periodeHorsChamp.periodeIntersection(p_incident.getPeriode());
      if (periodeIntersection != null) {
        chronoPeriodesAvecActivitesHorsChamp.ajouter(new ObjetChronoPeriodeConcrete(periodeIntersection));
      }
    }
    List listePeriodeSansChevauchement = OutilPeriodeAffiliation.determinerPeriodesSansChevauchement(chronoPeriodesAvecActivitesHorsChamp, p_incident.getPeriode());
    
    Iterator itPeriodeSansChevauchement = listePeriodeSansChevauchement.iterator();
    while (itPeriodeSansChevauchement.hasNext())
    {
      Periode periode = (Periode)itPeriodeSansChevauchement.next();
      
      p_chronoPeriodesAssimilables.ajouter(new ObjetChronoPeriodeConcrete(periode));
    }
  }
  
  private boolean estUnCongesSabbatiqueOuCongesPourCreationEntreprise(IncidentSpec p_incident)
  {
    return (p_incident.getNature() == 11) || (p_incident.getNature() == 10);
  }
  
  private Quantite determinerAppartenancePourNonExecution(ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
  {
    ChronologiePeriodes chronoPeriodesNonExecution = new ChronologiePeriodes();
    
    ParametresAffiliationSpec parametresAffiliation = p_comportementCalcul.getOutilParametreAffiliation();
    JustifierAffiliationSpec justifierAffiliation = p_comportementCalcul.getOutilJustifierAffiliation();
    
    Chronologie chronoAffiliationBase = (Chronologie)p_chronologies.get("chronoAffiBase");
    Chronologie chronoAffiliationNonExecution = (Chronologie)p_chronologies.get("chronoAffiNonExecution");
    
    Iterator itChronoNonExecution = chronoAffiliationNonExecution.iterer();
    while (itChronoNonExecution.hasNext())
    {
      ActiviteSalarie activiteSalarieAvecNonExecution = (ActiviteSalarie)itChronoNonExecution.next();
      
      Periode periodeNonExecution = OutilActiviteSalarie.getInstance().determinerPeriodeNonExecution(activiteSalarieAvecNonExecution);
      
      ChronologiePeriodes chronoPeriodesAvecActiviteAffiliationBase = new ChronologiePeriodes();
      
      Iterator itChronoAffiliationBase = chronoAffiliationBase.iterer();
      while (itChronoAffiliationBase.hasNext())
      {
        ActiviteSalarie activiteBase = (ActiviteSalarie)itChronoAffiliationBase.next();
        Periode periodeActiviteBase = new Periode(activiteBase.getDateDebut(), determinerDateFinActivite(activiteBase));
        if ((!activiteBase.equals(activiteSalarieAvecNonExecution)) && (periodeActiviteBase.chevauche(periodeNonExecution)))
        {
          Periode periodeIntersection = periodeActiviteBase.periodeIntersection(periodeNonExecution);
          if (periodeIntersection != null) {
            chronoPeriodesAvecActiviteAffiliationBase.ajouter(new ObjetChronoPeriodeConcrete(periodeIntersection));
          }
        }
      }
      if (chronoPeriodesAvecActiviteAffiliationBase.estVide())
      {
        chronoPeriodesNonExecution.ajouter(new ObjetChronoPeriodeConcrete(periodeNonExecution));
      }
      else
      {
        List listePeriodeSansChevauchement = OutilPeriodeAffiliation.determinerPeriodesSansChevauchement(chronoPeriodesAvecActiviteAffiliationBase, periodeNonExecution);
        
        Iterator itPeriodeSansChevauchement = listePeriodeSansChevauchement.iterator();
        while (itPeriodeSansChevauchement.hasNext())
        {
          Periode periodeNonExecutionPriseEnCompte = (Periode)itPeriodeSansChevauchement.next();
          
          chronoPeriodesNonExecution.ajouter(new ObjetChronoPeriodeConcrete(periodeNonExecutionPriseEnCompte));
        }
      }
    }
    Quantite quantiteAffiliationNonExecution = ZERO;
    if ((chronoPeriodesNonExecution != null) && (!chronoPeriodesNonExecution.estVide()))
    {
      int nombreJoursARetenir = OutilPeriodeAffiliation.determinerNombreJoursChronoApresFusionPeriode(chronoPeriodesNonExecution, p_comportementCalcul.getPeriodeRecherche());
      
      quantiteAffiliationNonExecution = parametresAffiliation.calculerQuantiteHeureNonExecution(nombreJoursARetenir);
      
      justifierAffiliation.ajouterAffiliationSupplementaire(p_justification, 8, quantiteAffiliationNonExecution);
    }
    return quantiteAffiliationNonExecution;
  }
  
  private Quantite calculerMaterniteAdoptionAccidentTravailSurChevauchementAffiliationA(ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Map p_chronologies)
  {
    Chronologie chronoPourAffiliationSupMaterniteAdoptionAccidentTravail = (Chronologie)p_chronologies.get("chronoAffiMaterAdoptionAccTravail");
    
    Chronologie chronoActivitesAffiliationBase = (Chronologie)p_chronologies.get("chronoAffiBase");
    
    return calculerSuspensionSurChevauchementAffiliationA(p_comportementCalcul, p_justification, chronoActivitesAffiliationBase, chronoPourAffiliationSupMaterniteAdoptionAccidentTravail);
  }
  
  protected Quantite calculerSuspensionSurChevauchementAffiliationA(ComportementAffiliationSpec p_comportementCalcul, JustificationAffiliation p_justification, Chronologie p_chronologieAffiliationBase, Chronologie p_chronologieAffiliationAAssimiler)
  {
    Quantite quantiteTotalHeure = ZERO;
    if ((p_chronologieAffiliationAAssimiler != null) && (!p_chronologieAffiliationAAssimiler.estVide()) && (p_chronologieAffiliationBase != null) && (!p_chronologieAffiliationBase.estVide()))
    {
      ParametresAffiliationSpec parametresAffiliation = p_comportementCalcul.getOutilParametreAffiliation();
      JustifierAffiliationSpec justifierAffiliation = p_comportementCalcul.getOutilJustifierAffiliation();
      
      Chronologie chronoActiviteBaseSansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(p_chronologieAffiliationBase).fusionnerChevauchementPeriodes();
      
      Chronologie chronoAffiliationSupAAssimilerSansChevauchement = OutilPeriodeAffiliation.construireChronologiePeriode(p_chronologieAffiliationAAssimiler).fusionnerChevauchementPeriodes();
      
      List listePeriodesAvecChevauchement = OutilPeriodeAffiliation.determinerPeriodesAvecChevauchement(chronoAffiliationSupAAssimilerSansChevauchement, chronoActiviteBaseSansChevauchement);
      for (int i = 0; i < listePeriodesAvecChevauchement.size(); i++)
      {
        Periode periodeCourante = (Periode)listePeriodesAvecChevauchement.get(i);
        
        Periode periodeAffiliationSupplementaireDansPRA = periodeCourante.periodeIntersection(p_comportementCalcul.getPeriodeRecherche());
        if (periodeAffiliationSupplementaireDansPRA != null)
        {
          int nombreJoursARetenir = periodeAffiliationSupplementaireDansPRA.getDuree();
          
          Quantite quantiteAffiliationSuspension = parametresAffiliation.calculerQuantiteHeureSuspension(nombreJoursARetenir);
          
          quantiteTotalHeure = quantiteTotalHeure.ajouter(quantiteAffiliationSuspension);
          
          justifierAffiliation.ajouterAffiliationSupplementaire(p_justification, 9, quantiteAffiliationSuspension);
        }
      }
    }
    return quantiteTotalHeure;
  }
  
  private Damj determinerDateFinActivite(ActiviteSalarie p_activite)
  {
    Damj premierJourNonExecution = OutilActiviteSalarie.getInstance().determinerPremierJourNonExecutionActivite(p_activite);
    if (premierJourNonExecution != null) {
      return premierJourNonExecution.veille();
    }
    return p_activite.getDateFin();
  }
  
  private void verifierComportementPourNonExecution(ComportementAffiliationSpec p_comportement)
    throws CoucheLogiqueException
  {
    if (p_comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (p_comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
    if (p_comportement.getReglementCandidat() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_REGLEMENT_CANDIDAT");
    }
  }
  
  private void verifierComportementPourSuspension(ComportementAffiliationSpec p_comportement)
    throws CoucheLogiqueException
  {
    if (p_comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (p_comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
  
  private void verifierComportementMaterniteAdoptionAccidentTravail(ComportementAffiliationSpec p_comportement)
    throws CoucheLogiqueException
  {
    if (p_comportement == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_AFFILIATION_ABSENT");
    }
    if (p_comportement.getPeriodeRecherche() == null) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_COMPORTEMENT_PERIODE_ABSENTE");
    }
  }
}

/* Location:
 * Qualified Name:     CalculAffiliationSupplementaire
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */