package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ComportementAffiliationSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.spec.ConstructionChronologieSpec;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAutreQueFormationCifCdd;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreCategorieEmploiParticulier;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreIncident;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNatureEvementPersonnel;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreNegation;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeE301;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeActiviteSalarieeHorsChamp;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeAvecReglement;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeFormationAssimilable;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeIndemnisationIjss;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodeNonExecutePourMotif;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesAttestees;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesSurFiltresExclusifs;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinApresDate;
import fr.unedic.cali.utilitaire.filtres.objetChronoPeriode.FiltreObjetChronoPeriodeFinAvantDate;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreChevauchePeriode;
import fr.unedic.util.temps.FiltreFinAvantOuCoincideAvecDate;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class ConstructionChronologie
  implements ConstructionChronologieSpec
{
  public static final String CHRONO_AFFILIATION_BASE = "chronoAffiBase";
  public static final String CHRONO_AFFILIATION_NON_EXECUTION = "chronoAffiNonExecution";
  public static final String CHRONO_AFFILIATION_SUSPENSION = "chronoAffiSuspension";
  public static final String CHRONO_AFFILIATION_ENSEIGNEMENT = "chronoAffiEnseignement";
  public static final String CHRONO_AFFILIATION_FORMATION = "chronoAffiFormation";
  public static final String CHRONO_AFFILIATION_MATERNITE_ADOPTION_ACCTRAVAIL = "chronoAffiMaterAdoptionAccTravail";
  public static final String CHRONO_MALADIE_DANS_PRA = "chronoMaladieDansPRA";
  
  public Map<String, Chronologie> determinerChronologies(IndividuSpec individu, ComportementAffiliationSpec comportement)
  {
    Map<String, Chronologie> resultat = new HashMap();
    
    Chronologie chronoCourante = determinerChronologiePourAffiliationBase(comportement);
    resultat.put("chronoAffiBase", chronoCourante);
    if (comportement.isCalculAffiliationSupplementaireNonExecution())
    {
      chronoCourante = determinerChronologiePourAffiliationSupplementaireNonExecution(comportement);
      
      resultat.put("chronoAffiNonExecution", chronoCourante);
    }
    if (comportement.isCalculAffiliationSupplementaireSuspension())
    {
      chronoCourante = determinerChronologiePourAffiliationSupplementaireSuspension(comportement);
      
      resultat.put("chronoAffiSuspension", chronoCourante);
    }
    if (comportement.isCalculAffiliationAssimilableEnseignement())
    {
      chronoCourante = determinerChronologiePourAssimilationEnseignants(comportement);
      
      resultat.put("chronoAffiEnseignement", chronoCourante);
    }
    if (comportement.isCalculAffiliationAssimilableFormation())
    {
      chronoCourante = determinerChronologiePourAssimilationFormation(comportement);
      
      resultat.put("chronoAffiFormation", chronoCourante);
    }
    if (comportement.isCalculAffiliationAssimilableMaterniteAdoptionAccidentTravail())
    {
      chronoCourante = determinerChronologiePourAssimilationMaterniteAdoptionAccidentTravail(comportement);
      
      resultat.put("chronoAffiMaterAdoptionAccTravail", chronoCourante);
    }
    chronoCourante = determinerActivitesAllongementPeriodeReference(individu, comportement);
    resultat.put("chronoMaladieDansPRA", chronoCourante);
    return resultat;
  }
  
  public Chronologie determinerChronologiePourAffiliationBase(ComportementAffiliationSpec comportement)
  {
    FiltrePeriodesSurFiltresExclusifs filtreOUAPR02p08 = new FiltrePeriodesSurFiltresExclusifs();
    filtreOUAPR02p08.ajouterFiltre(new FiltreActiviteSalarie());
    filtreOUAPR02p08.ajouterFiltre(new FiltrePeriodesAttestees());
    filtreOUAPR02p08.ajouterFiltre(new FiltreNegation(new FiltreActiviteSalarieAutreQueFormationCifCdd()));
    filtreOUAPR02p08.ajouterFiltre(new FiltrePeriodeActiviteSalarieeE301());
    
    FiltresTemporel filtreETAPR0208 = new FiltresTemporel();
    filtreETAPR0208.ajouterFiltre(new FiltreObjetChronoPeriodeFinApresDate(comportement.getPeriodeRecherche().getDebut().veille(), "MVS"));
    
    filtreETAPR0208.ajouterFiltre(new FiltreObjetChronoPeriodeFinAvantDate(comportement.getPeriodeRecherche().getFin().lendemain(), "MVS"));
    
    filtreETAPR0208.ajouterFiltre(new FiltrePeriodeAvecReglement(comportement.getListeReglementPrisEnCompte()));
    filtreETAPR0208.ajouterFiltre(new FiltreNegation(new FiltrePeriodeActiviteSalarieeHorsChamp()));
    
    FiltresTemporel filtrePourCalculAffiliationBase = new FiltresTemporel();
    filtrePourCalculAffiliationBase.ajouterFiltre(filtreOUAPR02p08);
    filtrePourCalculAffiliationBase.ajouterFiltre(filtreETAPR0208);
    
    return comportement.getChronologieActivitesParticipantes().copier(filtrePourCalculAffiliationBase);
  }
  
  public Chronologie determinerChronologiePourAffiliationSupplementaireSuspension(ComportementAffiliationSpec comportement)
  {
    Chronologie chronologiePourAffiliationSupplementaireSuspension = new ChronologiePeriodes();
    
    FiltreChevauchePeriode filtreChevauchePeriode = new FiltreChevauchePeriode(comportement.getPeriodeRecherche());
    
    Chronologie chronoBaseDetermination = determinerChronologiePourAffiliationBase(comportement);
    Iterator<?> it = chronoBaseDetermination.iterer();
    while (it.hasNext())
    {
      ActiviteSalarie activite = (ActiviteSalarie)it.next();
      Chronologie chronoPeriodeIncidentPourActivite = activite.getListePeriodesIncident();
      chronologiePourAffiliationSupplementaireSuspension.ajouter(chronoPeriodeIncidentPourActivite.copier(filtreChevauchePeriode));
    }
    return chronologiePourAffiliationSupplementaireSuspension;
  }
  
  public Chronologie determinerChronologiePourAffiliationSupplementaireNonExecution(ComportementAffiliationSpec comportement)
  {
    List<Reglement> listePeriodesAcceptees = new ArrayList();
    Reglement annexe8 = recupererReglementAnnexe8(comportement);
    if (annexe8 != null) {
      listePeriodesAcceptees.add(annexe8);
    }
    FiltrePeriodeNonExecutePourMotif filtreNonExecutionPourMotif = new FiltrePeriodeNonExecutePourMotif();
    filtreNonExecutionPourMotif.ajouterMotifNonExecution(35);
    filtreNonExecutionPourMotif.ajouterMotifNonExecution(3);
    
    FiltresTemporel filtrePourCalculAffiSupplNonExecution = new FiltresTemporel();
    filtrePourCalculAffiSupplNonExecution.ajouterFiltre(new FiltreFinDansBornes(comportement.getPeriodeRecherche()));
    filtrePourCalculAffiSupplNonExecution.ajouterFiltre(new FiltrePeriodeAvecReglement(listePeriodesAcceptees));
    filtrePourCalculAffiSupplNonExecution.ajouterFiltre(filtreNonExecutionPourMotif);
    
    Chronologie chronologiePourAffiliationSupplementaireNonExecution = comportement.getChronologieActivitesParticipantes().copier(filtrePourCalculAffiSupplNonExecution);
    
    return chronologiePourAffiliationSupplementaireNonExecution;
  }
  
  private Reglement recupererReglementAnnexe8(ComportementAffiliationSpec comportement)
  {
    Reglement annexe8 = null;
    List<Reglement> listeReglements = comportement.getListeReglementPrisEnCompte();
    for (Reglement reglement : listeReglements) {
      if (reglement.getNomReglement().equals("A8"))
      {
        annexe8 = reglement;
        break;
      }
    }
    return annexe8;
  }
  
  public Chronologie determinerChronologiePourAssimilationEnseignants(ComportementAffiliationSpec comportement)
  {
    FiltreCategorieEmploiParticulier filtreEmploiParticulier = new FiltreCategorieEmploiParticulier();
    filtreEmploiParticulier.ajouterCategorieEmploi(31);
    
    FiltresTemporel fitreChronoAssimilationEnseignants = new FiltresTemporel();
    fitreChronoAssimilationEnseignants.ajouterFiltre(new FiltreChevauchePeriode(comportement.getPeriodeRecherche()));
    fitreChronoAssimilationEnseignants.ajouterFiltre(filtreEmploiParticulier);
    
    Chronologie chronologiePourAssimilationEnseignants = comportement.getChronologieActivitesParticipantes().copier(fitreChronoAssimilationEnseignants);
    
    return chronologiePourAssimilationEnseignants;
  }
  
  public Chronologie determinerChronologiePourAssimilationFormation(ComportementAffiliationSpec comportement)
  {
    FiltresTemporel fitreChronoAssimilationFormation = new FiltresTemporel();
    fitreChronoAssimilationFormation.ajouterFiltre(new FiltreChevauchePeriode(comportement.getPeriodeRecherche()));
    fitreChronoAssimilationFormation.ajouterFiltre(new FiltrePeriodeFormationAssimilable());
    fitreChronoAssimilationFormation.ajouterFiltre(new FiltreFinAvantOuCoincideAvecDate(comportement.getPeriodeRecherche().getFin()));
    
    Chronologie chronologiePourAssimilationFormation = comportement.getChronologieActivitesParticipantes().copier(fitreChronoAssimilationFormation);
    
    return chronologiePourAssimilationFormation;
  }
  
  public Chronologie determinerChronologiePourAssimilationMaterniteAdoptionAccidentTravail(ComportementAffiliationSpec comportement)
  {
    FiltreNatureEvementPersonnel filtreNatureEvenementPersonnel = new FiltreNatureEvementPersonnel();
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(25);
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(26);
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(23);
    
    FiltresTemporel fitreChronoAssimilationMaterniteAdoptionAccidentTravail = new FiltresTemporel();
    fitreChronoAssimilationMaterniteAdoptionAccidentTravail.ajouterFiltre(new FiltreChevauchePeriode(comportement.getPeriodeRecherche()));
    fitreChronoAssimilationMaterniteAdoptionAccidentTravail.ajouterFiltre(new FiltreIncident());
    fitreChronoAssimilationMaterniteAdoptionAccidentTravail.ajouterFiltre(filtreNatureEvenementPersonnel);
    
    Chronologie chronologiePourAssimilationMaterniteAdoptionAccidentTravail = comportement.getChronologieActivitesParticipantes().copier(fitreChronoAssimilationMaterniteAdoptionAccidentTravail);
    
    return chronologiePourAssimilationMaterniteAdoptionAccidentTravail;
  }
  
  public Chronologie determinerChronologieActiviteExcluesDuChampApplication(IndividuSpec individu, Periode periode)
  {
    FiltresTemporel filtreActiviteHorsChamp = new FiltresTemporel();
    filtreActiviteHorsChamp.ajouterFiltre(new FiltrePeriodeActiviteSalarieeHorsChamp());
    filtreActiviteHorsChamp.ajouterFiltre(new FiltreChevauchePeriode(periode));
    
    Chronologie chronologieActivitesHorsChamp = recupererChronologiePourCalculAffiliation(individu).copier(filtreActiviteHorsChamp);
    
    return chronologieActivitesHorsChamp;
  }
  
  public Chronologie determinerActivitesAllongementPeriodeReference(IndividuSpec individu, ComportementAffiliationSpec comportement)
  {
    FiltreNatureEvementPersonnel filtreNatureEvenementPersonnel = new FiltreNatureEvementPersonnel();
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(22);
    filtreNatureEvenementPersonnel.ajouterNatureEvenementPersonnel(21);
    
    FiltresTemporel fitreChronoAllongementPeriodeReference = new FiltresTemporel();
    fitreChronoAllongementPeriodeReference.ajouterFiltre(new FiltrePeriodeIndemnisationIjss());
    fitreChronoAllongementPeriodeReference.ajouterFiltre(filtreNatureEvenementPersonnel);
    fitreChronoAllongementPeriodeReference.ajouterFiltre(new FiltreChevauchePeriode(comportement.getPeriodeRecherche()));
    
    Chronologie chronologieActivitesAllongementPeriodeReference = recupererChronologiePourCalculAffiliation(individu).copier(fitreChronoAllongementPeriodeReference);
    
    return chronologieActivitesAllongementPeriodeReference;
  }
  
  protected Chronologie recupererChronologiePourCalculAffiliation(IndividuSpec individu)
  {
    return individu.getChronoPeriodePasseProfessionnelLiquidation();
  }
}

/* Location:
 * Qualified Name:     ConstructionChronologie
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */