package fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation;

import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.dom.ObjetAlertesNonBloquantes;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.ObjetChronoPeriode;
import fr.unedic.util.temps.OutilOptimisationChronologie;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;

public class OutilPeriodeAffiliation
  implements OutilFonctionnel
{
  public static List decouperEnPeriodesElementaires(Periode periodeReference)
  {
    List listePeriodesElementaires = new ArrayList();
    ArrayList listeMoiscivils = periodeReference.decouperEnMoisCivils();
    Iterator it = listeMoiscivils.iterator();
    while (it.hasNext())
    {
      Periode periodeCourante = (Periode)it.next();
      PeriodeElementaireAffiliation periodeElementaire = PeriodeElementaireAffiliation.getInstance();
      periodeElementaire.setMois(periodeCourante);
      listePeriodesElementaires.add(periodeElementaire);
    }
    return listePeriodesElementaires;
  }
  
  public static int determinerNombreJoursChronoApresFusionPeriode(Chronologie chrono, Periode periode)
  {
    ChronologiePeriodes chronoPeriode = construireChronologiePeriode(chrono);
    int total = 0;
    if ((chronoPeriode != null) && (!chronoPeriode.estVide()))
    {
      ChronologiePeriodes chronoPeriodeFusion = chronoPeriode.fusionnerChevauchementPeriodes();
      Iterator<?> it = chronoPeriodeFusion.iterer();
      while (it.hasNext())
      {
        ObjetChronoPeriode objetPeriode = (ObjetChronoPeriode)it.next();
        Periode periodeCourante = new Periode(objetPeriode.getDateDebut(), objetPeriode.getDateFin());
        total += periode.inter(periodeCourante);
      }
    }
    return total;
  }
  
  public static int determinerNombreJoursChronoApresFusionPeriode(List listePeriode, Periode periode)
  {
    Iterator<?> itPeriodes = listePeriode.iterator();
    int total = 0;
    while (itPeriodes.hasNext())
    {
      Periode periodeSansChevauchement = (Periode)itPeriodes.next();
      
      total += periodeSansChevauchement.inter(periode);
    }
    return total;
  }
  
  public static ChronologiePeriodes construireChronologiePeriode(Chronologie chronoActivite)
  {
    if ((chronoActivite instanceof ChronologiePeriodes)) {
      return (ChronologiePeriodes)chronoActivite;
    }
    ChronologiePeriodes resultat = new ChronologiePeriodes();
    
    OutilOptimisationChronologie outilOptimisationChronologie = new OutilOptimisationChronologie(resultat);
    if (chronoActivite != null)
    {
      Iterator<?> it = chronoActivite.iterer();
      while (it.hasNext())
      {
        ObjetChronoPeriode periode = (ObjetChronoPeriode)it.next();
        
        outilOptimisationChronologie.ajouter(periode);
      }
    }
    return (ChronologiePeriodes)outilOptimisationChronologie.getChronologieTriee();
  }
  
  public static List<Periode> determinerPeriodesAvecChevauchement(Chronologie chrono1, Chronologie chrono2)
  {
    List<Periode> listePeriodesSansChevauchement = new ArrayList();
    if ((chrono1 != null) && (chrono2 != null))
    {
      chrono1.iterer();
      while (chrono1.encoreSuivant())
      {
        Temporel elementCourant1 = chrono1.elementSuivant();
        Periode periode1 = new Periode(elementCourant1.getDateDebut(), elementCourant1.getDateFin());
        chrono2.iterer();
        while (chrono2.encoreSuivant())
        {
          Temporel elementCourant2 = chrono2.elementSuivant();
          Periode periode2 = new Periode(elementCourant2.getDateDebut(), elementCourant2.getDateFin());
          Periode periodeInter = periode1.periodeIntersection(periode2);
          if (periodeInter != null) {
            listePeriodesSansChevauchement.add(periodeInter);
          }
        }
      }
    }
    return listePeriodesSansChevauchement;
  }
  
  public static void alimenterCollectionAlertesPNDS(Chronologie pnds, Collection collectionAlertesNonBloquante)
  {
    Iterator<?> iterPnds;
    if (collectionAlertesNonBloquante != null) {
      for (iterPnds = pnds.iterer(); iterPnds.hasNext();)
      {
        ObjetChronoPeriode pndsTemp = (ObjetChronoPeriode)iterPnds.next();
        ObjetAlertesNonBloquantes objetAlerteNonBloquante = new ObjetAlertesNonBloquantes(pndsTemp.getDateDebut(), pndsTemp.getDateFin(), 7);
        if (!collectionAlertesNonBloquante.contains(objetAlerteNonBloquante)) {
          collectionAlertesNonBloquante.add(objetAlerteNonBloquante);
        }
      }
    }
  }
  
  public static List<Periode> determinerPeriodesSansChevauchement(ChronologiePeriodes chrono, Periode periode)
  {
    ChronologiePeriodes chronoPeriodeFusion = null;
    if ((chrono != null) && (!chrono.estVide())) {
      chronoPeriodeFusion = chrono.fusionnerChevauchementPeriodes();
    }
    return determinerListePeriodesSansChevauchementPourChronoSansChevauchement(chronoPeriodeFusion, periode);
  }
  
  public static List<Periode> determinerListePeriodesSansChevauchementPourChronoSansChevauchement(ChronologiePeriodes chronologiesSansChevauchement, Periode periode)
  {
    List<Periode> listePeriodesSansChevauchement = new ArrayList();
    if ((chronologiesSansChevauchement != null) && (!chronologiesSansChevauchement.estVide()))
    {
      if (periode.inter(chronologiesSansChevauchement) == 0)
      {
        listePeriodesSansChevauchement.add(periode);
      }
      else
      {
        Iterator<?> it = chronologiesSansChevauchement.iterer();
        Periode periodeAAjouter = null;
        
        ObjetChronoPeriode premierElement = (ObjetChronoPeriode)it.next();
        if (periode.getDebut().estAvant(premierElement.getDateDebut()))
        {
          Periode periodeEntreElements = new Periode(periode.getDebut(), premierElement.getDateDebut().veille());
          periodeAAjouter = periodeEntreElements.periodeIntersection(periodeEntreElements);
          if (periodeAAjouter != null) {
            listePeriodesSansChevauchement.add(periodeAAjouter);
          }
        }
        Damj dateFinElementPrecedent = premierElement.getDateFin();
        while (it.hasNext())
        {
          ObjetChronoPeriode elementCourant = (ObjetChronoPeriode)it.next();
          if (dateFinElementPrecedent.estAvant(elementCourant.getDateDebut()))
          {
            Periode periodeEntreElements = new Periode(dateFinElementPrecedent.lendemain(), elementCourant.getDateDebut().veille());
            periodeAAjouter = periodeEntreElements.periodeIntersection(periode);
            if (periodeAAjouter != null) {
              listePeriodesSansChevauchement.add(periodeAAjouter);
            }
          }
          dateFinElementPrecedent = elementCourant.getDateFin();
        }
        if (dateFinElementPrecedent.estAvant(periode.getFin()))
        {
          Periode periodeEntreElements = new Periode(dateFinElementPrecedent.lendemain(), periode.getFin());
          periodeAAjouter = periodeEntreElements.periodeIntersection(periode);
          if (periodeAAjouter != null) {
            listePeriodesSansChevauchement.add(periodeAAjouter);
          }
        }
      }
    }
    else {
      listePeriodesSansChevauchement.add(periode);
    }
    return listePeriodesSansChevauchement;
  }
}

/* Location:
 * Qualified Name:     OutilPeriodeAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */