package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.dom.ConditionQuantiteAffiliationSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationDiffere;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Od;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsaffiliation.CalculAppartenance;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.autresdoms.ga.dom.ContratTravail;
import fr.unedic.cali.autresdoms.ga.dom.PeriodeMesureActivite;
import fr.unedic.cali.autresdoms.ga.dom.spec.SalarieSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.dom.pivot.Decision;
import fr.unedic.cali.dom.pivot.DemandePivot;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarie;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltrePeriodesLiquidables;
import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.FiltreFinDansBornes;
import fr.unedic.util.temps.FiltresTemporel;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import org.apache.commons.lang.StringUtils;

public class AlimentationBasePivot
{
  private static final String STRING_VIDE = "";
  public static final int READMISSION_DROIT_COURANT = 2;
  private static final int LONGUEUR_CODE_PAYS_ACTIVITE = 3;
  private static final int LONGUEUR_CODE_ACTIVITE_HORS_FRANCE = 2;
  
  public static AlimentationBasePivot getInstance()
  {
    return new AlimentationBasePivot();
  }
  
  public void alimenterDonneesProduit(DossierExamenSpec dossierExamen, DemandePivot demandePivot)
    throws ApplicativeException
  {
    Demande demandeAssurance = (Demande)dossierExamen.getDemande();
    
    Decision decisionPivot = demandePivot.getDecision();
    renseignerDecision(decisionPivot, demandeAssurance);
    
    fr.unedic.cali.dom.pivot.Attribution attributionPivot = demandePivot.getAttribution();
    if (attributionPivot != null) {
      renseignerAttribution(attributionPivot, demandeAssurance);
    }
    if (attributionPivot != null)
    {
      boolean alimenterMontantJournalier = true;
      
      boolean estUnAntecedent = "ASU_22".equals(demandeAssurance.getEvenementReferenceExamen().getTypeExamen());
      if (estUnAntecedent) {
        alimenterMontantJournalier = demandeAssurance.getSaisieAntecedent().getContexteDemande().intValue() != 4;
      }
      if (alimenterMontantJournalier) {
        alimenterMontantJournalierBrut(dossierExamen, attributionPivot);
      }
    }
  }
  
  protected void alimenterMontantJournalierBrut(DossierExamenSpec dossierExamen, fr.unedic.cali.dom.pivot.Attribution attributionPivot)
    throws ApplicativeException
  {
    fr.unedic.cali.asu.liquidation.outilsfonctionnels.AlimentationBasePivot.alimentationMontantAllocationJournaliereBrut(dossierExamen, attributionPivot);
  }
  
  private void renseignerAttribution(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande)
    throws ApplicativeException
  {
    renseignerDroitCourant(attribution, demande);
    
    renseignerDroitRetenu(attribution, demande);
  }
  
  private void alimenterCodeSousProduit(fr.unedic.cali.dom.pivot.Attribution attribution, Demande demande)
  {
    fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution decision = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution)demande.getDossierExamen();
    
    String codeSousProduitRetourne = decision.determinerCodeSousProduitPourSigma();
    
    attribution.setCodeSousProduitCourant(codeSousProduitRetourne);
    switch (decision.getNatureDecision())
    {
    case 10: 
    case 12: 
      attribution.setCodeSousProduitRetenu(codeSousProduitRetourne);
      break;
    case 3: 
    case 11: 
      if (decision.getAttributionPrecedente() != null)
      {
        AttributionSpec attributionPrec = decision.getAttributionPrecedente();
        attribution.setCodeSousProduitRetenu(attributionPrec.determinerCodeSousProduitPourSigma());
      }
      break;
    }
  }
  
  protected void renseignerDroitCourant(fr.unedic.cali.dom.pivot.Attribution attributionPivot, Demande demande)
    throws ApplicativeException
  {
    if ((demande.getDossierExamen() instanceof fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution))
    {
      fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution attributionDom = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution)demande.getDossierExamen();
      if ((attributionDom instanceof Od)) {
        attributionPivot.setPlus100trimestres(determineAuMoins100Trimestres(demande));
      }
      attributionPivot.setDateEffetAttribution(attributionDom.getConstitutionDateAttribution().getDateAttribution());
      
      attributionPivot.setPji(attributionDom.getConstitutionPointDepartIndemnisation().getPointDepartIndemnisation());
      if (attributionDom.getConstitutionReglementApplicable() != null) {
        attributionPivot.setReglementApplicableCourant(attributionDom.getConstitutionReglementApplicable().getReglement().getNomReglement().toUpperCase());
      }
      if ((attributionDom.getConstitutionDurees() != null) && (attributionDom.getConstitutionDurees().getDureeTheorique() != null)) {
        attributionPivot.setDureeTheoriqueDroitCourant(attributionDom.getConstitutionDurees().getDureeTheorique().getValeurEntiere());
      }
      if ((attributionDom.getConstitutionMontantsBruts() != null) && (attributionDom.getConstitutionMontantsBruts().getCapitalInitialBrut() != null)) {
        attributionPivot.setCapitalOdCourante(attributionDom.getConstitutionMontantsBruts().getCapitalInitialBrut().getValeur());
      }
      attributionPivot.setCapitalDroitPrecedentSp(determineCapitalPrecedentSp(demande));
      
      attributionPivot.setDateTheoriqueFinDroit(fr.unedic.cali.asu.outilsfonctionnels.AlimentationBasePivot.determineDateTheoriqueFinDroit(attributionDom));
      
      attributionPivot.setDateFinDelaiDecheance(determineDateFinDelaiDecheance(attributionPivot.getDateTheoriqueFinDroit()));
      
      ChronologiePeriodes chronoPeriodes = new ChronologiePeriodes();
      if (attributionDom.getConstitutionSalaireReference() != null)
      {
        boolean estClauseRattrapage = estContexteClauseRattrapage(demande);
        if (!estClauseRattrapage)
        {
          Collection<?> chronoPeriodesARetenir = attributionDom.getConstitutionSalaireReference().getCollectionActiviteSalarieParticipantSr();
          chronoPeriodes.ajouter(chronoPeriodesARetenir);
          
          BigDecimal nbJourDansPrc = new BigDecimal(DeterminationSalaireReference.determinerNbJoursEmploiDansPrc(demande.getDonneesTemporaires().getNbJourContratSurPraSpectacle(), attributionDom.getConstitutionSalaireReference().getPrc(), chronoPeriodes));
          
          attributionPivot.setNbJoursDiviseurSjrCourant(nbJourDansPrc);
          
          attributionPivot.setMontantSalaireReferenceSjrCourant(attributionDom.getConstitutionSalaireReference().getSalaireReferenceInitialPlafonne().getValeurMontant());
        }
        Periode periodePrc = attributionDom.getConstitutionSalaireReference().getPrc();
        attributionPivot.setDateDebutPrcDroitCourant(periodePrc.getDebut());
        attributionPivot.setDateFinPrcDroitCourant(periodePrc.getFin());
      }
      if (attributionDom.getConstitutionSalaireJournalierMoyen() != null)
      {
        attributionPivot.setMontantSjrCourantNonPlafonne(attributionDom.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenInitial().getValeurMontant());
        
        attributionPivot.setMontantSjrCourantPlafonne(attributionDom.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne().getValeurMontant());
      }
      if (attributionDom.getConstitutionNbHeuresTravaillees() != null)
      {
        attributionPivot.setNombreHeureTravailleEtendu(attributionDom.getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesEtendu().intValue());
        
        attributionPivot.setNbHeuresTravailleesA8A10SjrCourant(attributionDom.getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesPlafonne().intValue());
      }
      if (attributionDom.getConstitutionDelaisReport() != null)
      {
        attributionPivot.setNbJoursIccp(attributionDom.getConstitutionDelaisReport().getNbJoursCarenceStandard());
        
        attributionPivot.setUniteDureeIccp("C");
        
        attributionPivot.setDateDebutIccp(attributionDom.getConstitutionDelaisReport().getDebutCarenceStandard());
        
        attributionPivot.setDateFinIccp(attributionDom.getConstitutionDelaisReport().getTermeCarenceStandard());
        
        attributionPivot.setNbJoursIslr(attributionDom.getConstitutionDelaisReport().getNbJoursCarenceISLR());
        
        attributionPivot.setUniteDureeIslr("C");
        
        attributionPivot.setDateDebutIslr(attributionDom.getConstitutionDelaisReport().getDebutCarenceISLR());
        
        attributionPivot.setDateFinIslr(attributionDom.getConstitutionDelaisReport().getTermeCarenceISLR());
        
        attributionPivot.setNbJoursDiffere(attributionDom.getConstitutionDelaisReport().getNbJoursDelaiReport());
        
        attributionPivot.setUniteDureeDiffere("C");
        
        attributionPivot.setDateDebutDiffere(attributionDom.getConstitutionDelaisReport().getDebutDelaiReport());
        
        attributionPivot.setDateFinDiffere(attributionDom.getConstitutionDelaisReport().getTermeDelaiReport());
        if ((attributionDom.getConstitutionDelaisReport().getJustificationDiffere() != null) && (attributionDom.getConstitutionDelaisReport().getJustificationDiffere().getTotalSalairesNonPlafonnes() != null)) {
          attributionPivot.setMontantSalaireReferenceA10FNA(attributionDom.getConstitutionDelaisReport().getJustificationDiffere().getTotalSalairesNonPlafonnes().getValeurMontant());
        }
      }
      ValidationProduit validationProduitSpectacle = (ValidationProduit)((DossierAffecte)attributionDom.getDossierAffecte()).getValidationProduit();
      if (validationProduitSpectacle != null) {
        attributionPivot.setRangAllongementPRA(validationProduitSpectacle.getRangAllongement());
      }
      attributionPivot.setRegimeParticulier("");
      if ((attributionDom.getFaitGenerateur() != null) && (attributionDom.getFaitGenerateur().getPeriodeFaitGenerateur() != null) && (attributionDom.getFaitGenerateur().getPeriodeFaitGenerateur().isRegimeAlsaceMoselle())) {
        attributionPivot.setComplementSs("A");
      }
      alimenterCodesStatutFNA(demande.getFaitGenerateur(), attributionPivot);
      
      alimenterCodeSousProduit(attributionPivot, demande);
    }
  }
  
  protected boolean estContexteClauseRattrapage(Demande demande)
  {
    return (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ENTREECRA")) || (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ENCOURSCRA"));
  }
  
  private void alimenterCodesStatutFNA(FaitGenerateurSpec faitGenerateur, fr.unedic.cali.dom.pivot.Attribution attribution)
  {
    if ((faitGenerateur != null) && (faitGenerateur.getPeriodeFaitGenerateur() != null))
    {
      int pohf = faitGenerateur.getPeriodeFaitGenerateur().getContrat().getPohf();
      
      attribution.setCodePaysActivite(StringUtils.leftPad(Integer.toString(faitGenerateur.getPeriodeFaitGenerateur().getContrat().getPays()), 3, "0"));
      String pohfS;
      String pohfS;
      if (pohf != 0) {
        pohfS = StringUtils.leftPad(Integer.toString(pohf), 2, "0");
      } else {
        pohfS = "";
      }
      attribution.setCodeActiviteHorsFrance(pohfS);
    }
  }
  
  protected void renseignerDroitRetenu(fr.unedic.cali.dom.pivot.Attribution attributionPivot, Demande demande)
    throws CoucheLogiqueException
  {
    if ((demande.getDossierExamen() instanceof fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution))
    {
      fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution attributionDom = (fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution)demande.getDossierExamen();
      if (attributionDom.getConstitutionReglementApplicable() != null) {
        attributionPivot.setReglementApplicableRetenu(attributionDom.getConstitutionReglementApplicable().getReglement().getNomReglement().toUpperCase());
      }
      if (attributionDom.getNatureDecision() == 12)
      {
        attributionPivot.setFlagReadmission(2);
        
        attributionPivot.setMontantInitialCapitalMax(attributionDom.getConstitutionMontantsBruts().getMontantJournalierBrut().getValeurMontant());
      }
      attributionPivot.setCapitalOdPrecedente(BigDecimal.ZERO);
      if (attributionDom.getConstitutionDurees() != null) {
        attributionPivot.setDureeTheoriqueDroitRetenu(attributionDom.getConstitutionDurees().getDureeTheorique().getValeurEntiere());
      }
      if (attributionDom.getConstitutionSalaireReference() != null)
      {
        Periode periodePrc = attributionDom.getConstitutionSalaireReference().getPrc();
        attributionPivot.setFinPrcSjrRetenu(periodePrc.getFin());
      }
      if (attributionDom.getConstitutionSalaireJournalierMoyen() != null) {
        attributionPivot.setMontantSjrRetenuPlafonne(attributionDom.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenRevalorisePlafonne().getValeurMontant());
      }
    }
  }
  
  private void renseignerDecision(Decision decision, Demande demande)
    throws CoucheLogiqueException
  {
    DossierExamen dossierExamen = (DossierExamen)demande.getDossierExamen();
    
    renseigneAffiliation(decision, dossierExamen);
    
    renseignerDonneesPmc(decision, dossierExamen);
    
    renseignerCodeSousProduit(decision, demande);
  }
  
  private BigDecimal determineCapitalPrecedentSp(Demande demande)
  {
    Quantite qte = demande.getDonneesTemporaires().getCapitalReliquatSecteurPublic();
    return qte != null ? qte.getValeur() : null;
  }
  
  private Damj determineDateFinDelaiDecheance(Damj djiTheorique)
  {
    int troisAns = 3;
    Damj dateFin = null;
    DureeCalendaire delaiDecheance = new DureeCalendaire(3, 0, 0);
    if (djiTheorique != null) {
      dateFin = djiTheorique.deplacerVersAvant(delaiDecheance);
    }
    return dateFin;
  }
  
  protected String determineNomPourPivotUniteAffiliation(String punite)
    throws CoucheLogiqueException
  {
    String unite = "";
    if ((punite != null) && (!"".equals(punite))) {
      if ((punite.equals("heure de travail")) || (punite.equals("heure")))
      {
        unite = "H";
      }
      else if ((punite.equals("jour d'affiliation")) || (punite.equals("jour")))
      {
        unite = "J";
      }
      else if (punite.equals("embarquement administratif"))
      {
        unite = "E";
      }
      else if (punite.equals("vacation"))
      {
        unite = "V";
      }
      else
      {
        if (Log.isTraceActive(AlimentationBasePivot.class, Niveau.DEBUG)) {
          Log.ecritTrace(Niveau.DEBUG, AlimentationBasePivot.class, "determineNomPourPivotUniteAffiliation", "unité durée affiliation non mappée, unité reçue : " + unite.getClass().getName());
        }
        throw new UnsupportedOperationException("Alimentation Base pivot - Unité non mappée : " + unite);
      }
    }
    return unite;
  }
  
  protected void renseigneAffiliation(Decision decision, DossierExamen dossier)
    throws CoucheLogiqueException
  {
    int valeurTotale1 = 0;
    String nomUnite1 = "";
    
    String nomUniteAffiRequise = "";
    int valeurTotaleAffiRequise = 0;
    
    ValidationProduit validationProduitSpectacle = (ValidationProduit)((DossierAffecte)dossier.getDossierAffecte()).getValidationProduit();
    if (validationProduitSpectacle != null)
    {
      Quantite appartenance1 = validationProduitSpectacle.getQuantiteAcquise();
      if (appartenance1 != null)
      {
        valeurTotale1 = appartenance1.getValeur().intValue();
        nomUnite1 = appartenance1.getUnite().getNom();
      }
      if (valeurTotale1 != 0)
      {
        decision.setValeurQuantiteAffiliation(valeurTotale1);
        decision.setUniteAffiliation(determineNomPourPivotUniteAffiliation(nomUnite1));
      }
      if ((validationProduitSpectacle.getJustificationAffiliation() != null) && (validationProduitSpectacle.getJustificationAffiliation().getCollectionAssimilation() != null))
      {
        Collection<?> listeAssimilation = validationProduitSpectacle.getJustificationAffiliation().getCollectionAssimilation();
        renseignerAssimilation(decision, listeAssimilation);
      }
      decision.setNbHTravailHorsA8A10(determinerNbreHeuresTravailHorsA8A10(dossier, validationProduitSpectacle.getPeriodePra()).intValue());
      
      Periode pra = validationProduitSpectacle.getPeriodePra();
      if (pra != null)
      {
        decision.setDateDebutPra(pra.getDebut());
        decision.setDateFinPra(pra.getFin());
      }
      Quantite affiRequise = validationProduitSpectacle.getHeuresRequises();
      if (affiRequise != null)
      {
        valeurTotaleAffiRequise = affiRequise.getValeur().intValue();
        nomUniteAffiRequise = affiRequise.getUnite().getNom();
      }
      if (valeurTotaleAffiRequise != 0)
      {
        decision.setValeurQuantiteAffiliationRequise(valeurTotaleAffiRequise);
        decision.setUniteAffiliationRequise(determineNomPourPivotUniteAffiliation(nomUniteAffiRequise));
      }
    }
  }
  
  protected static void alimenterEtatPnds(Decision decision, ConditionQuantiteAffiliationSpec capa07)
  {
    if ((capa07 instanceof ConditionQuantiteAffiliation)) {
      decision.setEtatPndsPourCalculAffiliation(((ConditionQuantiteAffiliation)capa07).getEtatPndsPourCalculAffi());
    }
  }
  
  protected void renseignerAssimilation(Decision decision, Collection<?> listeAssimilation)
  {
    BigDecimal cumulHeuresAssimilees = BigDecimal.ZERO;
    
    BigDecimal cumulHeuresFormationAssimilees = BigDecimal.ZERO;
    BigDecimal cumulHeuresEnseignementAssimilees = BigDecimal.ZERO;
    BigDecimal cumulHeuresMaterniteAssimilees = BigDecimal.ZERO;
    BigDecimal cumulHeuresMaladieAssimilees = BigDecimal.ZERO;
    for (Iterator<?> it = listeAssimilation.iterator(); it.hasNext();)
    {
      AffiliationAssimilee affiAssimilee = (AffiliationAssimilee)it.next();
      if (affiAssimilee.getQuantite() != null)
      {
        BigDecimal dureeAffi = affiAssimilee.getQuantite().getValeur();
        cumulHeuresAssimilees = cumulHeuresAssimilees.add(dureeAffi);
        switch (affiAssimilee.getNature())
        {
        case 6: 
          cumulHeuresFormationAssimilees = cumulHeuresFormationAssimilees.add(dureeAffi);
          break;
        case 7: 
          cumulHeuresEnseignementAssimilees = cumulHeuresEnseignementAssimilees.add(dureeAffi);
          break;
        case 3: 
        case 4: 
          cumulHeuresMaterniteAssimilees = cumulHeuresMaterniteAssimilees.add(dureeAffi);
          break;
        case 5: 
        case 10: 
        case 12: 
        case 13: 
          cumulHeuresMaladieAssimilees = cumulHeuresMaladieAssimilees.add(dureeAffi);
        }
      }
    }
    decision.setValeurQuantiteAssimilation(cumulHeuresAssimilees.intValue());
    
    decision.setNbHEnseignementDispenseesAssimilees(cumulHeuresEnseignementAssimilees.intValue());
    
    decision.setNbHFormationProfessionnelleAssimiliees(cumulHeuresFormationAssimilees.intValue());
    
    decision.setNbHMaladieAssimilees(cumulHeuresMaladieAssimilees.intValue());
    
    decision.setNbHMaterniteAssimilees(cumulHeuresMaterniteAssimilees.intValue());
  }
  
  private String determineAuMoins100Trimestres(Demande demande)
  {
    String val;
    String val;
    if ((demande.getDemandeur().getDateCentTrimestres() != null) && (demande.getDemandeur().getDateCentTrimestres().estAvantOuCoincideAvec(demande.getFaitGenerateur().getDateFaitGenerateur()))) {
      val = "O";
    } else {
      val = "N";
    }
    return val;
  }
  
  private void renseignerDonneesPmc(Decision decision, DossierExamen dossier)
    throws CoucheLogiqueException
  {
    if ((dossier.getConstitutionDelaisReport() != null) && ((dossier.getConstitutionDelaisReport().getTermePMCIndemn() != null) || (dossier.getConstitutionDelaisReport().getTermePMCNonIndemn() != null)))
    {
      Damj termePmc = dossier.getConstitutionDelaisReport().getTermePMCIndemn() != null ? dossier.getConstitutionDelaisReport().getTermePMCIndemn() : dossier.getConstitutionDelaisReport().getTermePMCNonIndemn();
      
      int typePmc = dossier.getConstitutionDelaisReport().getTermePMCIndemn() != null ? 1 : 0;
      
      decision.setDateFinPmc(termePmc);
      
      decision.setTypePmc(typePmc);
    }
  }
  
  protected BigDecimal determinerNbreHeuresTravailHorsA8A10(DossierExamen dossier, Periode pra)
  {
    BigDecimal cumulHeuresTravailHorsA8A10 = new BigDecimal(0);
    if ((pra != null) && (!dossier.getDemande().estMigree()))
    {
      FiltresTemporel filtres = new FiltresTemporel();
      filtres.ajouterFiltre(new FiltreActiviteSalarie());
      filtres.ajouterFiltre(new FiltrePeriodesLiquidables());
      filtres.ajouterFiltre(new FiltreFinDansBornes(pra));
      
      ChronologiePeriodes chronoPassePro = dossier.getDemande().getDemandeur().getChronoPeriodePasseProfessionnel();
      Chronologie chronoActiviteSalarieFinDansPra = chronoPassePro.copier(filtres);
      Chronologie chronoActiviteSalarieParticipante = ConstructionChronologie.determinerChronoActivitesSalarieesNonSpectacle(chronoActiviteSalarieFinDansPra);
      
      ProduitAsuSpec produitAffecte = (ProduitAsuSpec)dossier.getDossierAffecte().getProduit();
      Convertisseur convertisseurUniteAffiliation = produitAffecte.determinerConvertisseurUniteAffiliation();
      if (chronoActiviteSalarieParticipante != null)
      {
        chronoActiviteSalarieParticipante.iterer();
        while (chronoActiviteSalarieParticipante.encoreSuivant())
        {
          ActiviteSalarie pas = (ActiviteSalarie)chronoActiviteSalarieParticipante.elementSuivant();
          BigDecimal heures = proratiserValeurSurPeriode(determinerQuantiteTotaleHeuresTravaille(pas, convertisseurUniteAffiliation).getValeur(), pas.getPeriode(), pra);
          
          cumulHeuresTravailHorsA8A10 = cumulHeuresTravailHorsA8A10.add(heures);
        }
      }
    }
    return Mathematiques.arrondiASup(cumulHeuresTravailHorsA8A10, 0);
  }
  
  private Quantite determinerQuantiteTotaleHeuresTravaille(SalarieSpec activite, Convertisseur convertisseurUniteAffiliation)
  {
    Quantite total = new Quantite(new BigDecimal(0), CalculAppartenance.UNITE_HEURE);
    if (activite != null)
    {
      Chronologie listePeriodeMesureActivite = activite.getListePeriodesMesureActivite();
      Iterator<?> itMesureActivite = listePeriodeMesureActivite.iterer();
      while (itMesureActivite.hasNext())
      {
        PeriodeMesureActivite pma = (PeriodeMesureActivite)itMesureActivite.next();
        Enumeration<?> interQuantiteAffiliation = pma.getListeQuantitesAffiliation().elements();
        while (interQuantiteAffiliation.hasMoreElements())
        {
          Quantite quantiteAppartenance = (Quantite)interQuantiteAffiliation.nextElement();
          Quantite quantiteTravail;
          Quantite quantiteTravail;
          if (quantiteAppartenance.getUnite().equals(CalculAppartenance.UNITE_HEURE)) {
            quantiteTravail = quantiteAppartenance;
          } else {
            quantiteTravail = convertisseurUniteAffiliation.convertir(quantiteAppartenance, CalculAppartenance.UNITE_HEURE);
          }
          total = total.ajouter(quantiteTravail);
        }
      }
    }
    return total;
  }
  
  private void renseignerCodeSousProduit(Decision decision, Demande demande)
  {
    boolean estClauseRattrapage = estContexteClauseRattrapage(demande);
    if (estClauseRattrapage) {
      decision.setCodeSousProduit("CR");
    }
  }
  
  private BigDecimal proratiserValeurSurPeriode(BigDecimal valeur, Periode periodeTravaillee, Periode pra)
  {
    int nombreJoursChevauchantPeriodeRef = periodeTravaillee.inter(pra);
    BigDecimal valeurProratisee;
    BigDecimal valeurProratisee;
    if (nombreJoursChevauchantPeriodeRef == 0)
    {
      valeurProratisee = BigDecimal.ZERO;
    }
    else
    {
      BigDecimal valeurProratisee;
      if (nombreJoursChevauchantPeriodeRef == periodeTravaillee.getDuree())
      {
        valeurProratisee = valeur;
      }
      else
      {
        BigDecimal nominateur1 = new BigDecimal(String.valueOf(nombreJoursChevauchantPeriodeRef));
        BigDecimal nominateur2 = valeur;
        BigDecimal denominateur = new BigDecimal(String.valueOf(periodeTravaillee.getDuree()));
        valeurProratisee = Mathematiques.proratiser(nominateur1, nominateur2, denominateur);
      }
    }
    return valeurProratisee;
  }
}

/* Location:
 * Qualified Name:     AlimentationBasePivot
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */