package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.CREM;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionQuantiteAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsAdmission;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Od;
import fr.unedic.cali.autresdoms.ga.dom.ActiviteSalarie;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Hashtable;

public class ConstitutionCREMConstituant
{
  private static final int NB_DECIMALES_ARRONDI_0 = 0;
  private static final int NB_DECIMALES_ARRONDI_2 = 2;
  private static final int NB_DECIMALES_ARRONDI_4 = 4;
  
  public static Hashtable recupererElementsConstituant(DossierExamenSpec p_dossierExamen)
  {
    Hashtable listeConstituant = CREM.getElementsConstitutantVides();
    if ((p_dossierExamen instanceof AttributionSpec))
    {
      DossierExamen dossierExamen = (DossierExamen)p_dossierExamen;
      if ((dossierExamen.getReglementApplicable() != null) && (dossierExamen.getReglementApplicable().getReglement() != null) && (dossierExamen.getReglementApplicable().getReglement().getNomReglement() != null)) {
        listeConstituant.put("Reglement applicable", dossierExamen.getReglementApplicable().getReglement().getNomReglement());
      }
      if ((dossierExamen.getConstitutionElementsActifs() != null) && (dossierExamen.getConstitutionElementsActifs().getConstitutionSalaireJournalierMoyen() != null)) {
        listeConstituant.put("Salaire journalier de ref", Mathematiques.arrondiASup(dossierExamen.getConstitutionElementsActifs().getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenInitial().getValeur(), 2).toString());
      }
      if ((dossierExamen.getConstitutionElementsActifs() != null) && (dossierExamen.getConstitutionElementsActifs().getConstitutionDurees() != null) && (dossierExamen.getConstitutionElementsActifs().getConstitutionDurees().getDureeEffective() != null)) {
        listeConstituant.put("Duree Produit Resultant", Mathematiques.arrondiASup(dossierExamen.getConstitutionElementsActifs().getConstitutionDurees().getDureeEffective().getValeur(), 2).toString());
      }
      if ((dossierExamen.getDemande() != null) && (dossierExamen.getDemande().estMigree()))
      {
        if (dossierExamen.getDemande().getDateExamen() != null) {
          listeConstituant.put("Date d examen", dossierExamen.getDemande().getDateExamen().toString());
        }
        if (dossierExamen.getDateAttribution() != null) {
          listeConstituant.put("Date d attribution", dossierExamen.getDateAttribution().toString());
        }
        if (dossierExamen.getConstitutionDelaisReport() != null)
        {
          if (dossierExamen.getConstitutionDelaisReport().getDebutPMCNonIndemn() != null) {
            listeConstituant.put("Carence PMC debut", dossierExamen.getConstitutionDelaisReport().getDebutPMCNonIndemn().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getTermePMCNonIndemn() != null) {
            listeConstituant.put("Carence PMC fin", dossierExamen.getConstitutionDelaisReport().getTermePMCNonIndemn().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getDebutCarenceISLR() != null) {
            listeConstituant.put("Differe ISLR debut", dossierExamen.getConstitutionDelaisReport().getDebutCarenceISLR().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getTermeCarenceISLR() != null) {
            listeConstituant.put("Differe ISLR fin", dossierExamen.getConstitutionDelaisReport().getTermeCarenceISLR().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getDebutDelaiReport() != null) {
            listeConstituant.put("Delai d attente debut", dossierExamen.getConstitutionDelaisReport().getDebutDelaiReport().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getTermeDelaiReport() != null) {
            listeConstituant.put("Delai d attente fin", dossierExamen.getConstitutionDelaisReport().getTermeDelaiReport().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getDebutCarenceStandard() != null) {
            listeConstituant.put("Differe standard debut", dossierExamen.getConstitutionDelaisReport().getDebutCarenceStandard().toString());
          }
          if (dossierExamen.getConstitutionDelaisReport().getTermeCarenceStandard() != null) {
            listeConstituant.put("Differe standard fin", dossierExamen.getConstitutionDelaisReport().getTermeCarenceStandard().toString());
          }
        }
      }
      if ((dossierExamen instanceof Od))
      {
        if ((dossierExamen.getConstitutionSalaireJournalierMoyen() != null) && (dossierExamen.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenInitial() != null)) {
          listeConstituant.put("Salaire journalier moyen", Mathematiques.arrondiASup(dossierExamen.getConstitutionSalaireJournalierMoyen().getMontantSalaireJournalierMoyenInitial().getValeurMontant(), 2).toString());
        }
        if ((dossierExamen.getConditionFaitGenerateur() != null) && (dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur() != null)) {
          listeConstituant.put("FGD", dossierExamen.getConditionFaitGenerateur().getPeriodeFaitGenerateur().getPeriode().toString());
        }
        if (((DossierAffectation)dossierExamen.getDossierAffecte() != null) && (((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit() != null) && (((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit() != null)) {
          listeConstituant.put("FCT retenue", ((DossierAffectation)dossierExamen.getDossierAffecte()).getValidationProduit().getPeriodeValidationProduit().getPeriode().toString());
        }
        if ((dossierExamen.getConditionAttributionAdmission() != null) && (dossierExamen.getConditionAttributionAdmission().getConditionQuantiteAffiliation() != null)) {
          listeConstituant.put("Affiliation quantite", Mathematiques.arrondiASup(dossierExamen.getConditionAttributionAdmission().getConditionQuantiteAffiliation().getQuantiteAppartenance().getValeur(), 2).toString());
        }
        if ((dossierExamen.getConditionAttributionAdmission() != null) && (dossierExamen.getConditionAttributionAdmission().getConditionQuantiteAffiliation() != null)) {
          listeConstituant.put("Affiliation unite", dossierExamen.getConditionAttributionAdmission().getConditionQuantiteAffiliation().getQuantiteAppartenance().getUnite().getNom());
        }
        if ((dossierExamen.getConstitutionElementsAdmission() != null) && (dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees() != null) && (dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesEtendu() != null)) {
          listeConstituant.put("Heures trav. PRA (NHTe)", String.valueOf(dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesEtendu().intValue()));
        }
        if ((dossierExamen.getConstitutionElementsAdmission() != null) && (dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees() != null) && (dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesPlafonne() != null)) {
          listeConstituant.put("Heures trav. PRA (NHTp)", String.valueOf(dossierExamen.getConstitutionElementsAdmission().getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesPlafonne().intValue()));
        }
        if ((dossierExamen.getDemande() != null) && (dossierExamen.getDemande().estMigree()))
        {
          listeConstituant.put("Coche apprenti", new Boolean(((Od)dossierExamen).isTopContratsRemuneresBaseSmic()).toString());
          if ((dossierExamen.getConstitutionSalaireReference() != null) && (dossierExamen.getConstitutionSalaireReference().getSalaireReferenceInitialPlafonne() != null)) {
            listeConstituant.put("Montant salaire reference", Mathematiques.arrondiASup(dossierExamen.getConstitutionSalaireReference().getSalaireReferenceInitialPlafonne().getValeur(), 2).toString());
          }
          if ((dossierExamen.getConstitutionSalaireJournalierMoyen() != null) && (dossierExamen.getConstitutionSalaireJournalierMoyen().getDateSalaireJournalierMoyenInitial() != null)) {
            listeConstituant.put("Date d effet du SR", dossierExamen.getConstitutionSalaireJournalierMoyen().getDateSalaireJournalierMoyenInitial().toString());
          }
        }
      }
    }
    return listeConstituant;
  }
}

/* Location:
 * Qualified Name:     ConstitutionCREMConstituant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */