package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.liquidation.outilsfonctionnels.DeterminationMontant;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.spe02.p03.calcul.dom.Montant;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationMontantsBruts;
import fr.unedic.cali.dom.affectation.GammeAsuSpec;
import fr.unedic.cali.dom.affectation.ProduitAsuSpec;
import fr.unedic.cali.dom.conteneurs.DonneesEntreesRecuperationMontant;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import java.util.Collection;

public class DeterminationMontantsBruts
  implements OutilFonctionnel
{
  private static final QuantiteEuro QUANTITE_ZERO = new QuantiteEuro("0");
  private static DeterminationMontantsBruts instance = null;
  
  public void determinerMontantsBruts(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    determinerListePensionInvalidite(attributionCourante);
    
    determinerMontantsBruts(attributionCourante);
  }
  
  private void determinerMontantsBruts(Attribution attribution)
    throws CoucheLogiqueException
  {
    if (attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts() == null) {
      attribution.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    }
    DonneesEntreesRecuperationMontant donneesEntrees = ((GammeAsuSpec)attribution.getGamme()).mapperDonneesEntreesRecuperationMontant(attribution);
    
    donneesEntrees.setDateCalculMontant(attribution.getDateEffet());
    
    Montant montantAAttribution = (Montant)DeterminationMontant.determinerMontant(donneesEntrees);
    
    alimenterResultatCepa(montantAAttribution, attribution);
  }
  
  private void determinerListePensionInvalidite(Attribution attribution)
    throws CoucheLogiqueException
  {
    if (attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts() == null) {
      attribution.getConstitutionElementsActifs().createConstitutionMontantsBruts();
    }
    ProduitAsuSpec produit = (ProduitAsuSpec)attribution.getProduit();
    Collection<?> listePensionInvalidite = produit.determinerPensionInvaliditeDroitCourant(attribution);
    ConstitutionMontantsBruts resultatCep = attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    resultatCep.setListePensionInvalidite(listePensionInvalidite);
  }
  
  public void determinerMontantsBrutsPourReprise(Demande demande)
    throws CoucheLogiqueException
  {
    Attribution attributionCourante = (Attribution)demande.getAttribution();
    
    determinerMontantsBruts(attributionCourante);
  }
  
  public static DeterminationMontantsBruts getInstance()
  {
    if (instance == null) {
      instance = new DeterminationMontantsBruts();
    }
    return instance;
  }
  
  public void alimenterResultatCepa(Montant montant, Attribution attribution)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts resultatCep = attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    
    resultatCep.setMontantAAttribution(montant);
    
    QuantiteEuro montantBase = calculerTotalMontant(montant.getPartieA(), montant.getPartieB(), montant.getPartieC());
    
    resultatCep.setCotisationRetraiteComplementaire(getQuantiteEuro(montant.getCrc()));
    resultatCep.setMontantBase(montantBase);
    resultatCep.setMontantBrutPensionInvaliditeDeduit(getQuantiteEuro(montant.getPensionInvaliditeADeduirePriseEnCompte()));
    resultatCep.setMontantJournalierAvantageVieillesse(getQuantiteEuro(montant.getMontantJournalierAvantageVieillesse()));
    resultatCep.setMontantJournalierAvantageVieillesseDeduit(getQuantiteEuro(montant.getMontantJournalierAvantageVieillesseDeduit()));
    
    resultatCep.setMontantJournalierBrut(getQuantiteEuro(montant.getMontantPrecompteEffectif()));
    resultatCep.setMontantJournalierBrutNonPrecompte(getQuantiteEuro(montant.getMontantBrut()));
    resultatCep.setMontantPartieA(getQuantiteEuro(montant.getPartieA()));
    resultatCep.setMontantPartieB(getQuantiteEuro(montant.getPartieB()));
    resultatCep.setMontantPartieC(getQuantiteEuro(montant.getPartieC()));
    resultatCep.setMontantPlafond(getQuantiteEuro(montant.getPlafond()));
    if (!((ProduitAsuSpec)attribution.getProduit()).estUnProduitSansDuree())
    {
      Quantite nbJourIndemnisesTheorique = attribution.getConstitutionElementsActifs().getConstitutionDurees().getDureeTheorique();
      Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(attribution, montant, attribution.getDateAttribution(), nbJourIndemnisesTheorique);
      
      resultatCep.setCapitalInitialBrut(getQuantiteEuro(capitalProduitCourant));
    }
    JustificationMontantsBruts justificationMontantsBruts = resultatCep.createJustificationMontantsBruts();
    
    justificationMontantsBruts.setCoefA1(montant.getCoefA1());
    justificationMontantsBruts.setCoefA2(montant.getCoefA2());
    justificationMontantsBruts.setCoefB1(montant.getCoefB1());
    justificationMontantsBruts.setCoefB2(montant.getCoefB2());
    justificationMontantsBruts.setCoefC(montant.getCoefC());
    justificationMontantsBruts.setForfaitHeures(montant.getNhf());
    justificationMontantsBruts.setMontantMini(getQuantiteEuro(montant.getMini()));
    justificationMontantsBruts.setSalaireReferenceForfaitaire(montant.getSrf());
  }
  
  private QuantiteEuro calculerTotalMontant(Quantite partieA, Quantite partieB, Quantite partieC)
  {
    QuantiteEuro somme = getQuantiteEuro(partieA);
    somme = getQuantiteEuro(somme.ajouter(getQuantiteEuro(partieB)));
    somme = getQuantiteEuro(somme.ajouter(getQuantiteEuro(partieC)));
    return somme;
  }
  
  private QuantiteEuro getQuantiteEuro(Quantite quantite)
  {
    if (quantite != null) {
      return new QuantiteEuro(quantite.getValeur());
    }
    return QUANTITE_ZERO;
  }
}

/* Location:
 * Qualified Name:     DeterminationMontantsBruts
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */