package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreInscriptionDemandeurEmploi;
import fr.unedic.cali.asu.parcours.ParcoursRechercheAlertesNonBloquantes;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.AffiliationAssimilee;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.PeriodeElementaireAffiliation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ValidationProduit;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.spec.SimuRechercheValiditeProduitSpec;
import fr.unedic.cali.dom.DomSimulationAffiliation;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.ResultatSimulationAffiliation;
import fr.unedic.cali.dom.affectation.ProduitSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public class OutilSimulationAffiliation
  implements OutilFonctionnel
{
  public ResultatSimulationAffiliation calculAffi(DomSimulationAffiliation domSimulationAffiliation)
    throws ApplicativeException
  {
    DemandeAssuranceSpec demandeFictive = creerDemandeAsu(domSimulationAffiliation);
    
    demandeFictive.getDemandeur().nettoyerPNDSSurActiviteSalariePourSpectacle();
    
    fr.unedic.cali.asu.outilsfonctionnels.OutilSimulationAffiliation.chargementListePNDSIndividu(demandeFictive, demandeFictive.getDateExamen());
    
    SimuRechercheValiditeProduitSpec simu = recupererOutilValiditeProduitSimu(domSimulationAffiliation);
    ValidationProduit produitValide = (ValidationProduit)simu.validerProduit(domSimulationAffiliation.getActivite(), demandeFictive);
    
    ResultatSimulationAffiliation resultat = new ResultatSimulationAffiliation();
    
    ProduitSpec produitPropose = produitValide.getProduitValide();
    resultat.setProduit(produitPropose);
    resultat.setProduitPropose(produitPropose.getLibelleCourt());
    
    resultat.setDatePraDebut(produitValide.getPeriodePra().getDebut());
    
    resultat.setDatePraFin(produitValide.getPeriodePra().getFin());
    
    resultat.setreglementApplicable(produitValide.getReglementApplicable().getLibelleCourt());
    
    String categ = Integer.toString(produitValide.getCatEmploiPart());
    resultat.setcatEmploi(categ);
    
    resultat.setAffiCalcule(produitValide.getQuantiteAcquise().getValeur());
    
    resultat.setUniteAffiCalcule(produitValide.getQuantiteAcquise().getUnite().getNom());
    
    BigDecimal cachetsGroupes = new BigDecimal(0);
    BigDecimal cachetsIsoles = new BigDecimal(0);
    Collection<PeriodeElementaireAffiliation> collecCachets = produitValide.getJustificationAffiliation().getCollectionPeriodeElementaireAffiliation();
    Iterator<PeriodeElementaireAffiliation> iterator = collecCachets.iterator();
    Object element = null;
    while (iterator.hasNext())
    {
      element = iterator.next();
      
      BigDecimal cachetgroupeA10 = ((PeriodeElementaireAffiliation)element).getCachetGroupeA10();
      BigDecimal cachetgroupeA8 = ((PeriodeElementaireAffiliation)element).getCachetGroupeA8();
      BigDecimal cachetisoleA10 = ((PeriodeElementaireAffiliation)element).getCachetIsoleA10();
      BigDecimal cachetisoleA8 = ((PeriodeElementaireAffiliation)element).getCachetIsoleA8();
      if (cachetgroupeA8 != null) {
        cachetsGroupes = cachetsGroupes.add(cachetgroupeA8);
      }
      if (cachetgroupeA10 != null) {
        cachetsGroupes = cachetsGroupes.add(cachetgroupeA10);
      }
      if (cachetisoleA8 != null) {
        cachetsIsoles = cachetsIsoles.add(cachetisoleA8);
      }
      if (cachetisoleA10 != null) {
        cachetsIsoles = cachetsIsoles.add(cachetisoleA10);
      }
    }
    resultat.setCachetGroupe(cachetsGroupes);
    
    resultat.setCachetIsole(cachetsIsoles);
    
    BigDecimal assimilation = new BigDecimal(0);
    Collection<AffiliationAssimilee> collecAssimi = produitValide.getJustificationAffiliation().getCollectionAssimilation();
    Iterator<AffiliationAssimilee> iterator2 = collecAssimi.iterator();
    Object element2 = null;
    while (iterator2.hasNext())
    {
      element2 = iterator2.next();
      BigDecimal assimi = ((AffiliationAssimilee)element2).getQuantite().getValeur();
      if (assimi != null) {
        assimilation = assimilation.add(assimi);
      }
    }
    resultat.setAssimilation(assimilation);
    
    resultat.setAllongementPra(produitValide.getRangAllongement());
    resultat.setHeuresRequises(produitValide.getHeuresRequises().getValeur());
    resultat.setJustifAffi(produitValide.getJustificationAffiliation());
    
    ParcoursRechercheAlertesNonBloquantes.getInstance().presencePeriodeDeclareeNonJustifiee(demandeFictive, produitValide.getPeriodePra(), domSimulationAffiliation.getIndividu().getChronoPeriodePasseProfessionnelLiquidation());
    
    Damj dateRecherche = domSimulationAffiliation.getDateFgd() != null ? domSimulationAffiliation.getDateFgd() : domSimulationAffiliation.getDateFct();
    ParcoursRechercheAlertesNonBloquantes.getInstance().presenceDVDansLes91Jours(demandeFictive, domSimulationAffiliation.getIndividu(), dateRecherche);
    
    resultat.setDemande(demandeFictive);
    
    return resultat;
  }
  
  protected SimuRechercheValiditeProduitSpec recupererOutilValiditeProduitSimu(DomSimulationAffiliation domSimulationAffiliation)
  {
    return SimuRechercheValiditeProduit.getInstance(domSimulationAffiliation.getDatePra());
  }
  
  private DemandeAssuranceSpec creerDemandeAsu(DomSimulationAffiliation domSimulation)
  {
    Demande demandeTemporaire = new Demande();
    demandeTemporaire.setDemandeur(domSimulation.getIndividu());
    EvenementReferenceExamenSpec ereFictif = new EreInscriptionDemandeurEmploi();
    ereFictif.setDateEvenement(domSimulation.getDateFct());
    demandeTemporaire.setEvenementReferenceExamen(ereFictif);
    demandeTemporaire.createDonneesTemporaires();
    demandeTemporaire.setDemandeLiquidee(true);
    
    demandeTemporaire.getDonneesTemporaires().setTypeCoordinationEuropeenne(domSimulation.getTypeCoordinationEuropeenne());
    
    return demandeTemporaire;
  }
}

/* Location:
 * Qualified Name:     OutilSimulationAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */