package fr.unedic.cali.asu.spe02.p05.antecedent;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.SaisieAntecedent;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels.DeterminationSalaireJournalierMoyenSPE02P05;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class GrapheAntecedent
  extends fr.unedic.cali.asu.spe02.antecedent.GrapheAntecedent
{
  public static GrapheAntecedent getInstance()
  {
    return new GrapheAntecedent();
  }
  
  protected void alimenterDateLimiteIndemnisation(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    ConstitutionDateLimiteIndemnisation dateLimiteIndemnisation = dossierExamen.getConstitutionElementsActifs().createConstitutionDateLimiteIndemnisation();
    dateLimiteIndemnisation.setDateLimiteIndemnisation(saisieAntecedent.getDateLimite());
  }
  
  protected void alimenterConstitutionDelais(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    ConstitutionDelaisReport delaisReport = dossierExamen.getConstitutionElementsActifs().createConstitutionDelaisReport();
    delaisReport.setQuantiteFranchiseCPMensuelle(new QuantiteJour(new BigDecimal(saisieAntecedent.getFranchiseCPMensuelle())));
    delaisReport.setQuantiteFranchiseSalaireMensuelle(new QuantiteJour(new BigDecimal(saisieAntecedent.getFranchiseSalaireMensuelle())));
    delaisReport.setFranchiseCongesPayes(saisieAntecedent.getFranchiseCPTotale());
    delaisReport.setNbJoursCarenceStandard(saisieAntecedent.getFranchiseSalaireTotale());
  }
  
  protected void alimenterConstitutionDurees(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {}
  
  protected void alimenterConstitutionMontantBrut(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
    throws CoucheLogiqueException
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)dossierExamen.getDemande(), "ENTREECRA"))
    {
      ConstitutionMontantsBruts constitutionMontants = dossierExamen.getConstitutionElementsActifs().createConstitutionMontantsBruts();
      constitutionMontants.setMontantJournalierBrutNonPrecompte(saisieAntecedent.getMontantCra());
    }
    super.alimenterConstitutionMontantBrut(dossierExamen, saisieAntecedent);
  }
  
  protected void alimenterConstitutionSjm(DossierExamen dossierExamen, SaisieAntecedent saisieAntecedent)
  {
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)dossierExamen.getDemande(), "ENTREECRA"))
    {
      IndividuSpec demandeur = dossierExamen.getDemande().getDemandeur();
      
      alimenterConstitutionSr(saisieAntecedent, demandeur, dossierExamen);
      
      ConstitutionSalaireJournalierMoyen constitutionSjm = dossierExamen.getConstitutionElementsActifs().createConstitutionSalaireJournalierMoyen();
      Damj dateAttribution = saisieAntecedent.getDateAttribution();
      QuantiteEuro plafondSjmr = DeterminationSalaireJournalierMoyenSPE02P05.getInstance().determinerPlafondSjmr(dateAttribution);
      
      constitutionSjm.setMontantSalaireJournalierMoyenInitial(saisieAntecedent.getSjmCra());
      constitutionSjm.setDateSalaireJournalierMoyenInitial(dateAttribution.veille());
      constitutionSjm.setDateSalaireJournalierMoyenRevalorisePlafonne(dateAttribution.veille());
      constitutionSjm.setMontantPlafond(plafondSjmr);
      constitutionSjm.setMontantSalaireJournalierMoyenRevalorisePlafonne(saisieAntecedent.getSjmCra());
    }
    else
    {
      super.alimenterConstitutionSjm(dossierExamen, saisieAntecedent);
    }
  }
  
  protected void determinerSalaireJournalierMoyen(Demande demande)
  {
    DeterminationSalaireJournalierMoyenSPE02P05.getInstance().determinerSalaireJournalierMoyen(demande);
  }
}

/* Location:
 * Qualified Name:     GrapheAntecedent
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */