package fr.unedic.cali.asu.spe02.p05.calcul.outilsfonctionnels;

import fr.unedic.cali.asu.calcul.dom.EtatAuDjiGamme;
import fr.unedic.cali.asu.calcul.parcours.ResultatDeterminationEtatDroit;
import fr.unedic.cali.asu.dom.ElementBaseIndemnisation;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.calcul.PostTraitementsHorsGamme;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalcul;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculSpec;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.parcours.ResultatDeterminationEtatDroitProduit;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class PostTraitements
  extends fr.unedic.cali.asu.spe02.p03.calcul.outilsfonctionnels.PostTraitements
{
  public static ResultatDeterminationEtatDroitProduit postTraitementResultatDeterminationEtatDroit(AttributionSpec attribution, CalendrierExecutionCalcul calendrierExecutionCalcul, Damj dateEtatDroit)
    throws CoucheLogiqueException
  {
    ResultatDeterminationEtatDroit resultat = new ResultatDeterminationEtatDroit();
    
    remplirResultatPostTraitement(attribution, calendrierExecutionCalcul, dateEtatDroit, resultat);
    
    EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)calendrierExecutionCalcul.getEtatAuDJI();
    if (etatAuDji != null)
    {
      Integer reliquatFCP = etatAuDji.getReliquatFCP() != null ? etatAuDji.getReliquatFCP() : null;
      Integer reliquatFS = etatAuDji.getReliquatFS() != null ? etatAuDji.getReliquatFS() : null;
      
      resultat.setReliquatFranchiseCP(reliquatFCP != null ? new QuantiteJour(Integer.toString(reliquatFCP.intValue())) : null);
      resultat.setReliquatFranchiseSalaire(reliquatFS != null ? new QuantiteJour(Integer.toString(reliquatFS.intValue())) : null);
      resultat.setReliquatDelaiAttente(etatAuDji.getReliquatDA() != null ? new QuantiteJour(Integer.toString(etatAuDji.getReliquatDA().intValue())) : null);
      resultat.setPeriodeApplicationDelaiAttente(etatAuDji.getPeriodeDA());
    }
    return resultat;
  }
  
  protected static void remplirResultatPostTraitement(AttributionSpec attribution, CalendrierExecutionCalculSpec calendrierExecutionCalcul, Damj dateEtatDroit, ResultatDeterminationEtatDroit resultat)
    throws CoucheLogiqueException
  {
    PostTraitementsHorsGamme.remplirResultatPostTraitement(attribution, calendrierExecutionCalcul, dateEtatDroit, resultat);
    
    EtatAuDjiGamme etatAuDji = (EtatAuDjiGamme)calendrierExecutionCalcul.getEtatAuDJI();
    if ((etatAuDji != null) && (dateEtatDroit.compareTo(calendrierExecutionCalcul.getDernierJourIndemnisable()) == 0))
    {
      if (calendrierExecutionCalcul.getEtatAttribution() == 6) {
        resultat.setEtatAttribution(1);
      } else if (calendrierExecutionCalcul.getDernierJourIndemnisable().compareTo(((Attribution)attribution).getElementBaseIndemnisation().getDateLimiteIndemnisation()) < 0) {
        resultat.setEtatAttribution(3);
      } else {
        resultat.setEtatAttribution(2);
      }
      resultat.setNbJourFormation(etatAuDji.getNbJourAREF());
      resultat.setNombreMoisIndemnisationAssurance(etatAuDji.getNbMoisIndemniseAsu());
      resultat.setEstNombreMoisIndemnisationAssuranceAlimente(etatAuDji.isEstNbMoisIndemniseAsu());
    }
    else
    {
      Quantite reliquatDureeIndemnisation = recupererReliquatDureeIndemnisation(calendrierExecutionCalcul);
      if (reliquatDureeIndemnisation != null) {
        resultat.setReliquatDureeIndemnisation(new Quantite(reliquatDureeIndemnisation.getValeur().setScale(0), reliquatDureeIndemnisation.getUnite()));
      }
      resultat.setCumulMoisActiviteReduite(recupererReliquatCumulAR(calendrierExecutionCalcul));
      resultat.setEtatAttribution(recupererEtatAttribution(calendrierExecutionCalcul));
      UniteTraitement dernierUT = (UniteTraitement)((CalendrierExecutionCalculPeriodique)calendrierExecutionCalcul).getChronologieUnitesTraitements().dernierElement();
      resultat.setNbJourFormation(dernierUT.getNbJoursFormationEnFinDUT());
      resultat.setNombreMoisIndemnisationAssurance(dernierUT.getNbMoisIndemniseAsu());
      resultat.setEstNombreMoisIndemnisationAssuranceAlimente(dernierUT.isEstNbMoisIndemniseAsu());
    }
  }
}

/* Location:
 * Qualified Name:     PostTraitements
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */