package fr.unedic.cali.asu.spe02.p05.liquidation.outilsaffiliation;

import fr.unedic.util.Convertisseur;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.UniteInvalideException;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import java.util.NoSuchElementException;

public class ConvertisseurUniteAffiliation
  implements Convertisseur
{
  private static ConvertisseurUniteAffiliation instance = null;
  private Map<String, BigDecimal> conversions = new HashMap();
  
  protected ConvertisseurUniteAffiliation()
  {
    conversions.put("heure de travail_jour d'affiliation", Mathematiques.diviseParDefaut(BigDecimal.ONE, new BigDecimal("5")));
    
    conversions.put("heure de travail_vacation", Mathematiques.diviseParDefaut(new BigDecimal("2"), new BigDecimal("5")));
    
    conversions.put("heure de travail_embarquement administratif", Mathematiques.diviseParDefaut(BigDecimal.ONE, new BigDecimal("5")));
    
    conversions.put("heure de travail_jour contribution", Mathematiques.diviseParDefaut(BigDecimal.ONE, new BigDecimal("5")));
    
    conversions.put("heure de travail_jour de suspension", Mathematiques.diviseParDefaut(BigDecimal.ONE, new BigDecimal("5")));
    
    conversions.put("heure de travail_cachet groupe", Mathematiques.diviseParDefaut(BigDecimal.ONE, new BigDecimal("12")));
    
    conversions.put("heure de travail_cachet isole", Mathematiques.diviseParDefaut(BigDecimal.ONE, new BigDecimal("12")));
    
    conversions.put("cachet isole_heure de travail", new BigDecimal("12"));
    
    conversions.put(UniteAffiliation.JOUR + "_" + "embarquement administratif", BigDecimal.ONE);
    
    conversions.put("heure de travail_heure de travail", BigDecimal.ONE);
  }
  
  public static synchronized ConvertisseurUniteAffiliation getInstance()
  {
    if (instance == null) {
      instance = new ConvertisseurUniteAffiliation();
    }
    return instance;
  }
  
  private BigDecimal chercherConversion(Unite uniteDepart, Unite uniteArrivee)
  {
    BigDecimal valeurConversion = (BigDecimal)conversions.get(uniteDepart.getNom() + "_" + uniteArrivee.getNom());
    if (valeurConversion != null) {
      return valeurConversion;
    }
    throw new NoSuchElementException("Pas de conversion pour les unités : " + uniteDepart.getNom() + " -> " + uniteArrivee.getNom());
  }
  
  public Quantite convertir(Quantite quantiteInitiale, Unite nouvelleUnite)
    throws UniteInvalideException
  {
    Quantite quantiteApresConversion = null;
    
    BigDecimal facteurConversion = getFacteurConversion((UniteAffiliation)quantiteInitiale.getUnite(), (UniteAffiliation)nouvelleUnite);
    quantiteApresConversion = new Quantite(facteurConversion.multiply(quantiteInitiale.getValeur()), nouvelleUnite);
    
    return quantiteApresConversion;
  }
  
  private BigDecimal getFacteurConversion(UniteAffiliation uniteDepart, UniteAffiliation uniteArrivee)
    throws UniteInvalideException
  {
    BigDecimal facteur = BigDecimal.ZERO;
    try
    {
      BigDecimal valeurConversion = chercherConversion(uniteDepart, uniteArrivee);
      facteur = valeurConversion;
    }
    catch (NoSuchElementException ex)
    {
      try
      {
        BigDecimal valeurConversion = chercherConversion(uniteArrivee, uniteDepart);
        facteur = Mathematiques.diviseParDefaut(BigDecimal.ONE, valeurConversion);
      }
      catch (NoSuchElementException exce)
      {
        try
        {
          facteur = getFacteurConversion(uniteDepart, (UniteAffiliation)UniteAffiliation.get("heure de travail")).multiply(getFacteurConversion((UniteAffiliation)UniteAffiliation.get("heure de travail"), uniteArrivee));
        }
        catch (NoSuchElementException excep)
        {
          throw new UniteInvalideException("Pas de conversion de " + uniteDepart.getNom() + " vers " + uniteArrivee.getNom());
        }
      }
    }
    return facteur;
  }
}

/* Location:
 * Qualified Name:     ConvertisseurUniteAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */