package fr.unedic.cali.asu.spe02.p05.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionDelaisReport;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationDiffere;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.JustificationFranchiseCongesPayes;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.AlimentationBaseEchanges;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.echange.Decision;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.CoucheLogiqueException;
import java.math.BigDecimal;

public class AlimentationBaseEchangesSPE02P05
  extends AlimentationBaseEchanges
{
  private static AlimentationBaseEchangesSPE02P05 instance;
  
  public static AlimentationBaseEchangesSPE02P05 getInstance()
  {
    if (instance == null) {
      instance = new AlimentationBaseEchangesSPE02P05();
    }
    return instance;
  }
  
  public void alimenterDonneesProduit(DossierExamenSpec dossierExamen, Decision demandeEchange)
    throws CoucheLogiqueException
  {
    super.alimenterDonneesProduit(dossierExamen, demandeEchange);
    alimenterDonneesClauseRattrapage(dossierExamen, demandeEchange);
  }
  
  protected void alimenterDonneesCourrier(DossierExamenSpec dossierExamenSpec, Decision demandeEchange)
    throws CoucheLogiqueException
  {
    if (!dossierExamenSpec.getDemande().estEnReExamen())
    {
      super.alimenterDonneesCourrier(dossierExamenSpec, demandeEchange);
      alimenterDonneesSpectacle2016(dossierExamenSpec, demandeEchange);
    }
  }
  
  private void alimenterDonneesSpectacle2016(DossierExamenSpec dossierExamen, Decision demandeEchange)
    throws CoucheLogiqueException
  {
    ConstitutionDelaisReport cepa = ((DossierExamen)dossierExamen).getConstitutionDelaisReport();
    alimenterDonneesCepaDelaisReport(cepa, demandeEchange);
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent((Demande)dossierExamen.getDemande(), "SORTIECRA")) {
      demandeEchange.setTopAreSpectacleEnCoursClauseRattrapage(1);
    } else {
      demandeEchange.setTopAreSpectacleEnCoursClauseRattrapage(0);
    }
    if ((dossierExamen instanceof AttributionAssuranceSpec))
    {
      AttributionAssuranceSpec attribution = (AttributionAssuranceSpec)dossierExamen;
      demandeEchange.setDateBanalisee(attribution.getDateLimiteIndemnisation());
    }
  }
  
  private void alimenterDonneesClauseRattrapage(DossierExamenSpec dossierExamen, Decision demandeEchange)
  {
    if ("ASU_31".equals(dossierExamen.getDemande().getEvenementReferenceExamen().getTypeExamen())) {
      demandeEchange.setCodeSousProduit("CR");
    }
  }
  
  protected boolean doitEffectuerRepriseStockSpectacle2016(DemandeSpec demande)
    throws CoucheLogiqueException
  {
    return true;
  }
  
  private void alimenterDonneesCepaDelaisReport(ConstitutionDelaisReport cepa, Decision demandeEchange)
  {
    if (cepa != null)
    {
      demandeEchange.setNombreJoursFranchiseCP(new BigDecimal(cepa.getFranchiseCongesPayes()));
      demandeEchange.setNombreJoursFranchiseSalaire(new BigDecimal(cepa.getNbJoursCarenceStandard()));
      if (cepa.getJustificationFranchiseCongesPayes() != null) {
        demandeEchange.setBaseCalculFranchiseCP(new BigDecimal(cepa.getJustificationFranchiseCongesPayes().getNbJoursTravaillesRetenus()));
      }
      if ((cepa.getJustificationDiffere() != null) && (cepa.getJustificationDiffere().getTotalSalairesNonPlafonnes() != null)) {
        demandeEchange.setBaseCalculFranchiseSalaire(cepa.getJustificationDiffere().getTotalSalairesNonPlafonnes().getValeurMontant());
      }
      if (cepa.getQuantiteFranchiseCPMensuelle() != null) {
        demandeEchange.setFranchiseCpMensuelle(cepa.getQuantiteFranchiseCPMensuelle().getValeurEntiere());
      }
      if (cepa.getQuantiteFranchiseSalaireMensuelle() != null) {
        demandeEchange.setFranchiseSalaireMensuelle(cepa.getQuantiteFranchiseSalaireMensuelle().getValeurEntiere());
      }
    }
  }
}

/* Location:
 * Qualified Name:     AlimentationBaseEchangesSPE02P05
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */