package fr.unedic.cali.asu.spe02.p05.liquidation.parcours.cep.sjm;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffecte;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.asu.dom.ValidationProduit;
import fr.unedic.cali.asu.outilsfonctionnels.OutilGestionContexteDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.Attribution;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionNbHeuresTravaillees;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireJournalierMoyen;
import fr.unedic.cali.asu.spe02.p03.liquidation.dom.ConstitutionSalaireReference;
import fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels.DeterminationSalaireJournalierMoyen;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class ConstitutionSalaireReferenceEtSjm
  extends ParcoursCali
{
  public Resultat demarrer(Contexte contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Resultat resultat = null;
    if (OutilGestionContexteDemande.estContexteDemandeAssurancePresent(demande, "ENTREECRA")) {
      resultat = effectuerTraitementEntreeClauseRattrapage(contexte);
    } else {
      resultat = effectuerTraitementClassique(contexte);
    }
    return resultat;
  }
  
  protected Resultat effectuerTraitementClassique(Contexte contexte)
    throws ApplicativeException
  {
    Resultat resultatCEPA = new Resultat();
    
    Resultat res1 = getParcoursConstitutionSalaireReference().demarrer(contexte);
    Resultat res2 = new ConstitutionSjm().demarrer(contexte);
    
    resultatCEPA.setEtat((res1.estSatisfait()) && (res2.estSatisfait()) ? 0 : 1);
    resultatCEPA.setCodeErreur(res1.getCodeErreur() != null ? res1.getCodeErreur() : res2.getCodeErreur());
    resultatCEPA.setMessageErreur(res1.getMessageErreur() != null ? res1.getMessageErreur() : res2.getMessageErreur());
    
    return resultatCEPA;
  }
  
  protected ParcoursCali getParcoursConstitutionSalaireReference()
  {
    return new ConstitutionSalaireReferenceSPE02P05();
  }
  
  protected Resultat effectuerTraitementEntreeClauseRattrapage(Contexte contexte)
  {
    Resultat resultat = new Resultat(0);
    Demande demande = DomLiquidationAssurance.getDemande(contexte);
    Attribution attribution = (Attribution)demande.getDossierExamen();
    ConstitutionSalaireJournalierMoyen constitutionSalaireJournalierMoyen = attribution.getConstitutionElementsActifs().createConstitutionSalaireJournalierMoyen();
    
    ConstitutionSalaireReference constitutionSalaireReference = attribution.getConstitutionElementsActifs().createConstitutionSalaireReference();
    constitutionSalaireReference.setPrc(((DossierAffecte)attribution.getDossierAffecte()).getValidationProduit().getPeriodePra());
    
    ResultatExecutionCalculSpec executionAttributionPrecedente = ((DomLiquidationAssurance)contexte.getDonnees()).getResultatExecutionCalculDroitPrecedent();
    
    Attribution attributionPrecedente = (Attribution)executionAttributionPrecedente.getAttributionEtudiee();
    Damj djiAttributionPrecedente = executionAttributionPrecedente.getDernierJourIndemnisable();
    QuantiteEuro srrp = attributionPrecedente.getConstitutionSalaireReference().getSalaireReferenceRevalorisePlafonne();
    
    BigDecimal nbreHeuresTravailleesPlafonnees = attributionPrecedente.getConstitutionNbHeuresTravaillees().getNombreHeuresTravailleesPlafonne();
    
    Reglement reglementApplicable = attributionPrecedente.getConstitutionReglementApplicable().getReglement();
    int coefficientHoraireJour = DeterminationSalaireJournalierMoyen.getInstance().determinerCoefficientHoraireJour(reglementApplicable);
    
    QuantiteEuro sjmr = DeterminationSalaireJournalierMoyen.getInstance().determinerSalaireJournalierMoyenRevalorise(srrp, coefficientHoraireJour, nbreHeuresTravailleesPlafonnees);
    
    QuantiteEuro plafondSjmr = DeterminationSalaireJournalierMoyen.getInstance().determinerPlafondSjmr(djiAttributionPrecedente);
    
    BigDecimal valeurSjmrp = sjmr.getValeurMontant().min(plafondSjmr.getValeurMontant());
    QuantiteEuro sjmrp = new QuantiteEuro(valeurSjmrp);
    
    constitutionSalaireJournalierMoyen.setMontantSalaireJournalierMoyenInitial(sjmrp);
    constitutionSalaireJournalierMoyen.setDateSalaireJournalierMoyenInitial(djiAttributionPrecedente);
    constitutionSalaireJournalierMoyen.setMontantSalaireJournalierMoyenRevalorisePlafonne(sjmrp);
    constitutionSalaireJournalierMoyen.setDateSalaireJournalierMoyenRevalorisePlafonne(djiAttributionPrecedente);
    constitutionSalaireJournalierMoyen.setMontantPlafond(plafondSjmr);
    
    return resultat;
  }
}

/* Location:
 * Qualified Name:     ConstitutionSalaireReferenceEtSjm
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */