package fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.spec.FormuleICCPSpec;
import fr.unedic.cali.asu.dom.Sjr;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.BaseDelaiReportAbstrait;
import fr.unedic.cali.parametres.EvenementParametre;
import fr.unedic.cali.parametres.ParametresIndemnisation;
import fr.unedic.util.Mathematiques;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.QuantiteJour;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FormuleDiffereICCPMontant
  implements FormuleICCPSpec
{
  private static final BigDecimal ZERO = new BigDecimal(0);
  
  public Object appliquerFormule(BaseDelaiReportAbstrait baseFormule)
    throws CoucheLogiqueException
  {
    if (baseFormule == null) {
      throw new IllegalArgumentException("Impossible d'appliquer la formule du différé ICCP sans BaseDelaiReport.");
    }
    QuantiteEuro quantiteEuroIccp = baseFormule.getQuantiteEuroIccp();
    if (quantiteEuroIccp == null) {
      throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_MONTANT_FORMULE_ICCP", "Impossible d'appliquer la formule du différé ICCP sans montant ICCP.");
    }
    BigDecimal valeurMontant = quantiteEuroIccp.getValeurMontant();
    
    Sjr salaireJournalierReference = baseFormule.getSjrrp();
    if (salaireJournalierReference == null) {
      throw new PasAssezInformationException("ASU_SC_L_ES_ED_CDR08_ABSENCE_SJRRP_FORMULE_ICCP", "Impossible d'appliquer la formule du différé ICCP sans montant SJRRP.");
    }
    BigDecimal valeurSjrrp = salaireJournalierReference.getSalaire();
    if (valeurSjrrp.compareTo(ZERO) == 0) {
      fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererException("ASU_SC_L_ES_ED_CDR08_INCOHERENCE_SJRRP_ICCP", new Object[] { salaireJournalierReference.getDateDepart() }, 2);
    }
    BigDecimal resultatFormule = calculerMontantDiffereICCP(baseFormule, salaireJournalierReference, valeurSjrrp, valeurMontant);
    
    QuantiteJour quantiteJourCalculee = new QuantiteJour(Mathematiques.tronque(resultatFormule, 0).toString());
    if (baseFormule.getNombreCongesPris() > 0)
    {
      int nbJoursICCP = quantiteJourCalculee.getNombreJours();
      
      quantiteJourCalculee = new QuantiteJour(new BigDecimal("0").max(new BigDecimal(nbJoursICCP - baseFormule.getNombreCongesPris())));
    }
    return quantiteJourCalculee;
  }
  
  protected BigDecimal calculerMontantDiffereICCP(BaseDelaiReportAbstrait baseFormule, Sjr salaireJournalierReference, BigDecimal valeurSjrrp, BigDecimal valeurMontant)
  {
    BigDecimal resultatFormule;
    BigDecimal resultatFormule;
    if (baseFormule.estTopContratsRemuneresBaseSmic())
    {
      Damj dateDebutAnnee = new Damj(salaireJournalierReference.getDateDepart());
      BigDecimal valeurSmicJournalier = ParametresIndemnisation.getParametresIndemnisation().getElementActif(dateDebutAnnee).getSmicJournalierBase35h();
      BigDecimal resultatFormule;
      if ((valeurSmicJournalier != null) && (valeurSmicJournalier.compareTo(valeurSjrrp) > 0)) {
        resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSmicJournalier);
      } else {
        resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSjrrp);
      }
    }
    else
    {
      resultatFormule = Mathematiques.diviseParDefaut(valeurMontant, valeurSjrrp);
    }
    return resultatFormule;
  }
  
  public int recupererPlafondISLR(BaseDelaiReportAbstrait baseFormule)
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée");
  }
  
  public boolean estFormuleConservatoire()
  {
    return false;
  }
}

/* Location:
 * Qualified Name:     FormuleDiffereICCPMontant
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */