package fr.unedic.cali.asu.cge01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionCSR28Jours;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionsAttributionAdmission;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.Rejet;
import fr.unedic.cali.autresdoms.ga.dom.spec.TravailSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Periode;

public class DeterminationCondition28JoursSuspension
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final int NB_JOURS = 42;
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCondition28JoursSuspension = new Resultat(0);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    DomLiquidationAssurance.getDemande(p_contexte).getDemandeur();
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    DonneesTemporaires donneesTemporaires = demandeCourante.getDonneesTemporaires();
    
    boolean isLeveeCondition28JoursSuspension = donneesTemporaires.isLeveeCondition28JoursChomageTotalSansRupture();
    DossierExamenSpec dossierExamen = demandeCourante.getDossierAffectation().getDossierExamen();
    if (!dossierExamen.estType(Rejet.class)) {
      if (!isLeveeCondition28JoursSuspension)
      {
        ConditionCSR28Jours conditionCSR28Jours = dossierExamenCourant.getConditionsAttributionAdmission().createConditionCSR28Jours();
        conditionCSR28Jours.setEtatSatisfait(true);
        
        Periode periodeSuspension = OutilsChomageSansRCT.getPeriodeSuspension(demandeCourante).getPeriode();
        if (periodeSuspension.getDuree() < getNombreJoursSuspension())
        {
          resultatCondition28JoursSuspension = new Resultat(1);
          conditionCSR28Jours.setCodeMotifEchec(202);
          resultatCondition28JoursSuspension.setMessageErreur(Integer.toString(conditionCSR28Jours.getCodeMotifEchec()));
          conditionCSR28Jours.setEtatSatisfait(false);
        }
      }
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCondition28JoursSuspension;
  }
  
  private int getNombreJoursSuspension()
  {
    return 42;
  }
  
  public void controlerContexte(Contexte p_context)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_context) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition des 28 jours de suspension impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_context).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Le demandeur est null: determination condition des 28 jours de suspension impossible.");
    }
  }
}

/* Location:
 * Qualified Name:     DeterminationCondition28JoursSuspension
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */