package fr.unedic.cali.asu.cge01.liquidation.parcours.asp;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.DonneesDemandeAssociee;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.EreDemandeAssociee;
import fr.unedic.cali.asu.dom.FormulaireAsu;
import fr.unedic.cali.asu.outilsfonctionnels.OutilDemande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutilCreationDemande;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;

public class ParcoursLiquidationDemandeSousJacenteCSPDroitCommun
  extends ParcoursCali
{
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    OutilTrace.tracerDebutParcours();
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    Demande demandeAssociee = creerDemandeAssociee(demande);
    
    lancerLiquidation(demandeAssociee, p_contexte);
    
    OutilTrace.tracerFinParcours();
    return new Resultat();
  }
  
  private Demande creerDemandeAssociee(Demande demande)
    throws ApplicativeException
  {
    String typeDemande = "ASU_21";
    Damj dateDepot = demande.getDateDepot();
    IndividuSpec individu = demande.getDemandeur();
    
    Demande demandeAssociee = (Demande)OutilCreationDemande.creerDemande(typeDemande, dateDepot, individu, demande.getFormulaire().getIdPec(), null);
    
    demandeAssociee.setDemandeur(demande.getDemandeur());
    
    ((FormulaireAsu)demandeAssociee.getFormulaire()).setReferenceExterne(demande.getFormulaire().getReferenceExterne());
    
    traiterDonneesForcees(demande, demandeAssociee);
    
    ((EreDemandeAssociee)demandeAssociee.getEvenementReferenceExamen()).setContexteDemande("ASPSJACENT");
    demandeAssociee.getDonneesTemporaires().setTypeContexteDemandeDonneesTemporaires("ASPSJACENT");
    
    demande.createDonneesDemandeAssociee();
    
    demande.getDonneesDemandeAssociee().setDemandeAssociee(demandeAssociee);
    ((EreDemandeAssociee)demandeAssociee.getEvenementReferenceExamen()).setDemandeMere(demande);
    
    return demandeAssociee;
  }
  
  private void traiterDonneesForcees(Demande demandeAsp, DemandeAssuranceSpec demandeSousJacente)
  {
    OutilDemande.copieDonneesForcees(demandeAsp, demandeSousJacente);
    
    demandeSousJacente.getDonneesTemporaires().setDateLimiteIndemnisationDonneeForcee(null);
    
    demandeSousJacente.getDonneesTemporaires().setInopposabiliteDelaiDecheance(false);
    demandeSousJacente.getDonneesTemporaires().setSaisieCasExpatriesDonneesTemporaire(false);
    demandeSousJacente.getDonneesTemporaires().setSaisieCasGeneralDonneesTemporaire(false);
    demandeSousJacente.getDonneesTemporaires().setSaisieCasSpectacleDonneesTemporaire(false);
  }
  
  private void lancerLiquidation(Demande p_demande, Contexte p_contexte)
    throws ApplicativeException
  {
    IndividuSpec individu = p_demande.getDemandeur();
    
    DomLiquidationAssurance dom = new DomLiquidationAssurance();
    Contexte contexte = new Contexte();
    contexte.setDonnees(dom);
    
    dom.setDemande(p_demande);
    dom.setIndividu(individu);
    
    dom.setContexteService(((DomLiquidationAssurance)p_contexte.getDonnees()).getContexteService());
    
    ParcoursLiquidationDemandeAssuranceCSPDroitCommun parcours = new ParcoursLiquidationDemandeAssuranceCSPDroitCommun();
    
    p_demande.setDemandeLiquidee(true);
    parcours.demarrer(contexte);
    p_demande.setDemandeLiquidee(false);
  }
}

/* Location:
 * Qualified Name:     ParcoursLiquidationDemandeSousJacenteCSPDroitCommun
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */