package fr.unedic.cali.asu.cge01.p02.liquidation.dom;

import fr.unedic.cali.asu.cge01.p02.liquidation.dom.gen.SjripGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.SjripSpec;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class Sjrip
  extends SjripGen
  implements ObjetPersistantSpec, SjripSpec
{
  private static final long serialVersionUID = -4009712268382294976L;
  
  public Sjrip() {}
  
  public Sjrip(DomPCSpec p_pc)
  {
    super(p_pc);
  }
  
  public Sjrip(QuantiteEuro p_plafondSjr, QuantiteEuro p_sjrInitial)
  {
    super.setPlafondSjr(p_plafondSjr);
    super.setSjrInitial(p_sjrInitial);
  }
  
  public Sjrip(Damj p_dateEffet, QuantiteEuro p_plafondSjr, QuantiteEuro p_sjrInitial)
  {
    super(p_dateEffet);
    super.setPlafondSjr(p_plafondSjr);
    super.setSjrInitial(p_sjrInitial);
  }
  
  public BigDecimal getSjrip()
  {
    BigDecimal valeurSjrip = new BigDecimal("0");
    if ((getSjrInitial() != null) && (getPlafondSjr() != null)) {
      valeurSjrip = getSjrInitial().getValeur().min(getPlafondSjr().getValeur());
    } else if (getSjrInitial() != null) {
      valeurSjrip = getSjrInitial().getValeur();
    } else if (getPlafondSjr() != null) {
      valeurSjrip = getPlafondSjr().getValeur();
    }
    return valeurSjrip;
  }
  
  public void setPrc(Prc p_prc)
  {
    DomManager.supprimer(super.getPrc(), p_prc);
    super.setPrc(p_prc);
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    chaineRetour.append(super.toString() + "\n");
    chaineRetour.append("Prc : " + super.getPrc() + "\n");
    chaineRetour.append("Plafond Sjr : " + super.getPlafondSjr() + "\n");
    chaineRetour.append("Sjr Initial : " + super.getSjrInitial() + "\n");
    return chaineRetour.toString();
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete()
  {
    DomManager.supprimer(super.getPrc());
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getPrc());
  }
  
  public void jdoPreStore() {}
  
  public ObjetMetierSpec copie()
  {
    Sjrip copie = new Sjrip();
    copieElements(copie);
    return copie;
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Sjrip copie = (Sjrip)p_copie;
    
    copie.setDateEvenement(getDateEvenement());
    if (getPrc() != null) {
      copie.setPrc((Prc)getPrc().copie());
    }
    copie.setPlafondSjr(getPlafondSjr());
    copie.setSjrInitial(getSjrInitial());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public String getContexteParticulierSjr()
  {
    return null;
  }
}

/* Location:
 * Qualified Name:     Sjrip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */