package fr.unedic.cali.asu.cge01.p03.liquidation.dom;

import fr.unedic.cali.asu.cge01.p03.liquidation.dom.gen.SjripGen;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.SjripSpec;
import fr.unedic.cali.dom.ObjetPersistantSpec;
import fr.unedic.cali.dom.persistance.util.DomManager;
import fr.unedic.transverse.dom.spec.DomPCSpec;
import fr.unedic.util.ObjetMetierSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class Sjrip
  extends SjripGen
  implements ObjetPersistantSpec, SjripSpec
{
  private static final long serialVersionUID = -6686265340999358072L;
  
  public Sjrip(DomPCSpec p_cepAbstraitPC)
  {
    super(p_cepAbstraitPC);
  }
  
  private Sjrip()
  {
    if (getDateEvenement() == null) {
      setDateEvenement(new Damj());
    }
  }
  
  public Sjrip(Damj p_dateEffet, QuantiteEuro p_plafondSjr, QuantiteEuro p_sjrInitial, DomPCSpec p_cepAbstraitPC)
  {
    super(p_cepAbstraitPC);
    setDateEvenement(p_dateEffet);
    setPlafondSjr(p_plafondSjr);
    setSjrInitial(p_sjrInitial);
  }
  
  public BigDecimal getSjrip()
  {
    BigDecimal valeurSjrip = new BigDecimal("0");
    if ((getSjrInitial() != null) && (getPlafondSjr() != null)) {
      valeurSjrip = getSjrInitial().getValeur().min(getPlafondSjr().getValeur());
    } else if (getSjrInitial() != null) {
      valeurSjrip = getSjrInitial().getValeur();
    } else if (getPlafondSjr() != null) {
      valeurSjrip = getPlafondSjr().getValeur();
    }
    return valeurSjrip;
  }
  
  public String toString()
  {
    StringBuffer chaineRetour = new StringBuffer();
    chaineRetour.append(super.toString() + "\n");
    chaineRetour.append("Prc : " + getPrc() + "\n");
    chaineRetour.append("Plafond Sjr : " + getPlafondSjr() + "\n");
    chaineRetour.append("Sjr Initial : " + getSjrInitial() + "\n");
    return chaineRetour.toString();
  }
  
  public void marquerGraphePersistant()
  {
    DomManager.persisterEnProfondeur(super.getPrc());
  }
  
  public ObjetMetierSpec copie()
  {
    throw new UnsupportedOperationException("Cette méthode ne doit pas être appelée! Appeller le méthode copieElements(ObjetMetierSpec).");
  }
  
  public void copieElements(ObjetMetierSpec p_copie)
  {
    Sjrip copie = (Sjrip)p_copie;
    
    copie.setDateEvenement(getDateEvenement());
    if (getPrc() != null) {
      copie.setPrc((Prc)getPrc().copie());
    }
    copie.setPlafondSjr(getPlafondSjr());
    copie.setSjrInitial(getSjrInitial());
  }
  
  public String getIdentifiant()
  {
    return DomManager.getIdentifiant(this);
  }
  
  public void jdoPostLoad() {}
  
  public void jdoPreStore() {}
  
  public void jdoPreClear() {}
  
  public void jdoPreDelete() {}
  
  public String getContexteParticulierSjr()
  {
    return null;
  }
  
  public void setPrc(Prc prc)
  {
    DomManager.supprimer(super.getPrc(), prc);
    super.setPrc(prc);
  }
}

/* Location:
 * Qualified Name:     Sjrip
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */