package fr.unedic.cali.asu.cge01.p03.liquidation.parcours;

import fr.unedic.archi.util.trace.Log;
import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConditionsAttributionReprise;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionDateAttribution;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.ConstitutionElementsSpec;
import fr.unedic.cali.asu.cge01.p03.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.cge01.p03.liquidation.outilsfonctionnels.DeterminationDateOdTheorique;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Damj;

public class ConstitutionDateAttributionPourReprise
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "Une demande est obligatoire pour ce produit. : ConstitutionDateReprise impossible");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    if (Log.isTraceActive(ConstitutionDateAttributionPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDateAttributionPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDateAttributionPourReprise.class, "demarrer", "\t\t******** Début Parcours ConstitutionDateReprise ********");
    }
    Resultat resultatCepr14 = new Resultat(0);
    
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    DossierExamen dossierExamenCourant = (DossierExamen)demande.getDossierExamen();
    
    ConstitutionDateAttribution constitutionDate = dossierExamenCourant.getConstitutionElementsActifs().createConstitutionDateAttribution();
    if (verifierPreconditions(p_contexte))
    {
      Damj dateReprise = DeterminationDateOdTheorique.determinerDateAttributionTheoriquePourReprise(demande);
      
      constitutionDate.setDateAttribution(dateReprise);
    }
    if (Log.isTraceActive(ConstitutionDateAttributionPourReprise.class, Niveau.DEBUG))
    {
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDateAttributionPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDateAttributionPourReprise.class, "demarrer", "\t\t******** Résultat Parcours ConstitutionDateReprise ********\n" + resultatCepr14);
      
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDateAttributionPourReprise.class, "demarrer", "");
      Log.ecritTrace(Niveau.DEBUG, ConstitutionDateAttributionPourReprise.class, "demarrer", "\t\t******** Fin Parcours ConstitutionDateReprise ********\n");
    }
    return resultatCepr14;
  }
  
  protected boolean verifierPreconditions(Contexte p_contexte)
  {
    boolean preconditionsValides = true;
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierExamen dossierExamenCourant = (DossierExamen)demandeCourante.getDossierExamen();
    if ((dossierExamenCourant.getConditionsAttributionReprise() != null) && (dossierExamenCourant.getConditionsAttributionReprise().estSatisfait())) {
      preconditionsValides = true;
    } else {
      preconditionsValides = false;
    }
    return preconditionsValides;
  }
}

/* Location:
 * Qualified Name:     ConstitutionDateAttributionPourReprise
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */