package fr.unedic.cali.asu.cge01.revision.outilsfonctionnels.sjr;

import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodePensionInvaliditeChaineeSpec;
import fr.unedic.cali.autresdoms.cohab.dom.spec.PeriodeSousPensionInvaliditeChaineeSpec;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.Iterator;

public final class OutilDeterminationMontantPi
{
  private static final BigDecimal MONTANT_0 = new BigDecimal("0");
  
  public static BigDecimal determinerMontantPensionInvalidite(Damj pDateEtude, Collection<PeriodePensionInvaliditeChaineeSpec> pListePi)
  {
    BigDecimal montantPi = MONTANT_0;
    if (pListePi != null)
    {
      Iterator<PeriodePensionInvaliditeChaineeSpec> iterateur = pListePi.iterator();
      while (iterateur.hasNext())
      {
        PeriodePensionInvaliditeChaineeSpec pi = (PeriodePensionInvaliditeChaineeSpec)iterateur.next();
        if (pi.getStatut() == 1)
        {
          Collection<PeriodeSousPensionInvaliditeChaineeSpec> listeSousPension = pi.getListeSousPensionInvalidite();
          
          montantPi = montantPi.add(recupererMontantAjouter(listeSousPension, pDateEtude));
        }
      }
    }
    return montantPi;
  }
  
  private static BigDecimal recupererMontantAjouter(Collection<PeriodeSousPensionInvaliditeChaineeSpec> pListeSousPension, Damj pDateEtude)
  {
    BigDecimal montantPi = MONTANT_0;
    if ((pListeSousPension != null) && (pListeSousPension.size() != 0))
    {
      Iterator<PeriodeSousPensionInvaliditeChaineeSpec> iterSousPension = pListeSousPension.iterator();
      while (iterSousPension.hasNext())
      {
        PeriodeSousPensionInvaliditeChaineeSpec sousPensionInvalidite = (PeriodeSousPensionInvaliditeChaineeSpec)iterSousPension.next();
        if ((estSousPensionINV2ouINV3(sousPensionInvalidite)) && (estSousPensionContientDate(sousPensionInvalidite, pDateEtude))) {
          return sousPensionInvalidite.getMontant().getValeur();
        }
      }
    }
    return montantPi;
  }
  
  private static boolean estSousPensionContientDate(PeriodeSousPensionInvaliditeChaineeSpec pSousPensionInvalidite, Damj pDateEtude)
  {
    return pSousPensionInvalidite.getPeriode().contient(pDateEtude);
  }
  
  private static boolean estSousPensionINV2ouINV3(PeriodeSousPensionInvaliditeChaineeSpec pSousPensionInvalidite)
  {
    return (pSousPensionInvalidite.getCodeNature().equalsIgnoreCase("INV2")) || (pSousPensionInvalidite.getCodeNature().equalsIgnoreCase("INV3"));
  }
}

/* Location:
 * Qualified Name:     OutilDeterminationMontantPi
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */