package fr.unedic.cali.asu.csr04.p01.liquidation.parcours;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.outilsfonctionnels.OutilsChomageSansRCT;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.autresdoms.cohab.dom.ObjetChronoPeriodePriseEnChargeSansFiltre;
import fr.unedic.cali.dom.FormulaireSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.outilsfonctionnels.OutillagePEC;
import fr.unedic.cali.outilsfonctionnels.filtres.FiltreActiviteSalarieAvecChomageTotalSansRupture;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.Resultat;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.FiltreFinDansBornes;

public class ParcoursControleDonneesForcees
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {}
  
  public Resultat demarrer(Contexte p_contexte)
    throws ApplicativeException
  {
    Demande demande = DomLiquidationAssurance.getDemande(p_contexte);
    
    Chronologie chronoPeriodesParticipantes = demande.getDemandeur().getChronoPeriodePasseProfessionnelLiquidation();
    Damj dateRecherche = demande.getDonneesTemporaires().getDateChomageTotalSansRupture();
    if (dateRecherche != null)
    {
      Chronologie chronoChomageTotalSansRupture = chronoPeriodesParticipantes.copier(new FiltreActiviteSalarieAvecChomageTotalSansRupture());
      
      Chronologie chronoChomageTotalSansRuptureAuJourForce = chronoChomageTotalSansRupture.copier(new FiltreFinDansBornes(dateRecherche, dateRecherche));
      if (chronoChomageTotalSansRuptureAuJourForce.estVide()) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_DATE_CSR_NON_VALIDE");
      }
    }
    if (demande.getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture() != null)
    {
      Damj dateFinIndemnisationAuDela182Jours = demande.getDonneesTemporaires().getDateMaximumPoursuiteIndeminisationChomageTotalSansRupture();
      Damj dateFinSuspension = OutilsChomageSansRCT.getDateFinSuspension(demande);
      if ((dateFinSuspension != null) && (dateFinSuspension.estAvant(dateFinIndemnisationAuDela182Jours))) {
        fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CSR_DATE_MAX_NON_VALIDE");
      }
    }
    if (demande.getDonneesTemporaires().getNouvelleDateAttributionChomageTotalSansRupture() != null)
    {
      Damj nouvelleDateAttribution = demande.getDonneesTemporaires().getNouvelleDateAttributionChomageTotalSansRupture();
      ObjetChronoPeriodePriseEnChargeSansFiltre pec = OutillagePEC.getPeriodePEC(demande.getDemandeur(), demande.getFormulaire().getIdPec());
      if (pec != null)
      {
        Damj dateIDE = pec.getDateDebut();
        if (!dateIDE.equals(nouvelleDateAttribution)) {
          fr.unedic.cali.asu.outilsfonctionnels.GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_CSR_NOUVELLE_DATE_ATTRIBUTION");
        }
      }
    }
    return new Resultat(0);
  }
}

/* Location:
 * Qualified Name:     ParcoursControleDonneesForcees
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */