package fr.unedic.cali.asu.cva10.p02.liquidation.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.AttributionAssuranceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDateLimiteIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionPointDepartIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.util.Quantite;
import fr.unedic.util.UniteAffiliation;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;

public class DeterminationDureeEffective
  extends fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective
{
  public static fr.unedic.cali.asu.cge01.liquidation.outilsfonctionnels.DeterminationDureeEffective getInstance()
  {
    return new DeterminationDureeEffective();
  }
  
  public DureeIndemnisation determinerDureeEffective(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    DossierExamen dossierExamen = (DossierExamen)p_demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = super.determinerDureeEffective(p_demande);
    
    int dureeEffectiveDc = trouverDureeADateLimiteIndemnisation(dossierExamen);
    dureeIndemnisation.setDureeEffective(new Quantite(dureeEffectiveDc, UniteAffiliation.JOUR));
    return dureeIndemnisation;
  }
  
  public DureeIndemnisation determinerDureeEffectivePourReprise(Demande p_demande)
    throws PasAssezInformationException, CoucheLogiqueException, ApplicativeException
  {
    AttributionAssuranceSpec reprise = (AttributionAssuranceSpec)p_demande.getDossierExamen();
    DossierExamen ouvertureDeDroit = (DossierExamen)reprise.getOuvertureDroit();
    DossierExamen dossierExamenDemandeCourante = (DossierExamen)p_demande.getDossierExamen();
    DureeIndemnisation dureeIndemnisation = super.determinerDureeEffectivePourReprise(p_demande);
    
    int dureeEffectiveDc = trouverDureeADateLimiteIndemnisationReprise(ouvertureDeDroit, dossierExamenDemandeCourante);
    dureeIndemnisation.setDureeEffective(new Quantite(dureeEffectiveDc, UniteAffiliation.JOUR));
    return dureeIndemnisation;
  }
  
  private int trouverDureeADateLimiteIndemnisation(DossierExamen p_dossierExamen)
  {
    int dureeMaxIndemnisation = 0;
    if (p_dossierExamen.getConstitutionDateLimiteIndemnisation() != null)
    {
      Damj dateLimiteIndemnisation = p_dossierExamen.getConstitutionDateLimiteIndemnisation().getDateLimiteIndem();
      Damj dateDebutIndemnisation = p_dossierExamen.getConstitutionDateLimiteIndemnisation().getDateDebutIndem();
      dureeMaxIndemnisation = new Periode(dateDebutIndemnisation, dateLimiteIndemnisation).getDuree();
    }
    return dureeMaxIndemnisation;
  }
  
  private int trouverDureeADateLimiteIndemnisationReprise(DossierExamen p_dossierExamenOrigine, DossierExamen p_dossierExamen)
  {
    int dureeMaxIndemnisation = 0;
    if (p_dossierExamenOrigine.getConstitutionDateLimiteIndemnisation() != null)
    {
      Damj dateLimiteIndemnisation = p_dossierExamenOrigine.getConstitutionDateLimiteIndemnisation().getDateLimiteIndem();
      Damj dateDebutIndemnisation = p_dossierExamen.getConstitutionPointDepartIndemnisation().getPji();
      dureeMaxIndemnisation = new Periode(dateDebutIndemnisation, dateLimiteIndemnisation).getDuree();
    }
    return dureeMaxIndemnisation;
  }
}

/* Location:
 * Qualified Name:     DeterminationDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */