package fr.unedic.cali.asu.mnt.outilsfonctionnels;

import fr.unedic.archi.logique.exception.ApplicativeException;
import fr.unedic.cali.asu.dom.DemandeAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.asu.mnt.dom.Accord;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintien;
import fr.unedic.cali.asu.mnt.dom.DemandeMaintienSpec;
import fr.unedic.cali.asu.mnt.dom.DossierExamen;
import fr.unedic.cali.asu.mnt.dom.DureeDetectionMaintien;
import fr.unedic.cali.calcul.dom.CalendrierExecutionCalculPeriodique;
import fr.unedic.cali.calcul.dom.EvenementFinQuantiteDroit;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.outilsfonctionnels.AppelCalculParLiquidation;
import fr.unedic.cali.parcours.ResultatExecutionCalculSpec;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.Damj;
import java.util.Collection;
import java.util.Iterator;

public class OutilsMaintien
{
  public static Damj determinerDateConditionNombreJoursIndemnisesNecessaireMaintien(CalendrierExecutionCalculPeriodique p_calendrier)
  {
    Damj dateConditionNombreJoursIndemnisesNecessaireMaintien = null;
    if (p_calendrier.getChronologieUnitesTraitements() != null)
    {
      Iterator iterateurUT = p_calendrier.getChronologieUnitesTraitements().iterer();
      while ((iterateurUT.hasNext()) && (dateConditionNombreJoursIndemnisesNecessaireMaintien == null))
      {
        UniteTraitement ut = (UniteTraitement)iterateurUT.next();
        if (ut.getCollectionEvenementsFinQuantiteDroit() != null)
        {
          Iterator iterateurFinsDeDuree = ut.getCollectionEvenementsFinQuantiteDroit().iterator();
          while ((iterateurFinsDeDuree.hasNext()) && (dateConditionNombreJoursIndemnisesNecessaireMaintien == null))
          {
            EvenementFinQuantiteDroit evenementFinDuree = (EvenementFinQuantiteDroit)iterateurFinsDeDuree.next();
            if ((evenementFinDuree.getQuantiteDroit() instanceof DureeDetectionMaintien)) {
              dateConditionNombreJoursIndemnisesNecessaireMaintien = evenementFinDuree.getDateEffet();
            }
          }
        }
      }
    }
    return dateConditionNombreJoursIndemnisesNecessaireMaintien;
  }
  
  public static Damj determinerDatePrevisionnelleFinIndemnisation(Accord attribution)
    throws ApplicativeException
  {
    Damj datePrevisionnelleFinIndemnisation = null;
    
    ResultatExecutionCalculSpec resultat = AppelCalculParLiquidation.executerCalculDeterminationEtatDroit(((DemandeMaintienSpec)attribution.getDemande()).getAttributionAssurance(), Damj.FIN_DES_TEMPS, true);
    if (!resultat.isCalendrierNul()) {
      datePrevisionnelleFinIndemnisation = resultat.getDernierJourIndemnisable();
    }
    return datePrevisionnelleFinIndemnisation;
  }
  
  public static String determinerPeriodeFaitGenerateurACharger(DossierExamen p_dossierExamen)
  {
    if (p_dossierExamen == null) {
      return null;
    }
    DemandeMaintien demande = (DemandeMaintien)p_dossierExamen.getDemande();
    if (demande == null) {
      return null;
    }
    DemandeAssuranceSpec demandeMaintenue = demande.getDemandeMaintenue();
    if (demandeMaintenue == null) {
      return null;
    }
    FaitGenerateurSpec faitGenerateur = demande.getFGDDroitMaintenu();
    if (faitGenerateur == null) {
      return null;
    }
    if (faitGenerateur.getRefusAdhesionFne() == null) {
      return faitGenerateur.getIdentifiantPeriodeFaitGenerateur();
    }
    return null;
  }
}

/* Location:
 * Qualified Name:     OutilsMaintien
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */