package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DonneesTemporaires;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.ReglementApplicableSpec;
import fr.unedic.cali.dom.IndividuSpec;
import fr.unedic.cali.dom.affectation.Reglement;
import fr.unedic.cali.outilsfonctionnels.OutilRetraite;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.temps.Damj;

public class ConstitutionDuree
  implements OutilFonctionnel
{
  private static final int NOMBRE_DE_JOUR_PIVOT_POUR_DETERMINER_DUREE_EFFECTIVE = 30;
  
  public static int calculerDureeEffective(IndividuSpec p_individu, Damj p_pointDeDepart, Quantite p_qteTheorique, boolean p_bornerALaRetraite)
    throws CoucheLogiqueException
  {
    if (p_qteTheorique.getValeurEntiere() <= 0) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_ALERTE_A11MB15");
    }
    return OutilRetraite.getInstance().bornerDureeALaRetraite(p_individu, p_pointDeDepart, p_qteTheorique, p_bornerALaRetraite);
  }
  
  public static Quantite calculerDureeEffectivePourAdmission(IndividuSpec p_individu, Damj p_pointDeDepart, Quantite p_qteTheorique, Unite p_uniteDefaut, boolean p_bornerALaRetraite)
    throws CoucheLogiqueException
  {
    int qteEffective = 0;
    if (p_qteTheorique.getValeurEntiere() <= 30) {
      qteEffective = p_qteTheorique.getValeurEntiere();
    } else {
      qteEffective = Math.max(30, p_qteTheorique.getValeurEntiere());
    }
    int dureeEffective = calculerDureeEffective(p_individu, p_pointDeDepart, new Quantite(qteEffective, p_uniteDefaut), p_bornerALaRetraite);
    
    return new Quantite(dureeEffective, p_uniteDefaut);
  }
  
  public static Quantite calculerDureeEffectivePourReprise(IndividuSpec p_individu, Damj p_pointDeDepart, Quantite p_qteTheorique, Unite p_uniteDefaut, boolean p_bornerALaRetraite)
    throws CoucheLogiqueException
  {
    int dureeEffective = calculerDureeEffective(p_individu, p_pointDeDepart, new Quantite(p_qteTheorique.getValeurEntiere(), p_uniteDefaut), p_bornerALaRetraite);
    
    return new Quantite(dureeEffective, p_uniteDefaut);
  }
  
  public static Quantite calculerDureeEffective(IndividuSpec p_individu, Damj p_pointDeDepart, Quantite p_qteTheorique, Quantite p_qteImputation, Unite p_uniteDefaut, boolean p_bornerALaRetraite)
    throws CoucheLogiqueException
  {
    int qteEffective = p_qteTheorique.getValeurEntiere() - p_qteImputation.getValeurEntiere();
    
    int dureeEffective = calculerDureeEffective(p_individu, p_pointDeDepart, new Quantite(qteEffective, p_uniteDefaut), p_bornerALaRetraite);
    
    return new Quantite(dureeEffective, p_uniteDefaut);
  }
  
  public static boolean bornageALaRetraiteApplicablePourAdmission(Demande p_demande)
  {
    String nomReglement = ((DossierExamenAssuranceSpec)p_demande.getDossierExamen()).getReglementApplicable().getReglement().getNomReglement();
    
    boolean leverBornage = p_demande.getDonneesTemporaires().isLeverBornageDureeEffectiveRetraite();
    
    boolean estAnnexe9 = ("A9A".equals(nomReglement)) || ("A9B".equals(nomReglement));
    
    return (!leverBornage) || (estAnnexe9);
  }
  
  public static boolean bornageALaRetraiteApplicablePourReprise(Demande p_demande)
  {
    String nomReglement = ((DossierExamenAssuranceSpec)p_demande.getDossierExamen()).getReglementApplicable().getReglement().getNomReglement();
    
    boolean leverBornage = p_demande.getDemandeOrigine().getDonneesTemporaires().isLeverBornageDureeEffectiveRetraite();
    
    boolean estAnnexe9 = ("A9A".equals(nomReglement)) || ("A9B".equals(nomReglement));
    
    return (!leverBornage) || (estAnnexe9);
  }
}

/* Location:
 * Qualified Name:     ConstitutionDuree
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */