package fr.unedic.cali.asu.outilsfonctionnels;

import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.dom.DossierExamenAssuranceSpec;
import fr.unedic.cali.asu.dom.FaitGenerateurSpec;
import fr.unedic.cali.dom.DemandeSpec;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.DossierExamenSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.cali.dom.ReadmissionSpec;
import fr.unedic.cali.dom.RejetSpec;
import fr.unedic.cali.dom.RepriseSpec;
import fr.unedic.cali.dom.affectation.ValidationProduitSpec;
import fr.unedic.util.services.CoucheLogiqueException;

public class ControleAnnulerReexamen
{
  public static void verifierAnnulerReexamen(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    DossierExamenSpec dossierExamen = p_demande.getDossierAffectation().getDossierExamen();
    
    verifierIntegriteDecision(p_demande);
    if (!(dossierExamen instanceof RepriseSpec)) {
      verifierPresencePeriodeFCT(dossierExamen);
    }
    verifierPresencePeriodeFGD(dossierExamen);
  }
  
  private static void verifierIntegriteDecision(DemandeSpec p_demande)
    throws CoucheLogiqueException
  {
    Demande demandeAsu = (Demande)p_demande;
    DossierExamenSpec dossierExamen = demandeAsu.getDossierExamen();
    if (((dossierExamen instanceof RepriseSpec)) || (((dossierExamen instanceof ReadmissionSpec)) && ((((ReadmissionSpec)dossierExamen).getNatureDecision() == 11) || (((ReadmissionSpec)dossierExamen).getNatureDecision() == 26))))
    {
      Demande demandeOrigine = demandeAsu.getDemandeOrigine();
      if (demandeOrigine.getClassementAdministratif() != null) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("HG_PR_CALI_L_ANNULER_REEXAMEN_DECISION_PREC");
      }
    }
  }
  
  private static void verifierPresencePeriodeFCT(DossierExamenSpec p_dossierExamen)
    throws CoucheLogiqueException
  {
    ValidationProduitSpec validationProduit = ((DossierAffectation)p_dossierExamen.getDossierAffecte()).getValidationProduit();
    if ((validationProduit != null) && (validationProduit.isEstProduitValide()) && (!(p_dossierExamen instanceof RejetSpec)) && 
      (validationProduit.getPeriodeValidationProduit() == null)) {
      GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PERIODE_FCT_INEXISTANTE");
    }
  }
  
  private static void verifierPresencePeriodeFGD(DossierExamenSpec p_dossierExamen)
    throws CoucheLogiqueException
  {
    if (((p_dossierExamen instanceof OdSpec)) || ((p_dossierExamen instanceof ReadmissionSpec)))
    {
      DossierExamenAssuranceSpec dossierExamenAssurance = (DossierExamenAssuranceSpec)p_dossierExamen;
      if (dossierExamenAssurance.getFaitGenerateur().getPeriodeFaitGenerateur() == null) {
        GestionnaireErreur.getInstance().genererCoucheLogiqueException("ASU_PR_CALI_L_PERIODE_FGD_INEXISTANTE");
      }
    }
  }
}

/* Location:
 * Qualified Name:     ControleAnnulerReexamen
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */