package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux;

import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.CalculAffiliation;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilPeriodesAffiliation;
import fr.unedic.cali.dom.Entretien;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.temps.Chronologie;
import fr.unedic.util.temps.ChronologiePeriodes;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.Periode;
import fr.unedic.util.temps.Temporel;
import java.math.BigDecimal;
import java.util.ListIterator;

public final class OutilPeriodesAffiliation
{
  public static Entretien recupererInformationsEntretien(DonneesEntreeOutilPeriodesAffiliation donnees)
  {
    Entretien entretien = new Entretien();
    if (donnees != null)
    {
      entretien.setAExerceActiviteSalarie((donnees.getChronoPeriodesDeclarees() != null) && (!donnees.getChronoPeriodesDeclarees().estVide()));
      entretien.setASuiviFormation(donnees.isPresenceFormation());
      entretien.setDateFinContrat(recupererDernierDeclaree(donnees));
    }
    return entretien;
  }
  
  public static Damj recupererDernierDeclaree(DonneesEntreeOutilPeriodesAffiliation donnees)
  {
    Damj dernierDeclare = null;
    Chronologie periodesD12I = donnees.getChronoPeriodesDeclarees();
    if ((periodesD12I != null) && (!periodesD12I.estVide()))
    {
      ListIterator<Temporel> iterator = periodesD12I.iterer();
      while (iterator.hasNext())
      {
        Temporel periodeCourante = (Temporel)iterator.next();
        Damj dateFin = periodeCourante.getDateFin();
        if ((dateFin != null) && (!dateFin.coincideAvec(Damj.FIN_DES_TEMPS))) {
          if (dernierDeclare == null) {
            dernierDeclare = dateFin;
          } else {
            dernierDeclare = Damj.max(dateFin, dernierDeclare);
          }
        }
      }
    }
    return dernierDeclare;
  }
  
  public static void calculerAffiliationDeclaree(Entretien entretien, DonneesEntreeOutilPeriodesAffiliation donneesAffi)
  {
    int affiliationDeclaree = calculerAffiliationTotale(donneesAffi);
    entretien.setQuantiteAffiliation(new Quantite(BigDecimal.valueOf(affiliationDeclaree), Unite.getParCode("11")));
    if (donneesAffi.getPra() != null)
    {
      entretien.setDateDebutPra(donneesAffi.getPra().getDebut());
      entretien.setDateFinPra(donneesAffi.getPra().getFin());
    }
  }
  
  public static int calculerAffiliationTotale(DonneesEntreeOutilPeriodesAffiliation donnees)
  {
    int affiliationTotale = 0;
    if (donnees != null)
    {
      Chronologie chronologieGlobale = new ChronologiePeriodes();
      if (donnees.getChronoPeriodesGAEC() != null) {
        chronologieGlobale.ajouter(donnees.getChronoPeriodesGAEC());
      }
      if (donnees.getChronoPeriodesDeclarees() != null)
      {
        ListIterator<Temporel> it = donnees.getChronoPeriodesDeclarees().iterer();
        while (it.hasNext())
        {
          Temporel periode = (Temporel)it.next();
          if ((periode.getDateFin() != null) && (periode.getDateFin().estAvantOuCoincideAvec(donnees.getPra().getFin()))) {
            chronologieGlobale.ajouter(periode);
          }
        }
      }
      affiliationTotale = CalculAffiliation.calculerAffiliation(chronologieGlobale, donnees.getPra());
    }
    return affiliationTotale;
  }
}

/* Location:
 * Qualified Name:     OutilPeriodesAffiliation
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */