package fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux;

import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.Parametres;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesEntreeOutilRecherchePra;
import fr.unedic.cali.asu.outilsfonctionnels.liquidationsimplifiee.flux.conteneurs.DonneesSortieOutilRecherchePra;
import fr.unedic.cali.asu.produits.liquidation.dom.ParametreLiquidationSimplifiee;
import fr.unedic.cali.asu.produits.liquidation.parametres.CleAccesPRA;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;
import java.util.Iterator;
import java.util.List;

public final class OutilRecherchePra
{
  public static DonneesSortieOutilRecherchePra recupererPra(DonneesEntreeOutilRecherchePra donnees)
  {
    DonneesSortieOutilRecherchePra donnesSortie = new DonneesSortieOutilRecherchePra();
    ParametreLiquidationSimplifiee param = recupererParametre(donnees);
    donnesSortie.setAffiRequise(param.getNombreJoursQuantiteAffiliation());
    donnesSortie.setPra(calculerPra(param, donnees));
    
    return donnesSortie;
  }
  
  private static ParametreLiquidationSimplifiee recupererParametre(DonneesEntreeOutilRecherchePra donnees)
  {
    ParametreLiquidationSimplifiee param = null;
    
    CleAccesPRA cle = Parametres.construireCleAccesPRA(donnees.getAgeALaFct(), donnees.getDateFinPra());
    
    boolean reliquatValide = donnees.getEtatReliquat() == 3;
    
    List<ParametreLiquidationSimplifiee> listeParametre = Parametres.chargerParametres();
    
    Iterator<ParametreLiquidationSimplifiee> it = listeParametre.iterator();
    while (it.hasNext())
    {
      param = (ParametreLiquidationSimplifiee)it.next();
      if ((param.estApplicable(cle)) && (reliquatValide == param.isReliquatValide())) {
        break;
      }
    }
    if (reliquatValide)
    {
      Damj debut = donnees.getFgdAsuPrecedent().lendemain();
      if (donnees.getDvPrecedantRepriseIPR() != null) {
        debut = Damj.max(debut, donnees.getDvPrecedantRepriseIPR().lendemain());
      }
      param.setDateDebutPra(debut);
    }
    return param;
  }
  
  private static Periode calculerPra(ParametreLiquidationSimplifiee parametre, DonneesEntreeOutilRecherchePra donnees)
  {
    Damj dateDebutPra = null;
    Damj dateFinPra = donnees.getDateFinPra();
    int nombreMoisPra = parametre.getNombreMoisPRA();
    if (parametre.getDateDebutPra() != null)
    {
      dateDebutPra = parametre.getDateDebutPra();
    }
    else
    {
      dateDebutPra = dateFinPra.deplacerVersArriere(new DureeCalendaire(0, nombreMoisPra));
      if (donnees.getFgdAsuPrecedent() != null) {
        dateDebutPra = Damj.max(donnees.getFgdAsuPrecedent().lendemain(), dateDebutPra);
      }
    }
    return new Periode(dateDebutPra, dateFinPra);
  }
  
  public static Damj recupererDateFinPra(DonneesEntreeOutilRecherchePra donnees)
  {
    Damj dateFinPra = null;
    Damj derniereFctGAEC = donnees.getDerniereFctPeriodeGAEC();
    Damj dernierFgdAsu = donnees.getFgdAsuPrecedent();
    Damj dernierDeclare = donnees.getDernierDeclare();
    
    Damj derniereFct = null;
    if ((derniereFctGAEC != null) && (dernierDeclare != null)) {
      derniereFct = Damj.max(derniereFctGAEC, dernierDeclare);
    } else if (derniereFctGAEC == null) {
      derniereFct = dernierDeclare;
    } else {
      derniereFct = derniereFctGAEC;
    }
    boolean fgdAvantFct = (derniereFct != null) && (dernierFgdAsu != null) && (derniereFct.estApres(dernierFgdAsu));
    boolean pasDeFgd = (derniereFct != null) && (dernierFgdAsu == null);
    if ((fgdAvantFct) || (pasDeFgd)) {
      dateFinPra = derniereFct;
    } else {
      dateFinPra = donnees.getDateInscription().veille();
    }
    return dateFinPra;
  }
}

/* Location:
 * Qualified Name:     OutilRecherchePra
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */