package fr.unedic.cali.asu.produits.liquidation.parcours;

import fr.unedic.archi.util.trace.Niveau;
import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.MontantAsuSpec;
import fr.unedic.cali.asu.outilsfonctionnels.AppelCalculParLiquidationAsu;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.Attribution;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionDurees;
import fr.unedic.cali.asu.produits.liquidation.dom.ConstitutionMontantsBruts;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.dom.DureeIndemnisation;
import fr.unedic.cali.asu.produits.liquidation.dom.spec.ConstitutionElementsSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.cali.parcours.ResultatDetailleNotificationProduit;
import fr.unedic.util.Quantite;
import fr.unedic.util.QuantiteEuro;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class ConstitutionCapitalAvecDureeEffective
  extends ParcoursCali
  implements ParcoursAssurance
{
  private static final QuantiteEuro QUANTITE_ZERO = new QuantiteEuro("0");
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours(Niveau.DEBUG);
    
    ResultatDetailleNotificationProduit resultatMontantsBruts = new ResultatDetailleNotificationProduit();
    resultatMontantsBruts.setEtat(1);
    
    Attribution attributionCourante = (Attribution)getAttribution(p_contexte);
    
    alimenterResultatCep(attributionCourante);
    
    resultatMontantsBruts.setEtat(0);
    
    OutilTrace.tracerFinParcours();
    return resultatMontantsBruts;
  }
  
  private void alimenterResultatCep(Attribution p_attribution)
    throws CoucheLogiqueException
  {
    ConstitutionMontantsBruts resultatCep = p_attribution.getConstitutionElementsActifs().getConstitutionMontantsBruts();
    
    MontantAsuSpec montantAAttribution = p_attribution.getConstitutionMontantsBruts().getMontantAAttribution();
    
    Quantite nbJourIndemnises = p_attribution.getConstitutionElementsActifs().getConstitutionDurees().getDureeIndemnisation().getDureeEffective();
    
    Quantite capitalProduitCourant = AppelCalculParLiquidationAsu.calculerCapital(p_attribution, montantAAttribution, p_attribution.getDateAttribution(), nbJourIndemnises);
    
    resultatCep.setCapitalInitialBrut(getQuantiteEuro(capitalProduitCourant));
  }
  
  private AttributionSpec getAttribution(Contexte p_contexte)
  {
    return DomLiquidationAssurance.getDemande(p_contexte).getAttribution();
  }
  
  private static QuantiteEuro getQuantiteEuro(Quantite p_quantite)
  {
    if (p_quantite != null) {
      return new QuantiteEuro(p_quantite.getValeur());
    }
    return QUANTITE_ZERO;
  }
}

/* Location:
 * Qualified Name:     ConstitutionCapitalAvecDureeEffective
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */