package fr.unedic.cali.asu.produits.liquidation.parcours;

import fr.unedic.cali.asu.ParcoursAssurance;
import fr.unedic.cali.asu.dom.CompetenceSpec;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.DossierAffectation;
import fr.unedic.cali.asu.parcours.DomLiquidationAssurance;
import fr.unedic.cali.asu.produits.liquidation.dom.ConditionDureeNonNulle;
import fr.unedic.cali.asu.produits.liquidation.dom.DossierExamen;
import fr.unedic.cali.asu.produits.liquidation.outilsfonctionnels.RechercheConditionDureeNonNulle;
import fr.unedic.cali.dom.ResultatElementDroit;
import fr.unedic.cali.outilsfonctionnels.OutilTrace;
import fr.unedic.cali.parcours.ParcoursCali;
import fr.unedic.util.services.Contexte;
import fr.unedic.util.services.ContexteException;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.services.Resultat;

public class DeterminationConditionDureeNonNulle
  extends ParcoursCali
  implements ParcoursAssurance
{
  public void controlerContexte(Contexte p_contexte)
    throws ContexteException
  {
    if (DomLiquidationAssurance.getDemande(p_contexte) == null) {
      throw new ContexteException("HG_PR_CALI_L_CONTEXTE_ABSENCE_DEMANDE_ASSURANCE", "La demande d'assurance courante est null: determination condition Cumul Prestation familiale impossible.");
    }
    if (DomLiquidationAssurance.getDemande(p_contexte).getDemandeur() == null) {
      throw new ContexteException("HG_PR_CALI_L_ERR_CTX_ABS_DEMANDEUR", "Le demandeur est null: determination condition Cumul Prestation familiale impossible.");
    }
  }
  
  public Resultat demarrer(Contexte p_contexte)
    throws CoucheLogiqueException
  {
    OutilTrace.tracerDebutParcours();
    
    Resultat resultatCapaSuppl = new Resultat(1);
    
    Demande demandeCourante = DomLiquidationAssurance.getDemande(p_contexte);
    
    DossierAffectation dossierAffectation = (DossierAffectation)demandeCourante.getDossierAffectation();
    DossierExamen dossierExamen = (DossierExamen)dossierAffectation.getDossierExamen();
    ConditionDureeNonNulle conditionDureeNonNulle = dossierExamen.createConditionDureeNonNulle();
    ResultatElementDroit resultatElementDroit = RechercheConditionDureeNonNulle.getInstance().rechercherConditionDureeNonNulle(demandeCourante);
    
    conditionDureeNonNulle.setEtat(resultatElementDroit.getEtat());
    conditionDureeNonNulle.setCodeMotifEchec(resultatElementDroit.getCodeMotifEchec());
    if (conditionDureeNonNulle.estSatisfait())
    {
      resultatCapaSuppl.setEtat(0);
    }
    else
    {
      resultatCapaSuppl.setEtat(1);
      resultatCapaSuppl.setMessageErreur(Integer.toString(conditionDureeNonNulle.getCodeMotifEchec()));
      
      dossierExamen.getCompetence().setCompetenceFinanciere(1);
      dossierExamen.getCompetence().setCompetenceAdministrative(1);
    }
    OutilTrace.tracerFinParcours();
    
    return resultatCapaSuppl;
  }
}

/* Location:
 * Qualified Name:     DeterminationConditionDureeNonNulle
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */