package fr.unedic.cali.asu.spe02.p03.liquidation.outilsfonctionnels;

import fr.unedic.cali.asu.dom.DelaiRechercheProduit;
import fr.unedic.cali.asu.dom.Demande;
import fr.unedic.cali.asu.dom.EreFinDroitSuiteRepriseNonSaisonniere;
import fr.unedic.cali.dom.DossierAffectationSpec;
import fr.unedic.cali.dom.EvenementReferenceExamenSpec;
import fr.unedic.cali.dom.OdSpec;
import fr.unedic.util.services.OutilFonctionnel;
import fr.unedic.util.services.PasAssezInformationException;
import fr.unedic.util.temps.CalculDelais;
import fr.unedic.util.temps.Damj;
import fr.unedic.util.temps.DureeCalendaire;
import fr.unedic.util.temps.Periode;

public class DelaiRechercheSinistres
  implements OutilFonctionnel
{
  public static DelaiRechercheProduit determinerDelaiRechercheSinistre(DossierAffectationSpec p_dossierAffectation, DureeCalendaire p_delaiAllongement)
    throws PasAssezInformationException
  {
    int douzeMois = 12;
    
    DelaiRechercheProduit delaiRetourne = null;
    
    Demande demande = (Demande)p_dossierAffectation.getDemande();
    
    Damj termeDelai = demande.getDateExamen().veille();
    if (((demande.getEvenementReferenceExamen() instanceof EreFinDroitSuiteRepriseNonSaisonniere)) || (demande.getEvenementReferenceExamen().getTypeExamen().equals("ASU_08")))
    {
      OdSpec odPrecedente = demande.rechercherOuvertureDroitPrecedenteDuMemeType();
      delaiRetourne = new DelaiRechercheProduit(odPrecedente.getDateAttribution(), termeDelai);
    }
    else
    {
      Periode delai = CalculDelais.determinerDelaiCalendaire(termeDelai, new DureeCalendaire(0, 12));
      delaiRetourne = new DelaiRechercheProduit(delai.getDebut(), delai.getFin());
    }
    if (p_delaiAllongement != null) {
      delaiRetourne = allongerDelaiRechercheSinistre(delaiRetourne, p_delaiAllongement);
    }
    Damj dateFgOdPrecedente = demande.getDateFaitGenerateurOdPrecedente();
    if ((dateFgOdPrecedente != null) && 
      (delaiRetourne.getDebut().estAvantOuCoincideAvec(dateFgOdPrecedente))) {
      delaiRetourne.setDebut(dateFgOdPrecedente.lendemain());
    }
    return delaiRetourne;
  }
  
  public static DelaiRechercheProduit allongerDelaiRechercheSinistre(DelaiRechercheProduit p_delaiRecherche, DureeCalendaire p_delaiAllongement)
    throws PasAssezInformationException
  {
    Damj dateDebut = p_delaiRecherche.getDebut().deplacerVersArriere(p_delaiAllongement);
    
    DelaiRechercheProduit delaiRetourne = new DelaiRechercheProduit(dateDebut, p_delaiRecherche.getFin());
    
    return delaiRetourne;
  }
}

/* Location:
 * Qualified Name:     DelaiRechercheSinistres
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */