package fr.unedic.cali.asu.ssp07.p04.calcul;

import fr.unedic.cali.calcul.dom.ConstituantsIndemnisation;
import fr.unedic.cali.calcul.dom.SyntheseARsurUT;
import fr.unedic.cali.calcul.dom.UniteTraitement;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.ContexteUT;
import fr.unedic.cali.calcul.outilsfonctionnels.dom.PeriodeAnalyseSpec;
import fr.unedic.cali.dom.AttributionSpec;
import fr.unedic.cali.dom.MontantBaseSpec;
import fr.unedic.cali.parametres.EvenementParametre;
import fr.unedic.cali.parametres.ParametresIndemnisation;
import fr.unedic.util.Quantite;
import fr.unedic.util.Unite;
import fr.unedic.util.services.CoucheLogiqueException;
import fr.unedic.util.temps.Damj;
import java.math.BigDecimal;

public class FacadeCalculProduitImpl
  extends fr.unedic.cali.asu.ssp07.p03.calcul.FacadeCalculProduitImpl
{
  public void cumulerMontantGlobalServiAttribution(ConstituantsIndemnisation p_constituantsIndemnisation, Quantite p_nbJoursImputes, MontantBaseSpec p_montant, AttributionSpec p_attribution)
  {
    BigDecimal montant = p_nbJoursImputes.getValeur().multiply(p_montant.getMontantBrut().getValeur());
    BigDecimal montantServi = BigDecimal.ZERO;
    if (p_constituantsIndemnisation.getMontantServi() != null) {
      montantServi = p_constituantsIndemnisation.getMontantServi().getValeur();
    }
    p_constituantsIndemnisation.setMontantServi(new Quantite(montantServi.add(montant), Unite.getParCode("22")));
  }
  
  public BigDecimal determinerMontantRestantAvantPlafond(AttributionSpec p_attribution, UniteTraitement p_ut, ContexteUT p_contexteUT, ConstituantsIndemnisation p_constituantsIndemnisation, MontantBaseSpec p_montant, PeriodeAnalyseSpec p_pa)
    throws CoucheLogiqueException
  {
    BigDecimal plafondMensuel = recupererPlafondGlobal(p_attribution, p_ut.getDateDebut());
    if (p_ut.getSyntheseARsurUT().getTotalGainUtilisePourDecalage() != null) {
      plafondMensuel = plafondMensuel.subtract(p_ut.getSyntheseARsurUT().getTotalGainUtilisePourDecalage().getValeur());
    }
    BigDecimal montantAvantPlafond = determinerCumulServi(p_constituantsIndemnisation);
    BigDecimal montantRestantAvantPlafond = BigDecimal.valueOf(0L).max(plafondMensuel.subtract(montantAvantPlafond));
    
    return montantRestantAvantPlafond;
  }
  
  public BigDecimal recupererPlafondGlobal(AttributionSpec p_attribution, Damj p_dateDebut)
  {
    ParametresIndemnisation paramHG = ParametresIndemnisation.getParametresIndemnisation();
    
    EvenementParametre evtParamHG = paramHG.getElementActif(p_dateDebut);
    
    BigDecimal plafond = evtParamHG.getPlafondMensuelSecuriteSociale().multiply(new BigDecimal("1.40"));
    return plafond;
  }
  
  public static BigDecimal determinerCumulServi(ConstituantsIndemnisation p_constituantsIndemnisation)
    throws CoucheLogiqueException
  {
    BigDecimal montantAvantPlafond = BigDecimal.ZERO;
    if (p_constituantsIndemnisation.getMontantServi() != null) {
      montantAvantPlafond = montantAvantPlafond.add(p_constituantsIndemnisation.getMontantServi().getValeur());
    }
    return montantAvantPlafond;
  }
  
  public void majCumulServiQuantitePlafonne(ConstituantsIndemnisation p_constituantsIndemnisation, UniteTraitement p_ut)
  {
    if (p_constituantsIndemnisation != null) {
      p_constituantsIndemnisation.setMontantServi(null);
    }
  }
}

/* Location:
 * Qualified Name:     FacadeCalculProduitImpl
 * Java Class Version: 6 (50.0)
 * JD-Core Version:    0.7.1
 */